﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;
using System.Net.Sockets;
using System.IO;
using System.IO.Pipes;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using MySql.Data.MySqlClient;

namespace mDownloaderService
{
	public partial class mDownloaderService : ServiceBase
	{
		/// <summary>
		/// Saver thread, saves downloaded documents
		/// </summary>
		/// <param name="threadParam"></param>
		private void threadSave(object threadParam)
		{
			activeSaves++;
			string threadSignature = "SaveThread";
			try
			{
				using (DownloadDatabase dbInterface = new DownloadDatabase(cfgDbConnectionString, Encoding.GetEncoding(cfgDbTextEncoding)))
				{
					thparamSave param = (thparamSave)threadParam;
					threadSignature = string.Format("{0} {1} SaveThread({2}): ", DateTime.Now.ToShortDateString(), DateTime.Now.ToShortTimeString(), param.instanceNumber.ToString());

					while (!stopService.WaitOne(threadYieldTime))
					{
						SaveRequest request = dequeueSaveRequest();
						if (null == request)
						{
							continue;
						}

						int affectedRows = dbInterface.SaveRequestResponse(request.request, request.response);
					}
				}
			}
			catch (Exception e)
			{
				eventLog.WriteEntry(threadSignature + "Exception: " + e.Message + Environment.NewLine + e.StackTrace, EventLogEntryType.Error);
			}
			finally
			{
				activeSaves--;
			}
		}

		/// <summary>
		/// Class of parameters passsed to threadSave threads
		/// </summary>
		protected class thparamSave
		{
			private static int _staticInstanceNumber = 0;
			private int _instanceNumber;

			public int instanceNumber
			{
				get
				{
					return _instanceNumber;
				}
			}

			public thparamSave()
			{
				lock (lockThparamSave)
				{
					_instanceNumber = _staticInstanceNumber++;
				}
			}
		}
		private static object lockThparamSave = new object();

		private object lockSaveQueue = new object();
		private volatile Queue<SaveRequest> saveQueue = new Queue<SaveRequest>();
		protected void enqueueSaveRequest(SaveRequest request)
		{
			lock (lockSaveQueue)
			{
				saveQueue.Enqueue(request);
			}
		}
		protected SaveRequest dequeueSaveRequest()
		{
			if (saveQueue.Count > 0)
			{
				lock (lockSaveQueue)
				{
					if (saveQueue.Count > 0)
					{
						return saveQueue.Dequeue();
					}
				}
			}
			return null;
		}
		public int saveQueueLength
		{
			get
			{
				lock (lockSaveQueue)
				{
					return saveQueue.Count();
				}
			}
		}

		private volatile int _activeSaves = 0;
		private object lockActiveSaves = new object();
		/// <summary>
		/// Counter indicating how many documents are currently being saved (how many threadSave in the ThreadPool)
		/// </summary>
		public int activeSaves
		{
			get
			{
				lock (lockActiveSaves)
				{
					return _activeSaves;
				}
			}
			set
			{
				lock (lockActiveSaves)
				{
					_activeSaves = value;
				}
			}
		}
		private volatile int _initiatedSaves = 0;
		private object lockInitiatedSaves = new object();
		/// <summary>
		/// Counter indicating the total number of downloaded documents that have been sent for saving
		/// </summary>
		public int initiatedSaves
		{
			get
			{
				lock (lockInitiatedSaves)
				{
					return _initiatedSaves;
				}
			}
			set
			{
				lock (lockInitiatedSaves)
				{
					_initiatedSaves = value;
				}
			}
		}
	}
}