﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.Text;

using System.IO;
using System.Net;
using System.Net.Sockets;
using System.Web.Services;
using System.Web.Services.Protocols;
using System.Xml;
using System.Xml.Serialization;

namespace mDownloaderWebService
{
	// NOTE: If you change the class name "mDownloaderWebService" here, you must also update the reference to "mDownloaderWebService" in Web.config and in the associated .svc file.
	public class mDownloaderWebService : ImDownloaderWebService
	{
		/// <summary>
		/// Create a HTTP GET download request
		/// </summary>
		/// <param name="url">Url of the document</param>
		/// <param name="intranet">True if the Url is on the intranet, false if it is on the internet</param>
		/// <returns>The Id of the request</returns>
		public int SendGetRequest(string url, bool intranet)
		{
			DownloadRequest request = new DownloadRequest();
			request.Intranet = intranet;
			request.Url = url;
			request.Method = HttpMethod.Get;
			request.PostData = String.Empty;
			return int.Parse(SendRequests( new DownloadRequest[] { request } ));
		}
		/// <summary>
		/// Create a HTTP POST download request
		/// </summary>
		/// <param name="url">Url of the document</param>
		/// <param name="postData">Data to post with the http request</param>
		/// <param name="intranet">True if the Url is on the intranet, false if it is on the internet</param>
		/// <returns>The Id of the request</returns>
		public int SendPostRequest(string url, string postData, bool intranet)
		{
			DownloadRequest request = new DownloadRequest();
			request.Intranet = intranet;
			request.Url = url;
			request.Method = HttpMethod.Post;
			request.PostData = postData;
			return int.Parse(SendRequests(new DownloadRequest[] { request }));
		}
		
		/// <summary>
		/// Start processing an existing download request for multiple documents
		/// </summary>
		/// <param name="requestId">The Id of the request</param>
		/// <returns>The Id of the request</returns>
		public int ProcessExistingMultipleRequest( int requestId )
		{
			return int.Parse(SendPacket(new string[] { "multi", requestId.ToString() }));
		}

		/// <summary>
		/// Create a download request for multiple documents at once
		/// </summary>
		/// <param name="requests">Definition of the downlaod requests</param>
		/// <returns>The Id of the request</returns>
		public int SendMultipleRequests(DownloadRequest[] requests)
		{
			return int.Parse(SendRequests(requests));
		}

		/// <summary>
		/// Returns the number of pending responses for a given download request
		/// </summary>
		/// <param name="requestId">Id of the request</param>
		/// <returns>Number of pending (processing) requests</returns>
		public int PendingResponses(int requestId)
		{
			return int.Parse(SendPacket(new string[] { "pending", requestId.ToString() }));
		}

		/// <summary>
		/// Reset responses of an existing request
		/// </summary>
		/// <param name="requestId">Id of the request</param>
		public int ResetRequest(int requestId)
		{
			return int.Parse(SendPacket(new string[] { "reset", requestId.ToString() }));
		}

		/// <summary>
		/// Delete a request and its responses
		/// </summary>
		/// <param name="requestId">Id of the request</param>
		public int DeleteRequest(int requestId)
		{
			return int.Parse(SendPacket(new string[] { "delete", requestId.ToString() }));
		}

		/// <summary>
		/// Returns the all the documents corresponding to a specific RequestId
		/// </summary>
		/// <param name="requestId">Id of the requests</param>
		/// <returns>XML Serialized data</returns>
		public string GetResults(int requestId)
		{
			return SendPacket(new string[] { "result", requestId.ToString() });
		}
		/// <summary>
		/// Returns the all the documents corresponding to a specific RequestId
		/// </summary>
		/// <param name="requestId">Id of the requests</param>
		/// <param name="urlIds">List of UrlId to fetch (others will be ignored)</param>
		/// <returns>XML Serialized data</returns>
		public string GetResultsFiltered(int requestId, int[] urlIds)
		{
			List<string> words = new List<string>();
			words.Add("result");
			words.Add(requestId.ToString());
			foreach (int urlId in urlIds)
			{
				words.Add(urlId.ToString());
			}
			return SendPacket(words.ToArray());
		}

		/// <summary>
		/// Build request packet and send it to the service
		/// </summary>
		/// <param name="requests">List of requests to send</param>
		/// <returns>The response from the server</returns>
		private string SendRequests(DownloadRequest[] requests)
		{
			if (1 == requests.Length)
			{
				if (requests[0].Method == HttpMethod.Post)
				{
					return SendPacket(new string[] { "post", requests[0].Url, requests[0].PostData, requests[0].Intranet ? "no-proxy" : "with-proxy" });
				}
				else
				{
					return SendPacket(new string[] { "get", requests[0].Url, requests[0].Intranet ? "no-proxy" : "proxy" });
				}
			}
			else
			{
				List<string> words = new List<string>();
				words.Add("makemulti");
				foreach (DownloadRequest request in requests)
				{
					words.Add(request.Method == HttpMethod.Post ? "post" : "get");
					words.Add(request.Url);
					words.Add(request.Method == HttpMethod.Post ? request.PostData : string.Empty );
					words.Add(request.Intranet ? "no-proxy" : "proxy");
				}
				return SendPacket(words.ToArray());
			}
			
		}

		/// <summary>
		/// Send packet to the service via the network
		/// </summary>
		/// <param name="words">List of "words" to transmit</param>
		/// <returns>The response of the server</returns>
		private string SendPacket(string[] words)
		{
			TcpClient client = new TcpClient();
			string response = "0";
			try
			{
				client.Connect(new IPEndPoint(IPAddress.Parse("127.0.0.1"), 1234));
				using (NetworkStream stream = client.GetStream())
				{
					string packet = string.Empty;
					foreach (string word in words)
					{
						if (0 != packet.Length)
						{
							packet += " ";
						}
						packet += word;
					}

					byte[] data = Encoding.UTF8.GetBytes(packet);
					stream.Write(data, 0, data.Length);

					System.IO.MemoryStream ms = new System.IO.MemoryStream();
					int read_buffer_size = 4096;
					byte[] read_buffer = new byte[read_buffer_size];
					do
					{
						int bytes_read = stream.Read(read_buffer, 0, read_buffer.Length);
						ms.Write(read_buffer, 0, bytes_read);
					} while (stream.DataAvailable);
					response = Encoding.UTF8.GetString(ms.ToArray());
				}
			}
			catch (Exception e)
			{
				// http://msdn.microsoft.com/en-us/library/ds492xtk(VS.71).aspx
				throw new SoapException("An error has occured", SoapException.ClientFaultCode, e);
			}
			finally
			{
				client.Close();
			}
			return response;
		}
	}
}
