/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

// Libcurl requires additional libraries (see below), and requires CURL_STATICLIB to be defined on Windows
//#define CURL_STATICLIB 
#include <curl/curl.h>
//#pragma comment( lib, "libcurl.lib" )
//#pragma comment( lib, "ws2_32.lib" )
//#pragma comment( lib, "winmm.lib" )
//#pragma comment( lib, "wldap32.lib" )

#include "udf.h"
#include "udf_http.h"
#include "win32.h"

/**
 * urlEncode( string STR )
 */
my_bool urlEncode_init(UDF_INIT *initid, UDF_ARGS *args, char *message){
	int stError = MYSQL_ERRMSG_SIZE;
	char szError[MYSQL_ERRMSG_SIZE];
	memset( (void *) szError, 0, MYSQL_ERRMSG_SIZE );

	// Check arguments
	if( 1 != args->arg_count ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:Init: Wrong arguments count for tcpSend(string STR): one arguments expected.", szError );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[0] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:Init: Wrong arguments count for tcpSend(string STR): string expected for argument 1", szError );
		return RC_INIT_ERROR;
	}
	// Allocate memory for output
	initid->max_length = (size_t)(args->lengths[0] * 3);
	initid->ptr = (char *)malloc((size_t)initid->max_length + 1);
	if( 0 == initid->ptr ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:init: alloc(%d b): %s", initid->max_length, szError );	// ATTENTION, NOT THREAD SAFE (because of errno)
		return RC_INIT_ERROR;
	}
	memset( initid->ptr, 0, (size_t)initid->max_length + 1 );

	// Set information about the return type
	initid->maybe_null = 0;

	// Return
	return RC_INIT_SUCCESS;
}
void urlEncode_deinit(UDF_INIT *initid){
	// Free allocated memory
	if( 0 != initid->ptr ) {
		free( (void *)initid->ptr );
	}
}

char * urlEncode(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *null_value, char *error ) {
/*	initid->ptr = strUrlEncode( initid->ptr, initid->max_length + 1, args->args[0], length );
	*null_value = 0;
	*error = 0;
	return initid->ptr;
*/	char * pstr = args->args[0];
	char * pbuf = initid->ptr;
	*length = 0;
	while (*pstr) {
		if (isalnum(*pstr) || *pstr == '-' || *pstr == '_' || *pstr == '.' || *pstr == '~') {
			*pbuf++ = *pstr;
			(*length)++;
		} else 
		if (*pstr == ' ') {
			//*pbuf++ = '+';
			//(*length)++;
			*pbuf++ = '%';
			*pbuf++ = '2';
			*pbuf++ = '0';
			(*length)+=3;
		} else {
			*pbuf++ = '%';
			*pbuf++ = to_hex(*pstr >> 4);
			*pbuf++ = to_hex(*pstr & 15);
			(*length)+=3;
		}
		pstr++;
	}
	*pbuf = '\0';

	*null_value = 0;
	*error = 0;
	return initid->ptr;
/**/
}

/**
 * urlDecode( string STR )
 */
my_bool urlDecode_init(UDF_INIT *initid, UDF_ARGS *args, char *message){
	int stError = MYSQL_ERRMSG_SIZE;
	char szError[MYSQL_ERRMSG_SIZE];
	memset( (void *) szError, 0, MYSQL_ERRMSG_SIZE );

	// Check arguments
	if( 1 != args->arg_count ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:Init: Wrong arguments count for tcpSend(string STR): one arguments expected.", szError );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[0] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:Init: Wrong arguments count for tcpSend(string STR): string expected for argument 1", szError );
		return RC_INIT_ERROR;
	}
	// Allocate memory for output
	initid->max_length = args->lengths[0];
	initid->ptr = (char *)malloc((size_t)initid->max_length + 1);
	if( 0 == initid->ptr ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "urlEncode:init: alloc(%d b): %s", initid->max_length, szError );	// ATTENTION, NOT THREAD SAFE (because of errno)
		return RC_INIT_ERROR;
	}
	memset( initid->ptr, 0, (size_t)initid->max_length + 1 );

	// Set information about the return type
	initid->maybe_null = 0;

	// Return
	return RC_INIT_SUCCESS;
}
void urlDecode_deinit(UDF_INIT *initid){
	// Free allocated memory
	if( 0 != initid->ptr ) {
		free( (void *)initid->ptr );
	}
}

char * urlDecode(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *null_value, char *error ) {
/*	initid->ptr = strUrlDecode( initid->ptr, initid->max_length + 1, args->args[0], length );
	*null_value = 0;
	*error = 0;
	return initid->ptr;
*/	char * pstr = args->args[0];
	char * pbuf = initid->ptr;
	*length = 0;
	
	while (*pstr) {
		if (*pstr == '%') {
			if (pstr[1] && pstr[2]) {
				if( pstr[1] == '2' && pstr[2] == '0' ) {
					*pbuf++ = ' ';
				} else {
					*pbuf++ = from_hex(pstr[1]) << 4 | from_hex(pstr[2]);
				}
				pstr += 2;
			}
		} else if (*pstr == '+') { 
			*pbuf++ = ' ';
		} else {
			*pbuf++ = *pstr;
		}
		(*length)++;
		pstr++;
	}
	*pbuf = '\0';

	*null_value = 0;
	*error = 0;
	return initid->ptr;
/**/
}


/* Converts a hex character to its integer value */
char from_hex(char ch) {
	return isdigit(ch) ? ch - '0' : tolower(ch) - 'a' + 10;
}

/* Converts an integer value to its hex character*/
char to_hex(char code) {
	static char hex[] = "0123456789abcdef";
	return hex[code & 15];
}



size_t curlReceiveCallback( void * pData, size_t cbSize, size_t cbNMemb, void * pArg ) {
	struct sizedBuffer * pBuffer = (struct sizedBuffer *)pArg;
	if( 0 == pBuffer->pData ) {
		pBuffer->cbData = max( 4096, cbSize * cbNMemb );
		pBuffer->pData = malloc( pBuffer->cbData );
		pBuffer->cbLength = 0;
		if( 0 == pBuffer->pData ) {
			return 0;
		}
	} else 
	if( pBuffer->cbLength + (cbSize * cbNMemb) > pBuffer->cbData ){
		pBuffer->cbData += max( 4096, cbSize * cbNMemb );
		pBuffer->pData = realloc( pBuffer->pData, pBuffer->cbData );
		if( 0 == pBuffer->pData ) {
			return 0;
		}
	}
	memcpy_s( (void *)((char *)pBuffer->pData + pBuffer->cbLength), pBuffer->cbData - pBuffer->cbLength, pData, cbSize * cbNMemb );
	pBuffer->cbLength += ( cbSize * cbNMemb );
	return cbSize * cbNMemb;
}

