﻿/*
 * © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous 
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Configuration;
using System.Xml;
using System.Web;
using System.Text.RegularExpressions;
using MetaNull.Configuration;

namespace mFileMonitorService
{
	/// <summary>
	/// Object holding data about an Input folder
	/// </summary>
	public class Input : ConfigurationElement
	{
		/// <summary>
		/// Constructor
		/// </summary>
		public Input()
		{
			// Attributes on the properties provide default values
		}

		/// <summary>
		/// Name of the input
		/// </summary>
		[ConfigurationProperty("name", IsRequired = true, IsKey = true, DefaultValue = "_")]
		[StringValidator(MinLength = 1, MaxLength = 255, InvalidCharacters = " ~!@#$%^&*()[]{}/;'\"|\\")]
		public string Name
		{
			get
			{
				return (string)this["name"];
			}
			set
			{
				this["name"] = value;
			}
		}
		/// <summary>
		/// Path of the folder
		/// </summary>
		[ConfigurationProperty("path", IsRequired = true, DefaultValue = "")]
		[StringValidator(InvalidCharacters = "*?\"<>|")]
		public string Path
		{
			get
			{
				return (string)this["path"];
			}
			set
			{
				this["path"] = value;
			}
		}
		/// <summary>
		/// File type filter
		/// </summary>
		[ConfigurationProperty("filter", IsRequired = true, DefaultValue = "")]
		[StringValidator(InvalidCharacters = "\\/:\"<>|")]
		public string Filter
		{
			get
			{
				return (string)this["filter"];
			}
			set
			{
				this["filter"] = value;
			}
		}
		/// <summary>
		/// Indicate whether subfolders should be watched as well
		/// </summary>
		[ConfigurationProperty("includeSubFolders", IsRequired = true, DefaultValue = false)]
		public bool IncludeSubFolders
		{
			get
			{
				return (bool)this["includeSubFolders"];
			}
			set
			{
				this["includeSubFolders"] = value;
			}
		}
		/// <summary>
		/// Indicate whether original file should be kept (copy) or not (move)
		/// </summary>
		[ConfigurationProperty("keepOriginal", IsRequired = true, DefaultValue = true)]
		public bool KeepOriginal
		{
			get
			{
				return (bool)this["keepOriginal"];
			}
			set
			{
				this["keepOriginal"] = value;
			}
		}

	}
}