<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - HomePage
 * @package tariqa3
 * @internal
 * @author Copyright © 2010, Pascal (Meta) Havelange
 */
namespace tariqa3 {
/**
 * Homepage of the application
 * @package MetaNull
 */
class Home extends BaseModule {

	/**
	 * The tariqa User
	 * @var tariqaUser
	 * @access private
	 */
	private $user;

	/**
	* Initializes the module
	* @access public
	* @return void
	*/
	public function onInitialize(){
		parent::onInitialize();
		$this->user = null;

		if (array_key_exists('multi_ajax_user_id', $_GET)){
			$user_id = $_GET['multi_ajax_user_id'];

			$this->user = \MetaNull\Tools\mCache::loadVariable("users/" . $user_id, null, true);
			if ($this->user == null) {
				$this->user = new tariqaUser( $user_id, true );
				\MetaNull\Tools\mCache::saveVariable($user, "users/" . $user_id, true);
			}
		}

		if ($this->user != null){
			\tariqa3\statics::loadTariqaClient($this->user);
		}
	}

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct( $config );
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return true;
	}

	/**
	 * Fetches the news for a given query
	 * @access public
	 * @return string
	 */
	public function fetchNews() {
		try {
			$db_query = statics::getQuery($_GET["query_id"]);
			$end_date = mktime(0, 0, 0, date('m'), date('d'), date('Y'));
			$start_date = strtotime('-' . $db_query->time_range . ' days', $end_date);
			$first = null;
			$count = null;
			if (array_key_exists('first', $_GET)) $first = $_GET["first"];
			if (array_key_exists('count', $_GET)) $count = $_GET["count"];
			$query = new \MetaNull\News\newsQuery($db_query->engine->engine_id, 'OS:' . $db_query->query, $start_date, $end_date, $first, $count);
			$query->engine_id = $db_query->engine->engine_id;
			$query->source_id = $db_query->source_id;

			$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
			$adapter = new newsAdapter($query, $config);
			$xml = $adapter->fetchNews();
			$printer = new \MetaNull\Tools\xslTransform($xml, 'newsPrinter/xhtml-test', \MetaNull\Tools\xslTransform::FORMAT_TEXT, $config);
			$content = $printer->transform();
		}
		catch (Exception $e) {
			throw new Exception('Error fetching the news::Query_id -> ' . $_GET["query_id"]);
		}

		$cond = !array_key_exists('output', $_GET) || $_GET["output"] == 'screen';

		return ($cond?'<query_id>' . $_GET['query_id'] . '</query_id><news><![CDATA[':'') . $content . ($cond?']]></news>':'');
	}

	/**
	 * Search news
	 * @access protected
	 * @return string
	 */
	protected function searchNews() {
		$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
		$defaults = $newsConfig['search']['default'];

		if (!array_key_exists('query', $_GET) && !array_key_exists('query', $_POST)) return null;
		else if (array_key_exists('query', $_GET)) $query = $_GET["query"];
		else $query = $_POST["query"];

		$original_query = $query;

		if (!array_key_exists('source_id', $_POST) && !array_key_exists('source_id', $_GET)) $source_id = $defaults["source_id"];
		else if (array_key_exists('source_id', $_GET)) $source_id = $_GET["source_id"];
		else $source_id = $_POST["source_id"];

		$source = statics::getSource($source_id);
		$engine_id = $source->engine_id;

		$start_date = null;
		$end_date = null;

		if (array_key_exists('start_date', $_GET)) $start_date = $_GET["start_date"];
		else if (array_key_exists('start_date', $_POST)) $start_date = $_POST["start_date"];

		if (array_key_exists('end_date', $_GET)) $end_date = $_GET["end_date"];
		else if (array_key_exists('end_date', $_POST)) $end_date = $_POST["end_date"];

		$first = 0;
		$count = null;

		if (array_key_exists('from', $_GET)) $first = $_GET["from"];
		else if (array_key_exists('from', $_POST)) $first = $_POST["from"];

		if (array_key_exists('count', $_GET)) $count = $_GET["count"];
		else if (array_key_exists('count', $_POST)) $count = $_POST["count"];

		$type = \MetaNull\News\unifiedQuerySyntax::UNIFIED_QUERY_SYNTAX;
		if (array_key_exists('type', $_GET)) $type = $_GET["type"];
		else if (array_key_exists('type', $_POST)) $type = $_POST["type"];

		$query = $type . ':' . $query;

		//$query = mb_convert_encoding($query, 'UTF-8');
		$query = iconv('UTF-8', 'UTF-8//TRANSLIT', $query);

		$format = $defaults['format'];

		if (array_key_exists('format', $_GET)) $format = $_GET["format"];
		else if (array_key_exists('format', $_POST)) $format = $_POST["format"];

		$specific_data = null;
		if (array_key_exists('specific_data', $_GET)) $specific_data = $_GET['specific_data'];
		else if (array_key_exists('specific_data', $_POST)) $specific_data = $_POST['specific_data'];

		//if ($specific_data != null) $specific_data = \MetaNull\Tools\mTools::rawurldecode($specific_data);

		try {
			$sq = $query;
			$query = new \MetaNull\News\newsQuery($engine_id, $sq, $start_date, $end_date, $first, $count, $specific_data);
			$query->source_id = $source_id;
			$adapter = new newsAdapter($query, $newsConfig);
			$xml = $adapter->fetchNews();

			/*$xml = $adapter->fetchNews(false);
			$xml->formatOutput = true;
			//error_log( $xml->saveXML() );
			var_dump($xml->saveXML());*/

			$dom = new \DOMDocument();
			$dom->loadXML($xml);
			$xpath = new \DOMXPath($dom);
			$nodes = $xpath->query('/articles/count/@value');

			foreach ($nodes as $node) {
				$results = $node->nodeValue;
				break;
			}

			$results_per_page = ($query->count === null?$defaults['results-per-page']:$query->count);

			$template = $defaults['template'];
			if (array_key_exists('template', $_GET)) $template = $_GET["template"];
			else if (array_key_exists('template', $_POST)) $template = $_POST["template"];

                        $xpath = new \DOMXPath($dom);
                        $rs = $xpath->query('//engine');

                        if ($rs->length > 0){
                            $eng = $rs->item(0)->nodeValue;
                            if ($eng == 'Error'){
                                $template = $defaults['error-template'];
                            }
                        }

			$printer = new \MetaNull\Tools\xslTransform($xml, 'newsPrinter/' . $template, $format, $newsConfig);
			$content = htmlspecialchars_decode($printer->transform());

			$content = str_replace(']]>', ']]&gt;', $content);
		}
		catch (Exception $e) {
			throw new Exception('Error searching the news::query -> ' . $query);
		}

		$cond = !array_key_exists('output', $_GET) || $_GET["output"] == 'screen';

		$s = ($source_id != 'null'?$source->description:'');
		$result_id = null;
		$navigation_id = null;
		$add_tab = true;

		if (array_key_exists('result_id', $_GET)) $result_id = $_GET['result_id'];
		else if (array_key_exists('result_id', $_POST)) $result_id = $_POST['result_id'];

		if (array_key_exists('navigation_id', $_GET)) $navigation_id = $_GET['navigation_id'];
		else if (array_key_exists('navigation_id', $_POST)) $navigation_id = $_POST['navigation_id'];

		if (array_key_exists('add_tab', $_GET)) $add_tab = ($_GET['add_tab'] == 'true');
		else if (array_key_exists('add_tab', $_POST)) $add_tab = ($_POST['add_tab'] == 'true');

		$display_xml = '<add_tab>' . ($add_tab?'true':'false') . '</add_tab>';
		if ($result_id != null) $display_xml .= '<result_id>' . $result_id . '</result_id>';
		if ($navigation_id != null) $display_xml .= '<navigation_id>' . $navigation_id . '</navigation_id>';

		$tab_id = '';
		if (array_key_exists('tab_id', $_GET)) $tab_id = "<tab_id>{$_GET['tab_id']}</tab_id>";
		else if (array_key_exists('tab_id', $_POST)) $tab_id = "<tab_id>{$_POST['tab_id']}</tab_id>";

		if ($results > $results_per_page && $query->engine_id != 'RSS'){
			//error_log( $xml->saveXML() );
			$text = '&nbsp;&nbsp;&nbsp;';
			$doc = new \DOMDocument('1.0', 'UTF-8');
			$doc->loadXML($xml);
			$xp = new \DOMXPath($doc);
			$rs = $xp->query('//article');
			if ($rs !== false){
				$to = $rs->length;
				$rs = $xp->query('//from');
				if ($rs !== false){
					$from = $rs->item(0)->nodeValue;
					$rs = $xp->query('//count');
					if ($rs !== false){
						$count = $rs->item(0)->nodeValue;
						$text = "<strong>{$from} - {$to}</strong> of {$count}";
					}
				}
			}
			$mainConfig = \MetaNull\Tools\mConfig::loadConfiguration(TARIQA_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
			$search = new multiAjaxSearch($original_query, $source_id, $mainConfig['application']['service_url'], 'searchResult', false, $query->start_date, $query->end_date, $query->first, $query->count, $type);
			$search->setResultId($result_id);
			$search->setNavigationId($navigation_id);
			if (!$add_tab) $search->noNewTab();
			if ($specific_data != null) $search->setSpecificData($specific_data);
			$navi = new Navigation($mainConfig, $search, $this->translationTable, $text);
			$navi->setOnBeforeNavigate("if (typeof(showFunction) == 'undefined') showFunction = function(id){ $('#' + id).show();}; showFunction('nav_load_{$result_id}');");
			$navi->setOnAfterNavigate("if (typeof(hideFunction) == 'undefined') hideFunction = function(id){ $('#' + id).hide();}; hideFunction('nav_load_{$result_id}');");
			$navigation = '<navigation>' . $navi->run() . '</navigation>';
		}
		else {
			$navigation = '<navigation/>';
		}

		$tpl = new \MetaNull\Application\MTemplate('m');
		$mainConfig = \MetaNull\Tools\mConfig::loadConfiguration(TARIQA_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
		$tpl->loadTemplate($mainConfig['templates']['base'] . '/' . $mainConfig['templates']['default'] . '/modules/tariqa3/Search/controls.html');
                $tpl->data = $this->translationTable;

                $controls = $tpl->transform();

		return '<source>' . $s . '</source>' .
				'<source_id>' . $source_id . '</source_id>' .
				'<engine>' . $engine_id . '</engine>' .
				'<count>' . $results . '</count>' .
				'<articles>' . ($cond?'<![CDATA[':'') . $content . ($cond?']]>':'') . '</articles>' .
                                '<controls><![CDATA[' . $controls . ']]></controls>'
				. $navigation . $display_xml . $tab_id;
		;
	}

	/**
	 * Performs an LDAP search
	 * @access protected
	 * @return string
	 */
	protected function ldapSearch() {
		$filter = '';
		if (array_key_exists('filter', $_GET)) $filter = $_GET['filter'];
		else if (array_key_exists('filter', $_POST)) $filter = $_POST['filter'];

		$mainConfig = \MetaNull\Tools\mConfig::loadConfiguration(TARIQA_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
		$auto_filter = '';
		foreach ($mainConfig['security']['groups'] as $group => $value){
			$auto_filter .= "(cudgroup={$group})";
		}

		$auto_filter = "(|{$auto_filter})";

                $tags = null;
                if (array_key_exists('tags', $_GET)){
                    $tags = \MetaNull\Tools\mTools::rawurldecode($_GET['tags']);
                }
                else if (array_key_exists('tags', $_POST)){
                    $tags = \MetaNull\Tools\mTools::rawurldecode($_POST['tags']);
                }

                if ($tags != null){
                    $db = statics::open_db_connection($this->config['database']);
                    $tags = explode(' ', $tags);
                    foreach ($tags as $tag){
                        $tag = $db->real_escape_string($tag);
                        $sql = <<<sql
select user_id from user_preferences
    where `key` = 'general/tags' and `data` like '%{$tag}%'
    group by user_id
    order by user_id
sql;
                        $query = $db->mQuery($sql);
                        while ($row = $query->fetch_assoc()){
                            $filter .= "(uid={$row['user_id']}*)";
                        }
                    }
                }

		$filter = "(&({$filter}){$auto_filter})";

		$results = statics::$tariqaClient->ldapFullSearch(statics::$tariqaToken, $filter, null, $mainConfig['application']['ldap-results']);
		$result = '';

		/* @var $entry LDAPEntry */
		foreach ($results->entries as $entry){
			$groups = '';
			foreach ($entry->groups as $group){
				if (array_key_exists($group, $mainConfig['security']['groups'])){
					$groups .= ($groups == ''?'':', ') . $this->translationTable['share_group_' . $group];
				}
			}

			$id = \MetaNull\Tools\mTools::rawurlencode('mail=' . \MetaNull\Tools\mTools::rawurlencode($entry->email) . '&uid=' . $entry->user_id);

			$result .= "<contact><name>{$entry->title} {$entry->displayname} ({$groups})</name><id>{$id}</id></contact>";
		}

		return $result;
	}

	/**
	 * Saves an article to the briefcase
	 * @param string $param_name param_desc
	 * @access protected
	 * @return string
	 */
	protected function sendToBriefcase() {
		require_once(TARIQA3_REL_PATH . '/tariqa3/modules/briefcase/Briefcase.class.php');
		$db = statics::open_db_connection($this->config['database']);
		return Briefcase::doSaveArticle($_GET['multi_ajax_user_id'], $db, $_GET['folder_id'], $_GET['type_id'], $_GET['id']);
	}

	/**
	 * Shares an article with an user
	 * @access protected
	 * @return string
	 */
	protected function shareArticle() {
		require_once(TARIQA3_REL_PATH . '/tariqa3/modules/sharing/Sharing.class.php');

		$mainConfig = \MetaNull\Tools\mConfig::loadConfiguration(TARIQA_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');

		$db = statics::open_db_connection($mainConfig['database']);

		$data = array(
			'article_ids' => $_POST['article_ids'],
			'article_titles' => $_POST['article_titles']
		);

		return Sharing::shareItem($this->user, $db, $_POST['share_with'], $data, Sharing::SHARE_ARTICLE, $_POST['message'], $mainConfig, $this->translationTable);
	}

	/**
	 * Gets the wikipedia data
	 * @access protected
	 * @return string
	 */
	protected function getWikipediaData() {
		try{
			//sleep(31);
			$wiki_data = statics::get_wiki_data($_GET['country_id']);
		}
		catch (\Exception $e){
			error_log(\MetaNull\Tools\mDump::dumpVariable($e, true));
			return "<error>There was a problem retrieving the data from wikipedia. The error message is {$e->getMessage()}</error>";
		}
		$tpl = new \MetaNull\Application\MTemplate('m');
		$mainConfig = \MetaNull\Tools\mConfig::loadConfiguration(TARIQA_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
		$tpl->loadTemplate($mainConfig['templates']['base'] . '/' . $mainConfig['templates']['default'] . '/modules/tariqa3/Countries/MapsSection/wiki_data.html');
		$tpl->data = $this->translationTable;
		$tpl->data['img_path'] = $mainConfig['templates']['baseurl'] . '/' . $mainConfig['templates']['default'] . '/images';;
		$tpl->data['capital'] = $wiki_data->capital;
		$tpl->data['head_of_state'] = $wiki_data->head_of_state;
		$tpl->data['head_of_state_title'] = $wiki_data->head_of_state_title;
		$tpl->data['flag_img_src'] = $wiki_data->flag;

		$tpl->data['wiki_details'] = array();
		$wiki_data->toc = substr($wiki_data->toc, 5, strlen($wiki_data->toc) - 11);
		$wiki_data->toc = preg_replace('/<ul>(.*)$/s', '<ul id="wiki_toc">\1', $wiki_data->toc);
		$tpl->data['toc'] = $wiki_data->toc;
		//\MetaNull\Tools\mDump::dumpVariable($wiki_data->toc);


		$id = 1;
		/* @var $detail WikipediaDetail */
		foreach ($wiki_data->details as $detail){
			$item_details = array();

			/* @var $pair Pair */
			foreach ($detail->data as $pair){
				$item_details[] = array(
					'key' => $pair->key,
					'value' => $pair->value,
				);
			}

			$tpl->data['wiki_details'][] = array(
				'id' => $id,
				'title' => $detail->name,
				'subtitle' => $detail->value,
				'item_details' => $item_details,
			);
		}

		$html = \MetaNull\Tools\mTools::rawurlencode($tpl->transform());

		return "<html>{$html}</html>";
	}

	/**
	 * Render the module's page (will be embedded in general layout)
	 * @return string
	 */
	public function onExecute() {
		$display = '';
		$root_node = "result";
		if (array_key_exists("root_node", $_GET)) $root_node = $_GET["root_node"];
		else if (array_key_exists('root_node', $_POST)) $root_node = $_POST['root_node'];
		if (!array_key_exists("no_root_node", $_GET) && !array_key_exists('no_root_node', $_POST)) {
			$display .= "<{$root_node}";
			if (array_key_exists("root_node_params", $_GET) || array_key_exists('root_node_params', $_POST)) {
				$root_node_params = (array_key_exists('root_node_params', $_GET)?$_GET['root_node_params']:$_POST['root_node_params']);
				foreach ($root_node_params as $key => $value) {
					$display .= " {$key}=\"{$value}\"";
				}
			}
			$display .= ">";
		}
		try {
			if (array_key_exists("action", $_GET) || array_key_exists('action', $_POST)) {
				$result = call_user_func(array($this, (array_key_exists('action', $_GET)?$_GET["action"]:$_POST['action'])));
				if (!array_key_exists('output', $_GET) || $_GET["output"] == 'screen' || !array_key_exists('output', $_POST) || $_POST['output'] == 'screen') {
					$display .= $result;
				}
				else if ($_GET["output"] == 'file' || $_POST['output'] == 'file') {
					$name = session_id();
					if (array_key_exists('fileName', $_GET)) $name = $_GET['fileName'];
					else if (array_key_exists('fileName', $_POST)) $name = $_POST['fileName'];
					$name = $this->config['application']['tmp'] . '/' . $name;
					$f = fopen($name . $_SERVER["QUERY_STRING"], 'wb');
					fwrite($f, $result, strlen($result));
					fclose($f);
				}
			}
		}
		catch (\MetaNull\Tools\mysqlException $e) {
			error_log(\MetaNull\Tools\mDump::dumpVariable($e, true, false));
			$display = "<error>There was a problem with the mysql database. Please contact the TARIQA team (RELEX-TARIQA@ec.europa.eu)</error>";
			return $display;
		}
		catch (\Exception $e) {
			error_log(\MetaNull\Tools\mDump::dumpVariable($e, true, false));
			$display = "<error>There was an unknown error in processing the multi ajax calls. Please contact the TARIQA team (RELEX-TARIQA@ec.europa.eu)</error>";
			return $display;
		}
		if (!array_key_exists("no_root_node", $_GET) && !array_key_exists('no_root_node', $_POST)) {
			$display .= "</{$root_node}>";
		}

		return $display;
	}

	/**
	 * Loads a newsticker feed
	 * @access protected
	 * @return string
	*/
	protected function loadNewstickers(){
		if (!array_key_exists('url', $_GET) && !array_key_exists('query_id', $_GET)) return '';

		$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
		$defaults = $newsConfig['search']['default'];

		if (array_key_exists('url', $_GET)){
			$url = \MetaNull\Tools\mTools::rawurldecode($_GET["url"]);
			$engine_id = "RSS";
			$query = new \MetaNull\News\newsQuery($engine_id, "OS:" . $url, null, null, 0, null, null);
		}
		else if (array_key_exists('query_id', $_GET)){
			$q = statics::getQuery($_GET['query_id']);
			if ($q->engine == null){
				if ($q->source == null){
					$q->source = statics::getSource($q->source_id);
				}
				$q->engine = statics::getEngine($q->source->engine_id);
			}

			$engine_id = $q->engine->engine_id;
			$query = new \MetaNull\News\newsQuery($engine_id, 'OS:' . $q->query, null, null, 1, null);
			$r = new timeRange($q->time_range);
			$query->start_date = $r->getStartDate();
			$query->end_date = $r->getEndDate();
		}

		try {
			$query->source_id = $defaults[strtolower($engine_id)]['source_id'];
			//$query->query = "OS:lower(title) like '%united states%'";

			$adapter = new newsAdapter($query, $newsConfig);
			$xml = $adapter->fetchNews();

			$template = 'rss';

			$printer = new \MetaNull\Tools\xslTransform($xml, 'newsPrinter/' . $template, \MetaNull\Tools\xslTransform::FORMAT_TEXT, $newsConfig);
			$content = $printer->transform();

			return '<html><![CDATA[' . $content . ']]></html><i>' . $_GET['i'] . '</i>';
		}
		catch (Exception $e) {
			throw new Exception('Error fetching the RSS feed ' . $url);
		}
	}

	/**
	 * Gets the applications headers set by the module
	 * @access public
	 * @return array
	 */
	public function getHeaders() {
		if (!array_key_exists('content_type', $_GET))
			return array("Content-type: text/xml; charset=utf-8");
		else {
			return array("Content-type: " . $_GET['content_type']);
		}
	}

}
}
?>