-- MySQL dump 10.11
--
-- Host: localhost    Database: tariqa3
-- ------------------------------------------------------
-- Server version	5.0.67-community

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `ajax_call_urls`
--

CREATE DATABASE  IF NOT EXISTS `tariqa3` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `tariqa3`;

DROP TABLE IF EXISTS `ajax_call_urls`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `ajax_call_urls` (
  `call_id` int(10) unsigned NOT NULL COMMENT 'Id of the Ajax Call',
  `url_id` smallint(5) unsigned NOT NULL COMMENT 'Id of the URL in the current multi-call',
  `url` varchar(2048) NOT NULL,
  `post_fields` longtext COMMENT 'the full data to post in an HTTP POST operation. You must make sure that the data is formatted the way you want the server to receive it',
  `http_code` smallint(5) unsigned default NULL COMMENT 'HTTP return code once the URL has been retrieved',
  `call_content` longblob COMMENT 'Data returned by the URL',
  `call_content_length` int(10) unsigned default NULL COMMENT 'Length of the data',
  `call_content_type` varchar(255) default 'application/binary',
  `call_header` text COMMENT 'HTTP Header of the document at the given URL',
  `call_error` text COMMENT 'Error data or NULL',
  `duration` float default NULL COMMENT 'Duration in seconds of the download',
  `last_update` datetime default NULL COMMENT 'Date/time at which the URL process was ended',
  `method` enum('get','post') NOT NULL default 'get' COMMENT 'Only GET is implemented at the moment',
  `use_proxy` enum('yes','no') NOT NULL default 'no' COMMENT 'If set to yes, uses the HTTP Proxy',
  PRIMARY KEY  (`call_id`,`url_id`),
  KEY `idx_content_type` (`call_content_type`),
  KEY `idx_content_length` (`call_content_length`),
  KEY `idx_durations` (`duration`),
  KEY `idx_method` (`method`),
  CONSTRAINT `fk_ajax_call_urls_ajax_calls` FOREIGN KEY (`call_id`) REFERENCES `ajax_calls` (`call_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `ajax_calls`
--

DROP TABLE IF EXISTS `ajax_calls`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `ajax_calls` (
  `call_id` int(10) unsigned NOT NULL auto_increment COMMENT 'Id of the Ajax Call',
  `call_time` datetime default NULL COMMENT 'Date/time at which the call was issued',
  `user_id` varchar(16) default NULL COMMENT 'The user which is requesting the URL',
  PRIMARY KEY  (`call_id`),
  KEY `FK_ajax_calls_users` (`user_id`),
  CONSTRAINT `FK_ajax_calls_users` FOREIGN KEY (`user_id`) REFERENCES `known_users` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=19403 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

/*!50003 SET @SAVE_SQL_MODE=@@SQL_MODE*/;

DELIMITER ;;
/*!50003 SET SESSION SQL_MODE="STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION" */;;
/*!50003 CREATE */ /*!50017 */ /*!50003 TRIGGER `trg_oninsert_ajax_call` BEFORE INSERT ON `ajax_calls` FOR EACH ROW begin

	if new.`call_time` is null then

		set new.`call_time` = now();

	end if;

end */;;

DELIMITER ;
/*!50003 SET SESSION SQL_MODE=@SAVE_SQL_MODE*/;

--
-- Table structure for table `briefcase_content`
--

DROP TABLE IF EXISTS `briefcase_content`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `briefcase_content` (
  `content_id` int(10) unsigned NOT NULL auto_increment COMMENT 'The content identifier',
  `name` blob NOT NULL COMMENT 'The content name',
  `type_id` int(10) unsigned NOT NULL COMMENT 'The content type',
  `folder_id` int(10) unsigned default NULL COMMENT 'The content folder',
  `data` longblob COMMENT 'The content data',
  `description` text COMMENT 'The content descirption',
  `mime_type` varchar(255) default NULL COMMENT 'The content mime type or NULL',
  `length` int(10) unsigned default NULL COMMENT 'The content length or NULL',
  `item_id` varchar(255) default NULL COMMENT 'The item identifier (e.g.: article id)',
  `user_id` varchar(16) NOT NULL COMMENT 'The user identifier',
  `display_order` int(11) NOT NULL default '0',
  PRIMARY KEY  (`content_id`),
  KEY `Index_2` (`type_id`),
  KEY `Index_3` (`folder_id`),
  KEY `FK_briefcase_content_users` (`user_id`),
  CONSTRAINT `FK_briefcase_content_folders` FOREIGN KEY (`folder_id`) REFERENCES `briefcase_folders` (`folder_id`),
  CONSTRAINT `FK_briefcase_content_types` FOREIGN KEY (`type_id`) REFERENCES `briefcase_contents_types` (`type_id`),
  CONSTRAINT `FK_briefcase_content_users` FOREIGN KEY (`user_id`) REFERENCES `known_users` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=1254 DEFAULT CHARSET=utf8 COMMENT='The briefcase content';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `briefcase_contents_types`
--

DROP TABLE IF EXISTS `briefcase_contents_types`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `briefcase_contents_types` (
  `type_id` int(10) unsigned NOT NULL auto_increment COMMENT 'The type identifier',
  `name` varchar(100) NOT NULL COMMENT 'The type name',
  `description` text COMMENT 'The type description',
  PRIMARY KEY  (`type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COMMENT='The list of type contents from the briefcase';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `briefcase_folders`
--

DROP TABLE IF EXISTS `briefcase_folders`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `briefcase_folders` (
  `folder_id` int(10) unsigned NOT NULL auto_increment COMMENT 'The folder identifier',
  `name` varchar(100) NOT NULL COMMENT 'The folder name',
  `description` text COMMENT 'The folder description',
  `parent_id` int(10) unsigned default NULL COMMENT 'The parent identifier',
  `type_id` int(10) unsigned default NULL COMMENT 'The type identifier',
  `user_id` varchar(16) NOT NULL COMMENT 'The user identifier',
  PRIMARY KEY  (`folder_id`),
  KEY `Index_2` (`parent_id`),
  KEY `FK_briefcase_folders_types` (`type_id`),
  CONSTRAINT `FK_briefcase_folders_parents` FOREIGN KEY (`parent_id`) REFERENCES `briefcase_folders` (`folder_id`) ON DELETE SET NULL ON UPDATE CASCADE,
  CONSTRAINT `FK_briefcase_folders_types` FOREIGN KEY (`type_id`) REFERENCES `briefcase_contents_types` (`type_id`) ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=51 DEFAULT CHARSET=utf8 COMMENT='The briefcase folders';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `known_users`
--

DROP TABLE IF EXISTS `known_users`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `known_users` (
  `user_id` varchar(16) NOT NULL,
  `first_access` datetime default NULL,
  PRIMARY KEY  (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `languages`
--

DROP TABLE IF EXISTS `languages`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `languages` (
  `language_id` varchar(2) NOT NULL COMMENT 'ISO 639-1',
  `iso_639_1` varchar(2) default NULL COMMENT 'ISO 639-1',
  `iso_639_2` varchar(3) default NULL COMMENT 'ISO 639-2',
  `name_en` varchar(255) NOT NULL COMMENT 'ISO 639-2/B',
  `name_fr` varchar(255) NOT NULL COMMENT 'ISO 639-2/B',
  `name` varchar(255) NOT NULL COMMENT 'Name in original language',
  `dir` varchar(3) NOT NULL default 'rtl' COMMENT 'Horizontal direction of the text',
  PRIMARY KEY  (`language_id`),
  KEY `idx_languages_name_en` (`name_en`),
  KEY `idx_languages_name_fr` (`name_fr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='List of languages (iso 639-2/b)';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `languages_sections`
--

DROP TABLE IF EXISTS `languages_sections`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `languages_sections` (
  `section_id` varchar(255) NOT NULL,
  `description` text,
  PRIMARY KEY  (`section_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Sections of the translation mechanism';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `translation`
--

DROP TABLE IF EXISTS `translation`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `translation` (
  `section_id` varchar(255) NOT NULL,
  `keyword` varchar(255) NOT NULL,
  `description` text,
  PRIMARY KEY  (`section_id`,`keyword`),
  CONSTRAINT `fk_translation_sections` FOREIGN KEY (`section_id`) REFERENCES `languages_sections` (`section_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Keys of the translation mechanism';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `translation_values`
--

DROP TABLE IF EXISTS `translation_values`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `translation_values` (
  `section_id` varchar(255) NOT NULL,
  `keyword` varchar(255) NOT NULL,
  `language_id` varchar(3) NOT NULL,
  `data` text,
  PRIMARY KEY  (`section_id`,`keyword`,`language_id`),
  KEY `idx_translation_values_sections` (`section_id`,`language_id`),
  KEY `fk_translation_values_languages` (`language_id`),
  CONSTRAINT `fk_translation_values_languages` FOREIGN KEY (`language_id`) REFERENCES `languages` (`language_id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `fk_translation_values_translation` FOREIGN KEY (`section_id`, `keyword`) REFERENCES `translation` (`section_id`, `keyword`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Translated texts for each key';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `user_articles`
--

DROP TABLE IF EXISTS `user_articles`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `user_articles` (
  `assoc_id` int(10) unsigned NOT NULL auto_increment,
  `user_id` varchar(16) NOT NULL,
  `article_id` varchar(255) NOT NULL COMMENT 'The article identifier',
  `ts` timestamp NOT NULL default CURRENT_TIMESTAMP COMMENT 'The current time',
  PRIMARY KEY  (`assoc_id`),
  KEY `FK_user_articles_users` (`user_id`),
  CONSTRAINT `FK_user_articles_users` FOREIGN KEY (`user_id`) REFERENCES `known_users` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `user_preferences`
--

DROP TABLE IF EXISTS `user_preferences`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `user_preferences` (
  `user_id` varchar(16) NOT NULL,
  `key` varchar(255) NOT NULL,
  `data` text,
  PRIMARY KEY  (`user_id`,`key`),
  CONSTRAINT `fk_user_preferences_known_users` FOREIGN KEY (`user_id`) REFERENCES `known_users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2010-12-20 15:59:24
