<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Application {

	/**
	 * Specialize mTemplateObject class to help handle MySQL queries
	 * 
	 * Example:
	 * -------- 
	 * - Template: (file: persons.html)
	 * <html><body>
	 * <table>
	 * <m:object key="my_query">
	 * 	<tr><td><m:value key="last_name" /></td>
	 * 		<td><m:value key="first_name" /></td>
	 * </tr>
	 * </m:object>
	 * </table>
	 * </body></html>
	 * 
	 * - PHP: (file: persons.php)
	 * <?php
	 * $my_query = new MTemplateObject_mysql();
	 * $my_query->user = "guest";
	 * $my_query->pass = "";
	 * $my_query->host = "localhost";
	 * $my_query->name = "test";
	 * $my_query->encoding = "utf8";
	 * $my_query->query = "select first_name, last_name from persons";
	 * $page = new MTemplate( "m" );
	 * $page->loadTemplate( "persons.html" );
	 * $page->data["my_query"] = $my_query;
	 * $page->useCache( FALSE );
	 * echo $page->transform();
	 * ?>
	 * 
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2007
 	 * @package MetaNull\Application
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class mTemplateObject_mysql extends mTemplateObject {
		
		protected $db = false;
		protected $rc = false;
		protected $query = false;
		
		public $host = "localhost";
		public $name = "test";
		public $user = "guest";
		public $encoding = "utf-8";
		public $pass = null;
		
		
		function __construct() {
			parent::__construct();
		}
		
		function initialize( $data = null ) {
			
			$data;	// $data is not used in this specific class
			
			$this->db = @mysql_connect( $this->host, $this->user, $this->pass );
			if( false === $this->db ) {
				return false;
			}
			if( false === @mysql_select_db( $this->name, $this->db )) {
				return false;
			}
			if( false === @mysql_query( "set names {$this->encoding}", $this->db )) {
				return false;
			}
			
/*			$query = $this->query;
			while( false !== ereg( "@@([a-zA-Z0-9/\\_-]+)@@", $query, $regs )) {
				$query = str_replace( $regs[0], $data[$regs[1]], $query );
			}
			error_log( $query );
*/
			$this->rc = @mysql_query( $this->query, $this->db );
			if( false === $this->rc ) {
				@mysql_close( $this->db );
				$this->db = false;
				return false;
			}
			return true;
		}
		
		function next() {
			if( false === $this->rc ) {
				return false;
			}
			$row = @mysql_fetch_array( $this->rc, MYSQL_ASSOC );
			return $row;
		}
		
		function destroy() {
			if( false !== $this->db ) {
				@mysql_close( $this->db );
				$this->db = false;
			}
		}
		
		function error() {
			if( false === $this->db ) {
				return "Could not connect to MySQL server on {$this->host}: \n" . mysql_error();
			}
			$errc = @mysql_errno( $this->db );
			$errm = @mysql_error( $this->db );
			return <<<error
MySQL Error #{$errc}:
{$errm}

In SQL query:
{$this->query}

error;
		}
		
	}

}