<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Authentication {
	
	/**
	 * Interface for User objects, used by the Authentication mechanism
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2008
	 * @see iAuthentication
	 * @package MetaNull\Authentication
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	interface iUser {
		/**
		 * Returns the UserId of the user
		 * @return string
		 */
		public function getUserId();
		
		/**
		 * Returns an array of valid attributes associated with
		 * @return array 
		 */
		public function getAttributeList();
		
		/**
		 * Check the group membership of an user
		 * @param string|array $groups Either the name of a group or an array of group names against which to check the membership of the user
		 * @param bool $binary_and If set to true, the user must be a member of ALL the groups in the list, otherwise it must belong to at least one of the groups
		 * @return bool 
		 */
		public function isMemberOf( $groups, $binary_and = false );
		
		/**
		 * Accessor, quickly access the user's attributes using object style syntax
		 * @return string
		 */
		public function __get( $attributeName );
		
		/**
		 * Accessor, quickly access the user's attributes using object style syntax
		 */
		public function __set( $attributeName, $value );
		
		/**
		 * Accessor, quickly access the user's attributes using object style syntax
		 * @return bool
		 */
		public function __isset( $attributeName );
		
		/**
		 * Accessor, quickly access the user's attributes using object style syntax
		 * @return bool
		 */
		public function __unset( $attributeName );
	}
	
}
?>