<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Commission{
	
	/**
	 * LDAP Database access, set on the European Commission's database
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2008
 	 * @package MetaNull\Commission
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class EC_LDAP extends \MetaNull\Net\mLDAP {
		
		/**
		 * The application's configuration array
		 * @var array
		 */
		private $app_config = null;

		/**
		 * List of existing attributes to fetch. The key in the array are used as aliases to the attributes by the EC_User class
		 */
		static $ldap_attributes = array( 'user_id'=>'uid',
			'user_group'=>'cudgroup',
			'user_class'=>'objectclass',
			'title'=>'title', 'first_name'=>'givenname', 'last_name'=>'sn', 'display_name'=>'cn',
			'email'=>'mail', 'phone'=>'telephonenumber', 'country'=>'c',
			'organisation'=>'sourceorganisation','directorate_general'=>'dg','directorate'=>'dir','unit'=>'div',
			'department'=>'departmentnumber', 'manager_id'=>'manager',
			'building'=>'building','floor'=>'floor','office'=>'room',
			'address'=>'physicaldeliveryofficename',
			'dn'=>'dn'
		);
		
		/**
		 * Construct a mLdap Object, using the EC Settings
		 */
		public function __construct() {
			$this->max_results = 10;
			$this->max_time = 7;
			$this->deref = LDAP_DEREF_NEVER;
			$this->app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT );

			parent::__construct( $this->app_config['ldap']['host'], (int)$this->app_config['ldap']['port'] );
		}
		
		/**
		 * Quick search in the directory
		 * @param string $filter the LDAP filter. ie: (|(uid=MY_USER_ID)(cn=MY_NAME*))
		 * @param false|array $required_attributes If false, retrieves default attributes, otherwise retrieve only specific attributes (the list should only contain real attributes names, as defined in the array values of $this->ldap_attributes )
		 * @return array
		 */
		public function search( $filter, $required_attributes = false ) {
			$attributes = (false === $required_attributes || !is_array($required_attributes)) ? EC_LDAP::$ldap_attributes : $required_attributes;
			sort( $attributes );
			return parent::search( $this->app_config['ldap']['basedn'], $filter, $attributes );
		}

		/**
		 * Connect to the server
		 *
		 * @param string $username The username to use to connect to the LDAP server, or false for anonymous connection
		 * @param string $password The password to use to connect to the LDAP server, or false for anonymous connection
		 * @return boolean True on success, false otherwise
		 */
		public function connect( $username = false, $password = false ) {
			if( false !== $username ) {
				return parent::connect( $username, $password );
			} else {
				return parent::connect( $this->app_config['ldap']['login'], $this->app_config['ldap']['password'] );
			}
		}
	}
	
}
?>