<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\News{

	/**
	 * Class representing a token for a news query
	 * @author Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @package MetaNull\News
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class queryToken {
		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_FUNC = ":FUNC:";

		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_OPERATOR = ":OPER:";

		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_LPAR = ":LEFT:";

		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_RPAR = ":RIGH:";

		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_KEYWORD = ":KEYW:";

		/**
		 * Constant
		 * @var string
		 */
		const TOKEN_TYPE_RESULT_KEYWORD = ":RESK:";

		/**
		 * Constant (reserved for later use)
		 * @var string
		 */
		const TOKEN_TYPE_SEPARATOR = ":SEPA:";

		/**
		 * Constant
		 * @var int
		 */
		const TYPE_LENGTH = 6;

		/**
		 * The type of the token
		 * @var string
		 * @access private
		 */
		public $type = null;

		/**
		 * The value of the token
		 * @var string
		 * @access private
		 */
		public $value = null;

		/**
		 * The quote to use
		 * @var string
		 * @access private
		 */
		public $quote = '"';

		/**
		 * The operator precedence (used only for operators)
		 * @var int
		 * @access public
		 */
		public $precedence = null;

		/**
		 * Constructs the object
		 * @param string $type The token type
		 * @param string $value The value of the token
		 * @param int $precedence The operator precedence (used only for operators) [OPTIONAL]
		 * @param string $quote The quote to use [OPTIONAL]
		 * @access public
		 * @return void
		 */
		public function __construct($type = null, $value = null, $precedence = null, $quote = '"') {
			$this->type = $type;
			$this->value = $value;
			$this->precedence = $precedence;
			$this->quote = $quote;
		}

	}
}
?>