<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Tools {

	/**
	 * Helper functions & classes for HTTP REQUESTS using the libcurl library
	 * @author Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2007-2010
	 * @package MetaNull\Tools
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class mCurl {
		/**
		 * Send a GET request to an HTTP Server and retrieves its results
		 *
		 * @param string $url Url to fetch
		 * @param integer &$http_code Reference to a variable that will receive the HTTP error code returned by the server.
		 * @param string $ssl_cert_path Full path rto the CA Certificate to use in case of SSL
		 * @param string $http_proxy Http Proxy setup (http://[user:password@]host:port
		 * @return The returned data on success, false otherwise.
		 */
		public static function Get( $url, &$http_code, $ssl_cert_path = false, $http_proxy = false ) {
			$http_code = false;
			$http_return = false;
			$hcurl = @curl_init();
			do {
				if( false === $hcurl ) {
					trigger_error( 'Unable to initialize libCurl!' );
					break;
				}
				if( false === @curl_setopt( $hcurl, CURLOPT_URL, $url )) {
					trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
					break;
				}
				if( false === @curl_setopt( $hcurl, CURLOPT_RETURNTRANSFER, 1 )) {
					trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
					break;
				}
				
				if( false !== $ssl_cert_path ) {
					if( false === @curl_setopt( $hcurl, CURLOPT_SSL_VERIFYHOST, 2 )) {
						trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
						break;
					}
					if( false === @curl_setopt( $hcurl, CURLOPT_SSL_VERIFYPEER, 1 )) {
						trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
						break;
					}
					if( false !== $ssl_cert_path ) {
						if( false === @curl_setopt( $hcurl, CURLOPT_CAINFO, $ssl_cert_path )) {
							trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
							break;
						}
					}
				}
				
				if( false !== $http_proxy ) {
					$proxy = Array( 'login' => false, 'host' => false, 'port' => false );
					$proxstr = ereg_replace( '^.*://', '', $http_proxy );
					$proxarr = explode( '@', $proxstr, 2 );
					if( 1 == count($proxarr )) {
						$tmp = explode( ':', $proxarr[0], 2 );
						$proxy['host'] = $tmp[0];
						if( isset( $tmp[1]) ) {
							$proxy['port'] = $tmp[1];
						}
					} else {
						$proxy['login'] = $proxarr[0];
						$tmp = explode( ':', $proxarr[1], 2 );
						$proxy['host'] = $tmp[0];
						if( isset( $tmp[1]) ) {
							$proxy['port'] = $tmp[1];
						}
					}
					if( false === @curl_setopt( $hcurl, CURLOPT_PROXY, $proxy['host'] )) {
						trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
						break;
					}
					if( false !== $proxy['port'] ) {
						if( false === @curl_setopt( $hcurl, CURLOPT_PROXY, $proxy['host'] )) {
							trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
							break;
						}
					}
					if( false === @curl_setopt( $hcurl, CURLOPT_PROXYTYPE, CURLPROXY_HTTP )) {
						trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
						break;
					}
					if( false !== $proxy['login'] ) {
						if( false === @curl_setopt( $hcurl, CURLOPT_PROXYAUTH, CURLAUTH_BASIC )) {
							trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
							break;
						}
						if( false === @curl_setopt( $hcurl, CURLOPT_PROXYUSERPWD, $proxy['login'] )) {
							trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
							break;
						}
					} else {
						if( false === @curl_setopt( $hcurl, CURLOPT_PROXYAUTH, CURLAUTH_NONE )) {
							trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
							break;
						}
					}
				}
				
				$http_return = curl_exec( $hcurl );
				if( false === $http_return ) {
					trigger_error( 'libCurl error #'.curl_errno($hcurl).': '.curl_error($hcurl), E_USER_ERROR );
					break;
				}
				
				$http_code = curl_getinfo( $hcurl, CURLINFO_HTTP_CODE );
		/*		if( 200 != $http_code ) {
					trigger_error( 'HTTP error #{$http_code}', E_USER_ERROR);
					$http_return = $http_code;
					break;
				}
		*/
			} while( false );
			if( false !== $hcurl ) {
				curl_close( $hcurl );
				$hcurl = false;
			}
			
			return $http_return;
		}
	}
}
?>