<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Tools {

    /**
     * A layer on top of mysqli class just to automatize error checking
     * Connections are made in a persistent way
     * @author Cosmin Popescu
     * @copyright © EUROPEAN COMMISSION, 2010
     * @package MetaNull\Tools
	 * @license http://ec.europa.eu/idabc/eupl
     */
    class mMysql extends \mysqli {

        /**
         * The constructor
         * @param string $host The host server
         * @param string $user The user name
         * @param string $password The password
         * @param string $database The database name
         * @param string $charset The charset [OPTIONAL]
         * @param string $autocommit The autocommit [OPTIONAL]
         * @access public
         * @return mysqli
         */
        public function __construct($host, $user, $password, $database, $port, $charset = 'UTF-8', $autocommit = true) {
            try {
                parent::__construct('p:' . $host, $user, $password, $database, (int) $port);
                if (mysqli_connect_errno ()) {
                    throw new \MetaNull\Tools\mysqlException('Error connecting to the database: ' . mysqli_connect_error(), mysqli_connect_errno());
                }
                $this->set_charset($charset);
                $this->autocommit($autocommit);
            } catch (\Exception $e) {
                throw new \MetaNull\Tools\mysqlException($e->getMessage(), $e->getcode());
            }
        }

        /**
         * The query function (it calls the mysqli query function and checks for errors
         * @param string $query The query
         * @access public
         * @return mixed
         */
        public function mQuery($query) {
            $rs = $this->query($query);
            if ($rs === false) {
                $error_message = 'Error #' + $this->errno . ' ' . $this->error . "\n";
                $error_message .= 'In SQL query: ' + "\n" + $query + "\n";
                throw new mysqlException($error_message, $this->errno);
            }
            return $rs;
        }

        /**
         * Gets the last inserted id
         * @access public
         * @return mixed
         */
        public function last_insert_id() {
            $last_id = null;
            $sql = 'select last_insert_id() as id';
            $rs = $this->mQuery($sql);
            if (null !== ($row = $rs->fetch_assoc())) {
                $last_id = $row['id'];
            }
            $rs->close();
            return $last_id;
        }

        /**
         * Gets the number of rows from a table
         * @param string $table The table name
         * @param string $condition The condition [OPTIONAL]
         * @access public
         * @return int
         */
        public function count_rows($table, $condition = null) {
            $sql = "select count(*) as 'count' from `{$table}`";
            if (null !== $condition) {
                $sql .= " where {$condition}";
            }
            $count = 0;
            $rs = $this->mQuery($sql);
            if (null !== ( $row = $rs->fetch_assoc())) {
                $count = $row['count'];
            }
            $rs->close();
            return $count;
        }

        /**
         * Gets a field value based on a condition
         * @param string $table The table name
         * @param string $field The field name
         * @param string $condition The condition
         * @access public
         * @return mixed
         */
        public function get_value($table, $field, $condition) {
            $sql = "select `{$field}` from `{$table}` where {$condition}";
            $query = $this->mQuery($sql);
            $val = null;
            if (null !== ( $row = $query->fetch_assoc())) {
                $val = $row[$field];
            }
            $query->close();
            return $val;
        }

        /**
         * Gets a value from a mysql function
         * @param string $name The function name
         * @param mixed $params The function parameters (a value or an array of values) [OPTIONAL]
         * @access protected
         * @return mixed
         */
        public function get_function_value($name, $params = null) {
            $p = '';
            if ($params != null){
                if (\is_array($params)){
                    foreach ($params as $param){
                        $p .= ($p == ''?'':', ') . "'" . $this->real_escape_string($param) . "'";
                    }
                }
                else $p = "'" . $this->real_escape_string ($params) . "'";
            }

            $sql = "select {$name}({$p}) as result";
            $query = $this->mQuery($sql);
            if (null !== ($row = $query->fetch_assoc())){
                return $row['result'];
            }

            return null;
        }

    }

}
?>