<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */


namespace tariqa3{

	/**
	 * Base class for all modules that requires language packs
	 * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class BaseModuleWithAuthenticationAndLanguages extends BaseModuleWithAuthentication {

		/**
		 * The whole translationTable for current language
		 * @var array
		 */
		public $translationTable;
		/**
		 * Build the module and parse the config file
		 * @param array $config The multidimentionnal config array
		 * @param string $charset Character set of the module's output
		 */
		public function __construct( $config, $charset = 'UTF-8' ) {
			parent::__construct( $config, $charset );
		}

		/**
		 * At initialisation, request authentication, or throw an exception on failure
		 */
		protected function onInitialize() {
			parent::onInitialize();
			if (isset($this->db) && $this->db != null){
				statics::load_user_prefs($this->user, $this->db);
				$user_id = $this->db->real_escape_string($this->user->user_id);
				$sql = "insert ignore into known_users(user_id, first_access) values('{$user_id}', now())";
				$this->db->mQuery($sql);
				$newstickers = $this->user->get_preference('general/newstickers');
				if ($newstickers == null){
					$s = 'title=' . $this->config['newstickers']['feed'][0]['title'] . '&speed=1&url=' . \MetaNull\Tools\mTools::rawurlencode($this->config['newstickers']['feed'][0]['url']);
					$this->user->set_preference('general/newstickers/0', $s, $this->db);
					$s = 'title=' . $this->config['newstickers']['feed'][1]['title'] . '&speed=1&url=' . \MetaNull\Tools\mTools::rawurlencode($this->config['newstickers']['feed'][1]['url']);
					$this->user->set_preference('general/newstickers/1', $s, $this->db);
				}
			}
			\tariqa3\statics::loadTariqaClient($this->user);
		}
		/**
		 * Get the translated text corresponding to a key or to a set of keys
		 * @param string|array|object $keys The key, an array of keys, or an object (properties used as keys)
		 * @return string|array|object Returns the tanslated text or an array or object containing translated text
		 */
		final public function translate( $keys ) {
			if( is_string( $keys )) {
				return $this->translateInternals( $keys );
			}
			if( is_array( $keys )) {
				$trslArray = array();
				foreach( $keys as $k => $v ) {
					$trslArray[$k] = $this->translate($v);
				}
				return $trslArray;
			}
			if( is_object( $keys )) {
				$o = $this->translate((array)$keys);
				foreach( $o as $k => $v ) {
					if( property_exists( get_class($keys), $k)) {
						$keys->$k = $v;
					}
				}
				return $keys;
			}
			return null;
		}
		/**
		 * Get the translated text associated to a specific key
		 * @param string $section The section's id
		 * @param string $key The text's key
		 * @return string
		 */
		final private function translateInternals( $key ) {
			if( !is_string( $key )) {
				throw new \InvalidArgumentException( '$keys argument must be of string type' );
			}
			if(!array_key_exists($key, $this->translationTable)) {
				return null;
			}
			return $this->translationTable[$key];
		}

	}
}
?>