<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

	/**
	 * Logoff from ECAS
	 * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class ECASLogoff extends \MetaNull\Application\mModule {
		
		/**
		 * The Authentication object
		 * @var MetaNull::Commission::EC_Authentication $auth
		 */
		protected $auth = false;

		/**
		 * Constructor: Construct an iAuthentication object
		 */
		public function __construct( $config ) {
			parent::__construct( $config );
			$this->auth = new \MetaNull\Commission\EC_Authentication( $this->config['application']['name'], $this->config['application']['url'], $this->config['security']['ssl-certificate']);
		}

		/**
		 * OnInitialisation, check if a session is already established.
		 * If yes, terminates it (it then redirects to the homepage but this is a behaviour of the iAuthentication implementation)
		 * Otherwise, just return to the homepage of the application
		 */
		protected function onInitialize() {
			parent::onInitialize();

			/**
			 * Start the HTTP session, <b>WITHOUT</b> requesting authentication
			 */
			$this->auth->startSession( false );
			/**
			 * If a session is established, closes it
			 */
			if( $this->auth->sessionEstablished() ) {
				$this->auth->endSession( true );
			}
			/**
			 * Else, go back to the home page
			 */
			else {
				header( 'Location: ' . $this->config['application']['url'] );
				exit();
			}
		}

		/**
		 * Process requests containing the "logoff" argument
		 */
		public function canProcessRequest() {
			return isset( $_GET['logoff'] ) ? true : false;
		}

		/**
		 * In the logoff module, the code is terminated right after the onInitialize method(which is in allcase redirecting the user)
		 * This method is therefore ne ver called (it must still be implemented as it is an abstract method of the parent class)
		 */
		protected function onExecute() {
			return "";
		}

		public function hasUpdatedConfiguration() {
			return false;
		}
	}
}
?>