<?php

	/**
	 * Containes information about a country
	 * @author Pascal Havelange
	 * @copyright  EUROPEAN COMMISSION, 2008
	 * */
	class Country {

		/**
		 * ISO 3166(2 alpha)
		 * @var string
		 * */
		public $code_iso2;
		
		/**
		 * ISO 3166(3 alpha)
		 * @var string
		 * */
		public $code_iso3;
		
		/**
		 * ISO 3166(numeric)
		 * @var int
		 * */
		public $code_isonum;
		
		/**
		 * E.C. COMREF PriKey
		 * @var string
		 * */
		public $code_comref;
		
		/**
		 * E.C. COMREF PriKey - Used in the CRF_DELEGATIONS table (sometimes it is out of synch with the primary code)
		 * @var string
		 * */
		public $code_comref_deleg;
		
		/**
		 * E.C. SYSPER2
		 * @var string
		 * */
		public $code_sysper2;
		
		/**
		 * Internet Assigned Numbers Authority
		 * @var string
		 * */
		public $code_iana;
		
		/**
		 * International Olympic Committee
		 * @var string
		 * */
		public $code_ioc;
		
		/**
		 * U.N. International Traffic Distinguished Signs
		 * @var string
		 * */
		public $code_un;
		
		/**
		 * I.T.U Codes for International Telephone calls
		 * @var string
		 * */
		public $code_itu;
		
		/**
		 * Name of the country in english
		 * @var string
		 * */
		public $name;
		
		/**
		 * If true, the country is a member of the European Union
		 * @var boolean
		 * */
		public $eu_member;
		
		/**
		 * If truen the country is officially recognised
		 * @var boolean
		 * */
		public $official;
		
		/**
		 * ISO2 Id of the Country 'owning' this land
		 * @var string
		 * */
		public $parent_code_iso2;
		
		/**
		 * Continent Id
		 * @var string
		 * @see Continent
		 * */
		public $continent_id;
		
		/**
		 * Oxford Analytica Country Name
		 * @var string
		 * */
		public $oxan_id;
		
		/**
		 * True if the country is a hotspot in the current day, False otherwise
		 * @var boolean
		 * */
		public $hotspot;
		
		/**
		 * Id of the cluster to which the country is belonging to
		 * @var int
		 * */
		public $cluster_id;
		
		/**
		 * The official region identifier
		 * @var int
		 * @access public
		*/
		public $region_id;

		/**
		 * The list of ReliefWeb maps
		 * @var ReliefWebMap[]
		 * @access public
		 */
		public $relief_web_maps = null;

		/**
		 * The list of GlobalAtlas maps
		 * @var GlobalAtlas[]
		 * @access public
		 */
		public $global_atlas_maps = null;

		/**
		 * The Wikipedia country profile
		 * @var WikipediaCountryProfile
		 * @access public
		 */
		public $wiki_data = null;
		
	}
?>