<?php

	/**
	 * Request object used by the Tariqa::fetchUrl() operation
	 * @see Tariqa::fetchUrl
	 * */
	class WebRequest {
		
		/**
		 * HTTP GET method
		 * */
		const HTTP_GET = "get";
		/**
		 * HTTP POST method
		 * */
		const HTTP_POST = "post";
		/**
		 * HTTP HEAD method
		 * */
		const HTTP_HEAD = "head";
		
		
		/**
		 * Default constructor
		 * @param string $url Url
		 * @param Pair[] $query An array of Pair containing the request arguments
		 * @param Pair[] $cookies
		 * @return WebRequest
		 * */
		public function __construct( $url, $query = false, $cookies = false, $method = self::HTTP_GET, $follow_redirect = true ) {
			$this->url = $url;
			$this->query = $query;
			$this->cookies = $cookies;
			$this->method = $method;
			$this->follow_redirect = $follow_redirect;
		}
		
		/**
		 * URL
		 * @var string
		 * */
		public $url;
		
		/**
		 * Cookies
		 * @var Pair[]
		 * */
		public $cookies;
		
		/**
		 * Query arguments
		 * @var Pair[]
		 * */
		public $query;
		
		/**
		 * HTTP Method
		 * @var string
		 * @see self::HTTP_GET
		 * @see self::HTTP_POST
		 * @see self::HTTP_HEAD
		 * */
		public $method;
		
		/**
		 * Follow redirections (up to three)
		 * @var boolean
		 * */
		public $follow_redirect;
	}
?>