<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

//require_once('UploadSection.class.php');
require_once('tariqa3/modules/sharing/Sharing.class.php');
/**
 * Section manager module (manages the horizontal sections of a page)
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
abstract class SpecialPage extends tariqa3Module {
    /**
     * The page template
     * @var MTemplate
     * @access protected
     */
    protected $template;

    /**
     * The page identifier
     * @var string
     * @access protected
     */
    protected $page_id;

    /**
     * The special page specific configuration array
     * @var array
     * @access protected
     */
    protected $own_config;

    /**
     * The list of flavours for the queries
     * @var Flavour[]
     * @access private
     */
    private $flavours;

    /**
     * The list of queries for the news
     * @var Query[][]
     * @access private
     */
    private $queries;

    /**
     * Constructs the object
     * @param string $page_id The page identifier
     * @param array $config The configuration array of the application
     * @access public
     * @return void
     */
    public function __construct($page_id, $config) {
	parent::__construct($config);
	$this->_isMenuable = false;
	$this->page_id = $page_id;
	$this->template = new \MetaNull\Application\MTemplate('m');
	$this->base_folder = 'modules/tariqa3/special_pages/' . $this->page_id;
	$this->own_config = \MetaNull\Tools\mConfig::loadConfiguration('config/special_pages/' . $this->page_id . '.xml', 'xml', $this->page_id . '_config');
	$this->info_setTitle($this->getTitle());
    }

    /**
     * Sets the page template
     * @param string $file_path The template file name
     * @access protected
     * @return void
     */
    protected function setTemplate($file) {
	$this->template->loadTemplate($file);
    }

    /**
     * Gets the page content
     * @access public
     * @return void
     */
    public function getPageContent() {
	$this->renderPage();
	return $this->template->transform();
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the name of the class (what it should appear in the menu
     * @access public
     * @return string
     */
    public function getName() {
	return $this->page_id;
    }

    /**
     * Returns the title of the page
     * @access public
     * @return string
     */
    public function getTitle() {
	return $this->own_config['page']['title'];
    }

    /**
     * Returns the description of the page
     * @access public
     * @return string
     */
    public function getDescription() {
	return $this->own_config['page']['description'];
    }

    /**
     * Gets the link of the module
     * @access public
     * @return string
     */
    public function getLink() {
	return statics::URL('special_page.php', 'module=' . $this->getName());
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$breadCrumb[] = new tariqa3ModuleDescriptor($this);
	return $breadCrumb;
    }

    /**
     * Gets the list of queries for the news
     * @access private
     * @return Query[][]
     */
    private function getQueries() {
	$queries = $this->own_config['news']['queries']['query'];
	$result = array();

	if (!isset($queries[0])){
	    $queries = array($queries);
	}

	foreach ($queries as $q) {
	    $query = statics::getQuery($q['id']);
	    if (!array_key_exists($q['tab'], $result)) {
		$result[$q['tab']] = array();
	    }

	    $i = 0;
	    while ($this->flavours[$i++]->flavour_id != $q['tab']){
	    }

	    $query->flavour = $this->flavours[$i - 1];
	    $query->block_description = $query->title;
	    $query->block_label = $query->title;
	    $query->block_display_order = $q['tab'];

	    $result[$q['tab']][] = $query;
	}

	return $result;
    }

    /**
     * Gets the list of flavours for the news
     * @param param_type $param_name param_desc
     * @access private
     * @return Flavour[]
     */
    private function getFlavours() {
	$flavours = $this->own_config['news']['tabs']['tab'];
	$result = array();
	if (!isset($flavours[0])){
	    $flavours = array($flavours);
	}
	foreach ($flavours as $flavour) {
	    $f = new \Flavour();
	    $f->flavour_id = $flavour['id'];
	    $f->name = $flavour['name'];

	    $result[] = $f;
	}

	return $result;
    }

    /**
     * Gets a news section for a special page
     * @access protected
     * @return string
     */
    protected function getNews() {
	$this->flavours = $this->getFlavours();
	$this->queries = $this->getQueries();

	$result = new NewsSection($this->config, 'modules/tariqa3/themes', 'news_tabs', $this->translationTable, $this->flavours, $this->queries, 'theme_page/' . $this->page_id . '/');
	$result->db = $this->db;
	$html = $result->run();
	$this->setMoreInfos($result->getInfo());

	$sharing = new Sharing($this->config, $this->translationTable);
	$html .= $sharing->run();
	$this->setMoreInfos($sharing->getInfo());

	$html .= $result->afterSection() . '<input type="hidden" id="theme_id" value="ifs"/>';
	
	return $html;
    }

    /**
     * Gets a document repository object (the HTML code)
     * @param string $id The HTML identifier
     * @param string $root_folder The root folder (relative path to the folder set through config file) [OPTIONAL]
     * @param string $title The title of the document repository [OPTIONAL]
     * @access protected
     * @return string
     */
    protected function getDocumentRepository($id, $root_folder = '', $title = null) {
	$config = $this->config;
	$result = new UploadSection($this->config, 'modules/tariqa3/themes', $id . '_section', $this->translationTable, $this->page_id, $id, $root_folder, $title);
	$result->db = $this->db;
	$html = $result->run();
	$this->setMoreInfos($result->getInfo());

	return $html;
    }
}
}
?>
