<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

	require_once('tariqa3/modules/Countries/NewsSection.class.php');

	/**
     * Generic class for handling the AJAX calls on the server side
	 * @author Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2010
     * @package tariqa3
	 * @license http://ec.europa.eu/idabc/eupl
     */
	class Ajax extends baseModule_RELEX_TARIQANG {

		/**
		 * The term to filter
		 * @var string
		 * @access private
		 * @static
		 */
		private static $term;

		/**
		 * Construct the Module object
		 * @param array $config The multidimentionnal array containing the application's configuration
		 */
		public function __construct( $config ) {
			parent::__construct( $config );
		}

		/**
		 * Checks if an user has access to a requested URL
		 * @param string $user_id The user identifier
		 * @param string $url The url
		 * @access private
		 * @return boolean
		 */
		private static function hasAccess($user_id, $url) {
			return true;
		}

		/**
		 * Sets a list of urls to be fetched through multi ajax mechanism
		 * @param string $user_id The user identifier
		 * @param mMysql $db The database connection
		 * @param string[] $urls The list of urls
		 * @param string $delimiter The delimiter used in the list of urls [OPTIONAL]
		 * @access private
		 * @return string
		 */
		public function setMultiAjaxCall($user_id, $db, $urls, $delimiter = '###') {
			$user = $db->real_escape_string($user_id);
			//Check if the user has access to the requested URL (it could be that the URL is a news search - if so, check
			//if the user has access to the requested news engine)

			/*if (!self::hasAccess($user)) {
				throw new \Exception("User access denied to URL {$row["url"]}::USER -> {$user}");
			}*/

			$sql = "insert into `ajax_calls`(`user_id`) values('{$user}')";
			$db->mQuery($sql);
			//Insert the call into the ajax_calls and get the new ID
			$id = $db->last_insert_id();

			if ($id == null) {
				return '<error>Error fetching the multi call id</error>';
			}

			//Get the delimiter and split the url values
			//$delimiter = $_POST["delimiter"];
			$url_id = 1;
			$sql = '';
			foreach ($urls as $url) {
				$parts = explode($delimiter, $url);
				if (count($parts) != 3) continue;
				$url = $db->real_escape_string(htmlspecialchars_decode($parts[0]));
				$use_proxy = $db->real_escape_string($parts[1]);
				$method = $db->real_escape_string($parts[2]);
				$post_data = 'null';
				if ($method == 'post') {
					$post_data = explode('?', $url, 2);
					if (count($post_data) == 2) {
						$url = $post_data[0];
						$post_data = "'" . $post_data[1] . "'";
					}
				}
				$parts = explode('?', $url, 2);
				if (count($parts) > 1){
					$gets = statics::post2array($parts[1]);
					if (array_key_exists('multi_ajax_user', $gets)){
						throw new \Exception('You cannot have the multi_ajax_user_id variable set in the GET list');
					}
				}

				$url .= (strpos($url, '?') === false ? '?' : '&') . 'multi_ajax_user_id=' . $user_id;
				/*if (array_key_exists('set_user', $_GET)){
				}*/
				$sql .= ($sql == ''?'':', ') . "('{$id}', '{$url_id}', '{$url}', '{$method}', '{$use_proxy}', {$post_data})";
				$url_id++;
			}
			//Insert all urls in the ajax_call_url - from here, the multicall service will process them
			$sql = "insert into `ajax_call_urls`(`call_id`, `url_id`, `url`, `method`, `use_proxy`, `post_fields`) values {$sql}";
			$db->mQuery($sql);

			//Trigger the call to the service
			$sql = "select callMUdfService('{$this->config['modules']['ajax']['multi-download']['host']}', {$this->config['modules']['ajax']['multi-download']['port']}, 'MULTI', '{$id}') as result";
			$query = $db->mQuery($sql);

			//Check the result
			if (false !== ($row = $query->fetch_assoc())) {
				//If it is null, the service is probably down - inform the user
				if ($row["result"] == null) {
					error_log('Error processing the multi ajax URLS. Probably the service is down. ');
					$error = 'MultiAjax error';//$this->translate('page/multiAjax/serviceDown');
					return "<call_id>{$id}</call_id><error>{$error}</error>";
				}
			}
			//Return the new ID
			return "<call_id>{$id}</call_id>";
		}

		/**
		 * Processes a list of urls in a multithreading fashion
		 * @access protected
		 * @return string
		 */
		protected function multiAjax() {
			if (!array_key_exists('what', $_GET)) return null;
			$db = statics::open_db_connection($this->config['database']);

			switch ($_GET["what"]) {
				//First step, set the urls
				case 'set_urls': {
					return $this->setMultiAjaxCall($this->user->user_id, $db, $_POST['url'], $_POST['delimiter']);
					}break
					;
				//Step 2, check the results
				case 'check_result': {
						$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
						//Get the user who is requesting the response
						$user = $this->user->user_id;
						$cond = '';
						//Check all the requests registred by this user
						foreach ($_GET["call_ids"] as $id) {
							$cond .= ($cond == ''?'':' or ') . ' `call_id` = ' . $db->real_escape_string($id);
						}

						if ($cond == '') {
							throw new \Exception("No CALL ID set");
						}

						//Set a timeout
						$timeout = $newsConfig['search']['default']['timeout'];
						$sql = "select * from `ajax_calls` where ({$cond}) and date_add(`call_time`, interval {$timeout} second) >= now()";
						$query = $db->mQuery($sql);

						while ($row = $query->fetch_assoc()) {
							//If a user is requesting the response for a call id that was not registred by him, throw an error.
							if ($row["user_id"] != $user) {
								throw new \Exception("User {$user} did not registred the call {$row["call_id"]}");
							}
						}
						//Get all the urls
						$sql = "select * from `ajax_call_urls` inner join `ajax_calls` using(`call_id`) where ({$cond}) and date_add(`call_time`, interval {$timeout} second) >= now()";

						$query = $db->mQuery($sql);
						$error = '';

						if ($query->num_rows == 0) {
							//If there is no url delete any possible URL left behind
							$sql = "delete from `ajax_calls` where ({$cond}) and date_add(`call_time`, interval {$timeout} second) >= now()";
							$db->mQuery($sql);
							//Check if there are urls which took longer than the timeout
							$sql = "select * from `ajax_calls` where ({$cond}) and date_add(`call_time`, interval {$timeout} second) < now()";
							$query = $db->mQuery($sql);
							if ($query->num_rows != 0) {
								//If so, report them to the user
								$ids = '';
								while ($row = $query->fetch_assoc()) {
									$ids .= ($ids == ''?'':', ') . $row["call_id"];
								}

								$tpl = new \MetaNull\Application\MTemplate('m');
								$tpl->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/error_message.html');
								$tpl->data['id'] = $ids;
								$tpl->data['url'] = statics::URL('index.php', 'module=timeout_error&ids=' . \MetaNull\Tools\mTools::rawurlencode($ids));
								$error = '<error><![CDATA[' . $tpl->transform() . ']]></error>';
								error_log("There was a timeout processing the following calls {$ids}");
							}

							//Inform the client that there are no more results to be expected
							return '<no_more_results>true</no_more_results>' . $error;
						}

						$result = '';
						$delete = '';

						while ($row = $query->fetch_assoc()) {
							//If there are urls, check that the user who is requesting them has the right to access them.
							if (!$this->hasAccess($user, $row["url"])) {
								throw new \Exception("User access denied to URL {$row["url"]}::USER -> {$user}");
							}
							if ($row["http_code"] != null) {
								//If we actually have a response, return it to the user
								$content = \MetaNull\Tools\mTools::rawurlencode($row["call_content"]);
								$response = <<<xml
<call_id>{$row["call_id"]}</call_id>
<url_id>{$row["url_id"]}</url_id>
<url><![CDATA[{$row["url"]}]]></url>
<http_code>{$row["http_code"]}</http_code>
<call_content><![CDATA[{$content}]]></call_content>
<call_content_length>{$row["call_content_length"]}</call_content_length>
<call_header><![CDATA[{$row["call_header"]}]]></call_header>
<call_error>{$row["call_error"]}</call_error>
<duration>{$row["duration"]}</duration>
<last_update>{$row["last_update"]}</last_update>
<method>{$row["method"]}</method>
xml;

								if ($row["http_code"] != 200) {
									error_log($row["url"] . ' got a ' . $row["http_code"] . ' code');
								}

								$result .= "<response>{$response}</response>";
								//And delete it from the list
								$delete .= ($delete == ''?'':' or ') . "(`url_id` = '{$row["url_id"]}' and `call_id` = '{$row["call_id"]}')";
							}
						}

						if ($delete != '') {
							$sql = "delete from `ajax_call_urls` where ({$delete})";
							$db->mQuery($sql);
						}
						if ($result == '') return '<no_response>true</no_response>';
						else {
							$sql = <<<sql
select
								call_id
from
								`ajax_calls` left join `ajax_call_urls` using(`call_id`)
where
								({$cond}) and date_add(`call_time`, interval {$timeout} second) >= now() and `ajax_call_urls`.`call_id` is null
group by `call_id`

sql;

							$query = $db->mQuery($sql);
							while ($row = $query->fetch_assoc()) {
								$result .= "<finished_call>{$row["call_id"]}</finished_call>";
								$sql = "delete from ajax_calls where call_id = '{$row['call_id']}'";
								$db->mQuery($sql);
							}
						}

						return $result;
					}break
					;
			}
		}

		/**
		 * Callback function used to filter the countries array
		 * @param Country $country An item of the array (a country)
		 * @access private
		 * @static
		 * @return boolean
		 */
		private static function countriesArrayFilter($country) {
			return (strpos(strtolower($country->name), strtolower($_GET['term'])) === false?false:true);
		}

		/**
		 * Performs a country search
		 * @access protected
		 * @return string
		 */
		protected function searchCountry() {
			$countries = statics::listCountries();
			$countries = array_filter($countries, array($this, 'countriesArrayFilter'));
			/* @var $country Country */
			$results = array();
			foreach ($countries as $country){
				$results[] = array(
					'id' => $country->code_iso2,
					'label' => $country->name,
					'value' => $country->name,
				);
			}

			return json_encode($results);
		}

		/**
		 * Callback function used to filter the tags array
		 * @param string $tag An item of the array
		 * @access private
		 * @static
		 * @return boolean
		 */
		private static function tagsArrayFilter($tag) {
			return (strpos(strtolower($tag), strtolower(self::$term)) === false?false:true);
		}

		/**
		 * Performs a tags search
		 * @access protected
		 * @return string
		 */
		protected function searchTags() {
			$db = statics::open_db_connection($this->config['database']);

			$pattern1 = '/[\t|\n|\r|,|\:|\.|\-]/i';
			$pattern2 = '/([ ]+)/';
			$terms = \preg_replace($pattern1, ' ', $_GET['term']);
			$terms = \preg_replace($pattern2, ' ', $terms);

			$terms = explode(" ", $terms);
			self::$term = $terms[count($terms) - 1];
			$st = $db->real_escape_string(self::$term);

			$sql = "select lower(`data`) as 'data' from user_preferences where `key` = 'general/tags' and `data` like '%{$st}%'";
			$query = $db->mQuery($sql);
			$tags = '';

			while ($row = $query->fetch_assoc()){
			$tags .= ($tags == '' ? '' : ' ') . $row['data'];
			}

			$tags = \preg_replace($pattern1, ' ', $tags);
			$tags = \preg_replace($pattern2, ' ', $tags);

			$tags = explode(' ', $tags);
			$tags = array_filter($tags, array($this, 'tagsArrayFilter'));

			$tags = \array_unique($tags);

			$results = array();
			foreach ($tags as $tag){
				$results[] = array(
					'id' => $tag,
					'label' => $tag,
					'value' => $tag,
				);
			}

			return json_encode($results);
		}

		/**
		 * Gets the id and the user preferences section for a filter update in the news section
		 * @access protected
		 * @return array
		 */
		protected function getSectionId() {
			$id = null;
			$pref = null;
			if (array_key_exists('country_id', $_GET)) {
				$id = $_GET['country_id'];
				$pref = 'country_page';
				$folder = 'Countries';
			}
			else if (array_key_exists('theme_id', $_GET)) {
				$id = $_GET['theme_id'];
				$pref = 'theme_page';
				$folder = 'Themes';
			}
			else if (array_key_exists('home_page', $_GET)){
				$id = 0;
				$pref = 'home_page';
				$folder = 'RiskMap';
			}
			else if (array_key_exists('news_wires', $_GET)){
				$id = 0;
				$pref = 'news_wires';
				$folder = 'NewsWires';
			}

			return array(
				'id' => $id,
				'pref' => $pref,
				'folder' => $folder,
			);
		}

		/**
		 * Removes a filter for a given query
		 * @access protected
		 * @return string
		 */
		protected function removeFilter() {
			$db = statics::open_db_connection($this->config['database']);
			$section = $this->getSectionId();
			$id = $section['id'];
			$pref = $section['pref'];
			//When removing a filter for a country page, just remove it from the database from the user preferences
			$this->user->set_preference($pref . '/' . $id . '/queries/filters/' . $_GET['query_id'], null, $db);
			$query = statics::getQuery($_GET['query_id']);
			$source_name = \MetaNull\Tools\mTools::rawurlencode($query->title);
			//And the return the flavour_id and the query_id, which are needed by JS to modify the HTML of the page
			return "<flavour_id>{$_GET['flavour_id']}</flavour_id><query_id>{$_GET['query_id']}</query_id><source_name>{$source_name}</source_name>";
		}

		/**
		 * Sets a filter for a given query and a given flavour on a country page
		 * @access protected
		 * @return string
		 */
		protected function setFilter() {
			$db = statics::open_db_connection($this->config['database']);

			//Construct the filter string from the POST values. The filter string is like query=my_search_string&start_date=date&end_date=date
			$filter = '';
			if (array_key_exists('query', $_POST)) {
				$filter .= 'query=' . $_POST['query'];
			}
			if (array_key_exists('start_date', $_POST)) {
				$filter .= ($filter == ''?'':'&') . 'start_date=' . $_POST['start_date'];
			}
			if (array_key_exists('end_date', $_POST)){
				$filter .= ($filter == ''?'':'&') . 'end_date=' . $_POST['end_date'];
			}

			$section = $this->getSectionId();

			error_log($section['pref'] . '/' . $section['id'] . '/queries/filters/' . $_GET['query_id']);

			//Set it into the user preferences
			$this->user->set_preference($section['pref'] . '/' . $section['id'] . '/queries/filters/' . $_GET['query_id'], $filter, $db);

			//Get the query which we are filtering
			$query = statics::getQuery($_GET['query_id']);
			$start_date = null;
			$end_date = null;

			//Just to be sure that the query object also has the flavour set up (will be used by the renderCustomFilter static function)
			NewsSection::setFlavour($section, $query);

			//Render the custom filter
			$filter = NewsSection::renderCustomFilter($filter, $query, $this->translationTable, $this->config['templates']['baseurl'] .
					'/' . $this->config['templates']['default'] . '/modules/tariqa3/' . $section['folder'] . '/NewsSection', $_GET['flavour_id']);
			$html = rawurlencode($filter['html']);

			//\MetaNull\Tools\mDump::dumpVariable($html);

			//The query text will include the filtering part (if defined by the user) translated into specific syntax
			$query_txt = rawurlencode($filter['query']);
			if ($filter['start_date'] != null) $start_date = $filter['start_date'];
			if ($filter['end_date'] != null) $end_date = $filter['end_date'];

			if ($start_date == null || $end_date == null){
				$c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
				if (!array_key_exists('string', $c)){
					$range = new timeRange($query->time_range);
					if ($start_date == null) $start_date = $range->getStartDate();
					if ($end_date == null) $end_date = $range->getEndDate();
				}
			}

			$specific_data = 'source_name%3D' . \MetaNull\Tools\mTools::rawurlencode($query->title);
			if (strpos($query->source->engine_id, 'aggregator') !== false){
				$specific_data .= "%26feed_id%3D{$query->query}";
			}

			$specific_data = '<specific_data>' . $specific_data . '</specific_data>';

			$dates = ($start_date == null?'':"<start_date>{$start_date}</start_date>") .
				($end_date == null?'':"<end_date>{$end_date}</end_date>");

			//Return the data. All the HTML processing will be done via Javascript.

			return "<flavour_id>{$_GET['flavour_id']}</flavour_id><query_id>{$_GET['query_id']}</query_id><html>{$html}</html>" .
				"<query><txt>{$query_txt}</txt><source_id>{$query->source_id}</source_id>" .
				"{$dates}</query>" .
				$specific_data;
		}

		/**
		 * Deletes a tab
		 * @access protected
		 * @return string
		 * */
		protected function deleteTab() {
			$db = statics::open_db_connection($this->config['database']);
			statics::load_user_prefs($this->user, $db);
			$id = $_GET['id'];
			$pattern = '/^prefered_(country|theme)_([A-Za-z]*|[0-9]*)$/';
			\preg_match_all($pattern, $id, $matches);
			if (count($matches) == 3){
			$id = $matches[2][0];
			if ($matches[1][0] == 'country'){
				$countries = $this->user->get_preference('general/countries');
				foreach ($countries as $i => $country_id){
				if ($country_id == $id){
					$this->user->set_preference('general/countries/' . $i, null, $db);
					break;
				}
				}
			}
			else if ($matches[1][0] == 'theme'){
				$themes = $this->user->get_preference('general/themes');
				foreach ($themes as $i => $theme_id){
				if ($theme_id == $id){
					$this->user->set_preference('general/themes/' . $i, null, $db);
					break;
				}
				}
			}
			}

			return 'Ok';
		}

		   /**
		 * Changes the current source
		 * @access protected
		 * @return string
		 */
		protected function changeSource() {
			$db = statics::open_db_connection($this->config['database']);
			statics::load_user_prefs($this->user, $db);
			$section = $this->getSectionId();
			//Set the new query as source for the indicated flavour into the user preferences
			$this->user->set_preference($section['pref'] . '/' . $section['id'] . '/queries/flavours/' . $_GET['flavour_id'], $_GET['query_id'], $db);

			//See if this query is also filtered by the user
			$filters = $this->user->get_preference($section['pref'] . '/' . $section['id'] . '/queries/filters');

			$filter = null;
			if ($filters != null){
				if (array_key_exists($_GET['query_id'], $filters)) $filter = $filters[$_GET['query_id']];
			}

			//Get the query from the database
			$query = statics::getQuery($_GET['query_id']);
			$start_date = null;
			$end_date = null;
			NewsSection::setFlavour($section, $query);

			$query_txt = rawurlencode($query->query);

			//If the query is filtered, use the values indicated by the end user
			if ($filter != null){
				$filter = NewsSection::renderCustomFilter($filter, $query, $this->translationTable, $this->config['templates']['baseurl'] .
						'/' . $this->config['templates']['default'] . '/modules/tariqa3/' . $section['folder'] . '/NewsSection');
				$query_txt = rawurlencode($filter['query']);
			}

			//Get all the queries for the flavour that we are filtering, in order to regenerate the sources list (we have to exclude the new current
			//query and to add the one which was previously used.
			if (array_key_exists('country_id', $_GET)){
				$_queries = statics::listCountryQueries($_GET['country_id'], $this->user->get_access_level());
				$queries = array();

				/* @var $q Query */
				foreach ($_queries as $q){
					if ($q->flavour->flavour_id == $_GET['flavour_id']) {
						$queries[] = $q;
					}
				}
			}
			else if (array_key_exists('theme_id', $_GET)){
				if ($_GET['flavour_id'] == 0){
					$theme = statics::get_theme($_GET['theme_id']);
					if ($theme != null){
						$queries = Themes::listLatestNewsQueries($theme, $this->translationTable, $this->user);
					}
				}
				else {
					$topic = statics::getThemeTopic($_GET['flavour_id'], $this->user->get_access_level());
					$queries = Themes::listTopicQueries($topic);
				}
			}
			else if (array_key_exists('home_page', $_GET)){
				$flavour = statics::getFlavour($_GET['flavour_id']);
				$_queries = statics::getHomePageQueries($this->user->get_access_level(), $flavour, $this->translationTable);
				$queries = array();
				/* @var $query Query */
				foreach ($_queries as $_query){
					if ($_query->flavour->flavour_id == $flavour->flavour_id && $_query->query_id != $_GET['query_id']){
					$_query->block_label = $_query->title;
					$queries[] = $_query;
					}
				}
				//\MetaNull\Tools\mDump::dumpVariable($queries);
			}
			else if (array_key_exists('news_wires', $_GET)){
				$queries = statics::listQueries($this->user->get_access_level(), $this->config['news-wires']['weblogs-source']);
				$q = statics::getQuery($this->config['news-wires']['query_id']);
				$queries = array_merge(array($q), $queries);
				$i = 1;
				$flavour = new \Flavour();
				$flavour->flavour_id = 0;
				foreach ($queries as $q){
					$q->flavour = $flavour;
					$q->block_display_order = $i++ * 10;
					$q->block_label = $q->title;
					$q->block_description = $q->title;
				}
			}

			//Get the new sources list
			$sources_list = NewsSection::getSourcesList($query, $queries, $this->config['templates']['baseurl'] .
				'/' . $this->config['templates']['default'] . '/modules/tariqa3/' . $section['folder'] . '/NewsSection/sources_list.html', $this->translationTable);

			//If the sources list is empty (although it should never be the case), use a &nbsp; instead of just leaving the div empty. If the
			//div is left empty, all results div will be included one into the next one, instead of beeing displayed one after the other
			//This looks like a bug in all the major browsers (IE, FF, Chrome). Not sure if it's true. Safest way is to use this workaround
			$html = ($filter == null?\MetaNull\Tools\mTools::rawurlencode('&nbsp;'):\MetaNull\Tools\mTools::rawurlencode($filter['html']));
			if ($filter['start_date'] != null) $start_date = $filter['start_date'];
			if ($filter['end_date'] != null) $end_date = $filter['end_date'];

			$sources_list = \MetaNull\Tools\mTools::rawurlencode($sources_list['html']);

			//Load the news config for the default values
			$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

			$range = new timeRange($query->time_range);

			$flavour_query = 'query_id=' . $query->query_id .
					'&query=' . \MetaNull\Tools\mTools::rawurlencode($query->query) . '&range=' . $range->getDays() .
					'&source_id=' . $query->source_id . '&count=' . $newsConfig['search']['default']['results-per-page'];
			$flavour_query = \MetaNull\Tools\mTools::rawurlencode($flavour_query);

			//By default display the link with the filter news, but check if the new selected query has searching capabilities. If not, just don't
			//display the filter the news and save search to briefcase links
			$filter_display = 'block';
			if (array_key_exists($query->engine->engine_id, $newsConfig['search']['default']['no-search'])){
				$filter_display = 'none';
			}

			//If the query is an aggregated one, then set the feed_id as specific data.
			$specific_data = '';
			if (strpos($query->source->engine_id, 'aggregator') !== false){
				$q = \MetaNull\Tools\mTools::rawurlencode($query->query);
				$t = \MetaNull\Tools\mTools::rawurlencode($query->title);
				$specific_data = "<specific_data>feed_id%3D{$q}%26source_name%3d{$t}</specific_data>";
			}

			if ($query->source->engine_id == "LatestNews"){
				$t = \MetaNull\Tools\mTools::rawurlencode($query->title);
				$specific_data = "<specific_data>source_name={$t}</specific_data>";
			}

			if ($start_date == null || $end_date == null){
				$c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
				if (!array_key_exists('string', $c)){
					$range = new timeRange($query->time_range);
					$start_date = $range->getStartDate();
					$end_date = $range->getEndDate();
				}
			}

			$dates = '';
			if ($start_date != null) $dates .= "<start_date>{$start_date}</start_date>";
			if ($end_date != null) $dates .= "<end_date>{$end_date}</end_date>";

			return <<<xml
<flavour_id>{$_GET['flavour_id']}</flavour_id>
<query_id>{$_GET['query_id']}</query_id>
<html>{$html}</html>
<query>
	<txt>{$query_txt}</txt>
	<source_id>{$query->source_id}</source_id>
	{$dates}
</query>
<sources_list>{$sources_list}</sources_list>
<flavour_query>{$flavour_query}</flavour_query>
<filter_display>{$filter_display}</filter_display>
$specific_data;
xml;
		}

		/**
		 * Saves a country page or thematic page search to the briefcase
		 * @param boolean $just_return_params If set to true, does not execute the saving, but just returns the post data and get data [OPTIONAL]
		 * @access protected
		 * @return string
		 */
		protected function saveSearchC($just_return_params = false) {
			//Get the query for which we are saving the search
			$query = statics::getQuery($_GET['query_id']);

			$db = statics::open_db_connection($this->config['database']);
			statics::load_user_prefs($this->user, $db);
			$section = $this->getSectionId();
			$filters = $this->user->get_preference($section['pref'] . '/' . $section['id'] . '/queries/filters');
			$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

			//See if the query is filtered. If true, then include also the user defined values into the search
			$filter = null;
			if (array_key_exists($_GET['query_id'], $filters)) $filter = $filters[$_GET['query_id']];

			$start_date = null;
			$end_date = null;

			$query_txt = \MetaNull\Tools\mTools::rawurlencode($query->query);

			if ($filter != null){
				//Render the custom filter. We will not use the HTML returned by the function, but we will use the other values
				$filter = NewsSection::renderCustomFilter($filter, $query, $this->translationTable, $this->config['templates']['baseurl'] .
						'/' . $this->config['templates']['default'] . '/modules/tariqa3/Countries');

				if (array_key_exists('start_date', $filter)) if ($filter['start_date'] != null) $start_date = date('Y-m-d', $filter['start_date']);
				if (array_key_exists('end_date', $filter)) if ($filter['end_date'] != null) $end_date = date('Y-m-d', $filter['end_date']);
				$query_txt = \MetaNull\Tools\mTools::rawurlencode($filter['query']);
			}

			$c = null;

			if ($start_date == null || $end_date == null){
				$c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
				if (!array_key_exists('string', $c)){
					$range = new timeRange($query->time_range);
					if ($start_date == null) $start_date = $range->getStartDate();
					if ($end_date == null) $end_date = $range->getEndDate();
				}
			}
			else {
				$start_date = strtotime($start_date);
				$end_date = strtotime($end_date);
			}

			//Generate the POST data and the GET data for the search to be saved in the database. These data differ for each engine in the
			//full search list
			$get_data = statics::URL('index.php', 'module=search&type=3&search_type=2');
			switch ($query->source->engine_id){
				case 'LexisNexis':
					if ($c == null || !array_key_exists('string', $c)){
						$query_txt .= ' ' . $query->time_range;
						$start_date = '';
						$end_date = '';
					}
					$sources_names = \MetaNull\Tools\mTools::rawurlencode($query->source->description);
					$post_data = "selected=0&engine=LexisNexis&query={$query_txt}&start_date={$start_date}&end_date={$end_date}" .
						"&results_per_page={$newsConfig['search']['default']['results-per-page']}&sort_by=Implied&sources_select=" .
						"&selected_sources={$query->source->source_data}&selected_sources_names={$sources_names}";
					break;
				case 'LatestNews':
					$range = '';
					$range_days = '';
					if ($start_date != null) $range = floor((time() - $start_date) / (60 * 60 * 24));
					if ($end_date != null) $range_days = $range - floor((time() - $end_date) / (60 * 60 * 24));
					$post_data = "selected=1&engine=LatestNews&query={$query_txt}&range={$range}&range_days={$range_days}" .
						"&results_per_page={$newsConfig['search']['default']['results-per-page']}";
					break;
				case 'Google':
				case 'GoogleWeb':
				case 'GoogleNews':
				case 'GoogleBlogs':
				case 'GoogleImages':
					if ($c == null || !array_key_exists('string', $c)){
						$query_txt .= ' ' . $query->time_range;
						$start_date = '';
						$end_date = '';
					}

					$selected = ($query->source->engine_id == 'GoogleWeb' || $query->source->engine_id == 'Google'?2:
						($query->source->engine_id == 'GoogleNews'?3:
						($query->source->engine_id == 'GoogleBlogs'?4:
						($query->source->engine_id == 'GoogleImages'?5:-1))));
					$engine = $query->source->engine_id;
					if ($engine == 'Google') $engine = 'GoogleWeb';
					$post_data = "selected={$selected}&engine={$engine}&query={$query_txt}&" .
						"&results_per_page={$newsConfig['search']['default']['results-per-page']}";
					break;
				case 'LatestNews_aggregator':
				case 'RSS_aggregator':
					if ($filter == null){
						$feed_id = $query_txt;
						$query_txt = '';
					}
					else {
						$feed_id = $query->query;
					}

					if ($query->source->engine_id == 'LatestNews_aggregator'){
						$feed = statics::$tariqaClient->GetAggregatedLatestnewsFeed(statics::$tariqaToken, $feed_id);
					}
					else if ($query->source->engine_id == 'RSS_aggregator'){
						$feed = statics::$tariqaClient->GetAggregatedRSSFeed(statics::$tariqaToken, $feed_id);
					}

					$selected = ($query->source->engine_id == 'RSS_aggregator'?6:($query->source->engine_id == 'LatestNews_aggregator'?7:-1));

					$range = '';
					$range_days = '';
					if ($start_date != null) $range = floor((time() - $start_date) / (60 * 60 * 24));
					if ($end_date != null) $range_days = $range - floor((time() - $end_date) / (60 * 60 * 24));

					$post_data = "selected={$selected}&engine={$query->source->engine_id}&query={$query_txt}&range={$range}&range_days={$range_days}" .
						"&results_per_page={$newsConfig['search']['default']['results-per-page']}&selected_feed_{$query->source->engine_id}={$feed_id}" .
						"&feed_{$query->source->engine_id}={$feed->title}";
					break;
			}

			if ($just_return_params){
				return array(
					'post_data' => $post_data,
					'get_data' => $get_data,
				);
			}
			else {
				return Briefcase::saveSearch($this->user->user_id, $db, $get_data, $post_data, $_GET['title'], null);
			}
		}

		/**
		 * Moves an item to a folder (for the briefcase)
		 * @access protected
		 * @return string
		 */
		protected function briefcaseMoveToFolder() {
			$db = statics::open_db_connection($this->config['database']);
			$resp = Briefcase::moveItemToFolder($this->user->user_id, $db, $_GET['source_id'], ($_GET['dest_id'] != 'null'?$_GET['dest_id']:null));

			if ($resp){
				return '<response>Ok</response>';
			}
			else {
				return '<response>Failed</response>';
			}
		}

		/**
		 * Moves a folder to another folder
		 * @access protected
		 * @return string
		 */
		protected function briefcaseMoveFolder() {
			$db = statics::open_db_connection($this->config['database']);
			$resp = Briefcase::moveFolder($this->user->user_id, $db, $_GET['source_id'], ($_GET['dest_id'] != 'null'?$_GET['dest_id']:null));

			if ($resp){
				return '<response>Ok</response>';
			}
			else {
				return '<response>Failed</response>';
			}
		}

		/**
		 * Search for an RSS or LatestNews aggregated feed
		 * @access protected
		 * @return string
		 */
		protected function searchFeed() {
			return FullAggregators::searchFeed($this->user, $_GET['term'], $_GET['type']);
		}

		/**
		 * Shares a search from a country page or a thematic page
		 * @access protected
		 * @return string
		 */
		protected function shareSearchC() {
			$data = $this->saveSearchC(true);
			//\MetaNull\Tools\mDump::dumpVariable($data);
			$db = statics::open_db_connection($this->config['database']);
			$data['title'] = $_POST['title'];

			Sharing::shareItem($this->user, $db, $_POST['share_with'], $data, Sharing::SHARE_SEARCH, $_POST['message'], $this->config, $this->translationTable);
		}

		/**
		 * Shares a search from a user search
		 * @access protected
		 * @return string
		 */
		protected function shareSearch() {
			$db = statics::open_db_connection($this->config['database']);
			$data = array(
				'post_data' => $_POST['post_data'],
				'get_data' => $_POST['get_data'],
				'title' => $_POST['title'],
			);

			Sharing::shareItem($this->user, $db, $_POST['share_with'], $data, Sharing::SHARE_SEARCH, $_POST['message'], $this->config, $this->translationTable);
		}

		/**
		 * Search for a Lexis Nexis source
		 * @access protected
		 * @return string
		 */
		protected function searchLexisSource() {
			$query = new \LexisNexisSourceSearchRequest();
			$query->query = $_GET['term'];
			$query->locale = 'en-US';
			$query->useCSP = false;

			$response = statics::$tariqaClient->LexisNexisSourceSearch(statics::$tariqaToken, $query);
			$result = array();

			/* @var $source LexisNexisSource */
			foreach ($response->sources as $source){
				if (!empty($source->id)){
				$result[] = array(
					'id' => $source->id,
					'label' => $source->name,
					'value' => $source->name,
				);
				}
			}

			return json_encode($result);
		}

		/**
		 * Adds a folder to the briefcase
		 * @access protected
		 * @return string
		 */
		protected function addBriefcaseFolder() {
			$db = statics::open_db_connection($this->config['database']);

			$parent_id = null;
			$type = substr($_GET['parent_id'], 0, 2);
			$id = substr($_GET['parent_id'], 2);

			if ($type == 'T_'){
				$parent_id = null;
				$type_id = $id;
			}
			else if ($type == 'F_') {
				$parent_id = $id;
				$type_id = $db->get_value('briefcase_folders', 'type_id', 'folder_id = "' . $db->real_escape_string($id) . '"');
			}
			else {
				throw new \Exception('Folder id not defined');
			}

			return Briefcase::addFolder($this->user->user_id, $db, $parent_id, $type_id, $_GET['name']);
		}

		/**
		 * Deletes a folder from the briefcase
		 * @access protected
		 * @return string
		 */
		protected function deleteBriefcaseFolder() {
			$db = statics::open_db_connection($this->config['database']);
			$id = substr($_GET['id'], 2);
			return Briefcase::deleteFolder($this->user->user_id, $db, $id);
		}

		/**
		 * Renames an item from the briefcase
		 * @access protected
		 * @return string
		 */
		protected function briefcaseRenameContent() {
			$db = statics::open_db_connection($this->config['database']);
			$id = substr($_GET['id'], 2);
			return Briefcase::renameContent($this->user->user_id, $db, $id, $_GET['new_name']);
		}

		/**
		 * Renames a briefcase folder
		 * @access protected
		 * @return string
		 */
		protected function renameBriefcaseFolder() {
			$db = statics::open_db_connection($this->config['database']);
			$id = substr($_GET['id'], 2);
			return Briefcase::renameFolder($this->user->user_id, $db, $id, $_GET['new_name']);
		}

		/**
		 * Sets an user to insert articles into the briefcase
		 * @access protected
		 * @return string
		 */
		protected function briefcaseSaveArticles() {
			$db = statics::open_db_connection($this->config['database']);
			return Briefcase::saveArticles($this->user->user_id, $db, $this->config, $_POST['article_ids'], $_POST['titles']);
		}

		/**
		 * Deletes an item from the briefcase
		 * @access protected
		 * @return string
		 */
		protected function briefcaseDeleteContent() {
			$db = statics::open_db_connection($this->config['database']);
			return Briefcase::deleteContent($this->user->user_id, $db, substr($_GET['id'], 2));
		}

		/**
		 * Empty a folder from the briefcase
		 * @access protected
		 * @return string
		 */
		protected function emptyBriefcaseFolder() {
			$db = statics::open_db_connection($this->config['database']);
			Briefcase::emptyFolder($this->user->user_id, $db, ($_GET['folder_id'] == 'null'?null:$_GET['folder_id']), ($_GET['type_id'] == 'null'?null:$_GET['type_id']), ($_GET['subfolders'] == 'y'?true:false));
			return "<deleted>ok</deleted><subfolders>{$_GET['subfolders']}</subfolders>";
		}

		/**
		 * Moves a file or a folder from a source to a destination
		 * @access protected
		 * @return string
		 */
		protected function moveItem() {
			$result = UploadSection::moveItem($this->user, $_GET['page'], $_GET['root_folder'], $_GET['type'], $_GET['source'], $_GET['destination'], $this->translationTable, $this->config);
			$new_tree = '&nbsp;';
			if ($result == 'Ok'){
				$upload_path = UploadSection::getFolder($_GET['page'], $_GET['root_folder']);
				$tree = new FilesTree($upload_path, $this->translate('recycle_bin'), $_GET['tree_id'], UploadSection::canUpload($this->user, UploadSection::getFolder($_GET['page']), $this->config));
				$new_tree = \MetaNull\Tools\mTools::rawurlencode($tree->folderHTML('themes_files_tree', null));
			}
			return "<operation>{$result}</operation><new_tree>{$new_tree}</new_tree>";
		}

		/**
		 * Removes an file or a folder (used by the upload control
		 * @access protected
		 * @return string
		 */
		protected function deleteItem() {
			$result = UploadSection::removeItem($this->user, $_GET['page'], $_GET['root_folder'], $_GET['source'], $this->translationTable, $this->config);
			$new_tree = '&nbsp;';
			if ($result == 'Ok'){
				$upload_path = UploadSection::getFolder($_GET['page'], $_GET['root_folder']);
				$tree = new FilesTree($upload_path, $this->translate('recycle_bin'), $_GET['tree_id'], UploadSection::canUpload($this->user, UploadSection::getFolder($_GET['page']), $this->config));
				$new_tree = \MetaNull\Tools\mTools::rawurlencode($tree->folderHTML('themes_files_tree', null));
			}
			return "<operation>{$result}</operation><new_tree>{$new_tree}</new_tree>";
		}

		/**
		 * Creates a new folder (used by the upload control)
		 * @access protected
		 * @return string
		 */
		protected function uploaderCreateFolder() {
			$result = UploadSection::createFolder($this->user, $_GET['page'], $_GET['root_folder'], $_GET['name'], $this->translationTable, $this->config);
			$new_tree = '&nbsp;';
			if ($result == 'Ok'){
				$upload_path = UploadSection::getFolder($_GET['page'], $_GET['root_folder']);
				$tree = new FilesTree($upload_path, $this->translate('recycle_bin'), $_GET['tree_id'], UploadSection::canUpload($this->user, UploadSection::getFolder($_GET['page']), $this->config));
				$new_tree = \MetaNull\Tools\mTools::rawurlencode($tree->folderHTML('themes_files_tree', null));
			}
			return "<operation>{$result}</operation><new_tree>{$new_tree}</new_tree>";
		}

		/**
		 * Does an AJAX file upload
		 * @access protected
		 * @return void
		 */
		protected function doAjaxFileUpload() {
			$result = "";
			$msg = "";
			$fileElementName = 'fileToUpload_' . $_GET['tree_id'];
			if(!empty($_FILES[$fileElementName]['error']))
			{
				switch($_FILES[$fileElementName]['error'])
				{

					case '1':
						$result = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
						break;
					case '2':
						$result = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
						break;
					case '3':
						$result = 'The uploaded file was only partially uploaded';
						break;
					case '4':
						$result = 'No file was uploaded.';
						break;

					case '6':
						$result = 'Missing a temporary folder';
						break;
					case '7':
						$result = 'Failed to write file to disk';
						break;
					case '8':
						$result = 'File upload stopped by extension';
						break;
					case '999':
					default:
						$result = 'No error code avaiable';
				}
			}elseif(empty($_FILES[$fileElementName]['tmp_name']) || $_FILES[$fileElementName]['tmp_name'] == 'none')
			{
				$result = 'No file was uploaded..';
			}else
			{
				$upload_path = UploadSection::getFolder($_GET['page'], $_GET['root_folder']);
				if (substr($upload_path, -1) != '/') $upload_path .= '/';
				if (move_uploaded_file($_FILES[$fileElementName]['tmp_name'], $upload_path . $_FILES[$fileElementName]['name'])){
					$result = "Ok";
				}
				else {
					$result = "Could not upload file";
				}
			}

			$new_tree = '&nbsp;';
			if ($result == 'Ok'){
				$upload_path = UploadSection::getFolder($_GET['page'], $_GET['root_folder']);
				$tree = new FilesTree($upload_path, $this->translate('recycle_bin'), $_GET['tree_id'], UploadSection::canUpload($this->user, UploadSection::getFolder($_GET['page']), $this->config));
				$new_tree = \MetaNull\Tools\mTools::rawurlencode($tree->folderHTML('themes_files_tree', null));
			}
			return "<operation>{$result}</operation><new_tree>{$new_tree}</new_tree>";
		}

		/**
		 * Saves a search to the briefcase
		 * @param param_type $param_name param_desc
		 * @access protected
		 * @return string
		 */
		protected function briefcaseSaveSearch() {
			$db = statics::open_db_connection($this->config['database']);
			return Briefcase::saveSearch($this->user->user_id, $db, $_POST['get_data'], $_POST['post_data'], $_GET['title'], null);
		}

		/**
		 * Saves the short text and the long text in a thematic page
		 * @access protected
		 * @return string
		 */
		protected function themeSaveText() {
			$result = ThemeTextsSection::saveTexts($this->user, $_GET['theme_id'], rawurldecode($_POST['short_text']), rawurldecode($_POST['long_text']));
			\MetaNull\Tools\mCache::deleteVariable('themes/' . $_GET['theme_id']);
			\MetaNull\Tools\mCache::deleteVariable('themes/list');
			return $result;
		}

		/**
		 * Adds a tab on a thematic page needed to display a topic query
		 * @access protected
		 * @return string
		 */
		protected function topicAddTab() {
			$db = statics::open_db_connection($this->config['database']);
			statics::load_user_prefs($this->user, $db);
			return ThemeTopicsSection::generateTab($this->user, $_GET['topic_id'], $_GET['query_id'], $this->translationTable, $this->config['templates']['base']
				. '/' . $this->config['templates']['default'] . '/modules/tariqa3/Themes/NewsSection');
		}

		/**
		 * Saves the new prefered channel
		 * @access protected
		 * @return string
		 */
		protected function changeChannel() {
			$db = statics::open_db_connection($this->config['database']);
			$this->user->set_preference('live_stream/channel', $_GET['channel_id'], $db);
			return '';
		}

		/**
		 * Retrieves the LexisNexis sources for a given folder
		 * @access protected
		 * @return string
		 */
		protected function browseLexisNexisSources() {
			$folder_id = null;
			if (array_key_exists('folder_id', $_GET)) {
			$folder_id = $_GET['folder_id'];
			if ($folder_id == 'null'){
				$folder_id = null;
			}
			}

			$sources = statics::browseLexisNexisSources($folder_id);

			$tpl2 = new \MetaNull\Application\MTemplate('m');
			$tpl2->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/modules/tariqa3/Search/FullLexisNexis/sources_tree.html');

			$tpl2->data['sources'] = array();

			foreach ($sources->folders as $folder){
			$tpl2->data['sources'][] = array(
				'id' => $folder->id,
				'name' => $folder->name,
				'type' => 'folder',
				'click' => 'return false',
				'class_name' => 'jstree-closed',
			);
			}

			foreach ($sources->sources as $source){
			$tpl2->data['sources'][] = array(
				'id' => $source->id,
				'name' => $source->name,
				'type' => 'source',
				'click' => 'addSource(' . $source->id . ', "' . $source->name . '")',
				'class_name' => 'dummy',
			);
			}

			return $tpl2->transform();
		}

		/**
		 * Searches a country for the countries list page
		 * @access protected
		 * @return string
		 * */
		protected function searchCountriesByContinent() {
			$folder_id = null;
			if (array_key_exists('folder_id', $_GET) && $_GET['folder_id'] != 'null') {
			$folder_id = $_GET['folder_id'];
			}

			if ($folder_id == null){
			if (array_key_exists('init', $_GET)){
				$continent = statics::getContinent($_GET['init']);
				$tpl = new \MetaNull\Application\MTemplate('m');
				$tpl->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/modules/tariqa3/Countries/searchContinent.html');
				$tpl->data['id'] = $continent->continent_id;
				$tpl->data['name'] = $continent->name;
			}
			else {
				$continents = statics::listContinents();
				$tpl = new \MetaNull\Application\MTemplate('m');
				$tpl->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/modules/tariqa3/Countries/searchContinents.html');
				$tpl->data['continents'] = array();
				foreach ($continents as $continent){
				$tpl->data['continents'][] = array(
					'id' => $continent->continent_id,
					'name' => $continent->name
				);
				}
			}

			return $tpl->transform();
			}
			else {
			$tpl = new \MetaNull\Application\MTemplate('m');
			$tpl->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/modules/tariqa3/Countries/searchCountry.html');

			if (array_key_exists('init', $_GET)){
				$cid = $_GET['init'];
			}
			else {
				$cid = preg_replace('/^continent_([\d]*)$/', '\1', $_GET['folder_id']);
			}

			$tpl->data['continent_id'] = $cid;

			$tpl->data['countries'] = array();
			$countries = statics::listCountries($cid);
			/* @var $country Country */
			foreach ($countries as $country){
				$tpl->data['countries'][] = array(
				'id' => $country->code_iso2,
				'name' => $country->name,
				'onclick' => (array_key_exists('init', $_GET) ? "js_open('index.php?module=countries&country_id=@m:value=id@', '_self', 'get')" : "return false"),
				'ondblclick' => (array_key_exists('init', $_GET) ? 'return false' : "js_open('index.php?module=countries&country_id=@m:value=id@', '_self', 'get')"),
				);
			}

			return $tpl->transform();
			}
		}

		/**
		 * Render the module
		 * @return string
		 */
		public function onExecute() {
			$display = '';
			$root_node = "result";
			if (array_key_exists("root_node", $_GET)) $root_node = $_GET["root_node"];
			if (!array_key_exists("no_root_node", $_GET)) {
				$display .= "<{$root_node}";
				if (array_key_exists("root_node_params", $_GET)) {
					foreach ($_GET["root_node_params"] as $key => $value) {
						$display .= " {$key}=\"{$value}\"";
					}
				}
				$display .= ">";
			}
			try {
				if (array_key_exists("action", $_GET)) {
					$result = call_user_func(array($this, $_GET["action"]));
					if (!array_key_exists('output', $_GET) || $_GET["output"] == 'screen') {
						$display .= $result;
					}
					else if ($_GET["output"] == 'file') {
						$name = session_id();
						if (array_key_exists('fileName', $_GET)) $name = $_GET['fileName'];
						$name = $this->config['application']['tmp'] . '/' . $name;
						$f = fopen($name . $_SERVER["QUERY_STRING"], 'wb');
						fwrite($f, $result, strlen($result));
						fclose($f);
					}
				}
			}
			catch (\MetaNull\Tools\mysqlException $e) {
				error_log(\MetaNull\Tools\mDump::dumpVariable($e, true, false));
				$display = "<error>There was a problem with the database</error>";
				return $display;
			}
			catch (\Exception $e) {
				error_log(\MetaNull\Tools\mDump::dumpVariable($e, true, false));
				$display = "<error>There was a problem processing the ajax request. The error message is {$e->getMessage()}</error>";
				return $display;
			}
			if (!array_key_exists("no_root_node", $_GET)) {
				$display .= "</{$root_node}>";
			}

			return $display;
		}

		/**
		 * Gets the default template file
		 * @access public
		 * @return string|null
		 */
		public function getDefaultTemplateFile() {
			return "ajax.html";
		}

		/**
		 * Gets the applications headers set by the module
		 * @access public
		 * @return array
		 */
		public function getHeaders() {
			if (!array_key_exists('content_type', $_GET))
				return array("Content-type: text/xml; charset=utf-8");
			else {
				return array("Content-type: " . $_GET['content_type']);
			}
		}

		/**
		 * Process the request that have the page set to ajax
		 */
		public function canProcessRequest() {
			return array_key_exists("module", $_GET) && $_GET["module"] == "ajax";
		}

	}
}
?>