<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

    /**
     * Briefcase module
     * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
     */
    class BriefcaseFolder extends TreeFolder {
        /**
         * The article type
         * @var int

         */
        const ARTICLE = 1;

        /**
         * The search type
         * @var int

         */
        const SEARCH = 2;

        /**
         * The document type
         * @var int

         */
        const DOCUMENT = 3;

        /**
         * The location type
         * @var int

         */
        const LOCATION = 4;

        /**
         * The shared material type
         * @var int

         */
        const SHARED_ITEM = 5;

        /**
         * The type identifier
         * @var int
         * @access private
         */
        private $type_id;
        /**
         * A database connection (used to read the folder's subfolders and items)
         * @var mMysql
         * @access private
         */
        private $db;
        /**
         * The user identifier
         * @var string
         * @access private
         */
        private $user_id;

        /**
         * Constructs the object
         * @param mMysql $db A database connection (used to read the folder's subfolders and items)
         * @param string $user_id The user identifier
         * @param string $name The name of the folder
         * @param int $type_id The type identifier
         * @access public
         * @return void
         */
        public function __construct($db, $user_id, $type_id) {
            $config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE);
            $templates_folder = "{$config['templates']['base']}/{$config['templates']['default']}";
            parent::__construct($templates_folder . '/briefcase_folder.html', true, 'T_' . $type_id);
            $this->db = $db;
            $this->user_id = $user_id;
            $this->type_id = $type_id;
        }

        /**
         * Returns the subfolders of the current folder as an associative array with all the subfolders
         * @param int $folder_id The folder identifier
         * @access public
         * @abstract
         * @return array|boolean
         */
        public function getSubFolders($folder_id) {
            $parent_id_cond = '`parent_id` is null';
            if ($folder_id != null)
                $parent_id_cond = "`parent_id` = '{$folder_id}'";

            $sql = <<<sql
		select * from
			`briefcase_folders`
		where
			{$parent_id_cond} and `user_id` = '{$this->user_id}' and `type_id` = '{$this->type_id}'
		order by
			`name`
sql;

            $query = $this->db->mQuery($sql);
            $result = array();
            while ($row = $query->fetch_assoc()) {
                $result[] = array(
                    'name' => $row['name'],
                    'folder_id' => $row['folder_id'],
                    'type' => 'folder'
                );
            }

            $query->close();

            return $result;
        }

        /**
         * Returns the files of the current folder as an associative array
         * @param int $folder_id The folder identifier
         * @access public
         * @return array|boolean
         */
        public function getFiles($folder_id) {
            $result = array();

            $folder_id_cond = '`folder_id` is null';
            if ($folder_id != null)
                $folder_id_cond = "`folder_id` = '{$folder_id}'";
            $sql = <<<sql
		select * from
			`briefcase_content`
		where
			{$folder_id_cond} and `type_id` = '{$this->type_id}' and `user_id` = '{$this->user_id}'
		order by
			`display_order`, `content_id`
sql;

            $query = $this->db->mQuery($sql);

            while ($row = $query->fetch_assoc()) {
                if ($row['type_id'] == self::SHARED_ITEM) {
                    if ($row['item_id'] == null) {
                        $row['type_id'] = self::SEARCH;
                    } else {
                        $row['type_id'] = self::ARTICLE;
                    }
                }
                switch ($row['type_id']) {
                    case self::LOCATION:
                    case self::DOCUMENT:
                    case self::ARTICLE:
                        //$open_link = statics::URL('index.php', 'module=article&type=briefcase&id=' . $row['content_id']);
                        $open_link = 'js_open("' . statics::URL('index.php', 'module=article&type=briefcase&id=' . $row['content_id']) . '", "_self")';
                        break;
                    case self::SEARCH:
                        $data = explode("\n", $row['data']);
                        $get_data = $this->db->real_escape_string(\MetaNull\Tools\mTools::rawurldecode($data[0]));
                        $post_data = $this->db->real_escape_string(\MetaNull\Tools\mTools::rawurldecode($data[1]));
                        $open_link = "js_open('{$get_data}', '_self', 'post', '{$post_data}')";
                        break;
                }
		
		$name = $row['name'];
		
		if (statics::_isIE()){
			$name = preg_replace('/[\x0a|\x20]/', '', $name);
			if ($name == '') {
			    $name = '&nbsp;';
			}
			else {
			    $name = $row['name'];
			}
		}
		
		//if ($row['content_id'] == 1042){
		//var_dump($name); die();
		//}
		
                $result[] = array(
                    'file_id' => $row['content_id'],
                    'name' => $name,
                    'open_link' => $open_link,
                    'type' => 'file'
                );
            }

            $query->close();
            return $result;
        }

    }

}
?>
