<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

	require_once('PreferencesCountryTree.class.php');
	require_once('TimezonesTree.class.php');
	require_once('tariqa3/modules/themes/ThemesTree.class.php');

	/**
	 * User's preferences module for testing purposes
	 * @author Cosmin Popescu, Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2010
     * @package tariqa3
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class Preferences extends tariqa3ModuleContent {

	/**
	 * The list of prefered countries
	 * @var Country[]
	 * @access private
	 */
	private $countries;

	/**
	 * The list of prefered themes
	 * @var Theme[]
	 * @access private
	 */
	private $themes;

	/**
	 * The prefered country
	 * @var Country
	 * @access private
	 */
	private $country;

	/**
	 * The prefered theme
	 * @var Theme
	 * @access private
	 */
	private $theme;

	/**
	 * The list of newstickers feeds
	 * @var string[][]
	 * @access private
	 */
	private $newstickers;

	/**
	 * The list of tags
	 * @var string
	 * @access private
	 */
	private $tags;

	/**
	 * The list of timezones
	 * @var string[]
	 * @access private
	 */
	private $timezones;

	/**
	 * The visual theme
	 * @var string
	 * @access private
	 */
	private $visual_theme;

        /**
         * The selection type
         * @var string
         * @access private
         */
        private $selection_type;

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct($config);
		$this->_isMenuable = false;
	}

	/**
	 * Renders the tree options of the preferences page
	 * @access protected
	 * @return array
	 */
	protected function getTrees() {
		$tree = new PreferencesCountryTree(statics::listContinents(), 'drag_country_tree.html');
		$selected_items = array();
		$result = array();
		$selected_text = '';
		/* @var $country Country */
		foreach ($this->countries as $country){
			$selected_text .= ($selected_text == ''?'':',') . $country->code_iso2;
			$selected_items[] = array(
				'id' => $country->code_iso2,
				'value' => $country->name,
				'custom_style' => 'background: url("' . $this->config['templates']['baseurl'] . '/' . $this->config['templates']['default'] .
					'/images/countries/' . strtolower($country->code_iso2) . '.png"); background-repeat: no-repeat; padding-left: 19px',
			);
		}

		$result['countries_tree_html'] = $this->treeOption('countries_tree', $tree, $this->translate('module/prefered_countries'),
			$this->translate('module/selected_countries'), $this->translate('module/remove_selected'), $selected_items, $selected_text);

		$tree = new ThemesTree($this->translate('module/select_theme'), 'briefcase_folder.html');
		$selected_items = array();
		$selected_text = '';
		/* @var $theme Theme */
		foreach ($this->themes as $theme){
			$selected_text .= ($selected_text == ''?'':',') . $theme->theme_id;
			$selected_items[] = array(
				'id' => $theme->theme_id,
				'value' => $theme->title, 
			);
		}

		$result['themes_tree_html'] = $this->treeOption('themes_tree', $tree, $this->translate('module/prefered_themes'), $this->translate('module/selected_themes'),
				$this->translate('module/remove_selected'), $selected_items, $selected_text);

		$selected_items = array();
		$selected_text = '';
		foreach ($this->timezones as $zone){
			$selected_text .= ($selected_text == ''?'':',') . $zone;
			$selected_items[] = array(
				'id' => $zone,
				'value' => $zone,
			);
		}
		$tree = new TimezonesTree('briefcase_folder.html');
		$result['timezones_tree_html'] = $this->treeOption('timezones_tree', $tree, $this->translate('module/timezones'), $this->translate('module/selected_timezones'),
				$this->translate('module/remove_selected'), $selected_items, $selected_text);

		return $result;
	}

	/**
	 * Renders a tree option
	 * @param string $id The identifier of the option
	 * @param FolderTree $tree The items tree
	 * @param string $title The title of the option
	 * @param string $selected_title The title of the selected items
	 * @param string $remove_selected The text of the link to remove a selected element
	 * @param array $selected_items The selected items
	 * @param string $selected_text The text of the selection (a list with the ids comma separated)
	 * @access protected
	 * @return string
	 */
	protected function treeOption($id, $tree, $title, $selected_title, $remove_selected, $selected_items, $selected_text) {
		$tpl = new \MetaNull\Application\MTemplate('m');
		$tpl->loadTemplate($this->getTemplateFilePath('tree_option.html'));

		$tpl->data = $this->translationTable;

		$tpl->data['title'] = $title;
		$tpl->data['id'] = $id;

		$tpl->data['tree_html'] = $tree->folderHTML('TEST', null);

		$tpl->data['selected_title'] = $selected_title;

		$tpl->data['selected_items'] = $selected_items;

		$tpl->data['remove_link'] = $remove_selected;

		$tpl->data['selected_text'] = $selected_text;

		return $tpl->transform();

	}

	/**
	 * Render the module
	 * @return string
	 */
	public function getPageContent() {
		$tpl = new \MetaNull\Application\MTemplate( 'm' );
		$tpl->loadTemplate($this->getTemplateFilePath('main.html'));
		$tpl->data = $this->translationTable;

		$tpl->data['country'] = ($this->country != null?$this->country->name:'');
		$tpl->data['country_id'] = ($this->country != null?$this->country->code_iso2:'');
		
		$tpl->data['themes'] = array();
		$themes = statics::listThemes();
		/* @var $theme Theme */
		foreach ($themes as $theme){
			$tpl->data['themes'][] = array(
				'id' => $theme->theme_id,
				'name' => $theme->title,
				'selected' => ($this->theme != null && $this->theme->theme_id == $theme->theme_id?'selected="selected"':''),
			);
		}

		$this->info_setJavascript(
			array(
				'scripts/preferences.js',
				'scripts/jquery.jstree.js',
				'scripts/jquery.cookie.js',
			)
		);

		$this->info_setStylesheet(
			array(
				$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
			)
		);

		$trees = $this->getTrees();
		$tpl->data['countries_tree_html'] = $trees['countries_tree_html'];
		$tpl->data['themes_tree_html'] = $trees['themes_tree_html'];
		$tpl->data['timezones_tree_html'] = $trees['timezones_tree_html'];

		$tpl->data['tags'] = $this->tags;

		$tpl->data['newstickers'] = array();
		$speed = array();

		for ($i = 0; $i < 2; $i++){
			$speed[$i] = ($this->newstickers[$i] != null?$this->newstickers[$i]['speed']:1);
			$tpl->data['newstickers'][] = array(
				'i' => $i,
				'title' => ($this->newstickers[$i] != null?\MetaNull\Tools\mTools::rawurldecode($this->newstickers[$i]['title']):''),
				'url' => ($this->newstickers[$i] != null?\MetaNull\Tools\mTools::rawurldecode($this->newstickers[$i]['url']):''),
				'speed' => $speed[$i], 
			);
		}

		$js_code = '';

		foreach ($speed as $i => $s){
			$js_code .= ($js_code == ''?'':"\n") . '$("#newsticker_speed_' . $i . '").slider({value: ' . $s . ', min: 1, max: 10});';
		}

		$method = (count($_POST) > 0?'post':'get');

		$js_code = <<<js
var METHOD = '{$method}';
function initSliders(){
	{$js_code};
}

js;

                $tpl->data['checkbox_selected'] = ($this->selection_type == Briefcase::CHECKBOX_SEL_TYPE?'selected="selected"':'');
                $tpl->data['ui_selected'] = ($this->selection_type == Briefcase::UI_SEL_TYPE?'selected="selected"':'');

		$this->info_setInlineJavascript($js_code);
		$this->info_setBodyOnLoad('initJQueryPref()');

		return $tpl->transform();
	}

	/**
	 * Saves the values into the user preferences
	 * @access protected
	 * @return void
	 */
	protected function save() {
		$this->user->set_preference('general/countries/%', null, $this->db);
		$this->user->set_preference('general/themes/%', null, $this->db);
		$this->user->set_preference('general/country_id', null, $this->db);
		$this->user->set_preference('general/theme_id', null, $this->db);
		$this->user->set_preference('general/newstickers/%', null, $this->db);
		$this->user->set_preference('general/tags', null, $this->db);
		$this->user->set_preference('general/timezones/%', null, $this->db);
		$this->user->set_preference('general/visual_theme', null, $this->db);
                $this->user->set_preference('general/selection_type', null, $this->db);

		if (strlen($_POST['text_selected_countries_tree']) > 0){
			$countries = explode(',', $_POST['text_selected_countries_tree']);
			$i = 0;
			foreach ($countries as $country_id){
				$this->user->set_preference('general/countries/' . $i, $country_id, $this->db);
				$i++;
			}
		}

		if (strlen($_POST['text_selected_themes_tree']) > 0){
			$themes = explode(',', $_POST['text_selected_themes_tree']);
			$i = 0;
			foreach ($themes as $theme_id){
				$this->user->set_preference('general/themes/' . $i, $theme_id, $this->db);
				$i++;
			}
		}

		if (array_key_exists('country_id', $_POST) && strlen($_POST['country_id']) > 0){
			$this->user->set_preference('general/country_id', $_POST['country_id'], $this->db);
		}

		if (array_key_exists('theme_id', $_POST) && strlen($_POST['theme_id']) > 0){
			$this->user->set_preference('general/theme_id', $_POST['theme_id'], $this->db);
		}

		for ($i = 0; $i < 2; $i++){
			$text = 'title=' . \MetaNull\Tools\mTools::rawurlencode($_POST['newsticker_title_' . $i]) .
				'&url=' . \MetaNull\Tools\mTools::rawurlencode($_POST['newsticker_url_' . $i]) .
				'&speed=' . $_POST['newsticker_speed_' . $i];

			$this->user->set_preference('general/newstickers/' . $i, $text, $this->db);
		}

		if (strlen($_POST['tags']) > 0){
			$this->user->set_preference('general/tags', $_POST['tags'], $this->db);
		}

		if (strlen($_POST['text_selected_timezones_tree']) > 0){
			$timezones = explode(',', $_POST['text_selected_timezones_tree']);
			$i = 0;
			foreach ($timezones as $zone){
				$this->user->set_preference('general/timezones/' . $i, $zone, $this->db);
				$i++;
			}
		}

		if (strlen($_POST['visual_theme']) > 0){
			$this->user->set_preference('general/visual_theme', $_POST['visual_theme'], $this->db);
		}

                if (strlen($_POST['selection_type']) > 0){
                    $this->user->set_preference('general/selection_type', $_POST['selection_type'], $this->db);;
                }
	}

	/**
	* Initializes the module
	* @access public
	* @return void
	*/
	public function onInitialize(){
		parent::onInitialize();

		if (count($_POST) > 0){
			$this->save();
		}

		$this->setDefaultLayout('frame.html');

		$countries = $this->user->get_preference('general/countries');
		if ($countries != null) {
			$this->countries = statics::listCountries(null, null, null, null, $countries);
		}
		$themes = $this->user->get_preference('general/themes');
		if ($themes != null){
			$this->themes = statics::listThemes($themes);
		}

		$country_id = $this->user->get_preference('general/country_id');
		if ($country_id != null){
			$this->country = statics::get_country($country_id);
		}

		$theme_id = $this->user->get_preference('general/theme_id');
		if ($theme_id != null){
			$this->theme = statics::get_theme($theme_id);
		}

		$newstickers = $this->user->get_preference('general/newstickers');
		if ($newstickers != null){
			$this->newstickers = array();
			foreach ($newstickers as $newsticker){
				$this->newstickers[] = statics::post2array($newsticker);
			}
		}

		$this->tags = $this->user->get_preference('general/tags');
		$this->timezones = $this->user->get_preference('general/timezones');
		/*for ($i = 0; $i < count($this->timezones); $i++){
			$this->timezones[$i] = str_replace('_', ' ', $this->timezones[$i]);
		}*/
		$this->visual_theme = $this->user->get_preference('general/visual_theme');
                $this->selection_type = $this->user->get_preference('general/selection_type');

                if ($this->selection_type == null) {
                    $this->selection_type = Briefcase::CHECKBOX_SEL_TYPE;
                }
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
	}

	/**
	 * Returns the name of the class (what it should appear in the menu
	 * @access public
	 * @return string
	 */
	public function getName() {
		return 'preferences';
	}

	/**
	 * Returns the title of the page
	 * @access public
	 * @return string
	 */
	public function getTitle() {
		return 'Tariqa 3 Preference page';
	}

	/**
	 * Returns the description of the page
	 * @access public
	 * @return string
	 */
	public function getDescription() {
		return 'The preference page';
	}

	/**
	 * Gets the link of the module
	 * @access public
	 * @return string
	 */
	public function getLink() {
		return statics::URL('index.php', 'module=' . $this->getName());
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$breadCrumb[] = new tariqa3ModuleDescriptor($this);
		$b = new tariqa3ModuleDescriptor();
		$b->label = 'Results';
		$breadCrumb[] = $b;


		return $breadCrumb;
	}
}

}

?>