<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

	require_once('tariqa3/modules/sharing/Sharing.class.php');
	
	/**
	 * Riskmap module
	 * @author Cosmin Popescu, Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2010
     * @package tariqa3
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class RiskMap extends tariqa3ModuleSectionManager {

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct( $config );
	}

	/**
	 * The list of queries
	 * @var Query[][]
	 * @access private
	 */
	private $queries;

	/**
	 * The list of tabs
	 * @var Flavour[]
	 * @access private
	 */
	private $flavours;

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && ($_GET['module'] == $this->getName() || $_GET['module'] == 'home');
	}

	/**
	 * Gets the countries map list
	 * @access protected
	 * @return string
	 */
	protected function getMapXML() {
		$xml = file_get_contents($this->config['application']['base-folder'] . '/flash/cluster-list.xml');
		$hotspots = statics::ListHotspots();

		$doc = new \DOMDocument('1.0', 'utf-8');
		$doc->loadXML($xml);
		$nodes = $doc->getElementsByTagName('country');

		for ($i = 0; $i < $nodes->length; $i++){
			$country_id = $nodes->item($i)->getAttribute('fips');
			foreach ($hotspots as $id){
				if ($id == $country_id){
					//$nodes->item($i)->setAttribute('hotspot', 'true');
					//$nodes->item($i)->setAttribute('color', '00ff00');
					$nodes->item($i)->setAttribute('flag', '1');
					break;
				}
			}
		}

		if( statics::_isIE() ) {
			header_remove( 'Pragma' );
			header_remove( 'Cache-Control' );
		}
		return $doc->saveXML();
	}

	/**
	 * Render the module's page (will be embedded in general layout)
	 * @return string
	 */
	public function getPageContent() {
		if (array_key_exists('map_xml', $_GET)) {
			return $this->getMapXML();
		}
		$template = new \MetaNull\Application\MTemplate( 'm' );
		$template->data['application/url'] = $this->config['application']['url'];
		$template->data['loadMapArgs'] =
				'worldMapUrl='.	rawurlencode($template->data['application/url'].'/flash/WorldMap_Tariqa1.5.swf' ) . '&amp;'.
				'dataUrl='.	rawurlencode($template->data['application/url'].'/flash/cluster-list.xml' ) . '&amp;'.
				'targetUrl='.	rawurlencode($template->data['application/url'].'/?module=countries&country_id=' ) . '&amp;'
		;
		$template->loadTemplate( $this->getTemplateFilePath( 'main.html' ));

		$news = new NewsSection($this->config, $this->base_folder, 'news_tabs', $this->translationTable, $this->flavours, $this->queries, 'home_page/0/');
		$this->addSection($news);

		$template->data['sections_html'] = $this->renderSections();

		$this->info_setStylesheet(
			array(
				$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
			)
		);

		$this->info_setJavascript(
			array(
				'scripts/jquery.cookie.js',
				'scripts/jquery.treeview.min.js',
				'scripts/search.js',
				'scripts/briefcase.js',
				'scripts/riskmap.js',
				'scripts/news_section.js',
			)
		);
		$this->info_setBodyOnLoad('initJQueryUI(1)');

		$sharing = new Sharing($this->config, $this->translationTable);
		$template->data['sharing_form'] = $sharing->run();
		$this->setMoreInfos($sharing->getInfo());

		return $template->transform();
	}

	/**
	 * Gets the default flavour for the latest news queries
	 * @param array $translationTable The translation matrix
	 * @access public
	 * @static
	 * @return Flavour
	 */
	public static function getDefaultFlavour($translationTable) {
            $flavour = new \Flavour();
            if ($translationTable == null) $flavour->name = "World news";
            else {
                    $flavour->name = $translationTable['module/latest_news'];
            }
            $flavour->flavour_id = 0;
            $flavour->description = 'Home page queries';

            return $flavour;
	}

	/**
	 * Initializes the module
	 * @access public
	 * @return void
	 */
	public function onInitialize() {
		parent::onInitialize();
		if (array_key_exists('map_xml', $_GET)){
			$this->setDefaultLayout('module.html');
			return ;
		}
		$this->queries = array();
		$this->flavours = array();

		//$flavour = self::getDefaultFlavour($this->translationTable);
		$queries = statics::getHomePageQueries($this->user->get_access_level(), null, $this->translationTable);

                $this->flavours = statics::getHomePageFlavours('');

                /* @var $query Query */
                foreach ($queries as $query){
                    if (!array_key_exists($query->flavour->flavour_id, $this->queries)){
                        $this->queries[$query->flavour->flavour_id] = array();
                    }
                    $this->queries[$query->flavour->flavour_id][] = $query;
                }
	}

	/**
	 * Returns the short name of the module (used by menus)
	 * @return string
	 */
	public function getName() {
		return 'riskmap';
	}
	/**
	 * Returns the title of the module (used in html/head/title)
	 * @return string
	 */
	public function getTitle() {
		return 'Tarîqa 3.0 - Risk Map / Cluster Analysis';
	}
	/**
	 * Returns the description of the module (used in html/head/description)
	 * @return string
	 */
	public function getDescription() {
		return 'Crisis-Room\'s World Risk Map based on Cluster Analysis and Hotspots mechanisms';
	}

	/**
	 * Returns the url to the current module (used in menus)
	 * @return string
	 */
	public function getLink() {
		return statics::URL( 'index.php', array( 'module'=>$this->getName() ), true );
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$breadCrumb[] = new tariqa3ModuleDescriptor($this);
		return $breadCrumb;
	}

	/**
	 * Gets the headers
	 * @access public
	 * @return array
	 */
	public function getHeaders() {
		if (array_key_exists('map_xml', $_GET))
			return array("Content-type: text/xml; charset=utf-8");
		else {
			return null;
		}
	}

	/**
	 * Gets the default template file
	 * @access public
	 * @return string|null
	 */
	public function getDefaultTemplateFile() {
		return array_key_exists('map_xml', $_GET) ? 'module.html' : null;
	}

}
}
?>