<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

    /**
     * Search module
     * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
     */
    class OxanFolder extends TreeFolder {
        /**
         * The list of oxan countries
         * @var MultiPair $items
         * @static
         * @access protected
         **/
        protected static $items;

        /**
         * The countries type
         **/
        const COUNTRIES = 0;

        /**
         * The countries type
         **/
        const TOPICS = 1;

        /**
         * Constructs the object
         * @param int $what The items to load (countries or topics)
         * @access public
         * @return void
         */
        public function __construct($what) {
            $config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE);
            $templates_folder = "{$config['templates']['base']}/{$config['templates']['default']}";
            parent::__construct($templates_folder . '/briefcase_folder.html', true, null);

            self::$items = array();
            if ($what == self::COUNTRIES){
                self::$items = statics::listOxanCountries();
            }
            else if ($what == self::TOPICS){
                self::$items = statics::listOxanTopics();
            }
        }

        /**
         * Returns the subfolders of the current folder as an associative array with all the subfolders
         * @param int $folder_id The folder identifier
         * @access public
         * @abstract
         * @return array|boolean
         */
        public function getSubFolders($folder_id) {
            if ($folder_id != null){
                return array();
            }

            $result = array();
            foreach (self::$items as $top){
                $result[] = array(
                    'name' => $top->key,
                    'folder_id' => 'ID_' . $top->key,
                    'type' => 'folder', 
                );
            }
            return $result;
        }

        /**
         * Returns the files of the current folder as an associative array
         * @param int $folder_id The folder identifier
         * @access public
         * @return array|boolean
         */
        public function getFiles($folder_id) {
            $result = array();
            foreach (self::$items as $top){
                if ('ID_' . $top->key == $folder_id){
                    foreach ($top->values as $sub){
                        $result[] = array(
                            'file_id' => 'CID_' . $sub,
                            'name' => $sub,
                            'open_link' => '',
                            'type' => 'file', 
                        );
                    }

                    break;
                }
            }
            return $result;
        }

    }

}
?>
