<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {
/**
 * Country module
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
 */
class Streaming extends tariqa3ModuleSectionManager {

	/**
	 * The categories of the TV channels
	 * @var TariqaTVChannelCategory[]
	 * @access protected
	 */
	protected $categories;

	/**
	 * The default channel to be displayed
	 * @var TariqaTVChannel
	 * @access private
	 */
	private $channel;

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct($config);
	}

	/**
	 * Render the module
	 * @return string
	 */
	public function getPageContent() {
		$tpl = new \MetaNull\Application\MTemplate( 'm' );
		$tpl->loadTemplate($this->getTemplateFilePath('streaming.html'));
		$tpl->data = $this->translationTable;

		$tpl->data['default_video_url'] = ($this->channel != null?$this->channel->streamingURL:'');

		$this->info_setJavascript(
				array(
				'scripts/streaming.js',
				)
		);

		$tpl->data['img_path'] = $this->config['templates']['baseurl'] . '/' . $this->config['templates']['default'] . '/images/tv';

		$tpl->data['categories'] = array();

		/* @var $category TariqaTVChannelCategory */
		foreach ($this->categories as $category) {
			$channels = array();
			/*@var $channel TariqaTVChannel */
			foreach ($category->channels as $channel) {
				$channels[] = array(
						'id' => $channel->channel_id,
						'url' => $channel->streamingURL,
						'logo' => $channel->logoURL,
				);
			}

			$tpl->data['categories'][] = array(
					'name' => $category->name,
					'channels' => $channels,
			);
		}

		return $tpl->transform();
	}

	/**
	 * Initializes the module
	 * @access public
	 * @return void
	 */
	public function onInitialize() {
		parent::onInitialize();
		$this->categories = statics::ListTVCategories();
		$default_channel_id = $this->user->get_preference('live_stream/channel');

		/* @var $category TariqaTVChannelCategory */
		foreach ($this->categories as $category) {
			/* @var $channel TariqaTVChannel */
			foreach ($category->channels as $channel) {
				if ($default_channel_id == null || $default_channel_id == $channel->channel_id) {
					$this->channel = $channel;
					break;
				}
			}
		}
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
	}

	/**
	 * Returns the name of the class (what it should appear in the menu
	 * @access public
	 * @return string
	 */
	public function getName() {
		return 'streaming';
	}

	/**
	 * Returns the title of the page
	 * @access public
	 * @return string
	 */
	public function getTitle() {
		return 'Tariqa 3 Live Streaming page';
	}

	/**
	 * Returns the description of the page
	 * @access public
	 * @return string
	 */
	public function getDescription() {
		return 'The live streaming page';
	}

	/**
	 * Gets the link of the module
	 * @access public
	 * @return string
	 */
	public function getLink() {
		return statics::URL('index.php', 'module=' . $this->getName());
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$breadCrumb[] = new tariqa3ModuleDescriptor($this);
		return $breadCrumb;
	}
}

}

?>