<?php
/*
 * Class representing the files and folders tree for the upload control
*/

namespace tariqa3{
class FilesTree extends TreeFolder {

    /**
     * The upload path
     * @var string
     * @access private
     */
    private $upload_path;

    /**
     * The name of the recycle bin folder
     * @var string
     * @access private
     */
    private $rb_name;

    /**
     * If true, then the current user can upload files
     * @var boolean
     * @access protected
     */
    protected $can_upload = false;

    /**
     * The tree HTML identifier
     * @var string
     * @access protected
     */
    protected $tree_id;

    /**
     * The files url
     * @var string
     * @access private
     */
    private $url;

    /**
     * Constructs the object
     * @param string $upload_path The upload path
     * @param string $recycle_bin_name The name of the recycle bin folder
     * @param string $tree_id The tree HTML identifier
     * @param boolean $can_upload If true, then the current user can upload files [OPTIONAL]
     * @access public
     * @return void
     */
    public function __construct($upload_path, $recycle_bin_name, $tree_id, $can_upload = false) {
	$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE);
	$templates_folder = "{$config['templates']['base']}/{$config['templates']['default']}";
	parent::__construct($templates_folder . '/briefcase_folder.html', false);
	$this->upload_path = $upload_path;
	$parts = explode('/', $this->upload_path);
	$base = (substr($this->upload_path, -1) == '/'?$parts[count($parts) - 2]:$parts[count($parts) - 2]);
	$this->rb_name = $recycle_bin_name;
	$this->can_upload = $can_upload;
	$this->tree_id = $tree_id;
	$this->url = $config['uploader']['url'] . '/tariqa3/' . $base . '/';
    }

    /**
     * Returns the subfolders of the current folder as an associative array with all the subfolders
     * @param int $continent_id The continent identifier
     * @access public
     * @return array|boolean
     */
    public function getSubFolders($folder_id) {
	$folder_id = str_replace('[' . $this->tree_id . ']', '', $folder_id);
	if ($folder_id == null) $folder = $this->upload_path;
	else $folder = $this->upload_path . $folder_id;
	$folder = str_replace("\\", '/', $folder);
	if (substr($folder, -1) != '/') $folder .= '/';

	$dh = opendir($folder);

	$result = array();

	while ($file = readdir($dh)) {
	    if ($file != '.' && $file != '..') {
		if (is_dir($folder . $file)) {
		    $result[] = array(
			    'folder_id' => '[' . $this->tree_id . ']' . $folder_id . $file . '/',
			    'name' => $file,
			    'type' => 'folder',
		    );
		}
	    }
	}

	return $result;
    }

    /**
     * Returns the files of the current folder as an associative array
     * @param int $folder_id The folder identifier
     * @access public
     * @return array|boolean
     */
    public function getFiles($folder_id) {
	$folder_id = str_replace('[' . $this->tree_id . ']', '', $folder_id);
	if ($folder_id == null) $folder = $this->upload_path;
	else $folder = $this->upload_path . $folder_id;
	$folder = str_replace("\\", '/', $folder);
	if (substr($folder, -1) != '/') $folder .= '/';

	$dh = opendir($folder);

	$result = array();

	while ($file = readdir($dh)) {
	    if ($file != '.' && $file != '..') {
		if (!is_dir($folder . $file)) {
		    $result[] = array(
			    'file_id' => '[' . $this->tree_id . ']' . $folder_id . $file . '/',
			    'name' => $file,
			    'type' => 'file',
			    'open_link' => 'js_open("' . $this->url . '/' .  $folder_id . $file . '", "_self", "get")'
		    );
		}
	    }
	}

	if ($folder_id == null && $this->can_upload) {
	    $config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE);
	    $result[] = array(
		    'file_id' => '[' . $this->tree_id . ']' . 'recycle_bin_id/',
		    'name' => $this->rb_name,
		    'type' => 'recycle',
		    'open_link' => 'return false',
	    );
	}

	return $result;
    }
}
}

?>
