<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */

namespace tariqa3 {

    /**
     * Helper class to generate a multi AJAX search URL
     */
    class multiAjaxSearch {
        /**
         * The Unified Query Syntax type
         * @var string

         */
        const UNIFIED_QUERY_SYNTAX = 'UQS';

        /**
         * The Original Syntax type
         * @var string

         */
        const ORIGINAL_SYNTAX = 'OS';

        /**
         * The source identifier
         * @var int
         * @access private
         */
        private $source_id;
        /**
         * The query string
         * @var string
         * @access private
         */
        private $query;
        /**
         * The start date (UNIX timestamp)
         * @var int
         * @access private
         */
        private $start_date = null;
        /**
         * The end date (UNIX timestamp
         * @var int
         * @access private
         */
        private $end_date = null;
        /**
         * The first result to be retrieved
         * @var int
         * @access private
         */
        private $from = null;
        /**
         * The number of results to be retrieved
         * @var int
         * @access private
         */
        private $count = null;
        /**
         * The type of the query syntax
         * @var string
         * @access private
         */
        private $type = null;
        /**
         * The name of the template
         * @var string
         * @access private
         */
        private $template = null;
        /**
         * The current page
         * @var int
         * @access private
         */
        private $current_page = 0;
        /**
         * The javascript name
         * @var string
         * @access private
         */
        private $js_name = 'generic_object';
        /**
         * The URL of the Tariqa service
         * @var string
         * @access private
         */
        private $tariqa_service_url;
        /**
         * If set to true, the javacript variable is global
         * @var boolean
         * @access private
         */
        private $global = false;
        /**
         * The ID of the HTML DIV where the result is going to be displayed
         * @var string
         * @access private
         */
        private $result_id;
        /**
         * The ID of the HTML DIV where the navigation of the results will be displayed (if necessary)
         * @var string
         * @access private
         */
        private $navigation_id;
        /**
         * If set to true, when returning a result, also add a new tab
         * @var boolean
         * @access private
         */
        private $add_tab = true;
        /**
         * The engine specific data
         * @var string
         * @access private
         */
        private $specific_data = null;
        /**
         * The tab ID (needed if you want for each search results to also add a tab)
         * @var string
         * @access private
         */
        private $tab_id = null;

        /**
         * Constructs the object
         * @param string $query The query
         * @param int $source_id The source_identifier
         * @param string $tariqa_service_url The URL of the tariqa service
         * @param string $js_name The javascript object name [OPTIONAL]
         * @param boolean $blobal If true, the javascript variable is global [OPTIONAL]
         * @param int $start_date The start date [OPTIONAL]
         * @param int $end_date The end_date [OPTIONAL]
         * @param int $from The first result to retrieve [OPTIONAL]
         * @param int $count The number of results to retrieve [OPTIONAL]
         * @param string $type The type of the query syntax [OPTIONAL]
         * @param string $template The template name [OPTIONAL]
         * @access public
         * @return void
         */
        public function __construct($query, $source_id, $tariqa_service_url, $js_name = 'generic_object', $global = false, $start_date = null, $end_date = null, $from = null, $count = null, $type = null, $template = null) {
            $this->query = $query;
            $this->source_id = $source_id;
            $this->result_id = 'html_result_' . $this->source_id;
            $this->navigation_id = 'navigation_' . $this->source_id;
            $this->tariqa_service_url = $tariqa_service_url;
            $this->js_name = $js_name;
            $this->start_date = $start_date;
            $this->end_date = $end_date;
            $this->from = $from;
            $this->count = $count;
            if ($type != null)
                $this->type = $type;
            else
                $this->type = self::UNIFIED_QUERY_SYNTAX;
            $this->template = $template;
            $this->global = $global;

            if ($this->count == null) {
                $newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
                $this->count = $newsConfig['search']['default']['results-per-page'];
            }
        }

        /**
         * Gets the object's javascript name
         * @access public
         * @return string
         */
        public function getName() {
            return $this->js_name;
        }

        /**
         * Sets the current page
         * @param int $page The page number (0 based)
         * @access public
         * @return void
         */
        public function setCurrentPage($page) {
            $this->current_page = $page;
        }

        /**
         * Sets the engine specific data
         * @param string $data The data
         * @access public
         * @return void
         */
        public function setSpecificData($data) {
            $this->specific_data = $data;
        }

        /**
         * Generates the URL
         * @access public
         * @return string
         */
        public function getURL() {
            $query = str_replace("\n", '', $this->query);
            $params = 'action=searchNews&source_id=' . $this->source_id . '&query=' . rawurlencode($query) .
                    '&type=' . $this->type . '&result_id=' . $this->result_id . '&navigation_id=' . $this->navigation_id .
                    '&add_tab=' . ($this->add_tab ? 'true' : 'false');

            if ($this->start_date !== null) {
                $params .= '&start_date=' . $this->start_date;
            }

            if ($this->end_date !== null) {
                $params .= '&end_date=' . $this->end_date;
            }

            if ($this->from !== null) {
                $params .= '&from=' . $this->from;
            }

            if ($this->count !== null) {
                $params .= '&count=' . $this->count;
            }

            if ($this->template !== null) {
                $params .= '&template=' . $this->template;
            }

            if ($this->specific_data != null) {
                $params .= '&specific_data=' . $this->specific_data;
            }

            return statics::URL($this->tariqa_service_url, $params);
        }

        /**
         * Creates the javascript code for generating the object
         * @param bool $refresh If true, then also refresh the news [OPTIONAL]
         * @access public
         * @return string
         */
        public function generate_js($refresh = false) {
            $result = '';
            $var = ($this->global ? '' : 'var ');

            $query = str_replace(array("\n", chr(13), chr(10)), "", $this->query);
            $query = str_replace('"', "\\\"", $query);

            $result = <<<js
	{$var}{$this->js_name} = new searchObject("{$query}", {$this->source_id});
	{$this->js_name}.setType('{$this->type}');

js;

            $result .= <<<js
	{$this->js_name}.setResultId('{$this->result_id}');
	{$this->js_name}.setNavigationId('{$this->navigation_id}');

js;

            if (!$this->add_tab) {
                $result .= <<<js
	{$this->js_name}.noNewTab();

js;
            }

            if ($this->start_date != null) {
                $result .= <<<js
	{$this->js_name}.setStartDate({$this->start_date});

js;
            }

            if ($this->end_date != null) {
                $result .= <<<js
	{$this->js_name}.setEndDate({$this->end_date});

js;
            }

            if ($this->from != null) {
                $result .= <<<js
	{$this->js_name}.setFrom({$this->from});

js;
            }

            if ($this->count != null) {
                $result .= <<<js
	{$this->js_name}.setCount({$this->count});

js;
            }

            if ($this->template != null) {
                $result .= <<<js
	{$this->js_name}.setTemplate({$this->template});

js;
            }

            if ($this->specific_data != null) {
                $data = str_replace("'", "\\'", $this->specific_data);
                $result .= <<<js
	{$this->js_name}.setSpecificData('{$data}');

js;
            }

            if ($this->tab_id != null) {
                $result .= <<<js
	   {$this->js_name}.setTabId('{$this->tab_id}');

js;
            }

            //error_log($this->specific_data);

            if ($refresh) {
                $result .= <<<js
   refreshNews({$this->js_name}.getSearchURL(), {$this->js_name}._afterNavigate, '{$this->result_id}', false);
js;
            }


            return $result;
        }

        /**
         * Sets the id of the HTML div that will display the results of the search
         * @param string $id The id
         * @access public
         * @return void
         */
        public function setResultId($id) {
            $this->result_id = $id;
        }

        /**
         * Sets the id of the HTML div that will display the navigation of the search
         * @param string $id The id
         * @access public
         * @return void
         */
        public function setNavigationId($id) {
            $this->navigation_id = $id;
        }

        /**
         * The search will not create a new tab
         * @access public
         * @return void
         */
        public function noNewTab() {
            $this->add_tab = false;
        }

        /**
         * Gets the source id of the search
         * @access public
         * @return int
         */
        public function getSourceId() {
            return $this->source_id;
        }

        /**
         * Sets the tab identifier
         * @param string $id The identifier
         * @access public
         * @return void
         */
        public function setTabId($id) {
            $this->tab_id = $id;
        }

        /**
         * Retrieves the navigation id
         * @access public
         * @return string
         */
        public function getNavigationId() {
            return $this->navigation_id;
        }

    }

}
?>
