<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search{
	/**
	 * Base class for fetching the news results from the RSS_aggregator or LatestNews_aggregator engine
	 * @author Cosmin Popescu
	 *
	 */
	class AggregatorsEngine extends searchEngine {

		/**
		 * Constructs the object
		 * @param array $newsConfig The news configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($newsConfig) {
			parent::__construct($newsConfig);
		}

		/**
		 * Fetches a list of articles
		 * @param newsQuery $query The query
		 * @access public
		 * @return tariqaSearchResultSet
		 */
		public function listArticles($query){
			$qstr = null;
			$data = \tariqa3\statics::post2array(\rawurldecode($query->specific_data));
			if (is_numeric(trim($query->query))){
				$feed_id = trim($query->query);
				if (array_key_exists('query', $data)) $qstr = rawurldecode($data['query']);
			}
			else {
				$d = \tariqa3\statics::post2array($query->query);
				if (array_key_exists('feed_id', $d) && array_key_exists('query', $d) && count($d) == 2){
					$qstr = $d['query'];
					$feed_id = $d['feed_id'];
				}
				else {
					$qstr = $query->query;
					if (array_key_exists('feed_id', $data)) $feed_id = rawurldecode($data['feed_id']);
					else {
						throw new \Exception("Feed id not defined");
					}
				}
			}

			$first = null;
			$count = $this->newsConfig['default']['results-per-page'];

			if ($query->first !== null) $first = $query->first - 1;
			if ($query->count !== null) $count = $query->count;

			$start_date = null;
			$end_date = null;

			if ($query->start_date != null){
				$start_date = $this->date2range($query->start_date);
			}
			if ($query->end_date != null){
				$end_date = $start_date - $this->date2range($query->end_date);
			}

			if ($query->engine_id == 'RSS_aggregator'){
				$results = \tariqa3\statics::$tariqaClient->ListAggregatedRSSArticles(
					\tariqa3\statics::$tariqaToken, $feed_id, $start_date, $first, $count, $end_date, $qstr
				);
				$articles_number = \tariqa3\statics::$tariqaClient->GetAggregatedRSSArticlesNumber(
					\tariqa3\statics::$tariqaToken, $feed_id, $start_date, $end_date, $qstr
				);
			}
			else {
				$results = \tariqa3\statics::$tariqaClient->ListAggregatedLatestnewsArticles(
					\tariqa3\statics::$tariqaToken, $feed_id, $start_date, $first, $count, $end_date, $qstr
				);
				$articles_number = \tariqa3\statics::$tariqaClient->GetAggregatedLatestnewsArticlesNumber(
					\tariqa3\statics::$tariqaToken, $feed_id, $start_date, $end_date, $qstr
				);
			}
			

			$result = new tariqaSearchResultSet();

			$result->query = $query->query;
			$engine = \tariqa3\statics::getEngine($query->engine_id);
                        $result->engine_name = $engine->name;
			$result->engine = $engine->engine_id;
			$result->source = $query->source_id;
			$result->from = $query->first;

			$feed = \tariqa3\statics::getAggregatedFeed($feed_id);
			if ($feed->picture == null){
				$result->logo = $engine->logo_url;
			}
			else {
				$result->logo = $feed->picture;
			}
			$result->provider_url = ($feed->link != null?$feed->link:$feed->url);

			if (array_key_exists('source_name', $data)){
				$result->source_name = $data['source_name'];
			}

			$result->count = $articles_number;
			$result->results_per_page = $query->count !== null?$query->count:count($results);

			$result->documents = array();

			/* @var $article RSS_article */
			foreach ($results as $article) {
				$document = new tariqaDocument();

				$document->title = $article->title;
				$document->id = $query->engine_id . ':' .
					$query->source_id. ':'  .
					urlencode($article->article_id);
				$document->url = $this->link($query->engine_id . '::' . urlencode($article->article_id));
				$document->js_link = $this->js_link($query->engine_id . '::' . urlencode($article->article_id), $article->title);

				$d = new \DateTime();
				$d->setTimestamp($article->date);

				$document->date = $d->getTimestamp() + $d->getOffset();

				$document->summary = ($query->engine_id == 'RSS_aggregator'?$article->description:($query->engine_id == 'LatestNews_aggregator' ? $article->summary : ''));
				$document->publisher = ($query->engine_id == 'RSS_aggregator'?$article->author:$query->engine_id == 'LatestNews_aggregator' ? $article->agency : '');

				$result->documents[] = $document;
			}

			return $result;
		}

		/**
		 * Gets a specific article
		 * @param string $article_id The article identifier
		 * @access public
                 * @abstract
		 * @return tariqaFullDocument
		 */
		public function getArticle($article_id){
			$parts = explode(':', $article_id, 3);
			if (count($parts) != 3){
				throw new \Exception('Document identifier not well formed');
			}

			if ($parts[0] == 'RSS_aggregator') $type = 0;
			else if ($parts[0] == 'LatestNews_aggregator') $type = 1;

			if ($type == 0){
				$document = \tariqa3\statics::$tariqaClient->GetAggregatedRSSArticle(\tariqa3\statics::$tariqaToken, $parts[2]);
			}
			else if ($type == 1){
				$document = \tariqa3\statics::$tariqaClient->GetAggregatedLatestnewsArticle(\tariqa3\statics::$tariqaToken, $parts[2]);
			}

			$result = new tariqaFullDocument();
			$result->id = $article_id;
			$result->engine = $parts[0];
			$result->source = $parts[1];

			$result->document_id = $document->article_id;
			$result->title = $document->title;

			$result->date = $document->date;
			$result->publisher = ($type == 0?$document->link:(($type == 1?$document->agency:null)));
			$content = ($type == 0?$document->description:(($type == 1?$document->content:null)));

			if ($type == 0){
				$config = \MetaNull\Tools\mConfig::loadConfiguration(
					APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config'
				);
				$template = $config['templates']['baseurl'] . '/' .
					$config['templates']['default'] .
					'/modules/tariqa3/Article/read_more.html';
				$tpl = new \MetaNull\Application\MTemplate('m');
				$tpl->loadTemplate($template);
				$tpl->data['id'] = $result->document_id;
				$tpl->data['url'] = \tariqa3\statics::URL('index.php', 'module=article&type=new&id=RSS::' . $document->link);
				$content .= $tpl->transform();
			}

			$result->body = $content;

			return $result;
		}

	}
}
?>