<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search{
	/**
	 * Base class for fetching the news results from the Factiva engine
	 * @author Cosmin Popescu
	 *
	 */
	class FactivaEngine extends searchEngine {

		/**
		 * Constructs the object
		 * @param array $newsConfig The news configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($newsConfig) {
			parent::__construct($newsConfig);
		}

		/**
		 * Fetches a list of articles
		 * @param newsQuery $query The query
		 * @access public
		 * @return tariqaSearchResultSet
		 */
		public function listArticles($query){
			$queryObj = new \FactivaContentQuery();
			$queryObj->searchString = $query->query;
			if ($query->first != null) $queryObj->first = $query->first;
			if ($query->count != null) $queryObj->count = $query->count;
			if ($query->source_id != null) {
				$source = \tariqa3\statics::getSource($query->source_id);
				if ($source->source_data != null) {
					$parts = explode(";", $source->source_data);
					$sources_arr = array();
					foreach ($parts as $s) $sources_arr[] = $s;
					$queryObj->sourceCodes = $sources_arr;
				}
			}
			$results = \tariqa3\statics::$tariqaClient->FactivaContentSearch(\tariqa3\statics::$tariqaToken, $queryObj);

			$result = new tariqaSearchResultSet();

			$result->query = $query->query;
			$engine = \tariqa3\statics::getEngine($query->engine_id);
                        $result->engine_name = $engine->name;
			$result->engine = $query->engine_id;
			$result->source = $query->source_id;
			$result->from = $query->first;
			$result->count = $results->queryHitCount;
			$result->results_per_page = $query->count !== null?$query->count:count($results->results);
			
			$result->documents = array();

			/* @var $article FactivaContentHeadline */
			foreach ($results->results as $article) {
				$document = new tariqaDocument();

				$title_str = "";
				foreach ($article->headline as $part) $title_str .= ($title_str == ""?"":" ") . $part;
				
				$document->title = $title_str;
				$document->id = $query->engine_id . ':' .
						$query->source_id . ':' .
						urlencode($article->accessionNo);
				$document->url = $this->link('Factiva:' . $query->source_id . ':' . urlencode($article->accessionNo));
				$document->js_link = $this->js_link(
						'Factiva:' . $query->source_id . ':' . urlencode($article->accessionNo),
						$title_str
				);

				$document->date = $article->publicationDate;

				$snippet = "";
				foreach ($article->snippet as $part) $snippet .= ($snippet == ""?"":"\n") . $part;

				$document->summary = $snippet;
				$document->publisher = $article->sourceName;

				$result->documents[] = $document;
			}

			return $result;
		}

		/**
		 * Gets a specific article
		 * @param string $article_id The article identifier
		 * @access public
	 * @abstract
		 * @return tariqaFullDocument
		 */
		public function getArticle($article_id){
			$parts = explode(':', $article_id, 3);
			if (count($parts) != 3){
				throw new \Exception('Document identifier not well formed');
			}

			$document = \tariqa3\statics::$tariqaClient->FactivaGetDocument(\tariqa3\statics::$tariqaToken, $id);

			$result = new tariqaFullDocument();
			$result->id = $article_id;
			$result->engine = $parts[0];
			$result->source = $parts[1];
			$result->document_id = $document->accessionNo;
			$title_str = '';
			foreach ($document->headline as $part) $title_str .= ($title_str == ""?"":" ") . $part;
			$result->title = $title_str;
			
			$result->date = $document->publicationDate;
			$result->publisher = $document->sourceName;

			$body = '';
			foreach ($document->leadParagraph as $paragraph) $body .= ($body == ''?'':'<br/>') . $paragraph;
			foreach ($document->tailParagraph as $paragraph) $body .= ($body == ''?'':'<br/>') . $paragraph;
			$result->body = $body;

			return $result;
		}

	}
}
?>