<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search{
	/**
	 * Base class for fetching the news results from the Google engine
	 * @author Cosmin Popescu
	 *
	 */
	class GoogleEngine extends searchEngine {

		/**
		 * Constructs the object
		 * @param array $newsConfig The news configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($newsConfig) {
			parent::__construct($newsConfig);
		}

		/**
		 * Sets the google type search
		 * @param string $engine The engine identifier
		 * @access private
		 * @return string
		 */
		private function getGoogleType($engine) {
			switch($engine) {
				case "GoogleBlogs": return "blogs";
				case "GoogleImages": return "images";
				case "GoogleNews": return "news";
				case "GoogleVideo": return "video";
				case "GoogleWeb": return "web";
				case "Google": return "web";
			}
		}

		/**
		 * Fetches a list of articles
		 * @param newsQuery $query The query
		 * @access public
		 * @return tariqaSearchResultSet
		 */
		public function listArticles($query){
			$queryObj = new \GoogleQuery();
			$queryObj->data = $this->getGoogleType($query->engine_id);
			$queryObj->query = $query->query;
			//$queryObj->start = 5;
			if ($query->source_id != null) {
				$source = \tariqa3\statics::getSource($query->source_id);
				$queryObj->source = $source->source_data;
			}

			if ($query->specific_data != null){
				$queryObj->query .= ' ' . $query->specific_data;
			}

			$p = new \Pair('userip', $_SERVER['REMOTE_ADDR']);

			$queryObj->specific_options = array($p);

			$results = \tariqa3\statics::$tariqaClient->googleSearch(\tariqa3\statics::$tariqaToken, $queryObj);

			if ($results->responseDetails != null) {
				error_log($results->responseDetails);
				throw new \Exception("Google Engine error. Please see the log for details");
			}
			if ($query->first !== null && $query->count !== null) {
				$results = \tariqa3\statics::$tariqaClient->googleFetch(
						\tariqa3\statics::$tariqaToken,
						$results,
						$query->first - 1,
						$query->count
				);
				//\MetaNull\Tools\mDump::dumpVariable($results);
			}

			$result = new tariqaSearchResultSet();

			$result->query = $query->query;
			$engine = \tariqa3\statics::getEngine($query->engine_id);
                        $result->engine_name = $engine->name;
			$result->engine = $query->engine_id;
			$result->source = $query->source_id;
			$result->from = $query->first;

			$engine = \tariqa3\statics::getEngine($query->engine_id);
			$result->logo = $engine->logo_url;
			$result->provider_url = $engine->doc_url;

			$result->count = ($results->estimatedResultCount != null?$results->estimatedResultCount:0);
			$result->results_per_page = $query->count !== null?$query->count:count($results->searchResults);

			$result->documents = array();

			/* @var $article GoogleSearchResult */
			foreach ($results->searchResults as $article) {
				$document = new tariqaDocument();

				$a = new \GoogleSearchResult();
				$a->GsearchResultClass = $article->GsearchResultClass;
				$a->content = $article->content;
				$a->specific_properties = $article->specific_properties;
				$a->title = $article->title;
				$a->titleNoFormatting = $article->titleNoFormatting;
				switch ($query->engine_id){
					case 'GoogleBlogs':
						foreach ($article->specific_properties as $prop){
							if ($prop->key == 'postUrl') {
								$a->unescapedUrl = $prop->value;
								$a->url = $prop->value;
								break;
							}
						}
						break;
					default:
						$a->unescapedUrl = $article->unescapedUrl;
						$a->url = $article->url;
						break;
				}
				$article = $a;
				
				$document->title = $article->titleNoFormatting;
				$document->id = $query->engine_id . ':' .
					$query->source_id . ':' .
					urlencode($article->unescapedUrl);
				$document->url = $this->link($query->engine_id . '::' . urlencode($article->unescapedUrl));
				$document->js_link = $this->js_link(
						$query->engine_id . '::' . urlencode($article->unescapedUrl),
						$article->titleNoFormatting
					);

				$date_value = 0;
				if ($query->engine_id == "GoogleNews" || $query->engine_id == "GoogleBlogs") {
					foreach ($article->specific_properties as $prop) {
						if ($prop->key == "publishedDate") {
							$date_value = $prop->value;
							break;
						}
					}
				}
				if ($query->engine_id == "GoogleVideo") {
					foreach ($article->specific_properties as $prop) {
						if ($prop->key == "published") {
							$date_value = $prop->value;
							break;
						}
					}
				}
				$document->date = $date_value;

				$document->summary = $article->content;

				$source = 'Google web';
				if ($query->engine_id == 'GoogleNews' || $query->engine_id == 'GoogleVideo') {
					$source = $article->publisher;
				}
				if ($query->engine_id == 'GoogleBlogs') {
					$source = $article->author;
				}
                                if ($query->engine_id == 'GoogleWeb' || $query->engine_id == 'Google'){
                                    $source = $article->unescapedUrl;
                                }
				$document->publisher = $source;

				$result->documents[] = $document;
			}

			return $result;
		}

		/**
		 * Gets a specific article
		 * @param string $article_id The article identifier
		 * @access public
	 * @abstract
		 * @return tariqaFullDocument
		 */
		public function getArticle($article_id){
			$parts = explode(':', $article_id, 3);
			if (count($parts) != 3){
				throw new \Exception('Document identifier not well formed');
			}

                        if ($parts[0] != 'RSS'){
                            $document = \tariqa3\statics::$tariqaClient->googleGetDocument(
                                    \tariqa3\statics::$tariqaToken, \MetaNull\Tools\mTools::rawurldecode($parts[2])
                            );
                        }
                        else {
                            $document = \tariqa3\statics::$tariqaClient->fetchUrl(\tariqa3\statics::$tariqaToken, new \WebRequest(\MetaNull\Tools\mTools::rawurldecode($parts[2])));
                        }

			$result = new tariqaFullDocument();
			$result->id = $article_id;
			$result->engine = $parts[0];
			$result->source = $parts[1];
			$result->document_id = $parts[2];
			$result->title = '';

			$result->date = 0;
			$result->publisher = '';

			if ($parts[0] != 'RSS'){
			    $base64 = base64_decode($document);
			    $result->body = ($base64 !== false?$base64:$document);
			}
			else {
			    $body = $document->body;
			    $body = preg_replace('/<script[^>]*>.*?<\/script>/si', '', $body);
			    $body = preg_replace('/<script[^>]*>/si', '', $body);
			    preg_match('/<head[^>]*>(.*?)<\/head>/si', $body, $matches);
			    if (count($matches) == 2){
				$result->html_headers = $matches[1];
				$body = preg_replace('/<head[^>]*>.*?<\/head>/si', '', $body);
			    }
			    $body = preg_replace('/<html[^>]*>/', '', $body);
			    $body = str_replace('</html>', '', $body);
			    $body = preg_replace('/<body[^>]*>/si', '', $body);
			    $body = str_replace('</body>', '', $body);

			    $result->body = $body;
			}

			return $result;
		}

	}
}
?>