<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search {

    /**
     * Base class for fetching the news results from the Latestnews engine
     * @author Cosmin Popescu
     *
     */
    class LatestNewsEngine extends searchEngine {

        /**
         * Constructs the object
         * @param array $newsConfig The news configuration array
         * @access public
         * @return void
         */
        public function __construct($newsConfig) {
            parent::__construct($newsConfig);
        }

        /**
         * Fetches a list of articles
         * @param newsQuery $query The query
         * @access public
         * @return tariqaSearchResultSet
         */
        public function listArticles($query) {
            $start_date = null;
            $end_date = null;

            if ($query->start_date != null) {
                $start_date = $this->date2range($query->start_date);
            }
            if ($query->end_date != null) {
                $end_date = $start_date - $this->date2range($query->end_date) + 1;
            }

            /* if ($end_date > $start_date) {
              $end_date = $start_date;
              } */

            //$query->query = str_replace("\\", '', $query->query);
            //\MetaNull\Tools\mDump::dumpVariable($query->query);

            if ($query->count == null) {
                $query->count = $this->newsConfig['default']['results-per-page'];
            }

            $results = \tariqa3\statics::$tariqaClient->fetchLatestNews(
                            \tariqa3\statics::$tariqaToken,
                            $query->query,
                            $start_date,
                            ($query->first !== null ? floor(($query->first - 1) / $query->count) : null),
                            ($query->first !== null ? $query->count : null), true, $end_date
            );

            $result = new tariqaSearchResultSet();

            $result->query = $query->query;
            $engine = \tariqa3\statics::getEngine($query->engine_id);
            $result->engine_name = $engine->name;
            $result->engine = $query->engine_id;
            $result->source = $query->source_id;
            //\MetaNull\Tools\mDump::dumpVariable($query->query_name);
            $result->from = $query->first;

            $result->logo = $engine->logo_url;
            $result->provider_url = $engine->doc_url;
            $result->count = $results->available_articles;
            $result->results_per_page = $query->count !== null ? $query->count : count($results->articles);

            $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));

            if (array_key_exists('source_name', $data)) {
                $result->source_name = $data['source_name'];
            }

            $result->documents = array();

            /* @var $article Article */
            foreach ($results->articles as $article) {
                $document = new tariqaDocument();

                $document->title = $article->title;
                $document->id = $query->engine_id . ':' . $query->source_id . ':' . urlencode($article->id);
                $document->url = $this->link('LatestNews::' . urlencode($article->id));
                $document->js_link = $this->js_link('LatestNews::' . urlencode($article->id), $article->title);

                $document->date = strtotime($article->date);

                $document->summary = $article->lead_para;
                $document->publisher = '';

                $result->documents[] = $document;
            }

            return $result;
        }

        /**
         * Gets a specific article
         * @param string $article_id The article identifier
         * @access public
         * @abstract
         * @return tariqaFullDocument
         */
        public function getArticle($article_id) {
            $parts = explode(':', $article_id, 3);
            if (count($parts) != 3) {
                throw new \Exception('Document identifier not well formed');
            }

            $document = \tariqa3\statics::$tariqaClient->latestNewsGetDocument(\tariqa3\statics::$tariqaToken, $parts[2]);

            $result = new tariqaFullDocument();
            $result->id = $article_id;
            $result->engine = $parts[0];
            $result->source = $parts[1];
            $result->document_id = $document->id;
            $result->title = $document->headline;

            $result->date = $document->date;
            $result->publisher = $document->agency;
            $result->body = $document->text;

            return $result;
        }

    }

}
?>