<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search{
	/**
	 * Base class for fetching the news results from the RSS engine
	 * @author Cosmin Popescu
	 *
	 */
	class RSSEngine extends GoogleEngine {

		/**
		 * Constructs the object
		 * @param array $newsConfig The news configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($newsConfig) {
			parent::__construct($newsConfig);
		}

		/**
		 * Fetches a list of articles
		 * @param newsQuery $query The query
		 * @access public
		 * @return tariqaSearchResultSet
		 */
		public function listArticles($query){
			$url = $query->query;
			$results = \tariqa3\statics::$tariqaClient->fetchRSS(\tariqa3\statics::$tariqaToken, $url, $query->first, null);

			$result = new tariqaSearchResultSet();

			$result->query = $query->query;
                        $engine = \tariqa3\statics::getEngine($query->engine_id);
			$result->engine = $query->engine_id;
                        $result->engine_name = $engine->name;
			$result->source = $query->source_id;
			$result->from = $query->first;

			$result->count = count($results->articles);
			$result->results_per_page = count($results->articles);

			$result->documents = array();

			/* @var $article Article */
			foreach ($results->articles as $article) {
				$document = new tariqaDocument();

				$document->title = $article->title;
				$document->id = $query->engine_id . ':' . $query->source_id. ':'  . urlencode($article->url);
				$document->url = $this->link('RSS::' . urlencode($article->url));
				$document->js_link = $this->js_link('RSS::' . urlencode($article->id), $article->title);

				$document->date = strtotime($article->date);

				$content = $article->lead_para;
				if ($content == '') $content = '<!--Content not available-->';
				$document->summary = $content;
				$document->publisher = $article->copyright;

				$result->documents[] = $document;
			}

			return $result;
		}

	}
}
?>