<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\search{
	/**
	 * Base class for fetching the news results from the Virage engine
	 * @author Cosmin Popescu
	 *
	 */
	class VirageEngine extends searchEngine {
		/**
		 * Constructs the object
		 * @param array $newsConfig The news configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($newsConfig) {
			parent::__construct($newsConfig);
		}

		/**
		 * Fetches a list of articles
		 * @param newsQuery $query The query
		 * @access public
		 * @return tariqaSearchResultSet
		 */
		public function listArticles($query){
			$queryObj = new \VirageSearchQuery();
			$queryObj->query = $query->query;
			if ($queryObj->query == '') $query = '*';
			$queryObj->minDate = $query->start_date;
			$queryObj->maxDate = $query->end_date;
			if ($query->count != null) $queryObj->maxResults = $query->count;

			$queryObj->stemming = true;
			if ($query->specific_data != null){
				$data = \tariqa3\statics::post2array($query->specific_data);

				if (array_key_exists('sort_by', $data)) $queryObj->sort = $data['sort_by'];
				if (array_key_exists('sort_order', $data)) $queryObj->sortOrder = $data['sort_order'];
				if (array_key_exists('file', $data)) $queryObj->fileName = $data['file'];
				if (array_key_exists('url', $data)) $queryObj->url = $data['url'];
				if (array_key_exists('stem', $data) && $data['stem'] == 'no') $queryObj->stemming = false;
			}

			$results = \tariqa3\statics::$tariqaClient->VirageSearch2(\tariqa3\statics::$tariqaToken, $queryObj);

			$result = new tariqaSearchResultSet();

			$result->query = $query->query;
                        $engine = \tariqa3\statics::getEngine($query->engine_id);
                        $result->engine_name = $engine->name;
			$result->engine = $query->engine_id;
			$result->source = $query->source_id;
			$result->from = $query->first;
			
			$result->count = $results->resultsFound;
			$result->results_per_page = $query->count !== null?$query->count:count($results->documents);

			$result->documents = array();

			/* @var $article VirageDocument */
			foreach ($results->documents as $article) {
				$document = new tariqaDocument();

				$document->title = $article->title;
				$document->id = $query->engine_id . ':' .
					$query->source_id . ':' .
					urlencode($article->document_id);
				$document->url = $this->link('Virage::' . urlencode($article->document_id));
				$document->js_link = $this->js_link('Virage::' . urlencode($article->document_id), $article->title);

				$document->date = strtotime($article->date);

				$document->summary = $article->documentContent;
				$document->publisher = null;

				$result->documents[] = $document;
			}

			return $result;
		}

		/**
		 * Gets a specific article
		 * @param string $article_id The article identifier
		 * @access public
	 * @abstract
		 * @return tariqaFullDocument
		 */
		public function getArticle($article_id){
			$parts = explode(':', $article_id, 3);
			if (count($parts) != 3){
				throw new \Exception('Document identifier not well formed');
			}

			$viragedoc = \tariqa3\statics::$tariqaClient->VirageGetDocument(\tariqa3\statics::$tariqaToken, $parts[2], true);

			$result = new tariqaFullDocument();
			$result->id = $article_id;
			$result->engine = $parts[0];
			$result->source = $parts[1];
			$result->document_id = $viragedoc->document_id;

			$result->title = $viragedoc->title;

			$result->date = strtotime($viragedoc->date);
			if (strpos($viragedoc->fileName, '/') === false) $viragedoc->fileName = '/' . $viragedoc->fileName;
			$pattern = '.*/([^/\?]*)[\?]*(.*)$';
			$query_string = ereg_replace($pattern, '\2', $viragedoc->fileName);
			$file_name = $this->newsConfig['virage']['movie-url'] . '/' .
				ereg_replace($pattern, '\1', $viragedoc->fileName) .
				($query_string != ''?'?' . $query_string : '');
			$result->publisher = $file_name;
			$result->body = $viragedoc->documentContent;

			return $result;
		}

	}
}
?>