<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

	/**
	 * Class representing a module section
	 * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class tariqa3ModuleSection extends tariqa3Module{

		/**
		 * The section identifier
		 * @var string
		 * @access protected
		 */
		protected $section_id;

		/**
		 * Constructs the object
		 * @param array $config The configuration array
		 * @param string $parentBase base_folder of the container class
		 * @param string $section_id The section identifier
		 * @access public
		 * @return void
		 */
		public function __construct($config, $parentBase, $section_id) {
			parent::__construct($config, false);
			$cls = explode('\\',get_class($this));
			$this->base_folder = $parentBase . '/' . preg_replace( "/[\\/\\\\]/", '/', $cls[count($cls)-1]);
			$this->section_id = $section_id;
		}

		/**
		 * Retrieves the section identifier
		 * @access public
		 * @return string
		 */
		public function get_section_id() {
			return $this->section_id;
		}

		/**
		 * Process all requests (this is the default module)
		 */
		public final function canProcessRequest() {
			return true;
		}

		/**
		 * Returns the name of the class (what it should appear in the menu
		 * @access public
		 * @return string
		 */
		public final function getName() {
			return '';
		}

		/**
		 * Returns the title of the page
		 * @access public
		 * @return string
		 */
		public final function getTitle() {
			return 'Tariqa 3 section';
		}

		/**
		 * Returns the description of the page
		 * @access public
		 * @return string
		 */
		public final function getDescription() {
			return 'The country section';
		}

		/**
		 * Gets the link of the module
		 * @access public
		 * @return string
		 */
		public final function getLink() {
			return null;
		}

		/**
		 * Return the items of the current breadcrumb path
		 * @return tariqa3ModuleDescriptor[]
		 */
		public final function getBreadCrumb() {
			return array();
		}

		/**
		* Render the module
		* @return string
		*/
		protected final function onExecute() {
			$template = new \MetaNull\Application\MTemplate( 'm' );
			$template->loadTemplate( $this->getThemeFilePath( 'module.html' ));

			$template->data['module-result'] = $this->getPageContent();

			return $template->transform();
		}

		/**
		 * If you want to display something before a section, just redefine this function and return the HTML to be displayed
		 * @access public
		 * @return string
		 */
		public function beforeSection() {
			return null;
		}

		/**
		 * If you want to display something after a section, just redefine this function and return the HTML to be displayed
		 * @access public
		 * @return string
		 */
		public function afterSection() {
			return null;
		}
	}
}
?>
