<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{
	
	/**
	 * Section manager module (manages the horizontal sections of a page)
	 * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class tariqa3ModuleSectionManager extends tariqa3Module{
		/**
		 * The sections (an array of classes extending the tariqa3ModuleSection class
		 * @var array
		 * @access private
		 */
		private $sections = array();

		/**
		 * Constructs the object
		 * @param array $config The configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($config) {
			parent::__construct($config);
		}

		/**
		 * Adds a section to the page
		 * @param tariqa3ModuleSection $section The section class
		 * @access public
		 * @return void
		 */
		public function addSection($section) {
			$section->db = $this->db;
			$this->sections[] = $section;
		}

		/**
		 * Renders the sections and retrieves the HTML content
		 * @access public
		 * @return string
		 */
		public function renderSections() {
			/* @var $section tariqa3ModuleSection */
			$tpl = new \MetaNull\Application\MTemplate('m');
			$tpl->loadTemplate($this->config['templates']['base'] . '/' . $this->config['templates']['default'] . '/sections.html');
			$tpl->data['sections'] = array();
			foreach ($this->sections as $section){
				$before = $section->beforeSection();
				$after = $section->afterSection();
				$tpl->data['sections'][] = array(
					'id' => $section->get_section_id(),
					'html' => $section->run(),
					'html_before' => $before,
					'html_after' => $after,
					'display_before' => ($before == null?'none':'block'),
					'display_after' => ($after == null?'none':'block'),
				);

				$this->setMoreInfos($section->getInfo());
			}

			return $tpl->transform();
		}
	}
}
?>
