<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3{
	/*
	 * Helper class for representing a jQuery tree
	 */
	abstract class TreeFolder{
		/**
		 * The template file
		 * @var string
		 * @access private
		 */
		private $template_file;

		/**
		 * The value of the null parent id
		 * @var string
		 * @access private
		 */
		private $null_id;

		/**
		 * If true, select the nodes in the tree when clicking on them
		 * @var boolean
		 * @access private
		 */
		private $select_nodes = true;

		/**
		 * Constructs the object
		 * @param string $template_file The template file to load
		 * @param boolean $select_nodes If true, select the nodes in the tree when clicking on them [OPTIONAL]
		 * @param string $null_id The tree id in case that the folder is null (we are searching for the folders without parent [OPTIONAL])
		 * @access public
		 * @return void
		 */
		public function __construct($template_file, $select_nodes = true, $null_id = null) {
			$this->template_file = $template_file;
			$this->null_id = $null_id;
			$this->select_nodes = $select_nodes;
		}

		/**
		 * Returns the subfolders of the current folder as an associative array with all the subfolders
		 * @param int $folder_id The folder identifier
		 * @access public
	 * @abstract
		 * @return array|boolean
		 */
		public abstract function getSubFolders($folder_id);

		/**
		 * Returns the files of the current folder as an associative array
		 * @param int $folder_id The folder identifier
		 * @access public
	 * @abstract
		 * @return array|boolean
		 */
		public abstract function getFiles($folder_id);

		/**
		 * Generates the HTML tree for a given folder
		 * @param string $name The name of the folder
		 * @param int $folder_id The folder identifier
                 * @param string $folder_type The folder type [OPTIONAL]
		 * @access public
		 * @return string
		 */
		public function folderHTML($name, $folder_id, $folder_type = null) {
			//Loads the template file
			$tpl = new \MetaNull\Application\MTemplate( 'm' );

			$tpl->loadTemplate($this->template_file);

			$tpl->data['id'] = ($folder_id == null?$this->null_id:'F_' . $folder_id);
			$tpl->data['name'] = $name;
			$tpl->data['sub_folders_html_content'] = '';
			$tpl->data['select_nodes'] = ($this->select_nodes?'true':'false');
			$tpl->data['folder_type'] = ($folder_type == null?'folder':$folder_type);
			if ($folder_id != null) $tpl->data['show_root_node'] = true;
			else {
				$tpl->data['show_root_node'] = $this->null_id != null;
			}

			//Get all the subfolders to display them first

			$rows = $this->getSubFolders($folder_id);

			foreach ($rows as $row){
				$tpl->data['sub_folders_html_content'] .= $this->folderHTML($row['name'], $row['folder_id'], $row['type']);
			}

			$tpl->data['folder_items'] = array();

			//After displaying the subfolders, then display the files

			$rows = $this->getFiles($folder_id);

			foreach ($rows as $row){
				$custom_style = '';
				if (array_key_exists('custom_style', $row)) $custom_style = $row['custom_style'];
				$tpl->data['folder_items'][] = array(
					'id' => 'I_' . $row['file_id'],
					'name' => $row['name'],
					'open_link' => $row['open_link'],
                                        'file_type' => $row['type'], 
					'custom_style' => $custom_style,
				);
			}

			return $tpl->transform();
		}
	}
}

?>
