-- MySQL dump 10.11
--
-- Host: d02di0827377    Database: hotspots
-- ------------------------------------------------------
-- Server version	5.0.67-community-nt

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `articles`
--

CREATE DATABASE  IF NOT EXISTS `hotspots` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `hotspots`;

DROP TABLE IF EXISTS `articles`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `articles` (
  `article_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier of the article (url is wrong as it can appear in several feeds)',
  `feed_id` int(11) unsigned NOT NULL COMMENT 'ID of the feed this article belongs to',
  `date` datetime default NULL COMMENT 'Date of publication of the article',
  `title` varchar(255) NOT NULL COMMENT 'Title of the article (truncated to 255 chars)',
  `headline` text COMMENT 'Title of the article (full length)',
  `summary` text COMMENT 'Summary of the article',
  `content` text COMMENT 'Body of the article',
  `language` varchar(12) default NULL COMMENT 'Language of the article',
  `agency` text COMMENT 'Name of the Press Agency',
  `latestnews_id` int(11) unsigned default NULL COMMENT 'Internal ID of the article in the LatestNews database',
  `ts_article` timestamp NOT NULL default CURRENT_TIMESTAMP COMMENT 'Load date of the article',
  PRIMARY KEY  (`article_id`),
  KEY `idx_articles_feed_id_date` (`feed_id`,`date`),
  KEY `idx_articles_feed_id_date_title` (`feed_id`,`date`,`title`),
  KEY `ix_articles_ts_article` (`ts_article`),
  KEY `idx_articles_title` (`title`),
  CONSTRAINT `fk_articles` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=99753 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='Stores the list of articles of each feed';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `articles_per_day`
--

DROP TABLE IF EXISTS `articles_per_day`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `articles_per_day` (
  `article_per_day_id` int(10) unsigned NOT NULL auto_increment,
  `date` date NOT NULL,
  `no` int(10) unsigned NOT NULL,
  `country_id` varchar(2) NOT NULL,
  PRIMARY KEY  USING BTREE (`article_per_day_id`)
) ENGINE=InnoDB AUTO_INCREMENT=23853 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `articles_per_hour`
--

DROP TABLE IF EXISTS `articles_per_hour`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `articles_per_hour` (
  `article_per_hour_id` int(10) unsigned NOT NULL auto_increment,
  `no` int(10) unsigned NOT NULL,
  `hour` int(10) unsigned NOT NULL,
  `date` date NOT NULL,
  `country_id` varchar(2) NOT NULL,
  PRIMARY KEY  (`article_per_hour_id`)
) ENGINE=InnoDB AUTO_INCREMENT=168136 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `countries`
--

DROP TABLE IF EXISTS `countries`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `countries` (
  `country_id` varchar(2) NOT NULL COMMENT 'ISO 3166-1',
  `name_en` varchar(255) NOT NULL COMMENT 'ISO 3166-2',
  `name_fr` varchar(255) NOT NULL COMMENT 'ISO 3166-2',
  `parent_country_id` varchar(2) default NULL COMMENT '"Parent" country or NULL',
  `eu_member` enum('0','1') NOT NULL default '0' COMMENT '1 if the Country belongs to the European Union',
  `continent_id` int(11) unsigned default NULL COMMENT 'Ref to the continent',
  `official` enum('0','1') NOT NULL default '1' COMMENT '0 If the country is not officialy recognised',
  `cluster_id` int(11) unsigned default NULL,
  `capital_city` varchar(255) default NULL,
  `capital_adm` varchar(255) default NULL,
  `region_id` int(11) unsigned default NULL,
  `other_country` enum('0','1') default '0' COMMENT 'If set to true, it means that there is another country with a similar name. ',
  PRIMARY KEY  (`country_id`),
  KEY `fk_countries_parents` (`parent_country_id`),
  KEY `idx_countries_name_en` (`name_en`),
  KEY `idx_countries_name_fr` (`name_fr`),
  KEY `fk_countries_continents` (`continent_id`),
  KEY `fk_countries_clusters` (`cluster_id`),
  KEY `FK_countries_official_regions` (`region_id`)
) ENGINE=FEDERATED DEFAULT CHARSET=utf8 CONNECTION='mysql://popesad:popesad@s-relex-crisis/meta_common/countries';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `countries_feeds`
--

DROP TABLE IF EXISTS `countries_feeds`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `countries_feeds` (
  `feed_id` int(11) NOT NULL,
  `country_id` varchar(16) NOT NULL,
  `type_id` int(11) NOT NULL,
  PRIMARY KEY  (`feed_id`,`country_id`,`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `feeds`
--

DROP TABLE IF EXISTS `feeds`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `feeds` (
  `feed_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier for the feed',
  `query` text NOT NULL COMMENT 'SQL WHERE statement',
  `time_range` int(11) NOT NULL default '1' COMMENT 'Number of hours to go backwards in the archive',
  `title` varchar(255) default NULL COMMENT 'Title of the feed',
  `description` text COMMENT 'Description of the feed',
  `picture` varchar(255) default NULL COMMENT 'URL to the embeded Logo',
  `link` varchar(255) default NULL COMMENT 'URL of the site corresponding to the current feed',
  `language` varchar(20) default NULL COMMENT 'Language of the feed (if avialable)',
  `copyright` text COMMENT 'Copyright information',
  `refresh_rate` int(10) unsigned NOT NULL default '15' COMMENT 'Refresh rate of the feed (in seconds). 0 means unrestricted',
  `last_refresh` datetime default NULL COMMENT 'Date/time at which the feed was last refreshed',
  PRIMARY KEY  (`feed_id`)
) ENGINE=InnoDB AUTO_INCREMENT=172 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='Stores the list of RSS feeds';
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `hotspots`
--

DROP TABLE IF EXISTS `hotspots`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `hotspots` (
  `country_id` varchar(2) NOT NULL,
  `date` date NOT NULL,
  `forced` enum('y','n') NOT NULL default 'n',
  PRIMARY KEY  USING BTREE (`country_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `pivot_data`
--

DROP TABLE IF EXISTS `pivot_data`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `pivot_data` (
  `country_id` varchar(2) NOT NULL default '',
  `2009_02_01` mediumint(5) default '0',
  `2009_02_02` mediumint(5) default '0',
  `2009_02_03` mediumint(5) default '0',
  `2009_02_04` mediumint(5) default '0',
  `2009_02_05` mediumint(5) default '0',
  `2009_02_06` mediumint(5) default '0',
  `2009_02_07` mediumint(5) default '0',
  `2009_02_08` mediumint(5) default '0',
  `2009_02_09` mediumint(5) default '0',
  `2009_02_10` mediumint(5) default '0',
  PRIMARY KEY  (`country_id`)
) ENGINE=MEMORY DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Table structure for table `statistics`
--

DROP TABLE IF EXISTS `statistics`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `statistics` (
  `country_id` varchar(2) NOT NULL COMMENT 'Country ISO2 code',
  `w_average` float default NULL COMMENT 'Average of articles per day (including weekends)',
  `w_stddev` float default NULL COMMENT 'Standard deviation of articles per day (including weekends)',
  `w_average_before` float default NULL COMMENT 'Average of articles per days older than an week (including weekends)',
  `w_stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (including weekends)',
  `average` float default NULL COMMENT 'Average of articles per day (excluding weekends)',
  `stddev` float default NULL COMMENT 'Standard deviation of articles per day (excluding weekends)',
  `average_before` float default NULL COMMENT 'Average of articles per days older than an week (excluding weekends)',
  `stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (excluding weekends)',
  `ow_average` float default NULL COMMENT 'Average of articles per day (only weekends)',
  `ow_stddev` float default NULL COMMENT 'Standard deviation of articles per day (only weekends)',
  `ow_average_before` float default NULL COMMENT 'Average of articles per days older than an week (only weekends)',
  `ow_stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (only weekends)',
  `w_variance` float default NULL COMMENT 'Variance of articles per day (including weekends)',
  `variance` float default NULL COMMENT 'Variance of articles per day (excluding weekends)',
  `ow_variance` float default NULL COMMENT 'Variance of articles per day (only weekends)',
  PRIMARY KEY  (`country_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2010-12-20 16:01:31
