<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */


	/**
	 * Containes information about a country
	 * @author Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2008
	 * */
	class Country {

		/**
		 * ISO 3166(2 alpha)
		 * @var string
		 * */
		public $code_iso2;
		
		/**
		 * ISO 3166(3 alpha)
		 * @var string
		 * */
		public $code_iso3;
		
		/**
		 * ISO 3166(numeric)
		 * @var int
		 * */
		public $code_isonum;
		
		/**
		 * E.C. COMREF PriKey
		 * @var string
		 * */
		public $code_comref;
		
		/**
		 * E.C. COMREF PriKey - Used in the CRF_DELEGATIONS table (sometimes it is out of synch with the primary code)
		 * @var string
		 * */
		public $code_comref_deleg;
		
		/**
		 * E.C. SYSPER2
		 * @var string
		 * */
		public $code_sysper2;
		
		/**
		 * Internet Assigned Numbers Authority
		 * @var string
		 * */
		public $code_iana;
		
		/**
		 * International Olympic Committee
		 * @var string
		 * */
		public $code_ioc;
		
		/**
		 * U.N. International Traffic Distinguished Signs
		 * @var string
		 * */
		public $code_un;
		
		/**
		 * I.T.U Codes for International Telephone calls
		 * @var string
		 * */
		public $code_itu;
		
		/**
		 * Name of the country in english
		 * @var string
		 * */
		public $name;
		
		/**
		 * If true, the country is a member of the European Union
		 * @var boolean
		 * */
		public $eu_member;
		
		/**
		 * If truen the country is officially recognised
		 * @var boolean
		 * */
		public $official;
		
		/**
		 * ISO2 Id of the Country 'owning' this land
		 * @var string
		 * */
		public $parent_code_iso2;
		
		/**
		 * Continent Id
		 * @var string
		 * @see Continent
		 * */
		public $continent_id;
		
		/**
		 * Oxford Analytica Country Name
		 * @var string
		 * */
		public $oxan_id;
		
		/**
		 * True if the country is a hotspot in the current day, False otherwise
		 * @var boolean
		 * */
		public $hotspot;
		
		/**
		 * Id of the cluster to which the country is belonging to
		 * @var int
		 * */
		public $cluster_id;
		
		/**
		 * The official region identifier
		 * @var int
		 * @access public
		*/
		public $region_id;

		/**
		 * The list of ReliefWeb maps
		 * @var ReliefWebMap[]
		 * @access public
		 */
		public $relief_web_maps = null;

		/**
		 * The list of GlobalAtlas maps
		 * @var GlobalAtlas[]
		 * @access public
		 */
		public $global_atlas_maps = null;

		/**
		 * The Wikipedia country profile
		 * @var WikipediaCountryProfile
		 * @access public
		 */
		public $wiki_data = null;
		
	}
?>