<?php

/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaAggregator extends Tariqa {

    /**
     * Configuration array
     * @var array
     * */
    protected $config = null;
    /**
     * The class is called using SOAP
     * @var boolean
     */
    public $soap;

    /**
     * Constructs a tariqaThemes Object
     * @return Tariqa
     * */
    public function __construct($config, $soap) {
        $this->config = $config;
        $this->soap = $soap;
    }

    /**
     * Get all feeds from the RSS Aggregator
     * @param string $token The session identifier
     * @return RSS_feed[]
     * */
    public function GetAllAggregatedRSSFeed($token) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $sql = <<<sql
select * from feeds;
sql;
        $query = $my->query($sql);
        if ($query === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        
        $rez = array();

        while ($row = $query->fetch_assoc()){
            $feed = new RSS_feed();
            $feed->copyright = $row["copyright"];
            $feed->description = $row["description"];
            $feed->feed_id = $row["feed_id"];
            $feed->language = $row["language"];
            $feed->last_refresh = ($row["last_refresh"] == "" ? 0 : strtotime($row["last_refresh"]));
            $feed->link = $row["link"];
            $feed->picture = ($row["manual_picture"] == null ? $row["picture"] : $row["manual_picture"]);
            $feed->refresh_rate = $row["refresh_rate"];
            $feed->title = $row["title"];
            $feed->url = $row["url"];
            $feed->use_proxy = $row["use_proxy"];
            $feed->has_video = $row['has_video'] == 'y';
            $feed->has_audio = $row['has_audio'] == 'y';

            $rez[] = $feed;
        }

        $query->free();
        $my->close();

        return $rez;
    }

    /**
     * Get a feed from RSS Aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier
     * @return RSS_feed
     * */
    public function GetAggregatedRSSFeed($token, $feed_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $id = $my->real_escape_string($feed_id);

        $sql = <<<sql
				select * from feeds where feed_id = '{$id}';
sql;
        if (($_feed = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $feed = $_feed->fetch_assoc();
        $rez = new RSS_feed();
        $rez->copyright = $feed["copyright"];
        $rez->description = $feed["description"];
        $rez->feed_id = $feed["feed_id"];
        $rez->language = $feed["language"];
        $rez->last_refresh = ($feed["last_refresh"] == "" ? 0 : strtotime($feed["last_refresh"]));
        $rez->link = $feed["link"];
        $rez->picture = ($feed["manual_picture"] == null ? $feed["picture"] : $feed["manual_picture"]);
        $rez->refresh_rate = $feed["refresh_rate"];
        $rez->title = $feed["title"];
        $rez->url = $feed["url"];
        $rez->use_proxy = $feed["use_proxy"];
        $rez->has_video = $feed['has_video'] == 'y';
        $rez->has_audio = $feed['has_audio'] == 'y';

        $_feed->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available feeds from RSS Aggregator
     * @param string $token The session identifier
     * @param string $title The title of the feed (it can be only a part of the title) [OPTIONAL]
     * @return RSS_feed[]
     * */
    public function ListAggregatedRSSFeeds($token, $title = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond = " feed_id != -1 ";
        if ($title != null) {
            $title = $my->real_escape_string($title);
            $cond = " title regexp '{$title}' ";
        }

        $sql = "select * from feeds where {$cond} order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new RSS_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = ($feed["last_refresh"] == "" ? 0 : strtotime($feed["last_refresh"]));
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->title = $feed["title"];
            $f->url = $feed["url"];
            $f->use_proxy = $feed["use_proxy"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available feeds for a selected country from the RSS aggregator
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @return RSS_feed[]
     * */
    public function GetCountryAggregatedRSSFeeds($token, $country) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $sql = "select rss_feeds.* from rss_feeds inner join rss_feeds_countries using(feed_id) where country_id = '{$cid}' order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new RSS_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = $feed["last_refresh"];
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->title = $feed["title"];
            $f->url = $feed["url"];
            $f->use_proxy = $feed["use_proxy"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available feeds for a selected theme from the RSS Aggregator
     * @param string $token The session identifier
     * @param int $theme_id The selected theme
     * @return RSS_feed[]
     * */
    public function GetThemeAggregatedRSSFeeds($token, $theme_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $sql = "select rss_feeds.* from rss_feeds inner join rss_feeds_themes using(feed_id) where theme_id = {$theme_id} order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new RSS_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = $feed["last_refresh"];
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->title = $feed["title"];
            $f->url = $feed["url"];
            $f->use_proxy = $feed["use_proxy"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get an article from the RSS Aggregator
     * @param string $token The session identifier
     * @param int $article_id The article identifier
     * @return RSS_article
     * */
    public function GetAggregatedRSSArticle($token, $article_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $id = $my->real_escape_string($article_id);

        $sql = <<<sql
				select * from articles where article_id = '{$id}';
sql;
        if (($_article = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $article = $_article->fetch_assoc();
        $rez = new RSS_article();
        $rez->article_id = $article["article_id"];
        $rez->author = $article["author"];
        $rez->comments = $article["comments"];
        $rez->date = strtotime($article["date"]);
        $rez->description = $article["description"];
        $rez->feed_id = $article["feed_id"];
        $rez->headline = $article["headline"];
        $rez->link = $article["link"];
        $rez->title = $article["title"];

        $_article->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available articles from the Aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return RSS_article[]
     * */
    public function ListAggregatedRSSArticles($token, $feed_id = null, $time_range = null, $record_range_from = null, $record_range_no = null, $time_range_count = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_feed = (is_null($feed_id) ? " feed_id <> -1 " : " feed_id = " . $my->real_escape_string($feed_id) . " ");
        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";
        $sql = <<<sql
				select *, unix_timestamp(date) as udate from articles
				where {$cond_feed} and {$cond_time} and {$cond_time_count} {$cond_query}
				order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new RSS_article();
            $a->article_id = $article["article_id"];
            $a->author = $article["author"];
            $a->comments = $article["comments"];
            $a->date = $article["udate"];
            $a->description = $article["description"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->link = $article["link"];
            $a->title = $article["title"];

            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the number of available articles from the Aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return int
     * */
    public function GetAggregatedRSSArticlesNumber($token, $feed_id = null, $time_range = null, $time_range_count = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("rss", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_feed = (is_null($feed_id) ? " feed_id <> -1 " : " feed_id = " . $my->real_escape_string($feed_id) . " ");
        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";
        $sql = <<<sql
				select count(*) as 'no' from articles
				where {$cond_feed} and {$cond_time} and {$cond_time_count} {$cond_query}
				order by `date` desc
sql;

        if (($q = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        $_q = $q->fetch_assoc();

        return $_q["no"];
    }

    /**
     * Get the list of available articles for a country from the RSS Aggregator
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return RSS_article[]
     * */
    public function GetCountryAggregatedRSSArticles($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`rss_articles`.*
from
	`rss_articles` inner join `rss_feeds` using(`feed_id`)
	inner join `rss_feeds_countries` using(`feed_id`)
where
	`country_id` = '{$cid}' and {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new RSS_article();
            $a->article_id = $article["article_id"];
            $a->author = $article["author"];
            $a->comments = $article["comments"];
            $a->date = $article["date"];
            $a->description = $article["description"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->link = $article["link"];
            $a->title = $article["title"];

            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available articles for a country from the RSS Aggregator
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return int
     * */
    public function GetCountryAggregatedRSSArticlesNumber($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $my2 = $this->OpenDatabase("rss", $error);
        if (false === $my2) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`rss_feeds`.feed_id
from
	`rss_feeds` inner join `rss_feeds_countries` using(`feed_id`)
where
	`country_id` = '{$cid}'
sql;

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $cond_feeds = "";

        while ($feed = $feeds->fetch_assoc()) {
            $cond_feeds .= ( $cond_feeds == "" ? "" : " or ") . " feed_id = '{$feed["feed_id"]}'";
        }

        if ($cond_feeds != "")
            $cond_feeds = "($cond_feeds) and ";

        $sql = <<<sql
select
	count(*) as 'no'
from
	`articles`
where
{$cond_feeds} {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (($q = $my2->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql);
            $my2->close();
            return null;
        }

        $_q = $q->fetch_assoc();

        $my->close();
        $my2->close();

        return $_q["no"];
    }

    /**
     * Get the list of available articles for a theme
     * @param string $token The session identifier
     * @param int $theme_id The selected theme
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return RSS_article[]
     * */
    public function GetThemeAggregatedRSSArticles($token, $theme_id, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`rss_articles`.*
from
	`rss_articles` inner join `rss_feeds` using(`feed_id`)
	inner join `rss_feeds_themes` using(`feed_id`)
where
	`theme_id` = '{$theme_id}' and {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new RSS_article();
            $a->article_id = $article["article_id"];
            $a->author = $article["author"];
            $a->comments = $article["comments"];
            $a->date = $article["date"];
            $a->description = $article["description"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->link = $article["link"];
            $a->title = $article["title"];

            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Get a feed from Latestnews Aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier
     * @return Latestnews_feed
     * */
    public function GetAggregatedLatestnewsFeed($token, $feed_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("latest_news", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $id = $my->real_escape_string($feed_id);

        $sql = <<<sql
				select * from feeds where feed_id = '{$id}';
sql;
        if (($_feed = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $feed = $_feed->fetch_assoc();
        $rez = new Latestnews_feed();
        $rez->copyright = $feed["copyright"];
        $rez->description = $feed["description"];
        $rez->feed_id = $feed["feed_id"];
        $rez->language = $feed["language"];
        $rez->last_refresh = ($feed["last_refresh"] == "" ? 0 : strtotime($feed["last_refresh"]));
        $rez->link = $feed["link"];
        $rez->picture = $feed["picture"];
        $rez->query = $feed["query"];
        $rez->refresh_rate = $feed["refresh_rate"];
        $rez->time_range = $feed["time_range"];
        $rez->title = $feed["title"];

        $_feed->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available feeds from latestnews aggregator
     * @param string $token The session identifier
     * @param string $title The title of the feed (it can be only a part of the title) [OPTIONAL]
     * @return Latestnews_feed[]
     * */
    public function ListAggregatedLatestnewsFeeds($token, $title = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("latest_news", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond = " feed_id != -1 ";
        if ($title != null) {
            $title = $my->real_escape_string($title);
            $cond = " title regexp '{$title}' ";
        }

        $sql = "select * from feeds where {$cond} order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new RSS_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = ($feed["last_refresh"] == "" ? 0 : strtotime($feed["last_refresh"]));
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->query = $feed["query"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->time_range = $feed["time_range"];
            $f->title = $feed["title"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available latestnews feeds for a selected country
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @return Latestnews_feed[]
     * */
    public function GetAggregatedLatestnewsCountryFeeds($token, $country) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $sql = "select latestnews_feeds.* from latestnews_feeds inner join latestnews_feeds_countries using(feed_id) where country_id = '{$cid}' order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new Latestnews_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = $feed["last_refresh"];
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->query = $feed["query"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->time_range = $feed["time_range"];
            $f->title = $feed["title"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available latestnews feeds for a selected theme
     * @param string $token The session identifier
     * @param int $theme_id The selected theme
     * @return Latestnews_feed[]
     * */
    public function GetAggregatedLatestnewsThemeFeeds($token, $theme_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $sql = "select latestnews_feeds.* from latestnews_feeds inner join latestnews_feeds_themes using(feed_id) where theme_id = {$theme_id} order by feed_id";

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($feed = $feeds->fetch_assoc()) {
            $f = new Latestnews_feed();
            $f->copyright = $feed["copyright"];
            $f->description = $feed["description"];
            $f->feed_id = $feed["feed_id"];
            $f->language = $feed["language"];
            $f->last_refresh = $feed["last_refresh"];
            $f->link = $feed["link"];
            $f->picture = $feed["picture"];
            $f->query = $feed["query"];
            $f->refresh_rate = $feed["refresh_rate"];
            $f->time_range = $feed["time_range"];
            $f->title = $feed["title"];

            array_push($rez, $f);
        }

        $feeds->free();
        $my->close();

        return $rez;
    }

    /**
     * Get an article from Latestnews Aggregator
     * @param string $token The session identifier
     * @param int $article_id The article identifier
     * @return Latestnews_article
     * */
    public function GetAggregatedLatestnewsArticle($token, $article_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("latest_news", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $id = $my->real_escape_string($article_id);

        $sql = <<<sql
				select * from articles where article_id = '{$id}';
sql;
        if (($_article = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $article = $_article->fetch_assoc();
        $rez = new Latestnews_article();
        $rez->article_id = $article["article_id"];
        $rez->agency = $article["agency"];
        $rez->content = $article["content"];
        $rez->date = strtotime($article["date"]);
        $rez->feed_id = $article["feed_id"];
        $rez->headline = $article["headline"];
        $rez->language = $article["language"];
        $rez->latestnews_id = $article["latestnews_id"];
        $rez->summary = $article["summary"];
        $rez->title = $article["title"];

        $_article->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available articles from Latestnews aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of articles to be retrieved from the first article(null means all articles) [OPTIONAL]
     * @param int $time_range_count The number of days starting from time range (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return Latestnews_article[]
     * */
    public function ListAggregatedLatestnewsArticles($token, $feed_id = null, $time_range = null, $record_range_from = null, $record_range_no = null, $time_range_count = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("latest_news", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_feed = (is_null($feed_id) ? " feed_id <> -1 " : " feed_id = " . $my->real_escape_string($feed_id) . " ");
        $cond_time = (is_null($time_range) ? " `date` <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
				select *, unix_timestamp(date) as udate from articles
				where {$cond_feed} and {$cond_time} and {$cond_time_count} {$cond_query}
				order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new Latestnews_article();
            $a->article_id = $article["article_id"];
            $a->agency = $article["agency"];
            $a->content = $article["content"];
            $a->date = $article["udate"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->language = $article["language"];
            $a->latestnews_id = $article["latestnews_id"];
            $a->summary = $article["summary"];
            $a->title = $article["title"];

            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the number of available articles from Latestnews aggregator
     * @param string $token The session identifier
     * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The number of days starting from time range (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return int
     * */
    public function GetAggregatedLatestnewsArticlesNumber($token, $feed_id = null, $time_range = null, $time_range_count = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("latest_news", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_feed = (is_null($feed_id) ? " feed_id <> -1 " : " feed_id = " . $my->real_escape_string($feed_id) . " ");
        $cond_time = (is_null($time_range) ? " `date` <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
				select count(*) as 'no' from articles
				where {$cond_feed} and {$cond_time} and {$cond_time_count} {$cond_query}
				order by `date` desc
sql;

        if (($q = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $_q = $q->fetch_assoc();

        $my->close();

        return $_q["no"];
    }

    /**
     * Get the number of available latestnews articles for a country
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return int
     * */
    public function GetAggregatedLatestnewsCountryArticlesNumber($token, $country, $time_range = null, $time_range_count = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $my2 = $this->OpenDatabase("latest_news", $error);
        if (false === $my2) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`latestnews_feeds`.feed_id
from
	`latestnews_feeds` inner join `latestnews_feeds_countries` using(`feed_id`)
where
	`country_id` = '{$cid}'
sql;

        if (($feeds = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $cond_feeds = "";

        while ($feed = $feeds->fetch_assoc()) {
            $cond_feeds .= ( $cond_feeds == "" ? "" : " or ") . " feed_id = '{$feed["feed_id"]}'";
        }

        if ($cond_feeds != "")
            $cond_feeds = "($cond_feeds) and ";

        $sql = <<<sql
select
	count(*) as 'no'
from
	`articles`
where
{$cond_feeds} {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (($q = $my2->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql);
            $my2->close();
            return null;
        }

        $_q = $q->fetch_assoc();

        $my->close();
        $my2->close();

        return $_q["no"];
    }

    /**
     * Get the list of available latestnews articles for a country
     * @param string $token The session identifier
     * @param Country $country The selected country
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return Latestnews_article[]
     * */
    public function GetAggregatedLatestnewsCountryArticles($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cid = $my->real_escape_string($country->code_iso2);

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`latestnews_articles`.*
from
	`latestnews_articles` inner join `latestnews_feeds` using(`feed_id`)
	inner join `latestnews_feeds_countries` using(`feed_id`)
where
	`country_id` = '{$cid}' and {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new Latestnews_article();
            $a->article_id = $article["article_id"];
            $a->agency = $article["agency"];
            $a->content = $article["content"];
            $a->date = $article["date"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->language = $article["language"];
            $a->latestnews_id = $article["latestnews_id"];
            $a->summary = $article["summary"];
            $a->title = $article["title"];

            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Get the list of available latestnews articles for a theme
     * @param string $token The session identifier
     * @param int $theme_id The selected theme
     * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
     * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
     * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
     * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
     * @param string $query The query to search from [OPTIONAL]
     * @return RSS_article[]
     * */
    public function GetAggregatedLatestnewsThemeArticles($token, $theme_id, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null, $query = null) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqapro", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $cond_time = (is_null($time_range) ? " date <> '0000-00-00 00:00:00'" : " date_add(`date`, interval {$time_range} day) >= now() ");
        $cond_time_count = (is_null($time_range_count) || is_null($time_range) ? " `date` <> '0000-00-00 00:00:00' " : " `date` <= date_add(date_sub(now(), interval {$time_range} day), interval {$time_range_count} day) ");
        $cond_query = '';
        if ($query != null)
            $cond_query = " and ({$query})";

        $sql = <<<sql
select
	`latestnews_articles`.*
from
	`latestnews_articles` inner join `latestnews_feeds` using(`feed_id`)
	inner join `latestnews_feeds_themes` using(`feed_id`)
where
	`theme_id` = '{$theme_id}' and {$cond_time} and {$cond_time_count} {$cond_query}
order by `date` desc
sql;

        if (!is_null($record_range_from) && !is_null($record_range_no))
            $sql .= " limit " . $record_range_from . ", " . $record_range_no;

        if (($articles = $my->query($sql)) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql);
            $my->close();
            return null;
        }

        $rez = array();

        while ($article = $articles->fetch_assoc()) {
            $a = new Latestnews_article();
            $a->article_id = $article["article_id"];
            $a->agency = $article["agency"];
            $a->content = $article["content"];
            $a->date = $article["date"];
            $a->feed_id = $article["feed_id"];
            $a->headline = $article["headline"];
            $a->language = $article["language"];
            $a->latestnews_id = $article["latestnews_id"];
            $a->summary = $article["summary"];
            $a->title = $article["title"];


            array_push($rez, $a);
        }

        $articles->free();
        $my->close();

        return $rez;
    }

    /**
     * Creates a new RSS Feed
     * @param string $token The session identifier
     * @param RSS_feed $feed The new feed to be inserted in the database
     * @param Country $country The feed country (null if there is not a country for this feed)
     * @param Theme $theme The feed theme (null if there is not a theme for this feed)
     * @return boolean
     * */
    public function CreateAggregatedRSSFeed($token, $feed, $country, $theme) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $url = (!is_null($feed->url) ? '"' . $my->real_escape_string($feed->url) . '"' : "null");
        $title = (!is_null($feed->title) ? '"' . $my->real_escape_string($feed->title) . '"' : "null");
        $description = (!is_null($feed->description) ? '"' . $my->real_escape_string($feed->description) . '"' : "null");
        $picture = (!is_null($feed->picture) ? '"' . $my->real_escape_string($feed->picture) . '"' : "null");
        $link = (!is_null($feed->link) ? '"' . $my->real_escape_string($feed - link) . '"' : "null");
        $language = (!is_null($feed->language) ? '"' . $my->real_escape_string($feed->language) . '"' : "null");
        $copyright = (!is_null($feed->copyright) ? '"' . $my->real_escape_string($feed->copyright) . '"' : "null");
        $use_proxy = (!is_null($feed->use_proxy) ? '"' . $my->real_escape_string(($feed->use_proxy ? 1 : 0)) . '"' : "null");
        $last_refresh = (!is_null($feed->last_refresh) ? '"' . $my->real_escape_string($feed->last_refresh) . '"' : "null");
        $refresh_rate = (!is_null($feed->refresh_rate) ? '"' . $my->real_escape_string($feed->refresh_rate) . '"' : "15");
        $my->autocommit(false);
        $sql = "start transaction";
        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				insert into rss_feeds(url, title, description, picture, link, language,
					copyright, refresh_rate, last_refresh, use_proxy)
				values({$url}, {$title}, {$description}, {$picture}, {$link},
				{$language}, {$copyright}, {$refresh_rate},
				{$last_refresh}, {$use_proxy})
sql;

        if ($my->query($sql) === false) {
            $my->rollback();
            $my->close();
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            return null;
        }

        $sql = "select last_insert_id() as id";
        if (($q = $my->query($sql)) === false) {
            $my->rollback();
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        $_q = $q->fetch_assoc();

        $feed_id = $_q["id"];
        $q->free();
        $my->commit();
        $my->autocommit(true);

        if (!is_null($country)) {
            $sql = <<<sql
					insert into rss_feeds_countries(feed_id, country_id)
					values({$feed_id}, '{$country->code_iso2}')
sql;

            if ($my->query($sql) === false) {
                return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
                $my->close();
                return null;
            }
        }

        if (!is_null($theme)) {
            $sql = <<<sql
					insert into rss_feeds_themes(feed_id, theme_id)
					values({$feed_id}, {$theme->theme_id})
sql;

            if ($my->query($sql) === false) {
                return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
                $my->close();
                return null;
            }
        }

        $my->close();

        return true;
    }

    /**
     * Updates an existing RSS Feed
     * @param string $token The session identifier
     * @param RSS_feed $feed The new feed to be inserted in the database
     * @return int (The number of records affected)
     * */
    public function UpdateAggregatedRSSFeed($token, $feed) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $url = (!is_null($feed->url) ? '"' . $my->real_escape_string($feed->url) . '"' : "null");
        $title = (!is_null($feed->title) ? '"' . $my->real_escape_string($feed->title) . '"' : "null");
        $description = (!is_null($feed->description) ? '"' . $my->real_escape_string($feed->description) . '"' : "null");
        $picture = (!is_null($feed->picture) ? '"' . $my->real_escape_string($feed->picture) . '"' : "null");
        $link = (!is_null($feed->link) ? '"' . $my->real_escape_string($feed - link) . '"' : "null");
        $language = (!is_null($feed->language) ? '"' . $my->real_escape_string($feed->language) . '"' : "null");
        $copyright = (!is_null($feed->copyright) ? '"' . $my->real_escape_string($feed->copyright) . '"' : "null");
        $use_proxy = (!is_null($feed->use_proxy) ? '"' . $my->real_escape_string(($feed->use_proxy ? 1 : 0)) . '"' : "null");
        $last_refresh = (!is_null($feed->last_refresh) ? '"' . $my->real_escape_string(date("Y-m-d", $feed->last_refresh)) . '"' : "null");
        $refresh_rate = (!is_null($feed->refresh_rate) ? '"' . $my->real_escape_string($feed->refresh_rate) . '"' : "null");

        $sql = <<<sql
				update rss_feeds set
					url = {$url},
					title = {$title},
					description = {$description},
					picture = {$picture},
					link = {$link},
					language = {$language},
					copyright = {$copyright},
					refresh_rate = {$refresh_rate},
					use_proxy = {$use_proxy}
				where feed_id = {$feed->feed_id}
sql;
        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        $my->close();
        return $my->affected_rows;
    }

    /**
     * Deletes a RSS Feed
     * @param string $token The session identifier
     * @param int $feed_id The feed identificator
     * @return boolean
     * */
    public function DeleteAggregatedRSSFeed($token, $feed_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $sql = <<<sql
				delete from rss_feeds where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				delete from rss_feeds_countries where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				delete from rss_feeds_themes where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $my->close();

        return true;
    }

    /**
     * Creates a new Latestnews Feed
     * @param string $token The session identifier
     * @param Latestnews_feed $feed The new feed to be inserted in the database
     * @param Country $country The feed country (null if there is not a country for this feed)
     * @param Theme $theme The feed theme (null if there is not a theme for this feed)
     * @return boolean
     * */
    public function CreateAggregatedLatestnewsFeed($token, $feed, $country, $theme) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $query = (!is_null($feed->query) ? '"' . $my->real_escape_string($feed->query) . '"' : "null");
        $title = (!is_null($feed->title) ? '"' . $my->real_escape_string($feed->title) . '"' : "null");
        $description = (!is_null($feed->description) ? '"' . $my->real_escape_string($feed->description) . '"' : "null");
        $picture = (!is_null($feed->picture) ? '"' . $my->real_escape_string($feed->picture) . '"' : "null");
        $link = (!is_null($feed->link) ? '"' . $my->real_escape_string($feed - link) . '"' : "null");
        $language = (!is_null($feed->language) ? '"' . $my->real_escape_string($feed->language) . '"' : "null");
        $copyright = (!is_null($feed->copyright) ? '"' . $my->real_escape_string($feed->copyright) . '"' : "null");
        $time_range = (!is_null($feed->time_range) ? '"' . $my->real_escape_string($feed->time_range) . '"' : "1");
        $last_refresh = (!is_null($feed->last_refresh) ? '"' . $my->real_escape_string($feed->last_refresh) . '"' : "null");
        $refresh_rate = (!is_null($feed->refresh_rate) ? '"' . $my->real_escape_string($feed->refresh_rate) . '"' : "15");

        $my->autocommit(false);
        $sql = "start transaction";
        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				insert into latestnews_feeds(query, title, description, picture, link, language,
					copyright, refresh_rate, last_refresh, time_range)
				values({$query}, {$title}, {$description}, {$picture}, {$link},
				{$language}, {$copyright}, {$refresh_rate},
				{$last_refresh}, {$time_range})
sql;

        if ($my->query($sql) === false) {
            $my->rollback();
            $my->close();
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            return null;
        }

        $sql = "select last_insert_id() as id";
        if (($q = $my->query($sql)) === false) {
            $my->rollback();
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        $_q = $q->fetch_assoc();

        $feed_id = $_q["id"];
        $q->free();
        $my->commit();
        $my->autocommit(true);

        if (!is_null($country)) {
            $sql = <<<sql
					insert into latestnews_feeds_countries(feed_id, country_id)
					values({$feed_id}, '{$country->code_iso2}')
sql;

            if ($my->query($sql) === false) {
                return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
                $my->close();
                return null;
            }
        }

        if (!is_null($theme)) {
            $sql = <<<sql
					insert into latestnews_feeds_themes(feed_id, theme_id)
					values({$feed_id}, {$theme->theme_id})
sql;

            if ($my->query($sql) === false) {
                return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
                $my->close();
                return null;
            }
        }

        $my->close();

        return true;
    }

    /**
     * Updates an existing Latestnews Feed
     * @param string $token The session identifier
     * @param Latestnews_feed $feed The new feed to be inserted in the database
     * @return int (The number of records affected)
     * */
    public function UpdateAggregatedLatestnewsFeed($token, $feed) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $query = (!is_null($feed->query) ? '"' . $my->real_escape_string($feed->query) . '"' : "null");
        $title = (!is_null($feed->title) ? '"' . $my->real_escape_string($feed->title) . '"' : "null");
        $description = (!is_null($feed->description) ? '"' . $my->real_escape_string($feed->description) . '"' : "null");
        $picture = (!is_null($feed->picture) ? '"' . $my->real_escape_string($feed->picture) . '"' : "null");
        $link = (!is_null($feed->link) ? '"' . $my->real_escape_string($feed - link) . '"' : "null");
        $language = (!is_null($feed->language) ? '"' . $my->real_escape_string($feed->language) . '"' : "null");
        $copyright = (!is_null($feed->copyright) ? '"' . $my->real_escape_string($feed->copyright) . '"' : "null");
        $time_range = (!is_null($feed->time_range) ? '"' . $my->real_escape_string($feed->time_range) . '"' : "null");
        $last_refresh = (!is_null($feed->last_refresh) ? '"' . $my->real_escape_string(date("Y-m-d", $feed->last_refresh)) . '"' : "null");
        $refresh_rate = (!is_null($feed->refresh_rate) ? '"' . $my->real_escape_string($feed->refresh_rate) . '"' : "null");

        $sql = <<<sql
				update latestnews_feeds set
					query = {$query},
					title = {$title},
					description = {$description},
					picture = {$picture},
					link = {$link},
					language = {$language},
					copyright = {$copyright},
					refresh_rate = {$refresh_rate},
					time_range = {$time_range}
				where feed_id = {$feed->feed_id}
sql;
        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }
        $my->close();
        return $my->affected_rows;
    }

    /**
     * Deletes a Latestnews Feed
     * @param string $token The session identifier
     * @param int $feed_id The feed identificator
     * @return boolean
     * */
    public function DeleteAggregatedLatestnewsFeed($token, $feed_id) {
        if (false === $this->CheckToken($token)) {
            return new SoapFault((string) self::e_session, self::e_session_msg);
            return null;
        }

        $error = false;
        $my = $this->OpenDatabase("tariqadev", $error);
        if (false === $my) {
            return new SoapFault((string) self::e_database, $error);
        }

        $sql = <<<sql
				delete from latestnews_feeds where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				delete from latestnews_feeds_countries where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $sql = <<<sql
				delete from latestnews_feeds_themes where feed_id = {$feed_id}
sql;

        if ($my->query($sql) === false) {
            return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query);
            $my->close();
            return null;
        }

        $my->close();

        return true;
    }

}

?>