<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaBuzztracker extends Tariqa {

	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get the Buzztracker map of a given date
	 * @param string $token Session identifier
	 * @param int $date The date to fetch (unix format timestamp)
	 * @return string[] The First element of the array is the HTML imagemap, the second element is the list of major hotspots
	 * */
	public function fetchBuzztracker( $token, $date ) {
		$url = "http://www.buzztracker.org/";
		if( 0 == $date ) {
			$date = time();
		}
		$url .= date( "Y/m/d", $date );

		$buz = $this->fetchUrl( $token, new WebRequest( $url ));
		$options = array(
				"drop-proprietary-attributes" => true,
				"clean" => true,
				"output-xhtml" => true,
				"show-body-only" => true,
		);
		$tidy = tidy_parse_string( $buz->body, $options, "utf8" );
		$tidy->cleanRepair();
		$bdy = (string)$tidy;
		$dom = new DomDocument();
		$dom->loadHTML( $bdy );

		$xp = new DOMXPath( $dom );
		$xpmap = "/html/body//table[1]/tr/td[2]/map/area";
		$xpimg = "/html/body//table[1]/tr/td[2]/img/@src";
		$xptxt = "/html/body//table[1]/tr/td[1]/ul[1]/li/a";

		$rs = $xp->query( $xpimg );
		if( 0 == $rs->length ) {
			return new SoapFault((string) self::e_http404, self::e_http404_msg );
			return null;
		}
		$result = array( "", "" );
		$result[0] .= "<img src=\"".$rs->item(0)->nodeValue."\" usemap=\"#map\" alt=\"Buzztracker\"/><map name=\"map\" id=\"map\" >";
		$rs = $xp->query( $xpmap );
		foreach( $rs as $node ) {
			$result[0] .= "<area ".
								"href=\"http://www.buzztracker.org".$node->getAttribute("href")."\" ".
								"shape=\"".$node->getAttribute("shape")."\" ".
								"coords=\"".$node->getAttribute("coords")."\" ".
								"alt=\"".$node->getAttribute("alt")."\" ".
							"/>\n";
		}
		$result[0] .= "</map>";
		$rs = $xp->query( $xptxt );
		foreach( $rs as $node ) {
			$result[1] .= "<a href=\"".$node->getAttribute("href")."\">".$node->nodeValue."</a><br/>\n";
		}

		return $result;
	}


}
?>