<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaGoogle extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Search for articles using Google News
	 * @param string $token Session Identifier
	 * @param GoogleQuery $query Query
	 * @return GoogleResultset
	 **/
	public function googleSearch( $token, $query ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_googleSearch( $query );
	}

	/**
	 * Fetch the next articles from a Google Search (returns NULL when no more articles are available)
	 * @param string $token Session Identifier
	 * @param GoogleResultset $resultset Resultset
	 * @param int $first The first article [OPTIONAL]
	 * @param int $count Count of articles [OPTIONAL]
	 * @return GoogleResultset
	 **/
	public function googleFetch( $token, $resultset, $first = null, $count = null ) {
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$query = unserialize( gzuncompress( base64_decode( $resultset->engineData )));
		$articles_per_page = count($resultset->searchResults);
		if ($first !== null){
			$_next = floor($first / $articles_per_page) * $articles_per_page;
		}
		else {
			$_next = 0;
		}

		$query->start = $_next;

		$rs = $this->_googleSearch( $query );

		if( $rs->estimatedResultCount < $query->start ) {
			return null;
		}

		if ($first !== null){
			$_start = $first % $articles_per_page;
			$_articles = array();

			for ($i = $_start; $i < $_start + min($count, $articles_per_page - $_start); $i++)
			    $_articles[] = $rs->searchResults[$i];

			if ($count > $articles_per_page - $_start){
				$fetched = $articles_per_page - $_start;
				while ($fetched < $count && $rs->estimatedResultCount >= $query->start){
					$query->start += $articles_per_page;
					try{
						$rs = $this->_googleSearch($query);
					}
					catch (Exception $e){
						if (count($_articles) > 0){
							$rs->searchResults = $_articles;
							return $rs;
						}
						else return null;
					}

					if ($rs->estimatedResultCount >= $query->start)
					for ($i = 0; $i < min($count - $fetched, $articles_per_page); $i++){
						$_articles[] = $rs->searchResults[$i];
					}
					$fetched += min($count - $fetched, $articles_per_page);
				}
			}

			$rs->searchResults = $_articles;
		}

		// if( $rs->estimatedResultCount != $resultset->estimatedResultCount ) {
		// }
		return $rs;
	}

	/**
	 * Search for articles using Google News
	 * @param string $token Session Identifier
	 * @param GoogleQuery $query Query
	 * @return GoogleResultset
	 **/
	protected function _googleSearch( $query ) {
		$args = array();
		$args[] = new Pair( 'v', '1.0' );
		$args[] = new Pair( 'key', $this->config['sources']['google']['api-key'] );
		if( null !== $query->query ) {	$args[] = new Pair( 'q', $query->query );	}
		if( null !== $query->start ) {	$args[] = new Pair( 'start', $query->start );
		} else {	$args[] = new Pair( 'start', '0' ); }
		if( null !== $query->source ) {
			$variables = explode('&', $query->source);
			
			foreach ($variables as $variable){
				$parts = explode('=', $variable);
				if (count($parts) == 2){
					$args[] = new Pair($parts[0], $parts[1]);
				}
			}	
			//$args[] = new Pair( 'ned', $query->source );	
		}
		if( GoogleQuery::scoring_Date == $query->scoring ) {	$args[] = new Pair( 'scoring', GoogleQuery::scoring_Date );	}
		else {
			$args[] = new Pair('scoring', $query->scoring);
		}
		if( null !== $query->topic ) {	$args[] = new Pair( 'topic', $query->topic );	}
		if( GoogleQuery::size_small == $query->size ) {
			$args[] = new Pair( 'rsz', GoogleQuery::size_small );
		} else {	$args[] = new Pair( 'rsz', GoogleQuery::size_large ); }

		if (is_array($query->specific_options))

		foreach($query->specific_options as $option){
			$args[] = $option;
		}

		$req = new WebRequest("http://ajax.googleapis.com/ajax/services/search/{$query->data}", $args, false, WebRequest::HTTP_GET );

		$req->follow_redirect = true;

		$resp = new WebDocument();
		$resp = $this->_fetchUrl( $req );

		$ggnrs = json_decode( $resp->body );

		$result = new GoogleResultset();
		$result->responseDetails = $ggnrs->responseDetails;
		$result->responseStatus = $ggnrs->responseStatus;

		if( null !== $result->responseDetails ) {
			throw new Exception(self::e_internal_error_msg . "\n" . 'HTTP ' . $result->responseStatus . ". \n" . $result->responseDetails);
			/*return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . 'HTTP ' . $result->responseStatus . ". \n" . $result->responseDetails );
				return null;*/
		}
		$result->currentPageIndex = $ggnrs->responseData->cursor->currentPageIndex;
		$result->estimatedResultCount = $ggnrs->responseData->cursor->estimatedResultCount;
		$result->moreResultsUrl = $ggnrs->responseData->cursor->moreResultsUrl;

		$result->engineData = base64_encode(gzcompress(serialize($query)));

		// foreach( $ggnrs->responseData->results )
		$result->pages = array();
		if (is_array($ggnrs->responseData->cursor->pages))
		foreach( $ggnrs->responseData->cursor->pages as $k => $page) {
			$result->pages[] = new Pair( $page->label, $page->start );
		}

		$result->searchResults = array();
		foreach( $ggnrs->responseData->results as $ggn_article) {
			$gnsr = new GoogleSearchResult();
			$gnsr->content = $ggn_article->content;
			$gnsr->title = $ggn_article->title;
			$gnsr->titleNoFormatting = $ggn_article->titleNoFormatting;

			switch($query->data){
				case "web":
					$gnsr->GsearchResultClass = 'GwebSearch';
					$gnsr->visibleUrl = $ggn_article->visibleUrl;
					$gnsr->cacheUrl = $ggn_article->cacheUrl;
					$gnsr->unescapedUrl = $ggn_article->unescapedUrl;
					$gnsr->url = $ggn_article->url;
					break;
				case "news":
					$gnsr->GsearchResultClass = 'GnewsSearch';
					$gnsr->clusterUrl = $ggn_article->clusterUrl;
					$gnsr->location = $ggn_article->location;
					$gnsr->publisher = $ggn_article->publisher;
					$gnsr->publishedDate = strtotime( $ggn_article->publishedDate );
					$gnsr->signedRedirectUrl = $ggn_article->signedRedirectUrl;
					$gnsr->language = $ggn_article->language;
					$gnsr->unescapedUrl = $ggn_article->unescapedUrl;
					$gnsr->url = $ggn_article->url;
					break;
				case "blogs":
					$gnsr->GsearchResultClass = 'GblogSearch';
					$gnsr->postUrl = $ggn_article->postUrl;
					$gnsr->author = $ggn_article->author;
					$gnsr->publishedDate = strtotime( $ggn_article->publishedDate );
					$gnsr->blogUrl = $ggn_article->blogUrl;
					break;
				case "video":
					$gnsr->GsearchResultClass = 'GvideoSearch';
					$gnsr->tbUrl = $ggn_article->tbUrl;
					$gnsr->tbWidth = $ggn_article->tbWidth;
					$gnsr->publisher = $ggn_article->publisher;
					$gnsr->published = strtotime( $ggn_article->published );
					$gnsr->tbHeight = $ggn_article->tbHeight;
					$gnsr->videoType = $ggn_article->videoType;
					$gnsr->playUrl = $ggn_article->playUrl;
					$gnsr->rating = $ggn_article->rating;
					$gnsr->duration = $ggn_article->duration;
					$gnsr->url = $ggn_article->url;
					break;
				case "images":
					$gnsr->GsearchResultClass = 'GimageSearch';
					$gnsr->width = $ggn_article->width;
					$gnsr->height = $ggn_article->height;
					$gnsr->imageId = $ggn_article->imageId;
					$gnsr->tbHeight = $ggn_article->tbHeight;
					$gnsr->visibleUrl = $ggn_article->visibleUrl;
					$gnsr->originalContextUrl = $ggn_article->originalContextUrl;
					$gnsr->content = $ggn_article->content;
					$gnsr->contentNoFormatting = $ggn_article->contentNoFormatting;
					$gnsr->tbUrl = $ggn_article->tbUrl;
					$gnsr->unescapedUrl = $ggn_article->unescapedUrl;
					$gnsr->url = $ggn_article->url;
					break;
			}
			
			$result->searchResults[] = $gnsr;
		}
		return $result;
	}
	
	/**
	 * Parses a google document
	 * @param string $token The session identifier
	 * @param string $url The document url
	 * @access protected
	 * @return string
	*/
	public function googleGetDocument($token, $url){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$request = new WebRequest($url);
		$resp = $this->_fetchUrl($request);
		
		if ($resp->http_code == 200)
			return $resp->body;
		
		ob_start();
			
		var_dump($resp);
		
		$contents = ob_get_contents();
		ob_end_clean();
		error_log($contents);
		
		return new SoapFault((string)self::e_http, "Error fetching Google Document");
		
		return null;
	}
}
?>