<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaHotspots extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get the list of hotspots for a day
	 * @param string $token The session identifier
	 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
	 * @return string[] A list of countries iso codes.
	 * */
	public function ListHotSpots($token, $day = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_listHotSpots( $day );
	}

	/**
	 * Get the list of hotspots for a day without authentification
	 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
	 * @return string[] A list of countries iso codes.
	 * */
	protected function _listHotSpots( $day = null){
		$error = false;
		$my = $this->OpenDatabase( "hotspots", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$date = (is_null($day)?date("Y-m-d"):date("Y-m-d", $day));

		$sql = <<<sql
				select * from `hotspots` where date = '{$date}'
sql;
		if (($hotspots = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$rez = array();

		while ($hotspot = $hotspots->fetch_assoc()){
			array_push($rez, $hotspot["country_id"]);
		}
		$hotspots->free();
		$my->close();

		return $rez;
	}



}
?>