<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaLatestNews extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Search for articles in the LatestNews database
	 * @param string $token Session Identifier
	 * @param string $query SQL query
	 * @param float $range Time range in days (you may use fractions!) [OPTIONAL]
	 * @return LatestNewsResultset
	 * */
	public function latestNewsSearch( $token, $query, $range = null ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		if( null === $range ) {
			$range = 1;
		}

		$rs = new LatestNewsResultset();

		$date_range = sprintf("%.3f", $range );
		$sql = <<<sql
select count(*)
from {$this->config["databases"]["latestnews"]["schemas"]}.wires a
where a.receptiondate >= (sysdate - {$date_range})
		{$query}
sql;

		$oracle = oci_pconnect( $this->config["databases"]["latestnews"]["user"], $this->config["databases"]["latestnews"]["pass"], $this->config["databases"]["latestnews"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $sql);
		if (!$stid) {
			$e = oci_error($oracle);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$count = oci_fetch_row( $stid );
		if( false === $count ) {
			return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . __FILE__ . " @line " . __LINE__ );
			return null;
		}
		$rs->documents_count = (int)$count[0];
		$rs->resultset_data = serialize( array('query'=>$query,'range'=>$range));

		return $rs;
	}

	/**
	 * Fetch the articles from the LatestNews database
	 * @param string $token Session Identifier
	 * @param LatestNewsResultset $resultset The resultset returned by a latestNewsSearch() operation
	 * @param int $first [OPTIONAL]
	 * @param int $count [OPTIONAL]
	 * @return LatestNewsDocument[]
	 * */
	public function latestNewsFetch( $token, $resultset, $first = null, $count = null ) {
		$documents = array();

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		if( null === $first ) {
			$first = 0;
		}
		if( null === $count ) {
			$count = 10;
		}

		// Compute the limits
		$limit_from = 1;
		$limit_to = $limit_from + $count;
		
		if( 0 > $first || $resultset->documents_count < ($first + 1)  ) {
			return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg . " {$first}, {$count}, {$resultset->resultset_data}");
			return null;
		}
		$limit_from = $first;
		$limit_to = min( $first + $count, $resultset->documents_count );
		$limit_from += 1;

		$data = unserialize( $resultset->resultset_data );

		// Fetch the requested articles
		if( 0 != $resultset->documents_count ) {
			$date_range = sprintf("%.3f", $data['range'] );
			$sql = <<<sql
select * from (
	select rownum as row_num, a.id,
		(cast(a.receptiondate as date) - to_date('19700101','YYYYMMDD')) * 86400 as wire_date,
		a.language, a.weight, a.title, a.summary, a.text, a.agency, a.urgent
	from {$this->config["databases"]["latestnews"]["schemas"]}.wires a
	where a.receptiondate >= (sysdate - {$date_range})
	{$data['query']}
)
where row_num between {$limit_from} and {$limit_to}
order by wire_date desc

sql;

	$oracle = oci_pconnect( $this->config["databases"]["latestnews"]["user"], $this->config["databases"]["latestnews"]["pass"], $this->config["databases"]["latestnews"]["dsn"], "UTF8" );
	if (!$oracle) {
		$e = oci_error();
		return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
		return null;
	}
	$stid = oci_parse($oracle, $sql);
	if (!$stid) {
		$e = oci_error($oracle);
		return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
		return null;
	}
	$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
	$r = oci_execute($stid, OCI_DEFAULT);
	if (!$r) {
		$e = oci_error($stid);
		return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
		return null;
	}
	while( $row = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ) ) {
		$document = new LatestNewsDocument();
		$document->id = (int)$row['ID'];
		$document->date = (int)$row['WIRE_DATE'];
		$document->headline = $row['TITLE'];
		$document->summary = $row['SUMMARY'];
		$document->text = $row['TEXT'];
		$document->agency = $row['AGENCY'];
		$document->language = $row['LANGUAGE'];
		$document->urgent = ('1'==$row['URGENT']?true:false);
		$document->weight = (int)$row['WEIGHT'];

		$documents[] = $document;
	}
		}

		return $documents;
	}

	/**
	 * Get a LatestNews Document
	 * @param string $token Session Identifier
	 * @param int $id Article ID
	 * @return LatestNewsDocument
	 * */
	public function latestNewsGetDocument( $token, $id ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$sql = <<<sql
select a.id,
	(cast(a.receptiondate as date) - to_date('19700101','YYYYMMDD')) * 86400 as wire_date,
	a.language, a.weight, a.title, a.summary, a.text, a.agency, a.urgent
from {$this->config["databases"]["latestnews"]["schemas"]}.wires a
where a.id = '{$id}'
sql;


		$oracle = oci_pconnect( $this->config["databases"]["latestnews"]["user"], $this->config["databases"]["latestnews"]["pass"], $this->config["databases"]["latestnews"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $sql);
		if (!$stid) {
			$e = oci_error($oracle);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$row = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS );
		if( false === $row ) {
			return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
			return null;
		}

		$document = new LatestNewsDocument();
		$document->id = (int)$row['ID'];
		$document->date = (int)$row['WIRE_DATE'];
		$document->headline = $row['TITLE'];
		$document->summary = $row['SUMMARY'];
		$document->text = $row['TEXT'];
		$document->agency = $row['AGENCY'];
		$document->language = $row['LANGUAGE'];
		$document->urgent = ('1'==$row['URGENT']?true:false);
		$document->weight = (int)$row['WEIGHT'];

		return $document;
	}

	/**
	 * Fetch the articles from the LatestNews database
	 * @param string $token Session Identifier
	 * @param string $query SQL query
	 * @param float $range Time range in days (you may use fractions!) [OPTIONAL]
	 * @param int $page_number Which page of articles to fetch [OPTIONAL]
	 * @param int $page_size How many articles should be displayed on each page [OPTIONAL]
	 * @param boolean $paginal If set to true, the results are paginated, else page_number represents the first result, and page_size the number of results [OPTIONAL]
	 * @param float $range_count The number of days to fetch the news starting ahead $range days (you may use fractions!) [OPTIONAL]
	 * @return Resultset
	 * */
	public function fetchLatestNews( $token, $query, $range = null, $page_number = null, $page_size = null, $paginal = true, $range_count = null) {
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		if( null === $range ) {
			$range = 1;
		}
		if( null === $page_number ) {
			$page_number = 0;
		}
		if( null === $page_size ) {
			$page_size = 10;
		}

		$rs = new Resultset();
		
		error_log($query);
		
		if (substr($query, 0, 3) != "and") $query = " and ({$query})";

		error_log($query);
		
		$date_range = sprintf("%.3f", $range );
		
		$cond_range_count = '';
		if ($range_count != null){
			$d = sprintf('%.3f', $date_range - $range_count);
			$cond_range_count = " and a.receptiondate <= sysdate - ({$d})";
		}

		$sql_base = <<<sql
from {$this->config["databases"]["latestnews"]["schemas"]}.wires a
where a.receptiondate >= (sysdate - {$date_range}) {$cond_range_count}
		{$query}
sql;

		// Count the number of available articles
		$sql = <<<sql
select count(*)
		{$sql_base}
sql;

		$oracle = oci_pconnect( $this->config["databases"]["latestnews"]["user"], $this->config["databases"]["latestnews"]["pass"], $this->config["databases"]["latestnews"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $sql);
		if (!$stid) {
			$e = oci_error($oracle);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$count = oci_fetch_row( $stid );
		if( false === $count ) {
			return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . __FILE__ . " @line " . __LINE__ );
			return null;
		}
		$rs->available_articles = (int)$count[0];

		// Compute the limits
		$limit_from = 1;
		$limit_to = $limit_from + $page_size;
		if ($paginal){
			/*if( 0 > $page_number || $rs->available_articles < (($page_number * $page_size) + 1)  ) {
				return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg . " {$page_number}, {$page_size}, {$rs->available_articles}");
				return null;
			}*/

			$limit_from = ($page_number * $page_size);
			$limit_to = min( ($limit_from + $page_size), $rs->available_articles );
			$limit_from += 1;
		}
		else {
			$limit_from = ($page_number);
			$limit_to = $page_number + $page_size - 1;
		}

		//if ($limit_to > $rs->available_articles) $limit_to = $rs->available_articles;

		$rs->first_article_index = $limit_from;
		$rs->last_article_index = $limit_to;

		// Fetch the requested articles
		if( 0 != $rs->available_articles ) {
			$sql = <<<sql
select * from (
        select rownum as row_num, id, wire_date, long_wire_date, language, weight, title, summary, text, agency, urgent
        from (
        	select a.id,
        		to_char(a.receptiondate,'DD/MM/YYYY') as wire_date,
        		to_char(a.receptiondate,'{$this->config["databases"]["latestnews"]["date-format"]}') as long_wire_date,
        		a.language, a.weight, a.title, a.summary, a.text, a.agency, a.urgent
        		{$sql_base}
        	order by long_wire_date desc
        )
)
where row_num between {$limit_from} and {$limit_to}
order by long_wire_date desc
sql;

		$stid = oci_parse($oracle, $sql);
		if (!$stid) {
			$e = oci_error($oracle);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		while( $row = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ) ) {
			$article = new Article();
			$article->id = $row["ID"];
			$article->title = $row["TITLE"];
			$article->body = $row["TEXT"];
			$article->lead_para = $row["SUMMARY"];
			$article->date = $row["LONG_WIRE_DATE"];
			$article->url = $row["ID"];
			
			$rs->articles[] = $article;
		}
		}

		return $rs;
	}

	/**
	 * Fetch the articles from the LatestNews database
	 * @param string $token Session Identifier
	 * @param string $id Article ID
	 * @return Article
	 * */
	public function getLatestNewsArticle( $token, $id ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$article = new Article();

		$sql_base = <<<sql
from {$this->config["databases"]["latestnews"]["schemas"]}.wires a
where a.id = '{$id}'
order by a.receptiondate desc
sql;


		$oracle = oci_pconnect( $this->config["databases"]["latestnews"]["user"], $this->config["databases"]["latestnews"]["pass"], $this->config["databases"]["latestnews"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$sql = <<<sql
select a.id,
	to_char(a.receptiondate,'DD/MM/YYYY') as wire_date,
	to_char(a.receptiondate,'{$this->config["databases"]["latestnews"]["date-format"]}') as long_wire_date,
	a.language, a.weight, a.title, a.summary, a.text, a.agency, a.urgent
		{$sql_base}
sql;
		$stid = oci_parse($oracle, $sql);
		if (!$stid) {
			$e = oci_error($oracle);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$row = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS );
		if( false === $row ) {
			return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
			return null;
		}

		$article->title = $row["TITLE"];
		$article->body = $row["TEXT"];
		$article->lead_para = $row["SUMMARY"];
		$article->date = $row["LONG_WIRE_DATE"];
		$article->url = $row["ID"];

		return $article;
	}
}
?>
