<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

require_once( "wsk/WSKClient.class.php" );
class tariqaLexisNexis extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Searches LexisNexis sources
	 * @param string $token The session identifier
	 * @param LexisNexisSourceSearchRequest $query The query for searching the sources
	 * @return LexisNexisSourceSearchResponse
		*/
	public function LexisNexisSourceSearch($token, $query){
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// If not cached, execute the search
		$resp = null;
		$internal_query_id = md5($query->query).md5(serialize($query));
		$tmp = $this->_GetServerVariable( "wsk:searchsource:{$internal_query_id}"  );
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}

		if( null == $resp ) {
			// Execute the search, getting only the number of available articles
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );

			// Note: Lexis Nexis does not like empty lines nor new lines
			$query->query = mb_ereg_replace( "[\r\n\t]", ' ', $query->query );

			$request = new WSKSearchSourceRequest();
			$request->binarySecurityToken = $wskToken;
			$request->locale = $query->locale;
			$request->folderId = $query->folderId;
			$request->partialSourceName = $query->query;
			$request->useCSP = true;

			$resp = $wsk->SearchSources( $request );

			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["search"];
			$this->_SetServerVariable( "wsk:searchsource:{$internal_query_id}", base64_encode( gzcompress( serialize($resp) )));
		}

		$res = new LexisNexisSourceSearchResponse();
		$res->sources = array();

		foreach($resp->sourceList->source as $source){
			$s = new LexisNexisSource();
			$s->id = $source->sourceId;
			$s->name = $source->name;
			$s->combinability = array();
			foreach ($source->combinabilityList as $c) $s->combinability[] = $c;

			$res->sources[] = $s;
		}
		return $res;

	}

	/**
	 * Search LexisNexis datawarehouse, and return a SearchID
	 * @param string $token Session Identifier
	 * @param LexisNexisQuery $query The search query
	 * @return LexisNexisSearchResult
	 * */
	public function LexisNexisSearch( $token, $query ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();
		
		// If not cached, execute the search
		$resp = null;
		$internal_query_id = md5($query->query).md5(serialize($query));
		//$tmp = $this->_GetServerVariable( "wsk:search:{$internal_query_id}"  );
		$tmp = "";
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}
		if( null == $resp ) {
			// Execute the search, getting only the number of available articles
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$options = null;
			if( null !== $query->startDate || null !== $query->endDate ) {
				if( null === $options ) {
					$options = new WSKSearchOptions();
				}
				$options->dateRestriction = new WSKDateRestriction();
				$options->dateRestriction->startDate = null === $query->startDate ? null : date( "Y-m-d", $query->startDate );
				$options->dateRestriction->endDate = null === $query->endDate ? null : date( "Y-m-d", $query->endDate );
			}
			if( null !== $query->sortOrder ) {
				if( null === $options ) {
					$options = new WSKSearchOptions();
				}
				$options->sortOrder = $query->sortOrder;
			}

			// Note: Lexis Nexis does not like empty lines nor new lines
			$query->query = mb_ereg_replace( "[\r\n\t]", ' ', $query->query );

			$request = new WSKSearchRequest( $wskToken, $query->query, $query->sources, $options );
			try {
				$resp = $wsk->Search( $request );
			} catch( SoapFault $fault ) {

				$error = "";
				if( property_exists( $fault, "detail" ) && is_object( $fault->detail ) && property_exists( $fault->detail, "errorDetail") ) {
					switch( $fault->detail->errorDetail->errorCode ) {
						case "INVALID_USER_CREDENTIALS" : {
							$error .=  "Invalid Username/Password!";
						} break;
						case "INVALID_SECURITY_TOKEN" : {
							$error .=  "The security token is not valid!";
						} break;
						case "EXPIRED_SECURITY_TOKEN" : {
							$error .=  "The security token has expired!";
						} break;
						case "SEARCH_TOO_GENERAL" : {
							$error .=  "Your search would return more than 3000 documents!";
						} break;
						default: {
							$error .=  "{$fault->detail->errorDetail->errorCode}";
						}
					}
					return new SoapFault((string) self::e_http, $error );
				} else {
					$this->dump_to_log($fault);
					return new SoapFault((string) self::e_http, "Unknown error" );
				}
			}

			/*ob_start();
				echo "REQUEST:\n";
				var_dump( $wsk->__getLastRequestHeaders() );
				echo "\n";
				var_dump( $wsk->__getLastRequest() );
				echo "RESPONSE:\n";
				var_dump( $wsk->__getLastResponseHeaders() );
				echo "\n";
				var_dump( $wsk->__getLastResponse() );
				echo "Done\n";
				$ob_content = ob_get_contents();
				ob_end_clean();
				error_log( $ob_content );*/

			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["search"];
			$this->_SetServerVariable( "wsk:search:{$internal_query_id}", base64_encode( gzcompress( serialize($resp) )));
		}
		return new LexisNexisSearchResult( $resp->searchId, $resp->documentsFound );
	}

	/**
	 * Retrieve specific documents in SITE (preview) format
	 * @param string $token Session Identifier
	 * @param string $searchId Contains a unique identifier that identifies the original search.
	 * @param int $begin Identifies the first document to be returned in the response. It must be used in conjunction with end.
	 * @param int $end Identifies the last document to be returned in the response. It must be used in conjunction with begin.
	 * @return LexisNexisDocument[]
	 * */
	public function LexisNexisGetDocuments( $token, $searchId, $begin = 1, $end = 20) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// If not cached, execute the search
		$resp = null;
		$internal_query_id = sprintf( "%d,%d,", $begin, $end ) . md5($searchId) . substr( $searchId, 0, 32) . substr( $searchId, -32);
		$tmp = $this->_GetServerVariable( "wsk:getcite:{$internal_query_id}"  );
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}
		if( null == $resp ) {
			// Execute the search, getting only the number of available articles
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$options = null;

			$request = new WSKGetDocumentsByRangeRequest(
			$wskToken, $searchId, null,
			new WSKRetrievalOptions(
			WSKRetrievalOptions::dvSearchHitsInContext,
			WSKRetrievalOptions::dmSemantic,
			new WSKDocumentRange( $begin, $end ),
			false
			)
			);
			$resp = new WSKGetDocumentsByRangeResponse();
			$resp = $wsk->GetDocumentsByRange( $request );

			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["search"];
			$this->_SetServerVariable( "wsk:getcite:{$internal_query_id}", base64_encode( gzcompress( serialize($resp) )));
		}
		unset( $resp->_cache_expire );
		$response = array();
		if( null !== $resp->documentContainerList && property_exists( $resp->documentContainerList, "documentContainer" ) ) {
                        if ( is_array( $resp->documentContainerList->documentContainer ) ) {
        			foreach( $resp->documentContainerList->documentContainer as $container ) {
        				try {
        					$response[] = new LexisNexisDocument( $container->documentId, $container->document );
        				} catch( Exception $e ) {
        					$str = $e->__toString();
        					return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\nInternal Exception:{$str}\n\nLexisNexisDocument({$container->documentId})\n");
        				}
        			}
                        }
                        else {
        					$response[] = new LexisNexisDocument( $resp->documentContainerList->documentContainer->documentId, $resp->documentContainerList->documentContainer->document );
                        }
		} else {
			$this->dump_to_log( $resp );
			return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\nWSKGetDocumentByRange({$searchId},{$begin},{$end})");
			return null;
		}

		return $response;
	}

	/**
	 * Retrieve specific documents  in full text or some other format and/or markup
	 * @param string $token Session Identifier
	 * @param string[] $documentIds List of Lexis Nexis document IDs
	 * @return LexisNexisDocument[]
	 * */
	public function LexisNexisGetFullDocuments( $token, $documentIds ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		$response = array();
		foreach( $documentIds as $documentId ) {
			$response[] = $this->_LexisNexisGetFullDocument( $documentId );
		}
		return $response;
	}

	/**
	 * Retrieve specific document in full text
	 * @param string $token Session Identifier
	 * @param string $documentId Document ID
	 * @return LexisNexisDocument
	 * */
	public function LexisNexisGetFullDocument( $token, $documentId ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_LexisNexisGetFullDocument( $documentId );
	}
	/**
	 * Retrieve specific document in full text [WITHOUT CHECKING USER's TOKEN]
	 * @param string $documentId Document ID
	 * @return LexisNexisDocument
	 * */
	protected function _LexisNexisGetFullDocument( $documentId ) {
		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// If not cached, execute the search
		$resp = null;
		$internal_query_id = $documentId;
		$tmp = $this->_GetServerVariable( "wsk:document:{$internal_query_id}"  );
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}
		if( null == $resp ) {
			// Execute the search, getting only the number of available articles
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$options = null;

			$request = new WSKGetDocumentsByDocumentIdRequest(
			$wskToken,
			new WSKDocumentIdList(
			array( $documentId )
			),
			new WSKRetrievalOptions(
			WSKRetrievalOptions::dvFullText,
			WSKRetrievalOptions::dmSemantic,
			null,
			false
			)
			);
			$resp = new WSKGetDocumentsByDocumentIdResponse();
			$resp = $wsk->GetDocumentsByDocumentId( $request );
			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["document"];
			$this->_SetServerVariable( "wsk:document:{$internal_query_id}", base64_encode( gzcompress( serialize($resp) )));
		}

		if( null != $resp->documentContainerList && property_exists( $resp->documentContainerList, "documentContainer" )) {
			$container = null;
			if( is_array( $resp->documentContainerList->documentContainer ) ) {
				$container = $resp->documentContainerList->documentContainer[0];
			} else {
				$container = $resp->documentContainerList->documentContainer;
			}
			try {
				$doc = new LexisNexisDocument( $container->documentId, $container->document );
				return $doc;
			} catch( Exception $e ) {
				$this->dump_to_log( $container );
				return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\nLexisNexisDocument({$container->documentId})");
			}
		}
		return null;
	}

	/**
	 * Retrieve a specific attachment [WITHOUT CHECKING USER's TOKEN]
	 * @param string $token Session Identifier
	 * @param string $attachmentId Attachment ID
	 * @return LexisNexisAttachment[]
	 * */
	public function LexisNexisGetAttachments( $token, $attachmentId ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_LexisNexisGetAttachments( $attachmentId );
	}

	/**
	 * Retrieve a specific attachment [WITHOUT CHECKING USER's TOKEN]
	 * @param string $attachmentId Attachment ID
	 * @return LexisNexisAttachment[]
	 * */
	protected function _LexisNexisGetAttachments( $attachmentId ) {
		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// Attachments are not cached!
		$resp = null;
		// Execute the operation
		$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
		$request = new WSKGetAttachmentsRequest(
		$wskToken,
		new WSKAttachmentIdList(
		array( $attachmentId )
		)
		);
		$resp = new WSKGetAttachmentsResponse();
		$resp = $wsk->GetAttachments( $request );

		$attachments = array();
		if( null != $resp->attachmentContainerList && property_exists( $resp->attachmentContainerList, "attachmentContainer" )) {
			$containers = array();
			if( is_array( $resp->attachmentContainerList->attachmentContainer )) {
				$containers = $resp->attachmentContainerList->attachmentContainer;
			} else {
				$containers[] = $resp->attachmentContainerList->attachmentContainer;
			}
			foreach( $containers as $container ) {
				$this->dump_to_log( $container );
				try {
					$attachments[] = new LexisNexisAttachment( $container->attachmentId, $container->mimeType, base64_encode( $container->attachment ));
				} catch( Exception $e ) {
					$this->dump_to_log( $container );
					return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\nLexisNexisAttachment({$container->attachmentId})");
				}
			}
		}
		return $attachments;
	}

	/**
	 * Establish a connection with the LexisNexis WSK and return the security token (might be cached for performance reasons)
	 * @return string WSK BinarySecurityToken
	 * */
	protected function WSKAuthenticate() {
		try {
			$cache_wsk_auth =  new WSKAuthenticateResponse();
			$tmp = $this->_GetServerVariable( "wsk" );
			if( 0 != strlen( $tmp )) {
				$cache_wsk_auth = unserialize( $tmp );
			}
			if( null !== $cache_wsk_auth->expiration ) {
				$regs = array();
				if( false !== ereg( "^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])T([0-9][0-9]):([0-9][0-9]):([0-9][0-9])\.[0-9]+Z$", $cache_wsk_auth->expiration, $regs )) {
					$expire = gmmktime( $regs[4], $regs[5], $regs[6], $regs[2], $regs[3], $regs[1] );
					if( $expire > (time() + 30)) {	// +30 the token should be valid for at least 30 more seconds from now on
						return $cache_wsk_auth->binarySecurityToken;
					}
				}
			}
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$req = new WSKAuthenticateRequest( $this->config["sources"]["lexisnexis"]["username"], $this->config["sources"]["lexisnexis"]["password"] );
			$cache_wsk_auth = $wsk->Authenticate( $req );
			$tmp = serialize( $cache_wsk_auth );
			$this->_SetServerVariable( "wsk", $tmp );
			return $cache_wsk_auth->binarySecurityToken;
		} catch( SoapFault $fault ) {
			$faultDetails = WSKClient::getFaultDetails( $fault );
			$error = "";
			if( false === $faultDetails ) {
				$error = @<<<txt
SOAP error:
Code: {$fault->faultcode}
String: {$fault->faultstring}
Actor: {$fault->faultactor}

txt;
			} else {
				$error =  "WSK error: {$faultDetails}";
			}
			return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . $error );
		}
	}

	/**
	 * Get a list of available Sources
	 * @param int $folderId [OPTIONAL]
	 * @return WSKBrowseSourcesResponse
	 * */
	protected function WSKBrowseSources( $folderId = null ) {
		$wskToken = $this->WSKAuthenticate();

		$resp = null;
		$tmp = $this->_GetServerVariable( "wsk:browsesources:{$folderId}" );
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}
		if( null == $resp ) {
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$req = new WSKBrowseSourcesRequest( $wskToken, "en-US", $folderId );
			$resp = new WSKBrowseSourcesResponse();
			$resp = $wsk->BrowseSources( $req );

			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["browseSources"];
			$this->_SetServerVariable( "wsk:browsesources:{$folderId}", base64_encode( gzcompress( serialize($resp) )));
		}

		return $resp;
	}

	/**
	 * Browse LexisNexis Source Folders
	 * @param string $token Session Identifier
	 * @param int $folderId ID of the folder to browse (if null, the root folder will be browsed) [OPTIONA]
	 * @return LexisNexisBrowseSourcesResponse
	 * */
	public function LexisNexisBrowseSources( $token, $folderId = null ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// If not cached, get the list of sources from lexisnexis
		$resp = null;
		$tmp = $this->_GetServerVariable( "wsk:browsesources:{$folderId}" );
		if( 0 != strlen( $tmp )) {
			$resp = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $resp->_cache_expire < time() ) {
				$resp = null;
			}
		}
		if( null == $resp ) {
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			$req = new WSKBrowseSourcesRequest( $wskToken, "en-US", $folderId );
			$resp = new WSKBrowseSourcesResponse();
			$resp = $wsk->BrowseSources( $req );

			$resp->_cache_expire = time() + (int)$this->config["cache"]["wsk"]["browseSources"];
			$this->_SetServerVariable( "wsk:browsesources:{$folderId}", base64_encode( gzcompress( serialize($resp) )));
		}

		return $this->WSK2LN_BrowseSourcesResponse( $resp, $folderId );
	}

	/**
	 * Get the Sort Keys available for each row of a LexisNexis SearchResult
	 * @param string $token Session Identifier
	 * @param string $searchId LexisNexis Search ID
	 * @return Pair[]
	 * */
	public function LexisNexisGetSortKeys( $token, $searchId ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// If not cached, execute the operation
		$sort_keys = null;
		$internal_query_id = md5($searchId).md5(serialize($searchId));
		$tmp = $this->_GetServerVariable( "wsk:sortkeys:{$internal_query_id}"  );
		if( 0 != strlen( $tmp )) {
			$sort_keys = unserialize( gzuncompress( base64_decode( $tmp )  ));
			if( $sort_keys["expire"] < time() ) {
				$sort_keys = null;
			}
		}
		if( null == $sort_keys ) {
			$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
			// Get Sort Keys
			$sort_keys = array();
			$sort_keys["expire"] = time() + (int)$this->config["cache"]["wsk"]["search"];

			$request = new WSKGetSortKeysRequest( $wskToken, $searchId );
			$rs_sk = $wsk->GetSortKeys( $request );
			if( null !== $rs_sk->sortKeyList &&
			property_exists( $rs_sk->sortKeyList, "sortKey") &&
			is_array( $rs_sk->sortKeyList->sortKey )
			) {
				foreach( $rs_sk->sortKeyList->sortKey as $sk ) {
					$sort_keys[] = new Pair( $sk->name, $sk->sortId );
				}
			}
			$this->_SetServerVariable( "wsk:sortkeys:{$internal_query_id}", base64_encode( gzcompress( serialize($sort_keys) )));
		}
		unset( $sort_keys["expire"] );
		return $sort_keys;
	}

	/* *
	 * This operation will accept a searchId and one or more  sortId values as input. The response will contain a new  searchId  value corresponding to a new answer set. The new answer set will contain the same documents as the original answer set, but will be reordered based on the sortId values supplied.
	 * @param string $token Session Identifier
	 * @param LexisNexisSortResultsQuery $query The SortResults query
	 * @return string The resorted search results set identifier.
	 */
	/*
		public function LexisNexisSortResults( $token, $query ) {
		// Check User Authentification
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
		return new SoapFault((string) self::e_session, self::e_session_msg );
		return null;
		}

		// Authenticate with Lexis Nexis
		$wskToken = $this->WSKAuthenticate();

		// Execute the search, getting only the number of available articles
		$wsk = new WSKClient( array( "cache_wsdl" => ( false === eregi( "^(1|yes|true)", $this->config["cache"]["wsk"]["wsdl"] ) ? false : true ) ), $this->config["application"]["path"] );
		$options = null;
		$request = new WSKSortResultsRequest( $wskToken, $query->searchId, $query->sortOrder );
		if( null !== $query->sortKeys ) {
		$request->sortStrategyList = new WSKSortStrategyList();
		$request->sortStrategyList->sortStrategy = array();
		foreach( $query->sortKeys as $sortKey ) {
		$request->sortStrategyList->sortStrategy[] = new WSKSortStrategy( $sortKey->key, $sortKey->value );
		}
		}
		$this->dump_to_log( $request );
		$resp = $wsk->SortResults( $request );
		$this->dump_to_log( $resp );

		return $resp->searchId;
		}
		*/

	/**
	 * Converts a WSKBrowseSourcesResponse into a LexisNexisBrowseSourcesResponse
	 * @param WSKBrowseSourcesResponse $object Response object
	 * @param int $folderId ID of the folder currently browsed
	 * @return LexisNexisBrowseSourcesResponse
	 */
	protected function WSK2LN_BrowseSourcesResponse( $object, $folderId = null ) {
		// Convert the received object into a LexisNexisBrowseSourcesResponse object
		$result = new LexisNexisBrowseSourcesResponse( $folderId );
		$result->folders = array();
		$result->sources = array();
		if( !property_exists( $object, "sourceList" )
		|| null === $object->sourceList
		|| !property_exists( $object->sourceList, "source" )
		|| null === $object->sourceList->source ) {
			// Nothing to do
		} else if( !is_array( $object->sourceList->source )) {
			$source = $object->sourceList->source;
			if( property_exists( $source, "name" ) &&
			property_exists( $source, "sourceId")
			) {
				$result->sources[] =
				new LexisNexisSource(
				$source->sourceId,
				$source->name,
				(!property_exists( $source->combinabilityList, "combinability" ) || null === $source->combinabilityList->combinability)
				? array()
				: ( is_string($source->combinabilityList->combinability)
				? array( $source->combinabilityList->combinability )
				: $source->combinabilityList->combinability
				)
				);
			} else {
				$error = "Unexpected answer received from LexisNexis Server ::BrowseSources({$folderId})";
				error_log( __FILE__ . " @line " . __LINE__ . ": " . $error );
				$this->dump_to_log( $object );
				return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . $error);
			}
		} else {
			foreach( $object->sourceList->source as $source ) {
				$result->sources[] =
				new LexisNexisSource(
				$source->sourceId,
				$source->name,
				(!property_exists( $source->combinabilityList, "combinability" ) || null === $source->combinabilityList->combinability)
				? array()
				: ( is_string($source->combinabilityList->combinability)
				? array( $source->combinabilityList->combinability )
				: $source->combinabilityList->combinability
				)
				);
			}
		}

		if( !property_exists( $object, "folderList" )
		|| null === $object->folderList
		|| !property_exists( $object->folderList, "folder" )
		|| null === $object->folderList->folder ) {
			// Nothing to do
		} else if( !is_array( $object->folderList->folder )) {
			$folder = $object->folderList->folder;
			if( property_exists( $source, "name" ) &&
			property_exists( $source, "folderId")
			) {
				$result->folders[] = new LexisNexisFolder( $folder->folderId, $folder->name );
			} else {
				$error = "Unexpected answer received from LexisNexis Server ::BrowseSources({$folderId})";
				error_log( __FILE__ . " @line " . __LINE__ . ": " . $error );
				$this->dump_to_log( $object );
				return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg . "\n" . $error);
			}
		} else {
			foreach( $object->folderList->folder as $folder ) {
				$result->folders[] = new LexisNexisFolder( $folder->folderId, $folder->name );
			}
		}

		return $result;
	}
}
?>
