<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaOxfordAnalytica extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Authenticate with Oxford Analytica
	 * @param string $token Session Identifier
	 * @return string[] The oxan cookies
	 * @internal
	 * */
	protected function oxanAuthenticate( $token ) {

		$cookies = array();

		// - 1 - Authenticate
		// - 1.0 Check if a session is already established with oxan, reuse it
		$ses_validity = $this->GetUserSessionVariable( $token, "oxan_validity" );
		$ses_cookies = $this->GetUserSessionVariable( $token, "oxan_cookies" );
		$ses_validity = '';
		if( "" != $ses_validity && (int)$ses_validity > time() ) {
			// - 1.1 - Already authenticated
			$cookies = unserialize( $ses_cookies );
		} else {
			// - 1.2 - Authenticate
			// Prepare the HTTP request
			$action = "https://www.oxan.com/oxweb/logon.aspx";
			$method = WebRequest::HTTP_GET;
			$cookies = false;
			$params = array();

			$params[] = new Pair("USERNAME", $this->config["sources"]["oxan"]["username"]);
			$params[] = new Pair("PASSWORD", $this->config["sources"]["oxan"]["password"]);
			$params[] = new Pair("ReturnURL", "/display.aspx?ItemID=DB164528");

			// Fetch the  results
			$webreq = new WebRequest( $action, $params, $cookies, $method );
			$webdoc = new WebDocument();
			$webdoc = $this->fetchUrl( $token, $webreq );
			
			$cookies = array();
			foreach( $webdoc->cookies as $cookie ) {
				switch( $cookie->name ) {
					case "LoggedIn":
					case "Oxweb":
					case "ASP.NET_SessionId": {
						$cookies[] = new Pair( $cookie->name, $cookie->value );
					} break;
				}
			}
			if( 2 != count( $cookies ) ) {
				// Wrong cookies sent by oxan...
				error_log( __FILE__ . " |line " . __LINE . " : " . self::e_internal_error_msg );
				return new SoapFault((string) self::e_internal_error, self::e_internal_error_msg );
				return null;
			}
			
			// - 1.3 - Save the authentication cookies for 15 minutes
			$this->SetUserSessionVariable( $token, "oxan_validity", sprintf( "%d", (time() + (60 * 15))) );
			$this->SetUserSessionVariable( $token, "oxan_cookies", serialize( $cookies ) );
		}

		return $cookies;
	}

	/**
	 * Parse a page from Oxford Analytica
	 * @param string $html The html page
	 * @return OxfordAnalyticaDocument
	 * @internal
	 * */
	protected function oxanParsePage( $html ) {

		$document = new OxfordAnalyticaDocument();

		//error_log($html);
		$xml = new DOMDocument();
		@$xml->loadHTML( $html );
		$xml->strictErrorChecking = false;

		$xpath = new DOMXPath( $xml );

		// Headline
		$nl = @$xpath->query( "//*[@id= 'CtlItemThis_headline' ]" );
		$document->headline = $nl->item(0)->nodeValue;
		
		if ($document->headline == '' || $document->headline == null){
			$nl = @$xpath->query('//title');
			$document->headline = $nl->item(0)->nodeValue;
			if ($document->headline == '' || $document->headline == null){
				$nl = @$xpath->query("//meta[@name='DC.title']");
				$document->headline = $nl->item(0)->getAttribute('content');
			}
		}

		// Date
		$nl = @$xpath->query( "//*[@id= 'CtlItemThis_dateparagraph' ]" );
		$document->date = $nl->item(0)->nodeValue;

		// Country Profiles
		$nl = @$xpath->query( "//*[@id= 'CtlItemThis_pcountrydata' ]/a/@href" );
		$document->country_profiles = array();
		foreach( $nl as $entry ) {
			$document->country_profiles[] = $entry->nodeValue;
		}

		// Find the ITEM segment
		$bitem = strpos( $html, "<!--BEGINITEM-->" );
		$eitem = strpos( $html, "<!--ENDITEM-->" );
		if( false === $bitem ||false === $eitem ) {
			//error_log( $html );
			return new SoapFault((string) self::e_invalid_format, self::e_invalid_format_msg );
			return false;
		}
		$bitem += 16;
		$item = substr( $html, $bitem, $eitem - $bitem );

		// Extracts the KEYWORD segment
		$bkwrd = strpos( $item, "<!--BEGINKEYWORDS-->" );
		$ekwrd = strpos( $item, "<!--ENDKEYWORDS-->" );
		$keywords = "";
		if( false !== $bkwrd ) {
			$bkwrd += 20;
			$keywords = substr( $item, $bkwrd, $ekwrd - $bkwrd );
			$bkwrd -= 20;
			$item = substr( $item, 0, $bkwrd );
		}

		$options = array(
				"clean" => true,
				"output-xhtml" => true,
				"show-body-only" => true,
				"newline" => "LF",
				"drop-proprietary-attributes" => true,
		);
		$tidy = tidy_parse_string( $item, $options, "utf8" );
		$tidy->cleanRepair();
		$document->body = (string)$tidy;

		$tidy = tidy_parse_string( $keywords, $options, "utf8" );
		$tidy->cleanRepair();
		$document->keywords = (string)$tidy;

		return $document;
	}

	/**
	 * Fetch a document from the Oxford Analytica engine
	 * @param string $token Session Identifier
	 * @param string $documentId The Oxan document identifier
	 * @return OxfordAnalyticaDocument
	 * */
	public function oxanFetchDocument( $token, $documentId ) {

		// Note: Requires login on Oxford Analytica, and forwarding the session using the ASP.NET_SessionId cookie
		// Note: The Session Token will be analysed by the fetchUrl Method
		// Therefore it is not tested here


		/*// - 1 - Authenticate
		$cookies = $this->oxanAuthenticate( $token );
		
		// - 2 - Fetch the document
		$action = "http://www.oxan.com/display.aspx";
		$method = WebRequest::HTTP_GET;
		$params = array();
		$params[] = new Pair( "ItemID", $documentId );
		
		// Fetch the  results
		$webreq = new WebRequest( $action, $params, $cookies, $method );
		$webdoc = new WebDocument();
		$webdoc = $this->fetchUrl( $token, $webreq );*/
		
		// - 3 - Extract the article from the page

		// - 1 - Authenticate
		// - 1.0 Check if a session is already established with oxan, reuse it
		// - 1.2 - Authenticate
		// Prepare the HTTP request
		$action = "https://www.oxan.com/oxweb/logon.aspx";
		$method = WebRequest::HTTP_GET;
		$params = array();

		$params[] = new Pair("USERNAME", $this->config["sources"]["oxan"]["username"]);
		$params[] = new Pair("PASSWORD", $this->config["sources"]["oxan"]["password"]);
		$params[] = new Pair("ReturnURL", "/display.aspx?ItemID={$documentId}");

		// Fetch the  results
		$webreq = new WebRequest( $action, $params, $cookies, $method );
		$webdoc = new WebDocument();
		$webdoc = $this->fetchUrl( $token, $webreq );
		
		return $this->oxanParsePage( $webdoc->body );
	}

	/**
	 * Fetch a document from the Oxford Analytica engine
	 * @param string $token Session Identifier
	 * @param string $documentId The Oxan document identifier
	 * @return OxfordAnalyticaDocument
	 * */
	public function oxanFetchUrl( $token, $relative_url ) {

		//$relative_url = str_replace( "&amp;", "&", $relative_url );

		// Note: Requires login on Oxford Analytica, and forwarding the session using the ASP.NET_SessionId cookie
		// Note: The Session Token will be analysed by the fetchUrl Method
		// Therefore it is not tested here

		/*// - 1 - Authenticate
		$cookies = $this->oxanAuthenticate( $token );

		// - 2 - Fetch the document
		$action = "http://www.oxan.com{$relative_url}";
		$method = WebRequest::HTTP_GET;
		$params = false;

		// Fetch the  results
		$webreq = new WebRequest( $action, $params, $cookies, $method );
		$webdoc = new WebDocument();
		$webdoc = $this->fetchUrl( $token, $webreq );*/

		$action = "https://www.oxan.com/oxweb/logon.aspx";
		$method = WebRequest::HTTP_GET;
		$params = array();

		$params[] = new Pair("USERNAME", $this->config["sources"]["oxan"]["username"]);
		$params[] = new Pair("PASSWORD", $this->config["sources"]["oxan"]["password"]);
		$params[] = new Pair("ReturnURL", $relative_url);

		// Fetch the  results
		$webreq = new WebRequest( $action, $params, $cookies, $method );
		$webdoc = new WebDocument();
		$webdoc = $this->fetchUrl( $token, $webreq );
		
		// - 3 - Extract the article from the page
		return $this->oxanParsePage( $webdoc->body );
	}

	/**
	 * Search Oxford Analytica
	 * @param string $token Session Identifier
	 * @param OxfordAnalyticaSimpleQuery $query
	 * @return OxfordAnalyticaSearchResult
	 * */
	public function oxanSimpleSearch( $token, $query  ) {
		return $this->oxanSearch( $token, $query, $query );
	}

	/**
	 * Search Oxford Analytica
	 * @param string $token Session Identifier
	 * @param OxfordAnalyticaDetailedQuery $query
	 * @return OxfordAnalyticaSearchResult
	 * */
	public function oxanDetailedSearch( $token, $query  ) {
		return $this->oxanSearch( $token, null, $query );
	}

	/**
	 * Get the URL of a Country Profile page
	 * NOTES:
	 * Oxford Analytica is setup to accept access to its data from Tarîqa users
	 * No token is required here, as the user will neeed to be authenticated into Tarîqa to be able to proceed!
	 * @param Country $country Country descriptor
	 * @return string
	 * */
	public function oxanCountryProfileURL( $country  ) {
		if( null === $country->oxan_id ) {
			return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
			return null;
		}
		return $this->oxanGateway( "/oxweb/countrydata.aspx?country=" . rawurlencode( $country->oxan_id ));
	}

	/**
	 * This function will transform oxan urls into tariqa urls suitable for the oxan special logon mechanism mechanism
	 * NOTES:
	 * Oxford Analytica is setup to accept access to its data from Tarîqa users
	 * No token is required here, as the user will neeed to be authenticated into Tarîqa to be able to proceed!
	 * @param string $oxan_url The Oxford Analytica URL
	 * @return string The Tariqa url
	 * */
	public function oxanGateway( $oxan_url ) {
		$oxan_path = str_replace( "http://www.oxan.com", "", trim( $oxan_url ) );
		return "https://webgate.ec.europa.eu/tariqa/oxweb/?indirect=" . rawurlencode($oxan_path );
	}
	/**
	 * Runs a search amongst OxfordAnalytica articles
	 * @param string $token Session Identifier
	 * @param OxfordAnalyticaSimpleQuery|null Simple query or null if detailed query is used
	 * @param OxfordAnalyticaDetailedQuery|null Detailed query or null if simple query is used
	 * @return OxfordAnalyticaSearchResult
	 * */
	protected function oxanSearch( $token, $simpleQuery = null, $detailedQuery = null ) {
		// Note:
		// The Session Token will be analysed by the fetchUrl Method
		// Therefore it is not tested here

		// Prepare the HTTP request
		$action = "http://www.oxan.com/searchresults.aspx";
		$method = WebRequest::HTTP_GET;
		$cookies = false;
		$params = array();

		$query = null;
		if( null !== $simpleQuery ) {
			$query = &$simpleQuery;
		} else
		if( null !== $detailedQuery ) {
			$query = &$detailedQuery;
		} else {
			return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
		}

		$params[] = new Pair( "DisplayMode", OxfordAnalyticaQueryBase::DM_XML );
		switch( $query->storyType ) {
			case OxfordAnalyticaQueryBase::ST_COUNTRY_PROFILE:
			case OxfordAnalyticaQueryBase::ST_EXECUTIVE_SUMMARY:
			case OxfordAnalyticaQueryBase::ST_FULL_LENGTH_ARTICLE: {
				$params[] = new Pair( "StoryType", $query->storyType );
			} break;
			default: {
				$params[] = new Pair( "StoryType", OxfordAnalyticaQueryBase::ST_EXECUTIVE_SUMMARY );
			} break;
		}

		if( $query->from ) {
			$params[] = new Pair( "From", date( "Y-m-d", $query->from ) );
		}
		if( $query->to ) {
			$params[] = new Pair( "To", date( "Y-m-d", $query->to ) );
		}
		if( $query->pageLen ) {
			$params[] = new Pair( "PageLen", sprintf( "%d", $query->pageLen ) );
		} else {
			$params[] = new Pair( "PageLen", "10" );
		}
		if( $query->pageNo ) {
			$params[] = new Pair( "PageNo", sprintf( "%d", $query->pageNo ) );
		} else {
			$params[] = new Pair( "PageNo", "0" );
		}

		if( null !== $simpleQuery ) {
			$params[] = new Pair( "query", $simpleQuery->query );
			if( $simpleQuery->sortByRelevance ) {
				$params[] = new Pair( "sortByRelevance", "true" );
			}
		} else {
			if( 0 != strlen( $detailedQuery->country )) {
				$params[] = new Pair( "country", $detailedQuery->country );
			}
			if( 0 != strlen( $detailedQuery->topic )) {
				$params[] = new Pair( "topic", $detailedQuery->topic );
			}
			if( 0 != strlen( $detailedQuery->titling )) {
				$params[] = new Pair( "titling", $detailedQuery->titling );
			}
			if( 0 != strlen( $detailedQuery->freetext )) {
				$params[] = new Pair( "freetext", $detailedQuery->freetext );
			}
			if( $detailedQuery->primary ) {
				$params[] = new Pair( "primary", "true" );
			}
		}

		// Fetch the  results
		$webreq = new WebRequest( $action, $params, $cookies, $method );
		$webdoc = new WebDocument();
		$webdoc = $this->fetchUrl( $token, $webreq );

		// Parse the response
		$xml = new DOMDocument();
		$xml->loadXML( $webdoc->body );
		$xml->formatOutput = true;
		$xml->preserveWhiteSpace = false;

		$xpath = new DOMXPath( $xml );

		$results = new OxfordAnalyticaSearchResult();

		// Total number of articles
		$rs = new DOMNodeList();
		$rs = $xpath->query( "/SearchResult/@TotalNumberOfMatches" );
		if( 0 == $rs->length ) {
			return new SoapFault((string) self::e_invalid_format, self::e_invalid_format_msg );
			return null;
		}
		$results->totalNumberOfMatches = $rs->item( 0 )->nodeValue;

		// Fetch the navigation
		$rs = $xpath->query( "/SearchResult/Navigation/*" );
		if( $rs->length ) {
			$results->navigation = new OxfordAnalyticaNavigation();
			foreach( $rs as $navigationNode ) {
				switch( $navigationNode->nodeName ) {
					case "UserURL" : {		$results->navigation->userURL = 		$this->oxanGateway( $navigationNode->nodeValue ); } break;
					case "PreviousPage" : {	$results->navigation->previousPage = 	$this->oxanGateway( $navigationNode->nodeValue ); } break;
					case "NextPage" : {		$results->navigation->nextPage = 		$this->oxanGateway( $navigationNode->nodeValue ); } break;
				}
			}}

			// Fetch the articles
			$rs = $xpath->query( "/SearchResult/HitItem" );
			if( $rs->length ) {
				foreach( $rs as $hitItemNode ) {
					$item = new OxfordAnalyticaHitItem();
					$item->itemId = $hitItemNode->attributes->getNamedItem( "ItemID" )->nodeValue;
					$strtime = $hitItemNode->attributes->getNamedItem( "FirstRunDate" )->nodeValue;
					$arrtime = explode( "-", $strtime );
					$item->firstRunDate = mktime( 0, 0, 0, $arrtime[1], $arrtime[2], $arrtime[0] );
					$item->isFree = (false !== eregi( "^true$", $hitItemNode->attributes->getNamedItem( "IsFree" )->nodeValue) ? true : false );
					$item->score = (float)$hitItemNode->attributes->getNamedItem( "Score" )->nodeValue;

					foreach( $hitItemNode->childNodes as $dataNode ) {
						switch( $dataNode->nodeName ) {
							case "Headline": {
								$item->headline = $dataNode->nodeValue;
							} break;
							case "URL": {
								$item->url = $this->oxanGateway( $dataNode->nodeValue );
							} break;
							case "Products": {
								if( !is_array( $item->products )) {
									$item->products = array();
								}
								foreach( $dataNode->childNodes as $productNode ) {
									$item->products[] = $productNode->attributes->getNamedItem( "Code" )->nodeValue;
								}
							} break;
						}
					}

					$results->hitItem[] = $item;
				}}


				return $results;
	}

	/**
	 * Get the "static" list of countries as defined in Oxford Analytica documentation
	 * @return MultiPair[]
	 * */
	public function oxanGetStaticCountryList() {
		$oxanCountries = array();
		$values = array(
				"Ethiopia", "Nigeria", "AF", "Gabon", "Reunion", "Africa", "Gambia", "Rwanda", "Angola", "Ghana", "Saint Helena", "AU", "Guinea",
				"Sao Tome", "Benin", "Guinea-Bissau", "Senegal", "Botswana", "Ivory Coast", "Seychelles", "Burkina Faso", "Kenya", "Sierra Leone",
				"Burundi", "Lesotho", "Somalia", "Cameroon", "Liberia", "South Africa", "Cape Verde", "Madagascar", "Sudan", "Central African Republic",
				"Malawi", "Swaziland", "Chad", "Mali", "Tanzania", "Comoros", "Mauritania", "Togo", "Congo-Brazzaville", "Mauritius", "Uganda", "Congo-Kinshasa",
				"Mayotte", "West Africa", "Djibouti", "Mozambique", "Zaire", "Equatorial Guinea", "Namibia", "Zambia", "Eritrea", "Niger", "Zimbabwe"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "AFRICA", $values );
				$values = array(
				"Hong Kong", "Pacific", "Afghanistan", "India", "Pakistan", "American Samoa", "Indian Ocean", "Palau", "AP", "Indonesia", "Papua New Guinea",
				"APEC", "Japan", "Philippines", "ASEAN", "Kiribati", "Pitcairn", "Asia", "Laos", "Singapore", "Australia", "Macao", "Solomon Islands", "Bangladesh",
				"Macau", "South Asia", "Bhutan", "Malaysia", "South Korea", "Brunei", "Maldives", "South-east Asia", "Burma", "Mariana Islands", "Sri Lanka",
				"Cambodia", "Marshall Islands", "Taiwan", "China", "Micronesia", "Thailand", "Cook Islands", "Mongolia", "Tonga", "East Asia", "Nauru",
				"Tuvalu", "East Timor", "Nepal", "Vanuatu", "Fiji", "New Caledonia", "Vietnam", "French Polynesia", "New Zealand", "Wallis and Futuna", "Guam",
				"North Korea", "Western Samoa"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "ASIA PACIFIC", $values );

				$values = array(
				"CIS", "Russia", "Armenia", "Georgia", "Tajikistan", "Azerbaijan", "Kazakhstan", "Turkmenistan", "Belarus", "Kyrgyzstan", "Ukraine", "Caucasus",
				"Moldova", "Uzbekistan", "Central Asia", "RUCIS"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "CIS", $values );

				$values = array(
				"Estonia", "Montenegro", "Albania", "EU", "Netherlands", "Andorra", "EUR", "Northern Ireland", "Austria", "Finland", "Norway", "Balkans", "France",
				"Poland", "Baltic states", "Germany", "Portugal", "Belgium", "Gibraltar", "Romania", "Bosnia-Hercegovina", "Greece", "San Marino", "Bulgaria",
				"Hungary", "Serbia", "Croatia", "Iceland", "Slovakia", "Cyprus", "Ireland", "Slovenia", "Czech Republic", "Italy", "Spain", "Czechoslovakia",
				"Latvia", "Sweden", "Denmark", "Liechtenstein", "Switzerland", "Eastern Europe", "Lithuania", "United Kingdom", "Eastern Germany", "Luxembourg",
				"Vatican City", "EC", "Macedonia", "WE", "EE", "Malta", "Western Europe", "EFTA", "Monaco", "Yugoslavia"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "EUROPE", $values );

				$values = array(
				"INT", "OECD", "Antarctica", "International", "OPEC", "Commonwealth", "LDCs", "United Nations", "GATT", "NAFTA", "WTO", "IMF-World Bank", "NATO"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "INTERNATIONAL ORGANISATIONS", $values );

				$values = array(
				"Dominican Republic", "Netherlands Antilles", "Anguilla", "Ecuador", "Nicaragua", "Antigua and Barbuda", "El Salvador", "Panama", "Argentina",
				"Falkland Islands", "Paraguay", "Aruba", "French Guiana", "Peru", "Bahamas", "Grenada", "Puerto Rico", "Barbados", "Guadeloupe", "Saint Kitts and Nevis",
				"Belize", "Guatemala", "Saint Lucia", "Bermuda", "Guyana", "Saint Vincent", "Bolivia", "Haiti", "Suriname", "Brazil", "Honduras", "Trinidad and Tobago",
				"Caribbean", "Jamaica", "Turks and Caicos", "Cayman Islands", "LA/C", "Uruguay", "Central America", "Latin America", "Venezuela", "Chile",
				"Leeward Islands", "Virgin Islands", "Colombia", "Martinique", "Virgin Islands (British)", "Costa Rica", "Mercosur", "Windward Islands", "Cuba",
				"Mexico", "Dominica", "Montserrat"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "LATIN AMERICA / CARIBBEAN", $values );

				$values = array(
				"Kuwait", "Qatar", "Algeria", "Lebanon", "Saudi Arabia", "Bahrain", "Libya", "Syria", "Egypt", "ME/NAF", "Tunisia", "Gulf states", "Middle East",
				"Turkey", "Iran", "Morocco", "United Arab Emirates", "Iraq", "North Africa", "Western Sahara", "Israel", "Oman", "Yemen", "Jordan", "Palestinians"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "MIDDLE EAST / NORTH AFRICA", $values );

				$values = array(
				"NA", "United States", "Canada", "North America", "Greenland", "Saint Pierre and Miquelon"
				);
				sort( $values );
				$oxanCountries[] = new MultiPair( "NORTH AMERICA", $values );

				return $oxanCountries;
	}

	/**
	 * Get the "static" list of topics as defined in Oxford Analytica documentation
	 * @return MultiPair[]
	 * */
	public function oxanGetStaticTopicList() {

		$oxanTopics = array();
		$values = array(
				"energy","patents","agriculture","environment","pensions","aid","equities","policy","balance of payments","exchange rate","prices",
				"black market","fiscal","private sector","bonds","foreign investment","privatisation","capital flows","foreign trade","productivity",
				"consumer","growth","property","corporate","integration","public sector","debt","investment","regulation","deregulation","labour",
				"strike","derivatives","monetary","technology","economy","natural disasters","trade","employment","natural resources","wages"
				);
				sort( $values );
				$oxanTopics[] = new MultiPair( "ECONOMY", $values);
				$values = array(
				"fishing","pharmaceutical","advertising","food","retail","aerospace","gas","services","airlines","gold","shipbuilding","arms","industry",
				"shipping","automobile","infrastructure","soft commodities","banking","insurance","steel","biotechnology","leisure","sugar","chemical",
				"manufacturing","telecommunications","coal","media","textiles","coffee","metals","timber","computers","mining","tin","construction",
				"narcotics","tourism","electricity","nuclear energy","transport","electronics","oil","utilities","finance","paper"
				);
				sort( $values );
				$oxanTopics[] = new MultiPair( "INDUSTRY", $values);
				$values = array(
				"international law","summit","arms control","international relations","talks","border conflict","invasion","treaty","espionage","sanctions",
				"war","foreign policy","security"
				);
				sort( $values );
				$oxanTopics[] = new MultiPair( "INTERNATIONAL RELATIONS", $values);
				$values = array(
				"government","politics","assassination","guerrillas","rebellion","civil war","human rights","referendum","constitution","judicial","reform",
				"corruption","legislation","regional","coup","military","religion","decentralisation","nationality","riot","defence","nuclear weapons",
				"terrorism","election","opposition","unions","emergency","party","ethnic","police"
				);
				sort( $values );
				$oxanTopics[] = new MultiPair( "POLITICS", $values);
				$values = array(
				"health","poverty","crime","immigration","refugees","education","pollution","social","famine","population","welfare"
				);
				sort( $values );
				$oxanTopics[] = new MultiPair( "SOCIAL", $values);

				return $oxanTopics;
	}
}
?>
