<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaQueriesAndSources extends Tariqa {

	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */

	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}


	/**
	 * Get the list of available Flavours for the homepage
	 * @param string $token The session identifier
	 * @return Flavour[]
	 * */
	public function GetHomePageFlavours($token) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select *
from `homepage_flavours` f
sql;

		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$tabs = array();
		while ($rs = $queries->fetch_assoc()){
			$f = new Flavour();

			$f->name = $rs["name"];
			$f->description = $rs["description"];
			$f->flavour_id = $rs["flavour_id"];

			array_push($tabs, $f);
		}
		$queries->free();
		$my->close();

		return $tabs;
	}
	
	/**
	 * Get the list of available queries for the homepage
	 * @param string $token The session identifier
	 * @return Query[]
	 * */
	public function GetHomepageQueries($token){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select
    q.*, h.`description` as 'block_description', h.`display_order` as '__block_display_order',
		f.`flavour_id`, f.`name` `flavour_name`, f.`description` `flavour_description`
from
    `queries` q 
	inner join `queries_homepage` h using(`query_id`)
	left join `homepage_flavours` f on f.`flavour_id` = h.`flavour_id`
order by
    `h`.`display_order`;
sql;

		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($rs = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $rs["title"];
			$q->description = $rs["description"];
			$q->query = $rs["query"];
			$q->query_id = $rs["query_id"];
			$q->source_id = $rs["source_id"];
			$q->block_description = $rs["block_description"];
			$q->block_display_order = $rs["__block_display_order"];
			$q->time_range = $rs["time_range"];
			$q->icon = $rs['icon'];

			if( empty( $rs['flavour_id']) ) {
				$q->flavour = null;
			} else {
				$q->flavour = new Flavour();
				$q->flavour->name = $rs['flavour_name'];
				$q->flavour->description = $rs['flavour_description'];
				$q->flavour->flavour_id = $rs['flavour_id'];
			}

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();
		
		return $this->filterQueries($rez, $user_id, false, $token);
	}

	/**
	 * Get the list of available queries for the homepage
	 * @param string $token The session identifier
	 * @return Query[]
	 * */
	public function GetVideoQueries($token){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		/*                        $sql = <<<sql
		 select
		 q.*, v.`description` as 'block_description', v.`display_order` as 'block_display_order'
		 from
		 `queries` q inner join `queries_video` v using(`query_id`)
		 order by
		 `display_order`;
		 sql;
		 */
		$sql = <<<sql
select
    q.*, q.`description` as 'block_description'
from
    `queries` q
where source_id = 46
order by
    `query_id`;
sql;
		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($rs = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $rs["title"];
			$q->description = $rs["description"];
			$q->query = $rs["query"];
			$q->query_id = $rs["query_id"];
			$q->source_id = $rs["source_id"];
			$q->block_description = $rs["block_description"];
			$q->block_display_order = 0;
			$q->time_range = $rs["time_range"];

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();

		return $this->filterQueries($rez, $user_id);
	}

	/**
	 * Get the list of quicksearch sources
	 * @param string $token The session identifier
	 * @return QuickSearchSource[]
	 * */

	public function ListQuickSearchSources($token){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$access_level = $this->_GetUserVariable($user_id, 'access_level', false);

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select *
from `sources` s inner join `quicksearch_sources` qs using (source_id)
	inner join engines using(engine_id)
where
	access_level <= '{$access_level}'
order by `order`;
sql;

		if (($sources = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($source = $sources->fetch_assoc()){
			$s = new Source();

			$s->copyright = $source["copyright"];
			$s->description = $source["description"];
			$s->disclaimer = $source["disclaimer"];
			$s->doc_url = $source["doc_url"];
			$s->engine_id = $source["engine_id"];
			$s->icon_url = $source["icon_url"];
			$s->logo_url = $source["logo_url"];
			$s->source_data = $source["source_data"];
			$s->title = $source["title"];
			$s->source_id = $source["source_id"];

			$qs = new QuickSearchSource();
			$qs->source = $s;
			$qs->display_title = $source['display_title'];
			$qs->order = $source['order'];

			array_push($rez, $qs);
		}

		$sources->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of a source without authentication
	 * @param string $token The session identifier
	 * @param int $source_id The source identifier
	 * @return Source
	 * */

	private function _getSource($token, $source_id){
		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($source_id);

		$sql = <<<sql
				select * from sources where source_id = {$id};
sql;

		if (($_source = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$source = $_source->fetch_assoc();
		$rez = new Source();
		$rez->copyright = $source["copyright"];
		$rez->description = $source["description"];
		$rez->disclaimer = $source["disclaimer"];
		$rez->doc_url = $source["doc_url"];
		$rez->engine_id = $source["engine_id"];
		$rez->icon_url = $source["icon_url"];
		$rez->logo_url = $source["logo_url"];
		$rez->source_data = $source["source_data"];
		$rez->title = $source["title"];
		$rez->source_id = $source["source_id"];

		$_source->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of a source
	 * @param string $token The session identifier
	 * @param int $source_id The source identifier
	 * @return Source
	 * */

	public function GetSource($token, $source_id){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_getSource($token, $source_id);
	}

	/**
	 * Get the list of available sources
	 * @param string $token The session identifier
	 * @return Source[]
	 * */

	public function ListSources($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
				select * from sources order by title;
sql;

		if (($sources = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($source = $sources->fetch_assoc()){
			$s = new Source();

			$s->copyright = $source["copyright"];
			$s->description = $source["description"];
			$s->disclaimer = $source["disclaimer"];
			$s->doc_url = $source["doc_url"];
			$s->engine_id = $source["engine_id"];
			$s->icon_url = $source["icon_url"];
			$s->logo_url = $source["logo_url"];
			$s->source_data = $source["source_data"];
			$s->title = $source["title"];
			$s->source_id = $source["source_id"];

			array_push($rez, $s);
		}

		$sources->free();
		$my->close();

		return $rez;
	}

	/**
	 * Lists the full search sources
	 * @param string $token The session identifier
	 * @access public
	 * @return FullSearchSource[]
	 */
	public function ListFullSearchSources($token) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$access_level = $this->_GetUserVariable($user_id, 'access_level', false);

		$sources = $this->config['sources']['full-search'];
		$result = array();

		foreach ($sources as $id => $level){
			if ($level <= $access_level){
				$source = new FullSearchSource();
				$source->id = $id;
				$source->access_level = $level;

				$result[] = $source;
			}
		}
		
		return $result;
	}

	/**
	 * Get the content of flavour
	 * @param string $token The session identifier
	 * @param int $flavour_id The flavour identifier
	 * @return Flavour
	 * */

	public function GetFlavour($token, $flavour_id){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($flavour_id);

		$sql = <<<sql
				select * from flavours where flavour_id = '{$id}';
sql;
		if (($_flavour = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$flavour = $_flavour->fetch_assoc();
		$rez = new Flavour();
		$rez->description = $flavour["description"];
		$rez->name = $flavour["name"];
		$rez->flavour_id = $flavour["flavour_id"];

		$_flavour->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the list of available flavours
	 * @param string $token The session identifier
	 * @return Flavour[]
	 * */

	public function ListFlavours($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
				select * from flavours order by flavour_id;
sql;

		if (($flavours = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($flavour = $flavours->fetch_assoc()){
			$s = new Flavour();

			$s->description = $flavour["description"];
			$s->flavour_id = $flavour["flavour_id"];
			$s->name = $flavour["name"];

			array_push($rez, $s);
		}

		$flavours->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of an engine without authentication
	 * @param string $token The session identifier
	 * @param string $engine_id The engine identifier
	 * @return Engine
	 * */

	public function _getEngine($token, $engine_id){
		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($engine_id);

		$sql = <<<sql
				select * from engines where engine_id = '{$id}';
sql;
		if (($_engine = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$engine = $_engine->fetch_assoc();
		$rez = new Engine();
		$rez->copyright = $engine["copyright"];
		$rez->description = $engine["description"];
		$rez->disclaimer = $engine["disclaimer"];
		$rez->doc_url = $engine["doc_url"];
		$rez->icon_url = $engine["icon_url"];
		$rez->logo_url = $engine["logo_url"];
		$rez->name = $engine["name"];
		$rez->data = $engine["data"];
		$rez->engine_id = $engine["engine_id"];

		$_engine->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of an engine
	 * @param string $token The session identifier
	 * @param string $engine_id The engine identifier
	 * @return Engine
	 * */

	public function GetEngine($token, $engine_id){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_getEngine($token, $engine_id);
	}

	/**
	 * Get the list of available engines
	 * @param string $token The session identifier
	 * @return Engine[]
	 * */

	public function ListEngines($token){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$access_level = $this->_GetUserVariable($user_id, 'access_level', false);

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
				select * from engines order by name where access_level <= '{$access_level}';
sql;

		if (($engines = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($engine = $engines->fetch_assoc()){
			$s = new Engine();

			$s->copyright = $engine["copyright"];
			$s->description = $engine["description"];
			$s->disclaimer = $engine["disclaimer"];
			$s->doc_url = $engine["doc_url"];
			$s->engine_id = $engine["engine_id"];
			$s->icon_url = $engine["icon_url"];
			$s->logo_url = $engine["logo_url"];
			$s->name = $engine["name"];
			$s->data = $engine["data"];
			$s->access_level = $engine['access_level'];

			array_push($rez, $s);
		}

		$engines->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of a query
	 * @param string $token The session identifier
	 * @param int $query_id The query identifier
	 * @param boolean $get_source If set to true, also fetch the source [OPTIONAL]
	 * @param boolean $get_engine If set to true, also fetch the engine [OPTIONAL]
	 * @return Query
	 * */

	public function GetQuery($token, $query_id, $get_source = false, $get_engine = false){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($query_id);

		$sql = <<<sql
				select * from queries where query_id = {$id};
sql;

		if (($_query = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rs = $_query->fetch_assoc();
		$rez = new Query();
		$rez->description = $rs["description"];
		$rez->title = $rs["title"];
		$rez->query = $rs["query"];
		$rez->source_id = $rs["source_id"];
		$rez->query_id = $rs["query_id"];
		$rez->block_description = null;
		$rez->block_label = null;
		$rez->block_display_order = null;
		$rez->time_range = $rs["time_range"];

		$rez->flavour = $this->GetFlavour($token, $rs["flavour_id"]);
		
		if ($get_source){
			$rez->source = $this->_getSource($token, $rs["source_id"]);
		}

		if ($get_engine){
			$rez->engine = $this->_getEngine($token, $rez->source->engine_id);
		}

		$_query->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the content of one or more query
	 * @param string $token The session identifier
	 * @param int[] $query_ids A list of query identifiers
	 * @return Query[]
	 * */

	private function _GetQuery($token, $query_ids){
		/*if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
			}*/

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$cond = "";
		foreach ($query_ids as $query_id)
		$cond .= ($cond == ""?"":" or ") . " query_id = '{$query_id}' ";
		$cond = "({$cond})";

		$sql = <<<sql
				select * from queries where {$cond}
sql;

		if (($_query = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$res = array();

		while ($rs = $_query->fetch_assoc()){
			$q = new Query();
			$q->description = $rs["description"];
			$q->title = $rs["title"];
			$q->query = $rs["query"];
			$q->source_id = $rs["source_id"];
			$q->query_id = $rs["query_id"];
			$q->block_description = null;
			$q->block_label = null;
			$q->block_display_order = null;
			$q->time_range = $rs["time_range"];

			//$q->flavour = $this->GetFlavour($token, $query["flavour_id"]);

			array_push($res, $q);
		}

		$_query->free();
		$my->close();

		return $res;
	}

	/**
	 * Get the list of available queries
	 * @param string $token The session identifier
	 * @param int $source_id The source identifier of the queries to retrieve [OPTIONAL]
	 * @param boolean $weblogs_data If true, then get also the weblogs data [OPTIONAL]
	 * @return Query[]
	 * */

	public function ListQueries($token, $source_id = null, $weblogs_data = false){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$cond = 'source_id <> -8';
		if ($source_id != null) {
			$source_id = $my->real_escape_string($source_id);
			$cond = " source_id = '{$source_id}' ";
		}

		if (!$weblogs_data){
			$sql = <<<sql
					select * from queries where {$cond} order by title;
sql;
		}
		else {
			$sql = <<<sql
					select * from queries left join weblogs using(query_id) where {$cond} order by title;
sql;
		}

		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($rs = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $rs["title"];
			$q->description = $rs["description"];
			$q->query = $rs["query"];
			$q->query_id = $rs["query_id"];
			$q->source_id = $rs["source_id"];
			$q->block_description = null;
			$q->block_display_order = null;
			$q->block_label = null;
			$q->time_range = $rs["time_range"];
			$q->weblog_id = $rs['name'];
			$q->icon = $rs['icon'];

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();

		return $this->filterQueries($rez, $user_id);
	}

	/**
	 * Get the list of available queries for a defined contry
	 * @param string $token The session identifier
	 * @param Country $country The selected country
	 * @param int $flavour_id The flavour identifier [OPTIONAL]
	 * @return Query[]
	 * */

	public function GetCountryQueries($token, $country, $flavour_id = null){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($country->code_iso2);

		if ($flavour_id != null){
			$flavour = $this->GetFlavour($token, $flavour_id);
			$sql = <<<sql
				select queries.*, label as block_label, queries_countries.description as block_description, display_order as block_display_order from queries
				inner join queries_countries on queries.query_id = queries_countries.query_id
				where queries_countries.country_id = '{$id}' and queries_countries.flavour_id = '{$flavour_id}'
				order by title;
sql;
		}
		else{
			$flavour  = null;
			$sql = <<<sql
                                select queries.*, label as block_label, queries_countries.description as block_description, display_order as block_display_order,
                                flavours.name as flavour_name, flavours.description as flavour_description, flavours.flavour_id as flavour_id
                                from queries inner join queries_countries on queries.query_id = queries_countries.query_id
                                left join flavours on queries_countries.flavour_id = flavours.flavour_id
                                where queries_countries.country_id = '{$id}'
                                order by flavours.flavour_id, block_display_order
sql;
		}
		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$rez = array();

		while ($rs = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $rs["title"];
			$q->description = $rs["description"];
			$q->query = $rs["query"];
			$q->query_id = $rs["query_id"];
			$q->source_id = $rs["source_id"];
			$q->block_description = $rs["block_description"];
			$q->block_display_order = $rs["block_display_order"];
			$q->block_label = $rs["block_label"];
			$q->time_range = $rs["time_range"];
                        $q->icon = $rs['icon'];
			if ($flavour != null){
                          $q->flavour = $flavour;
                        }
                        else {
                          $f = new Flavour();
                          $f->description = $rs['flavour_description'];
                          $f->flavour_id = $rs['flavour_id'];
                          $f->name = $rs['flavour_name'];
                          $q->flavour = $f;
                        }

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();

		return $this->filterQueries($rez, $user_id);
	}

	/**
	 * Get the list of available queries for a defined region
	 * @param string $token The session identifier
	 * @param int $region_id The selected country
	 * @param int $flavour_id The flavour identifier [OPTIONAL]
	 * @return Query[]
	 * */

	public function GetRegionQueries($token, $region_id, $flavour_id = null){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($region_id);

		if ($flavour_id != null){
			$flavour = $this->GetFlavour($token, $flavour_id);
			$sql = <<<sql
select
	queries.*, label as block_label, queries_regions.description as block_description, display_order as block_display_order
from
	queries inner join queries_regions on queries.query_id = queries_regions.query_id
where
	queries_regions.region_id = '{$id}' and flavour_id = '{$flavour_id}'
order by title;
sql;
		}
		else{
			$flavour  = null;
			$sql = <<<sql
select
	queries.*, label as block_label, queries_regions.description as block_description, display_order as block_display_order
from
	queries inner join queries_regions on queries.query_id = queries_regions.query_id
where
	queries_regions.region_id = '{$id}'
order by title;
sql;
		}
		if (($queries = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $rs );
			$my->close();
			return null;
		}

		$rez = array();

		while ($rs = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $rs["title"];
			$q->description = $rs["description"];
			$q->query = $rs["query"];
			$q->query_id = $rs["query_id"];
			$q->source_id = $rs["source_id"];
			$q->block_description = $rs["block_description"];
			$q->block_display_order = $rs["block_display_order"];
			$q->block_label = $rs["block_label"];
			$q->time_range = $rs["time_range"];
			$q->flavour = $flavour;

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();

		return $this->filterQueries($rez, $user_id);
	}

	/**
	 * Lists the news stickers groups
	 * @param string $token The session identifier
	 * @return NewStickerGroup[]
	 */
	public function ListNewStickerGroups($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select * from `newstickers_groups` order by `name`
sql;

		if (($q = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$res = array();

		while ($group = $q->fetch_assoc()){
			$g = new NewStickerGroup();
			$g->name = $group["name"];

			$sql = <<<sql
select
	`query_id`
from
	`newstickers_queries`
where
	`group_id` = '{$group["group_id"]}'
order by
	`query_id`
sql;

			if (($q2 = $my->query($sql)) === false){
				return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
				$my->close();
				return null;
			}

			$g->queries = array();
			$ids = array();
			while ($rs = $q2->fetch_assoc()){
				//$g->queries[] = $this->GetQuery($token, $query["query_id"]);
				$ids[] = $rs["query_id"];
			}

			$g->queries = $this->_GetQuery($token, $ids);

			array_push($res, $g);

		}

		return $res;

	}

	/**
	 * The access level of the current user
	 * @var int
	 * @access private static
	 */
	private static $access_level;

	/**
	 * Filters the queries
	 * @param Query $rs The query being checked
	 * @access private static
	 * @return boolean
	 */
	private static function do_filter($rs) {
		if ($rs->engine == null) return false;

		return ($rs->engine->access_level <= self::$access_level);
	}

	/**
	 * Filters the list of queries
	 * @param Query[] $queries The list of queries
	 * @param string $user_id The user identifier
         * @param boolean $no_articles If true, then also include the queries with no results (this is only for aggregated RSS) [OPTIONAL]
         * @param string $token The session identifier [OPTIONAL]
	 * @access public
	 * @return Query[]
	 */
	public function filterQueries($queries, $user_id, $no_articles = true, $token = null) {
		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		/* @var $query Query */
		foreach ($queries as $key => $rs){
			if ($rs->engine == null){
				$source_id = $my->real_escape_string($rs->source_id);
				$sql = "select * from engines where engine_id = (select engine_id from sources where source_id = '{$source_id}')";

				if (($q = $my->query($sql)) === false){
					return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
					$my->close();
					return null;
				}

				if ($e = $q->fetch_assoc()){
					$engine = new Engine();
					$engine->access_level = $e['access_level'];
					$engine->copyright = $e['copyright'];
					$engine->data = $e['data'];
					$engine->description = $e['description'];
					$engine->disclaimer = $e['disclaimer'];
					$engine->doc_url = $e['doc_url'];
					$engine->engine_id = $e['engine_id'];
					$engine->icon_url = $e['icon_url'];
					$engine->logo_url = $e['logo_url'];
					$engine->name = $e['name'];

					$rs->engine = $engine;
				}
			}
                    if (!$no_articles && ($rs->engine->engine_id == 'RSS_aggregator' || $rs->engine->engine_id == 'RSS') && is_numeric($rs->query)){
                        if ($this->GetAggregatedRSSArticlesNumber($token, $rs->query) <= 0) {
							unset($queries[$key]);
						}
                    }
		}

		self::$access_level = $this->_GetUserVariable($user_id, 'access_level', false);

		$result = array_filter($queries, array($this, 'do_filter'));

		return $result;
	}

}
?>