<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaSession extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	 */
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */

	public function __construct($config, $soap) {
		$this->config = $config;
		$this->soap = $soap;
	}

	/**
	 * Fetch the value of a variable saved in the user's session
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @return string The value of the variable
	 * */
	public function GetUserSessionVariable( $token, $key ) {
		return $this->GetUserVariable( $token, $key, false );
	}
	/**
	 * Fetch the value of a variable saved in the user's session
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @return string The value of the variable
	 * */
	public function GetUserPersistentVariable( $token, $key ) {
		return $this->GetUserVariable( $token, $key, true );
	}

	/**
	 * Fetch the value of a variable saved either in the user's session either in his/herpersistent storage
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
	 * @return string The value of the variable
	 * */
	protected function GetUserVariable( $token, $key, $persistent = false ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_GetUserVariable($user_id, $key, $persistent);
	}

	/**
	 * Save a variable in the user's session
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @param string $value The variable's value
	 * @return boolean
	 * */
	public function SetUserSessionVariable( $token, $key, $value ) {
		return $this->SetUserVariable( $token, $key, $value, false );
	}
	/**
	 * Save a variable in the user's persistent storage
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @param string $value The variable's value
	 * @return boolean
	 * */
	public function SetUserPersistentVariable( $token, $key, $value ) {
		return $this->SetUserVariable( $token, $key, $value, true );
	}

	/**
	 * Save a variable in the user's session
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @param string $value The variable's value
	 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
	 * @return boolean
	 * */
	protected function SetUserVariable( $token, $key, $value, $persistent = false ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_SetUserVariable($user_id, $key, $value, $persistent);
	}

	/**
	 * Set all user's session variables at once
	 * @param string $token The session identifier
	 * @param Pair[] $variables The list of variables
	 * @return boolean
	 * */
	public function SetUserSessionVariables( $token, $variables ) {
		return $this->SetUserVariables( $token, $variables, false );
	}
	/**
	 * Set all user's persistent variables at once
	 * @param string $token The session identifier
	 * @param Pair[] $variables The list of variables
	 * @return boolean
	 * */
	public function SetUserPersistentVariables( $token, $variables ) {
		return $this->SetUserVariables( $token, $variables, true );
	}

	/**
	 * Save all variables in the user's session or persistent storage at once
	 * @param string $token The session identifier
	 * @param Pair[] $variables The list of variables
	 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
	 * @return boolean
	 * */
	protected function SetUserVariables( $token, $variables, $persistent = false ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$db_user_id = $my->real_escape_string( $user_id );
		$table = ($persistent ? "persistent_data" : "sessions_data");

		// Set the session variables;
		$queries = array();

		$queries[] = "start transaction";
		$queries[] = "delete from `{$table}` where `user_id` = '{$db_user_id}'";

		$basequery = "replace into `{$table}`(`user_id`, `key`, `value`) values ";
		$query = "";
		foreach( $variables as $k => $pair ) {
			if( 0 == ($k % 25) ) {
				if( 0 != $k ) {
					$queries[] = $basequery . $query;
					$query = "";
				}
			} else {
				$query .= ",\n";
			}
			$db_key = $my->real_escape_string( $pair->key );
			$db_value = $my->real_escape_string( $pair->value );
			$query .= <<<sql
('{$db_user_id}', '{$db_key}', '{$db_value}')
sql;
		}
		if( 0 != strlen( $query )) {
			$queries[] = $basequery . $query;
		}

		$my->autocommit(false);
		foreach( $queries as $query ) {
			$rs = $my->query( $query );
			if( false === $rs ) {
				$error = $my->error;
				$errno = $my->errno;
				$my->rollback();
				$my->close();
				return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$errno}, {$error}", null, $query );
				return false;
			}
		}
		$my->commit();
		$my->autocommit(true);
		$my->close();

		return true;
	}

	/**
	 * Fetch the list of user's session variables
	 * @param string $token The session identifier
	 * @return Pair[] List of variables
	 * */
	public function GetUserSessionVariables( $token) {
		return $this->GetUserVariables( $token, false );
	}
	/**
	 * Fetch the list of user's persistent variables
	 * @param string $token The session identifier
	 * @return Pair[] List of variables
	 * */
	public function GetUserPersistentVariables( $token) {
		return $this->GetUserVariables( $token, true );
	}

	/**
	 * Fetch the list of user's session/persistent variables
	 * @param string $token The session identifier
	 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
	 * @return Pair[] The value of the variable
	 * */
	protected function GetUserVariables( $token, $persistent = false ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$db_user_id = $my->real_escape_string( $user_id );
		$table = ($persistent ? "persistent_data" : "sessions_data");

		// Fetch the session variable
		$query = <<<sql
select *
from `{$table}` d
where d.`user_id` = '{$db_user_id}'
sql;
		$result = array();
		$rs = $my->query( $query );
		while( $row = $rs->fetch_assoc() ) {
			$result[] = new Pair( $row["key"], $row["value"] );
		}
		$rs->free();
		$my->close();

		return $result;
	}

	/**
	 * Fetch the value of a variable saved in the server's persistent storage (WITHOUT CHECKING THE SESSION TOKEN)
	 * @param string $key The variable name (255 characters max)
	 * @return string The value of the variable
	 * @access protected
	 * */
	protected function _GetServerVariable( $key ) {
		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$db_key = $my->real_escape_string( $key );

		// Fetch the session variable
		$query = <<<sql
select *
from `server_data` d
where d.`key` = '{$db_key}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 != $rs->num_rows ) {
			$variable = $rs->fetch_assoc();
		} else {
			$variable = array( "value" => "" );
		}

		$rs->free();
		$my->close();

		return $variable["value"];
	}

	/**
	 * Save a variable in the server's persistent storage (WITHOUT CHECKING THE SESSION TOKEN)
	 * @param string $token Session identifier
	 * @param string $key Variable name (255 characters max)
	 * @param string $value Value
	 * @return boolean
	 * @access protected
	 * */
	protected function _SetServerVariable( $key, $value ) {
		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$db_key = $my->real_escape_string( $key );
		$db_value = $my->real_escape_string( $value );

		// Fetch the session variable
		$query = <<<sql
replace into `server_data`(
	`key`, `value`
) values (
	'{$db_key}', '{$db_value}'
)
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return false;
		}
		$my->close();

		return true;
	}

	/**
	 * Fetch the list of server variables (WITHOUT CHECKING THE SESSION TOKEN)
	 * @param string $token The session identifier
	 * @return Pair[] List of variables
	 * @access protected
	 * */
	protected function _GetServerVariables() {
		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		// Fetch the session variable
		$query = <<<sql
select *
from `server_data` d
sql;
		$result = array();
		$rs = $my->query( $query );
		while( $row = $rs->fetch_assoc() ) {
			$result[] = new Pair( $row["key"], $row["value"] );
		}
		$rs->free();
		$my->close();

		return $result;
	}

	/**
	 * Set all server variables at once (WITHOUT CHECKING THE SESSION TOKEN)
	 * @param string $token The session identifier
	 * @param Pair[] $variables The list of variables
	 * @return boolean
	 * @access protected
	 * */
	protected function _SetServerVariables( $variables ) {
		$error = false;
		$my = $this->OpenDatabase( "soap", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
			return null;
		}

		// Set the session variables;
		$queries = array();

		$queries[] = "start transaction";
		$queries[] = "truncate `server_data`";

		$basequery = "replace into `server_data`(`key`, `value`) values ";
		$query = "";
		foreach( $variables as $k => $pair ) {
			if( 0 == ($k % 25) ) {
				if( 0 != $k ) {
					$queries[] = $basequery . $query;
					$query = "";
				}
			} else {
				$query .= ",\n";
			}
			$db_key = $my->real_escape_string( $pair->key );
			$db_value = $my->real_escape_string( $pair->value );
			$query .= <<<sql
('{$db_key}', '{$db_value}')
sql;
		}
		if( 0 != strlen( $query )) {
			$queries[] = $basequery . $query;
		}

		$my->autocommit(false);
		foreach( $queries as $query ) {
			$rs = $my->query( $query );
			if( false === $rs ) {
				$error = $my->error;
				$errno = $my->errno;
				$my->rollback();
				$my->close();
				return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$errno}, {$error}", null, $query );
				return false;
			}
		}
		$my->commit();
		$my->autocommit(true);
		$my->close();

		return true;
	}

	/**
	 * Fetch the value of a variable saved in the server's persistent storage
	 * @param string $token The session identifier
	 * @param string $key The variable name (255 characters max)
	 * @return string The value of the variable
	 * */
	public function GetServerVariable( $token, $key ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		return $this->_GetServerVariable( $key );
	}

	/**
	 * Fetch the list of server variables
	 * @param string $token The session identifier
	 * @return Pair[] List of variables
	 * */
	public function GetServerVariables( $token) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		return $this->_GetServerVariables();
	}

	/**
	 * Set all server variables at once
	 * @param string $token The session identifier
	 * @param Pair[] $variables The list of variables
	 * @return boolean
	 * */
	public function SetServerVariables( $token, $variables ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		return $this->_SetServerVariables( $variables );
	}

	/**
	 * Save a variable in the server's persistent storage
	 * @param string $token Session identifier
	 * @param string $key Variable name (255 characters max)
	 * @param string $value Value
	 * @return boolean
	 * */
	public function SetServerVariable( $token, $key, $value ) {
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		return $this->_SetServerVariable( $key, $value );
	}
}
?>