<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaStaticUsers extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Gets a list of users from the system cache
	 * @param string $token The session identifier
	 * @param string $department The LDAP departments from which to list the users [OPTIONAL]
	 * @return SystemCacheUser[]
	 */
	public function ListSystemCachedUsers($token, $department = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		if ($department != null) {
			$department = $my->real_escape_string($department);
			$cond_dep = " where `ldap_department` = '{$department}' ";
			if ($department == "") $cond_dep .= " or `ldap_department` is null ";
		}
		else $cond_dep = null;

		$sql = <<<sql
select
	*
from `users`
		{$cond_dep}
order by `user_id`
sql;
		if (($users = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$res = array();

		while ($user = $users->fetch_assoc()){
			$u = new SystemCacheUser();

			$u->creation_time = $user["creation_time"];
			$u->ldap_department = $user["ldap_department"];
			$u->ldap_displayname = $user["ldap_displayname"];
			$u->ldap_email = $user["ldap_email"];
			$u->ldap_firstname = $user["ldap_firstname"];
			$u->ldap_group = array();
			if ($user["ldap_group"] != "" && $user["ldap_group"] != null){
				$parts = explode(",", $user["ldap_group"]);
				foreach($parts as $part) $u->ldap_group[] = $part;
			}
			$u->ldap_lastname = $user["ldap_lastname"];
			$u->ldap_office = $user["ldap_office"];
			$u->ldap_phone = $user["ldap_phone"];
			$u->ldap_title = $user["ldap_title"];
			$u->user_id = $user["user_id"];

			array_push($res, $u);
		}

		return $res;

	}

	/**
	 * Get a system cached LDAP user
	 * @param string $token The session identifier
	 * @param string $user_id The user identifier
	 * @return SystemCacheUser
	 */
	public function GetSystemCachedUser($token, $user_id){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$user_id = $my->real_escape_string($user_id);

		$sql = <<<sql
select
	*
from `users`
where `user_id` = '{$user_id}';
sql;
		if (($q = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		if (($user = $q->fetch_assoc()) === false) return null;

		$u = new SystemCacheUser();

		$u->creation_time = $user["creation_time"];
		$u->ldap_department = $user["ldap_department"];
		$u->ldap_displayname = $user["ldap_displayname"];
		$u->ldap_email = $user["ldap_email"];
		$u->ldap_firstname = $user["ldap_firstname"];
		$u->ldap_group = array();
		if ($user["ldap_group"] != "" && $user["ldap_group"] != null){
			$parts = explode(",", $user["ldap_group"]);
			foreach($parts as $part) $u->ldap_group[] = $part;
		}
		$u->ldap_lastname = $user["ldap_lastname"];
		$u->ldap_office = $user["ldap_office"];
		$u->ldap_phone = $user["ldap_phone"];
		$u->ldap_title = $user["ldap_title"];
		$u->user_id = $user["user_id"];

		return $u;

	}

	/**
	 * List the LDAP departments from system cache
	 * @param string $token The session identifier
	 * @return string[]
	 */
	public function ListLDAPCachedDepartments($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select
	if(`ldap_department` is null, '', `ldap_department`) as 'ldap_department'
from
	`users`
group by if(`ldap_department` is null, '', `ldap_department`)
order by `ldap_department`
sql;

		if (($departments = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$res = array();

		while ($department = $departments->fetch_assoc()){
			$res[] = $department["ldap_department"];
		}

		return $res;
	}

}
?>