<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

require_once("lib/ecldap.inc.php");
class tariqaTools extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Search the Commission's LDAP database by name or user id
	 * @param string $token Session Identifier
	 * @param string $name A portion of the name to search (if not including any wildcards ('*') characters, it will be automatically appended AT THE END of the name)
	 * @param int $max_time Maximum duration of the LDAP request in seconds [OPTIONAL]
	 * @param int $max_results Maximum number of entries returned by the query [OPTIONAL]
	 * @return LDAPResultSet
	 **/
	public function ldapSearch( $token, $name, $max_time, $max_results ) {
		$filter = "";
		if( false === strpos( $name, "*" )) {
			$filter = "(|(uid={$name})(cn={$name}*))";
		} else {
			$filter = "(|(uid={$name})(cn={$name}))";
		}
		return $this->ldapFullSearch( $token, $filter, $max_time, $max_results );
	}

	/**
	 * Search the Commission's LDAP database
	 * @param string $token Session Identifier
	 * @param string $filter LDAP Query
	 * @param int $max_time Maximum duration of the LDAP request in seconds [OPTIONAL]
	 * @param int $max_results Maximum number of entries returned by the query [OPTIONAL]
	 * @return LDAPResultSet
	 **/
	public function ldapFullSearch( $token, $filter, $max_time, $max_results ) {
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		if( null === $max_time ) {
			$max_time = 5;
		}
		if( null === $max_results ) {
			$max_results = 50;
		}

		$resultset = new LDAPResultSet();

		$ldap = new EC_LDAP();
		$ldap->connect();
		$ldap->max_results = $max_results;
		$ldap->max_time = $max_time;
		$res = $ldap->search( $filter );
		$resultset->ldap_errno = $ldap->errno();
		$resultset->ldap_error = $ldap->error();
		$ldap->close();

		if( false === $res ) {
			$resultset->success = false;
		} else {
			$resultset->success = true;
			$entries = array();
			foreach( $res as $entry ) {
				$entries[] = new LDAPEntry( $entry );
			}
			$resultset->entries = $entries;
			$resultset->num_results = count($entries);
		}
		if( LDAPResultSet::LDAP_TIMELIMIT_EXCEEDED == $resultset->ldap_errno ) {
			$resultset->timelimit_exceeded = true;
		}
		if( LDAPResultSet::LDAP_SIZELIMIT_EXCEEDED == $resultset->ldap_errno ) {
			$resultset->sizelimit_exceeded = true;
		}
		if( LDAPResultSet::LDAP_PARTIAL_RESULTS == $resultset->ldap_errno ) {
			$resultset->partial_result = true;
		}

		return $resultset;
	}

	/**
	 * Send an e-mail message to a list of recipients
	 * @param string[] $to
	 * @param string $sujet
	 * @param string $contenu
	 * @param Attachment[] $attachments [OPTIONAL]
	 * @param string[] $cc List of recipients (Carbon copy) [OPTIONAL]
	 * @param string[] $bcc List of recipients (Blind carbon copy) [OPTIONAL]
	 * @return boolean
	 * */
	public function sendMail( $to, $sujet, $contenu, $attachments, $cc, $bcc ) {
		try {
			if (!class_exists("mSmtp")){
				require_once("lib/msmtp.inc.php");
			}
			$smtp = new mSmtp( $this->config["smtp"]["mailbox"], $this->config["smtp"]["host"], (int)$this->config["smtp"]["port"] );
			$smtp->setRecipients( $to );
			$smtp->setSubject( $sujet );
			$smtp->setMessage( $contenu );
			if( null !== $attachments && is_array( $attachments ) && 0 != count( $attachments )) {
				foreach( $attachments as $attachment ) {
					$smtp->addAttachment( base64_decode($attachment->data), $attachment->filename, $attachment->mime, true, $attachment->attachment_id );
				}
			}
			if( null !== $cc ) {
				$smtp->setCC( $cc );
			}
			if( null !== $bcc ) {
				$smtp->setBCC( $bcc );
			}
			$smtp->send();
		} catch( smtpException $e ) {
			return new SoapFault((string) self::e_smtp, self::e_smtp_msg . ":\n" . (string)$e);
			return false;
		}
		return true;
	}

	/**
	 * Fetch a document from the internet
	 * @param WebRequest $request HTTP query
	 * @return WebDocument
	 * @access protected
	 * */
	protected function _fetchUrl( $request ) {
		$post_fields = false;
		if( WebRequest::HTTP_POST != $request->method ) {
			if( is_array( $request->query ) && count( $request->query)) {
				$query_string = "";
				foreach( $request->query as $argument ) {
					$query_string .= $argument->key . "=" . rawurlencode($argument->value) . "&";
				}
				if( false !== strpos( "?", $request->url )) {
					if( "&" != substr( $request->url, -1 )){
						$request->url .= "&";
					}
					$request->url .= $query_string;
				} else {
					$request->url .= "?".$query_string;
				}
			}
		} else {
			if( is_array( $request->query ) && count( $request->query)) {
				$post_fields = array();
				foreach( $request->query as $argument ) {
					$post_fields[$argument->key] = rawurlencode($argument->value);
				}
			} else {
				$post_fields = false;
			}
		}
		$cookies = false;
		if( is_array( $request->cookies ) && count( $request->cookies )) {
			$cookies = "";
			foreach( $request->cookies as $cookie ) {
				$cookies .= $cookie->key . "=" . rawurlencode($cookie->value) . ";";
			}
		}

		$temp = tempnam( null, "cookie_" );
		$options = array(
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_URL => $request->url,
		CURLOPT_HEADER => true,
		CURLOPT_BINARYTRANSFER => true,
		CURLOPT_AUTOREFERER => true,
		CURLOPT_FOLLOWLOCATION => $request->follow_redirect,
		CURLOPT_MAXREDIRS => 3,
		CURLOPT_FRESH_CONNECT => true,
		CURLOPT_SSL_VERIFYPEER => false,
		CURLOPT_PROXYAUTH => CURLAUTH_BASIC,
		CURLOPT_PROXYPORT => (int)$this->config["proxy"]["port"],
		CURLOPT_PROXYTYPE => CURLPROXY_HTTP,
		CURLOPT_PROXY => ((int)$this->config["proxy"]["enable"]) ? $this->config["proxy"]["host"] : false,
		CURLOPT_PROXYUSERPWD => ((0 != strlen($this->config["proxy"]["user"])) ? ( "{$this->config["proxy"]["user"]}:{$this->config["proxy"]["password"]}") : false),
		CURLOPT_COOKIEJAR => $temp,
		//CURLOPT_REFERER => "https://webgate.ec.europa.eu/tariqa/",
		//CURLOPT_USERAGENT => "European Commission - DG RELEX; Tariqa Soap::fetchUrl (php5 - libCurl)",
		CURLOPT_USERAGENT => "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0",
		);
		
		if( WebRequest::HTTP_HEAD == $request->method ) {
			$options[CURLOPT_HTTPGET] = true;
			$options[CURLOPT_HEADER] = true;
			$options[CURLOPT_NOBODY] = true;
		} if( WebRequest::HTTP_POST == $request->method ) {
			$options[CURLOPT_POST] = true;
			$options[CURLOPT_POSTFIELDS] = $post_fields;
		}else {
			$options[CURLOPT_HTTPGET] = true;

		}
		if( false !== $cookies ) {
			$options[CURLOPT_COOKIE] =  $cookies;
		}

		$errno = false; $error = false; $info = false;
		$webdoc = new WebDocument();
		$curl = curl_init();

		curl_setopt_array( $curl, $options );

		$_doc = curl_exec( $curl );
		
		if( false === $_doc ) {
			$errno = curl_errno( $curl );
			$error = curl_error( $curl );
			curl_close( $curl );
			return new SoapFault((string) self::e_http, self::e_http_msg . " #{$errno}, {$error}" );
			@unlink( $temp );
			return null;
		}
		
		$_docparts = preg_split('/[\r]?\n[\r]?\n/', $_doc, 2 );
		
		$doc = '';
		$hdr = '';
		$cks = array();
		if( count($_docparts) != 2 ) {
			error_log('?? Invalid HTTP format ??');
			$doc = $_docparts[0];
		}
		else {
			$hdr = $_docparts[0];
			$doc = $_docparts[1];
			while (substr($doc, 0, 5) == 'HTTP/'){
				$_docparts = preg_split('/[\r]?\n[\r]?\n/', $doc, 2 );
				if (count($_docparts) != 2){
					error_log('?? Invalid HTTP format ??');
					$doc = $_docparts[0];
					break;
				}
				else {
					$hdr .= "\n" . $_docparts[0];
					$doc = $_docparts[1];
				}	
			}
		}
		
		preg_match_all('/^Set-Cookie: (.*)$/m', $hdr, $cks );
		if (count($cks) > 1){
			$cks = $cks[1];
		}
		else {
			$cks = $cks[0];
		}
			$info = curl_getinfo( $curl );
			$webdoc->url = $info["url"];
			$webdoc->http_code = $info["http_code"];
			$webdoc->content_type = $info["content_type"];
			$webdoc->content_length = $info["download_content_length"];
			$webdoc->speed_download = $info["speed_download"];
			$webdoc->total_time = $info["total_time"];
			$type = explode(";", $info["content_type"]);
			$charset = "";
			foreach ($type as $t){
				if (strpos($t, "charset") !== false){
					$c = explode("=", $t, 2);
					if (count($c) > 1){
						$charset = $c[1];
					}
				}
			}
			if ( strpos($type[0], 'text') === 0){
                                $webdoc->body = @iconv(empty($charset) ? 'UTF-8' : $charset, 'UTF-8//TRANSLIT', $doc);
				//$webdoc->body = utf8_encode($doc);
			}
			else {
				$webdoc->body = $doc;
			}
		curl_close( $curl );
		
/*		if( file_exists( $temp ) ) {
			//$webdoc->cookies = array(file_get_contents( $temp ));
			$webdoc->cookies = array();
			$ck = explode( "\r\n", file_get_contents( $temp ));
			foreach( $ck as $ix => $cookie ) {
				if( "#" == substr( $cookie, 0, 1 )) {
					continue;
				}
				if( 0 == strlen( $cookie )) {
					continue;
				}
				$cook_arr = explode( "\t", $cookie );
				if( 7 != count( $cook_arr )) {
					return new SoapFault((string) self::e_internal_error, __FILE__ . "@" . __LINE__ . ": Error parsing cookie [{$cookie}] : " . print_r($cook_arr, true ) );
				} else {
					$webdoc->cookies[] = new Cookie( $cook_arr[5], $cook_arr[6], $cook_arr[4], $cook_arr[0], $cook_arr[2], $cook_arr[1], $cook_arr[3] );
				}
			}
		}
*/
		if( !is_array( $webdoc->cookies ) ) {
			$webdoc->cookies = array();
		}

		$default_domain = preg_replace( '/^[^\/\/]*\/\/([^\/]*)\/.*$/', '\1', $webdoc->url );
		
		foreach( $cks as $idx => $ckline ) {
			if ($idx == 0){
				continue ;
			}
			$cookie = new Cookie();
			$ckparts = preg_split( '/; /', $ckline );
			foreach( $ckparts as $ckorder => $ckitem ) {
				$ckpartsxpl = preg_split( '/=/', $ckitem, 2 );
				if( $ckorder == 0 ) {
					$cookie->name = $ckpartsxpl[0];
					$cookie->value = preg_replace( '/[\r|\n]/', '', $ckpartsxpl[1] );
				} else {
					if( 1 == count( $ckpartsxpl )) {
						if( false === $cookie->extra1 ) {
							$cookie->extra1 = preg_replace( '/[\r|\n]/', '', $ckpartsxpl[0] );
						} else {
							$cookie->extra2 = preg_replace( '/[\r|\n]/', '', $ckpartsxpl[0] );
						}
						// More than 2... Ignored :-(
					} else {
						if( property_exists( $cookie, $ckpartsxpl[0] )) {
							$cookie->$ckpartsxpl[0] = preg_replace( '/[\r|\n]/', '', $ckpartsxpl[1] );
						} else {
							// Ignored :-(
						}
					}
				}
				
			}
			if( false === $cookie->domain ) {
				$cookie->domain = $default_domain;
			}
			$webdoc->cookies[] = $cookie;
		}
		
		@unlink( $temp );
			
		return $webdoc;

	}
	/**
	 * Fetch a document from the internet
	 * @param string $token Session identifier
	 * @param WebRequest $request HTTP query
	 * @return WebDocument
	 * */
	public function fetchUrl( $token, $request ) {
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_fetchUrl( $request );
	}

	/**
	 * Fetch a document from the intranet
	 * @param WebRequest $request HTTP query
	 * @return WebDocument
	 * @access protected
	 * */
	private function fetchUrlNoProxy( $token, $request ) {
		// ATTENTION: This method would bring high security risks (access intranet documents from outside)
		// IT MUST REMAIN DISABLED!
		return new SoapFault((string) self::e_forbidden, self::e_forbidden_msg );
		return null;
	}

	/**
	 * Fetch a document from the intranet
	 * @param WebRequest $request HTTP query
	 * @return WebDocument
	 * @access protected
	 * */
	protected function _fetchUrlNoProxy( $request ) {
		$post_fields = false;
		if( WebRequest::HTTP_POST != $request->method ) {
			if( is_array( $request->query ) && count( $request->query)) {
				$query_string = "";
				foreach( $request->query as $argument ) {
					$query_string .= $argument->key . "=" . rawurlencode($argument->value) . "&";
				}
				if( false !== strpos( "?", $request->url )) {
					if( "&" != substr( $request->url, -1 )){
						$request->url .= "&";
					}
					$request->url .= $query_string;
				} else {
					$request->url .= "?".$query_string;
				}
			}
		} else {
			if( is_array( $request->query ) && count( $request->query)) {
				$post_fields = array();
				foreach( $request->query as $argument ) {
					$post_fields[$argument->key] = rawurlencode($argument->value);
				}
			} else {
				$post_fields = false;
			}
		}
		$cookies = false;
		if( is_array( $request->cookies ) && count( $request->cookies )) {
			$cookies = "";
			foreach( $request->cookies as $cookie ) {
				$cookies .= $cookie->key . "=" . rawurlencode($cookie->value) . ";";
			}
		}

		$temp = tempnam( null, "cookie_" );
		$options = array(
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_URL => $request->url,
		CURLOPT_HEADER => false,
		CURLOPT_BINARYTRANSFER => true,
		CURLOPT_AUTOREFERER => true,
		CURLOPT_FOLLOWLOCATION => $request->follow_redirect,
		CURLOPT_MAXREDIRS => 3,
		CURLOPT_FRESH_CONNECT => true,
		CURLOPT_SSL_VERIFYPEER => false,
		CURLOPT_COOKIEJAR => $temp,
		//CURLOPT_REFERER => "https://webgate.ec.europa.eu/tariqa/",
		//CURLOPT_USERAGENT => "European Commission - DG RELEX; Tariqa Soap::fetchUrl (php5 - libCurl)",
		CURLOPT_USERAGENT => "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0",
		);

		if( WebRequest::HTTP_HEAD == $request->method ) {
			$options[CURLOPT_HTTPGET] = true;
			$options[CURLOPT_HEADER] = true;
			$options[CURLOPT_NOBODY] = true;
		} if( WebRequest::HTTP_POST == $request->method ) {
			$options[CURLOPT_POST] = true;
			$options[CURLOPT_POSTFIELDS] = $post_fields;
		}else {
			$options[CURLOPT_HTTPGET] = true;

		}
		if( false !== $cookies ) {
			$options[CURLOPT_COOKIE] =  $cookies;
		}

		$errno = false; $error = false; $info = false;
		$webdoc = new WebDocument();
		$curl = curl_init();
		curl_setopt_array( $curl, $options );

		$doc = curl_exec( $curl );
		if( false === $doc ) {
			$errno = curl_errno( $curl );
			$error = curl_error( $curl );
			curl_close( $curl );
			return new SoapFault((string) self::e_http, self::e_http_msg . " #{$errno}, {$error}" );
			@unlink( $temp );
			return null;
		} else {
			$info = curl_getinfo( $curl );
			$webdoc->url = $info["url"];
			$webdoc->http_code = $info["http_code"];
			$webdoc->content_type = $info["content_type"];
			$webdoc->content_length = $info["download_content_length"];
			$webdoc->speed_download = $info["speed_download"];
			$webdoc->total_time = $info["total_time"];
			$webdoc->body = $doc;
		}
		curl_close( $curl );

		if( file_exists( $temp ) ) {
			//$webdoc->cookies = array(file_get_contents( $temp ));
			$webdoc->cookies = array();
			$ck = explode( "\r\n", file_get_contents( $temp ));
			foreach( $ck as $ix => $cookie ) {
				if( "#" == substr( $cookie, 0, 1 )) {
					continue;
				}
				if( 0 == strlen( $cookie )) {
					continue;
				}
				$cook_arr = explode( "\t", $cookie );
				if( 7 != count( $cook_arr )) {
					return new SoapFault((string) self::e_internal_error, __FILE__ . "@" . __LINE__ . ": Error parsing cookie [{$cookie}] : " . print_r($cook_arr, true ) );
				} else {
					$webdoc->cookies[] = new Cookie( $cook_arr[5], $cook_arr[6], $cook_arr[4], $cook_arr[0], $cook_arr[2], $cook_arr[1], $cook_arr[3] );
				}
			}
		}
		@unlink( $temp );

		return $webdoc;
	}

	/**
	 * Retrieve the content of an RSS feed
	 * @param string $token Session Identifier
	 * @param string $url Url of the feed
	 * @param int $first The first article to fetch [OPTIONAL]
	 * @param int $count The number of articles to fetch [OPTIONAL]
	 * @return Channel The Rss Feed's channel and articles
	 * */
	public function fetchRSS( $token, $url, $first = null, $count = null ) {
		$rss = $this->fetchUrl( $token, new WebRequest( $url ));
		
		$dom = new DomDocument();
		if( false === @$dom->loadXML( $rss->body )) {
			return new SoapFault((string) self::e_invalid_format, self::e_invalid_format_msg );
			return null;
		}
		$dom->indent = true;

		$xp = new DOMXPath( $dom );
		$xparticle = "//item";
		$xpchannel = "//channel";
		$xpimage = "//channel/image";

		$rs = $xp->query( $xpchannel );
		if( 0 == $rs->length ) {
			return new SoapFault((string) self::e_invalid_format, self::e_invalid_format_msg );
			return null;
		}
		$feed = new Channel();

		for( $i = 0; $i < $rs->item(0)->childNodes->length; $i ++ ) {
			switch( $rs->item(0)->childNodes->item( $i )->nodeName ) {
				case "title": { 		$feed->title = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
				case "description": { 	$feed->description = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
				case "link": { 			$feed->link = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
			}
		}

		$rs = $xp->query( $xpimage );
		if( 0 != $rs->length ) {
			for( $i = 0; $i < $rs->item(0)->childNodes->length; $i ++ ) {
				switch( $rs->item(0)->childNodes->item( $i )->nodeName ) {
					case "title": { 	$feed->image_title = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
					case "url": {	 	$feed->image = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
					case "link": { 		$feed->image_link = $rs->item(0)->childNodes->item( $i )->nodeValue; } break;
				}
			}
		}

		$rs = $xp->query( $xparticle );
		for( $i = ($first == null?0:$first); $i < ($count == null || $first + $count >= $rs->length?$rs->length:$first + $count); $i ++ ) {
			$item = $rs->item( $i );
			$article = new Article();
			$article->enclosure_length = null;
			$article->enclosure_type = null;
			$article->enclosure_url = null;
			for( $j = 0; $j < $item->childNodes->length; $j ++ ) {
				switch( $item->childNodes->item( $j )->nodeName ) {
					case "title": { 		$article->title = $item->childNodes->item( $j )->nodeValue; } break;
					case "description": { 	$article->body = $item->childNodes->item( $j )->nodeValue; } break;
					case "link": { 			$article->url = $item->childNodes->item( $j )->nodeValue; } break;
					case "pubDate": {		$article->date = $item->childNodes->item( $j )->nodeValue; } break;
					case "enclosure":
						$chNode = $item->childNodes->item( $j );
						$article->enclosure_length = $chNode->getAttribute("length");
						$article->enclosure_url = $chNode->getAttribute("url");
						$article->enclosure_type = $chNode->getAttribute("type");

						if ($article->enclosure_length == "") $article->enclosure_length = null;
						if ($article->enclosure_type == "") $article->enclosure_type = null;
						if ($article->enclosure_url == "") $article->enclosure_url = null;
						break;
				}
			}
			$feed->articles[] = $article;
		}

		return $feed;
	}

	/**
	 * Gets the nymex market share quotations
	 * @param string $token The session identifier
	 * @return NymexQuotation[]
		*/
	public function GetNymexQuotations($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
			
		$url = "http://www.nymex.com/index.aspx";

		$nymex = $this->fetchUrl( $token, new WebRequest( $url ));
		$options = array(
				"drop-proprietary-attributes" => true,
				"clean" => true,
				"output-xhtml" => true,
				"show-body-only" => true,
		);
		$tidy = tidy_parse_string( $nymex->body, $options, "utf8" );
		$tidy->cleanRepair();
		$body = (string)$tidy;
			
		$doc = new DomDocument();
		$doc->loadHTML( $body );
			
		$xpath = new DOMXPath($doc);
		$config = file_get_contents($this->config["nymex"]["config-file"]);
		$docconfig = new DOMDocument();
		$docconfig->loadXML($config);
		$xpath2 = new DOMXPath($docconfig);
		$rs = $xpath2->query("//elements/element");
			
		$res = array();
			
		foreach ($rs as $node){
			$rs_nymex = $xpath->query($node->getAttribute("xpath_name"));
			if ($rs_nymex->length != 0){
				$q = new NymexQuotation();
				$q->name = $rs_nymex->item(0)->nodeValue;
					
				$rs_nymex = $xpath->query($node->getAttribute("xpath_quotation"));
				if ($rs_nymex->length != 0) {
					$q->quotation = $rs_nymex->item(0)->nodeValue;
				}
					
				$rs_nymex = $xpath->query($node->getAttribute("xpath_delta"));
				if ($rs_nymex->length != 0){
					$q->change = $rs_nymex->item(0)->nodeValue;
				}
					
				array_push($res, $q);
			}
		}
			
		return $res;
	}

	/**
	 * List the crisis room users
	 * @param string $token The session identifier
	 * @return string[]
		*/
	public function ListCrisisRoomUsers($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
			
		$sql = <<<sql
select `user_id` from `crisis_room`.`crisisroom_users` where `is_admin` = 'y' order by `user_id`
sql;

		if (($users = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
			
		$res = array();
			
		while ($user = $users->fetch_assoc()){
			$res[] = $user["user_id"];
		}
			
		return $res;

	}
	
	/**
	 * Lists the sources for the advanced search
	 * @param string $token The token identifier
	 * @access public
	 * @return AdvancedSearch[]
	*/
	public function ListAdvancedSearchSources($token){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
		
		$sql = <<<sql
select * from `adv_search` order by `order`, `title`, `engine_id`, `source_id`
sql;

		if (($query = $my->query($sql)) === false){
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		
		$res = array();
		while ($row = $query->fetch_assoc()){
			$s = new AdvancedSearch();
			
			$s->description = $row["description"];
			$s->engine_id = $row["engine_id"];
			$s->source_id = $row["source_id"];
			$s->title = $row["title"];
			
			$res[] = $row;
		}
		
		return $res;
	}

}
?>
