<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaVideoArchive extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	
	/**
	 * Get the list of available Channels from the video archive (channels that have records)
	 * @param string $token The session identifier
	 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
	 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
	 * @param int $end_date End date (unix timestamp) [OPTIONAL]
	 * @param string $title Program title (* wildcard supported) [OPTIONAL]
	 * @return string[]
	 * */
	public function listVideoArchiveChannels( $token, $channel = null, $start_date = null, $end_date = null, $title = null ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "video-archive", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
		$query = 'select distinct `channel_name` as `name` ' . $this->videoArchiveBuildSQLQuery( null, null, $channel, $start_date, $end_date, $title );
		$rs = $my->query( $query );
		if( false === $rs ) {
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$channels = array();
		while( ($row = $rs->fetch_assoc()) ) {
			$channels[] = $row['name'];
		}
		$rs->free();
		$my->close();

		return $channels;
	}

	/**
	 * Get the list of available Records from the video archive
	 * @param string $token The session identifier
	 * @param int $first_record Number of the first record to return (default 0) [OPTIONAL]
	 * @param int $record_count Number of records to return (default all) [OPTIONAL]
	 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
	 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
	 * @param int $end_date End date (unix timestamp) [OPTIONAL]
	 * @param string $title Program title (* wildcard supported) [OPTIONAL]
	 * @return VideoArchiveRecord[]
	 * */
	public function listVideoArchiveRecords( $token, $first_record = null, $record_count = null, $channel = null, $start_date = null, $end_date = null, $title = null ) {
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "video-archive", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
		$query = <<<sql
select date_format(s.`date`,'%Y-%m-%d %H:%i:%s') as `date`,
date_format(s.`length`,'%H:%i:%s') as `length`,
s.`length` as raw_length,
convert(c.`channel_name` using utf8) as `channel_name`,
convert(s.`title` using utf8) as `title`,
convert(s.`description` using utf8) as `description`,
s.`capture_filename`

sql;
		$query .= $this->videoArchiveBuildSQLQuery( $first_record, null, $channel, $start_date, $end_date, $title );
		//error_log( str_replace( "\r\n", "\n", $query ));
		$rs = $my->query( $query );
		if( false === $rs ) {
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$i = 0;
		$records = array();
		while( ($row = $rs->fetch_assoc()) && $i < $record_count ) {
			$record = new VideoArchiveRecord( $row );
			$file_name = urldecode(preg_replace('/^.*\/(.*)$/i', '\1', $record->url));
			if (file_exists("d:\\MCapture\\Files\\{$file_name}") && $i < $record_count){
			   $records[] = $record;
			   $i++;
                        }
		}
		$rs->free();
		$my->close();

		return $records;
	}

	/**
	 * Count the number of available Records from the video archive
	 * @param string $token The session identifier
	 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
	 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
	 * @param int $end_date End date (unix timestamp) [OPTIONAL]
	 * @param string $title Program title (* wildcard supported) [OPTIONAL]
	 * @return int
	 * */
	public function countVideoArchiveRecords( $token, $channel = null, $start_date = null, $end_date = null, $title = null ) {

		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "video-archive", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
		$query = 'select count(*) as `cnt` ' . $this->videoArchiveBuildSQLQuery( null, null, $channel, $start_date, $end_date, $title );
		//			error_log( str_replace( "\r\n", "\n", $query ));
		$rs = $my->query( $query );
		if( false === $rs ) {
			return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$row = $rs->fetch_assoc();
		$rs->free();
		$my->close();

		return (int)$row['cnt'];
	}

	/**
	 * Build the SQL query for Vide Archive Access
	 * @param int $first_record Number of the first record to return (default 0) [OPTIONAL]
	 * @param int $record_count Number of records to return (default all) [OPTIONAL]
	 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
	 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
	 * @param int $end_date End date (unix timestamp) [OPTIONAL]
	 * @param string $title Program title (* wildcard supported) [OPTIONAL]
	 * @return string
	 * */
	protected function videoArchiveBuildSQLQuery( $first_record = null, $record_count = null, $channel = null, $start_date = null, $end_date = null, $title = null ) {
		/*ob_start();
		 var_dump( $first_record );
		 var_dump( $record_count );
		 var_dump( $channel );
		 var_dump( $start_date );
		 var_dump( $end_date );
		 var_dump( $title );
		 error_log( ob_get_contents() );
		 ob_end_clean();
		 */
		$my = $this->OpenDatabase( "video-archive", $error );
		if( false === $my ) {
			return new SoapFault((string) self::e_database, $error );
		}
		$query = <<<sql

from `schedule` s
	left join channels c on
	s.channel_number = c.number and
	s.channel_type_id = c.type_id and
	s.channel_group_id = c.group_id
where s.`capture_status` = 'done'

sql;
		if( !empty( $channel )) {
			$param = $my->real_escape_string( $channel );
			/*$param = str_replace( "\\*", "\0", $param );
			$param = str_replace( '*', '%', $param );
			$param = str_replace( "\0", '*', $param );*/
			$query .= "and s.`capture_filename` regexp '{$param}'\n";
		}
		if( !empty( $title )) {
			$param = $my->real_escape_string( $title );
			/*$param = str_replace( "\\*", "\0", $param );
			$param = str_replace( '*', '%', $param );
			$param = str_replace( "\0", '*', $param );*/
			$query .= "and s.`title` regexp '{$param}'\n";
		}
		if( !empty( $start_date )) {
			$date = date( 'Y-m-d H:i:s', $start_date );
			$query .= <<<sql
and (
	s.`date` >= '{$date}'
)

sql;
		}
		if( !empty( $end_date )) {
			$date = date( 'Y-m-d H:i:s', $end_date );
			$query .= <<<sql
and (
	s.`date` <= '{$date}'
)

sql;
		}
		$query .= <<<sql
order by s.`date` desc, c.`channel_name` asc

sql;
		if( !empty( $record_count )) {
			if( empty( $first_record )) {
				$query .= 'limit ' . $record_count;
			} else {
				$query .= 'limit ' . $first_record . ', ' . $record_count;
			}
		}
		$my->close();
		
		return $query;
	}

}
?>