<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaVirage extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Search for a video in the database using Virage
	 * @param string $token The session identifier
	 * @param VirageSearchQuery $query The query to be executed
	 * @param boolean $completeDocs If set to true, it returns the complete document without the images. Else, it returns only a few fields [OPTIONAL]
	 * @param boolean $getImages If set to true, also get the images [OPTIONAL]
	 * @return VirageSearchResult
	 * */
	private function DoVirageSearch($token, $query, $completeDocs = false, $getImages = false){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;

		if( ($query->query == "" || $query->query == null) && ($query->fileName == "" || $query->fileName == null) && ($query->url == "" || $query->url == null) ) {
			return new SoapFault((string) self::e_http, self::e_http_msg. ": 404, You have to set a query text, a file name or a URL", null, null );
			return null;
		}
		$url = "";
		if ($query->query != "" && $query->query != null){
			$url .= "Text=" . htmlspecialchars($query->query);
		}

		if ($query->fileName != "" && $query->fileName != null){
			$url .= ($url == ""?"":"&") . "FieldText=WILD{*" . htmlspecialchars($query->fileName) . "*}:DRETITLE";
		}

		if ($query->url != "" && $query->url != null){
			$url .= ($url == ""?"":"&") . "FieldText=WILD{*" . htmlspecialchars($query->url) . "*}:URL";
		}

		if ($query->minDate != "" && $query->minDate != null){
			$url .= "&MinDate=" . rawurlencode(date("d/m/Y", time($query->minDate)));
		}

		if ($query->maxDate != "" && $query->maxDate != null){
			$url .= "&MaxDate=" . rawurlencode(date("d/m/Y", time($query->maxDate)));
		}

		if ($query->sort != "" && $query->sort != null){
			switch ($query->sort) {
				case "Date": $url .= "&Sort=" . ($query->sortOrder == "desc"?"ReverseDate":"Date");break;
				case "Relevance": $url .= "&Sort=" . ($query->sortOrder == "desc"?"ReverseRelevance":"Relevance");break;
				case "STARTTIME": $url .= "&Sort=STARTTIME:" . ($query->sortOrder == "desc"?"numberdecreasing":"numberincreasing");break;
				case "ENDTIME": $url .= "&Sort=ENDTIME:" . ($query->sortOrder == "desc"?"numberdecreasing":"numberincreasing");break;
			}
		}

		if ($query->maxResults != null && $query->maxResults != null){
			$url .= "&MaxResults=" . rawurlencode($query->maxResults);
		}

		$url .= ($query->stemming?"&Stemming=true&":"&Stemming=false&");
		if ($completeDocs){
			$fields = "print=Fields&PrintFields=DRETITLE,DREDATE,DREDBNAME,STARTTIME,ENDTIME,CONTENTTYPE,SWF,SWF_TIME,OCR_WORDS,OCR_MSEC_TIME,OCR_WEIGHTS,SOFTSOUND_MSEC_TIME,SOFTSOUND_WORDS,SOFTSOUND_WEIGHTS,DRECONTENT";
		}
		else $fields = "&print=Fields&PrintFields=DRECONTENT";
		if ($getImages){
			$fields .= ',LARGE_KEYFRAME_JPEG_IMAGES,LARGE_KEYFRAME_JPEG_MSEC_TIME,SMALL_KEYFRAME_JPEG_IMAGES,SMALL_KEYFRAME_JPEG_MSEC_TIME';
		}
		$url .= $fields . "&highlight=terms";
		$url = $this->config["virage"]["server-url"] . "?action=query&" . $url;
		
		$wResult = $this->_fetchUrlNoProxy( new WebRequest($url));
		/*if (($f = fopen($url, "rb")) === false){
			return new SoapFault((string) self::e_session, "Error opening the link: {$url}}" );
			return null;
		}

		$wResult = "";
		while (!feof($f)){
			$wResult .= fread($f, 8096);
		}
		fclose($f);*/

		$xResult = new DOMDocument();
		//$xResult->loadXML($wResult->body);

		if ($xResult->loadXML($wResult->body) === false){
			return new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$wResult}" );
			return null;
		}

		$xpath = new DOMXPath($xResult);
		$nodes = $xpath->query("/autnresponse/responsedata/*");

		$Result = new VirageSearchResult();
		$Result->query = $query;
		$Result->documents = array();
		$images = new VirageDocumentImages();
		
		$i = 0;

		foreach ($nodes as $node){
			switch ($node->nodeName){
				case "autn:numhits":
					$Result->resultsFound = $node->nodeValue;
					break;
				case "autn:hit":
					$document = new VirageDocument();
					foreach($node->childNodes as $doc_property){
						switch ($doc_property->nodeName){
							case "autn:weight": $document->weight = $doc_property->nodeValue; break;
							case "autn:links": $document->links = $doc_property->nodeValue; break;
							case "autn:id": $document->document_id = $doc_property->nodeValue; break;
							case "autn:section": $document->section = $doc_property->nodeValue; break;
							case "autn:title": $document->title = $doc_property->nodeValue; break;
							case "autn:reference":
								$parts = explode("\\", $doc_property->nodeValue);
								$fileName = $parts[count($parts) - 1];
								$document->fileName = $this->config["virage"]["livestream"] . $fileName;
								break;
						}
					}

					$doc = $xpath->query("//autn:id[text() = '{$document->document_id}']/../autn:content/DOCUMENT");

					for( $i = 0; $i < $doc->item(0)->childNodes->length; $i++){
						$complete_doc = $doc->item(0)->childNodes->item($i);
						switch ($complete_doc->nodeName){
							case "DRECONTENT":
								$content = $complete_doc->nodeValue;
								$content = htmlspecialchars_decode($content);
								$content = str_replace("<font color=red>", "<span class=\"highlight\">", $content);
								$content = str_replace("</font>", "</span>", $content);
								$document->documentContent = $content;
								break;
							case "CONTENTTYPE": $document->contentType = $complete_doc->nodeValue; break;
							case "DREDBNAME": $document->database = $complete_doc->nodeValue; break;
							case "DREDATE": $document->date = $complete_doc->nodeValue; break;
							case "DRETITLE": $document->dre_title = $complete_doc->nodeValue; break;
							case "ENDTIME": $document->endTime = $complete_doc->nodeValue; break;
							case "STARTTIME": $document->startTime = $complete_doc->nodeValue; break;
							case "CONTENTTYPE": $document->contentType = $complete_doc->nodeValue; break;

							case "OCR_MSEC_TIME": $document->setOCRMSecTime($complete_doc->nodeValue); break;
							case "OCR_WEIGHTS": $document->setOCRWeight($complete_doc->nodeValue); break;
							case "OCR_WORDS": $document->setOCRWords($complete_doc->nodeValue); break;
							case "SOFTSOUND_MSEC_TIME": $document->setSoftSoundMSecTime($complete_doc->nodeValue); break;
							case "SOFTSOUND_WEIGHTS": $document->setSoftSoundWeights($complete_doc->nodeValue); break;
							case "SOFTSOUND_WORDS": $document->setSoftSoundWords($complete_doc->nodeValue); break;
							case "SWF": $document->setSWFLocation($complete_doc->nodeValue); break;
							case "SWF_TIME": $document->setSWFTime($complete_doc->nodeValue); break;
						}
						if ($getImages){
							switch ($complete_doc->nodeName){
								case "LARGE_KEYFRAME_JPEG_IMAGES": $images->setLargeImageContent($complete_doc->nodeValue); break;
								case "LARGE_KEYFRAME_JPEG_MSEC_TIME": $images->setLargeImageMSecTime($complete_doc->nodeValue); break;
								case "SMALL_KEYFRAME_JPEG_IMAGES": $images->setSmallImageContent($complete_doc->nodeValue); break;
								case "SMALL_KEYFRAME_JPEG_MSEC_TIME": $images->setSmallImageMSecTime($complete_doc->nodeValue); break;
							}
						}
						
					}
					$document->correctSWFLocation($this->config["virage"]["swf-location"]);
					
					if ($getImages){
						$images->document_id = $document->document_id;
						$document->images = $images;
						$images = new VirageDocumentImages();
						
					}

					array_push($Result->documents, $document);
					break;
			}
		}
		
		return $Result;
	}

	/**
	 * Search for a video in the database using Virage
	 * @param string $token The session identifier
	 * @param VirageSearchQuery $query The query to be executed
	 * @return VirageSearchResult
	 * */
	public function VirageSearch($token, $query){
		return $this->DoVirageSearch($token, $query);
	}

	/**
	 * Search for a video in the database using Virage and returns the complete document without the images
	 * @param string $token The session identifier
	 * @param VirageSearchQuery $query The query to be executed
	 * @param boolean $getImages If set to true, get the images also [OPTIONAL]
	 * @return VirageSearchResult
	 * */
	public function VirageSearch2($token, $query, $getImages = false){
		return $this->DoVirageSearch($token, $query, true, $getImages);
	}

	/**
	 * Get a Virage document without authentication
	 * @param string $token The session identifier
	 * @param int $document_id The document identifier
	 * @param boolean $getImages If true, then it also returns the document images
	 * @access private
	 * @return VirageDocument
	 * */
	private function _VirageGetDocument($document_id, $getImages){
		$fields = "print=Fields&PrintFields=DRETITLE,DREDATE,DREDBNAME,STARTTIME,ENDTIME,CONTENTTYPE,SWF,SWF_TIME,OCR_WORDS,OCR_MSEC_TIME,OCR_WEIGHTS,SOFTSOUND_MSEC_TIME,SOFTSOUND_WORDS,SOFTSOUND_WEIGHTS,DRECONTENT";
		if ($getImages) $fields = "print=all";
		$url = $this->config["virage"]["server-url"] . "action=getcontent&id=" . $document_id . "&" . $fields;

		$wResult = $this->_fetchUrlNoProxy( new WebRequest($url));
		/*if (($f = fopen($url, "rb")) === false){
			return new SoapFault((string) self::e_session, "Error opening the link: {$url}}" );
			return null;
		}

		$wResult = "";
		while (!feof($f)){
			$wResult .= fread($f, 8096);
		}
		fclose($f);*/

		$xResult = new DOMDocument();
		if ($xResult->loadXML($wResult->body) === false){
			return new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$wResult}" );
			return null;
		}

		$xpath = new DOMXPath($xResult);

		$nodes = $xpath->query("/autnresponse/responsedata/autn:hit");

		$Result = new VirageDocument();
		$images = new VirageDocumentImages();

		$i = 0;

		foreach ($nodes as $node){
			foreach($node->childNodes as $doc_property){
				switch ($doc_property->nodeName){
					case "autn:weight": $Result->weight = $doc_property->nodeValue; break;
					case "autn:links": $Result->links = $doc_property->nodeValue; break;
					case "autn:id": $Result->document_id = $doc_property->nodeValue; break;
					case "autn:section": $Result->section = $doc_property->nodeValue; break;
					case "autn:title": $Result->title = $doc_property->nodeValue; break;
					case "autn:reference":
						$parts = explode("\\", $doc_property->nodeValue);
						$fileName = $parts[count($parts) - 1];
						$Result->fileName = $this->config["virage"]["livestream"] . $fileName;
						break;
				}
			}

			$doc = $xpath->query("//autn:id[text() = '{$Result->document_id}']/../autn:content/DOCUMENT");

			for( $i = 0; $i < $doc->item(0)->childNodes->length; $i++){
				$complete_doc = $doc->item(0)->childNodes->item($i);
				switch ($complete_doc->nodeName){
					case "DRECONTENT":
						$content = $complete_doc->nodeValue;
						$content = htmlspecialchars_decode($content);
						$content = str_replace("<font color=red>", "<span class=\"highlight\">", $content);
						$content = str_replace("</font>", "</span>", $content);
						$Result->documentContent = $content;
						break;
					case "CONTENTTYPE": $Result->contentType = $complete_doc->nodeValue; break;
					case "DREDBNAME": $Result->database = $complete_doc->nodeValue; break;
					case "DREDATE": $Result->date = $complete_doc->nodeValue; break;
					case "DRETITLE": $Result->dre_title = $complete_doc->nodeValue; break;
					case "ENDTIME": $Result->endTime = $complete_doc->nodeValue; break;
					case "STARTTIME": $Result->startTime = $complete_doc->nodeValue; break;
					case "CONTENTTYPE": $Result->contentType = $complete_doc->nodeValue; break;

					case "OCR_MSEC_TIME": $Result->setOCRMSecTime($complete_doc->nodeValue); break;
					case "OCR_WEIGHTS": $Result->setOCRWeight($complete_doc->nodeValue); break;
					case "OCR_WORDS": $Result->setOCRWords($complete_doc->nodeValue); break;
					case "SOFTSOUND_MSEC_TIME": $Result->setSoftSoundMSecTime($complete_doc->nodeValue); break;
					case "SOFTSOUND_WEIGHTS": $Result->setSoftSoundWeights($complete_doc->nodeValue); break;
					case "SOFTSOUND_WORDS": $Result->setSoftSoundWords($complete_doc->nodeValue); break;
					case "SWF": $Result->setSWFLocation($complete_doc->nodeValue); break;
					case "SWF_TIME": $Result->setSWFTime($complete_doc->nodeValue); break;
				}

				if ($getImages){
					switch ($complete_doc->nodeName){
						case "LARGE_KEYFRAME_JPEG_IMAGES": $images->setLargeImageContent($complete_doc->nodeValue); break;
						case "LARGE_KEYFRAME_JPEG_MSEC_TIME": $images->setLargeImageMSecTime($complete_doc->nodeValue); break;
						case "SMALL_KEYFRAME_JPEG_IMAGES": $images->setSmallImageContent($complete_doc->nodeValue); break;
						case "SMALL_KEYFRAME_JPEG_MSEC_TIME": $images->setSmallImageMSecTime($complete_doc->nodeValue); break;
					}
				}
			}
			$Result->correctSWFLocation($this->config["virage"]["swf-location"]);

			if ($getImages){
				$Result->images = $images;
			}

		}

		return $Result;
	}

	/**
	 * Get a Virage document
	 * @param string $token The session identifier
	 * @param int $document_id The document identifier
	 * @param boolean $getImages If true, then it also returns the document images
	 * @return VirageDocument
	 * */
	public function VirageGetDocument($token, $document_id, $getImages){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		return $this->_VirageGetDocument($document_id, $getImages);
	}

	/**
	 * Get a Virage document images
	 * @param int $document_id The document identifier
	 * @return VirageDocumentImages
	 * */

	private function _VirageGetDocumentImages($document_id){
		$fields = "print=Fields&PrintFields=LARGE_KEYFRAME_JPEG_IMAGES,LARGE_KEYFRAME_JPEG_MSEC_TIME,SMALL_KEYFRAME_JPEG_IMAGES,SMALL_KEYFRAME_JPEG_MSEC_TIME";
		$url = $this->config["virage"]["server-url"] . "action=getcontent&id=" . $document_id . "&" . $fields;

		$wResult = $this->_fetchUrlNoProxy( new WebRequest($url));
		/*if (($f = fopen($url, "rb")) === false){
			return new SoapFault((string) self::e_session, "Error opening the link: {$url}}" );
			return null;
		}

		$wResult = "";
		while (!feof($f)){
			$wResult .= fread($f, 8096);
		}
		fclose($f);*/

		$xResult = new DOMDocument();
		if ($xResult->loadXML($wResult->body) === false){
			return new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$wResult}" );
			return null;
		}

		$xpath = new DOMXPath($xResult);
		$path = "/autnresponse/responsedata/autn:hit/autn:content/DOCUMENT/";

		$Result = new VirageDocumentImages();

		$Result->document_id = $document_id;
		$Result->setLargeImageContent($xpath->query($path . "LARGE_KEYFRAME_JPEG_IMAGES")->item(0)->nodeValue);
		$Result->setLargeImageMSecTime($xpath->query($path . "LARGE_KEYFRAME_JPEG_MSEC_TIME")->item(0)->nodeValue);
		$Result->setSmallImageContent($xpath->query($path . "SMALL_KEYFRAME_JPEG_IMAGES")->item(0)->nodeValue);
		$Result->setSmallImageMSecTime($xpath->query($path . "SMALL_KEYFRAME_JPEG_MSEC_TIME")->item(0)->nodeValue);

		return $Result;
	}
	
	/**
	 * Get a Virage document images by calling the private method _VirageGetDocumentImages (this does not require authentication)
	 * @param string $token The session identifier
	 * @param int $document_id The document identifier
	 * @return VirageDocumentImages
	 * */

	public function VirageGetDocumentImages($token, $document_id){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		return $this->_VirageGetDocumentImages($document_id);
	}
	
	/**
	 * Get the full text of a video document without the authentication
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param VirageDocument $document The document [OPTIONAL]
	 * @access public
	 * @return string
	*/
	private function _VirageGetFullText($token, $document_id, $document = null){
		if ($document == null){
			$document = $this->VirageGetDocument($token, $document_id, false);
		}

		$file = pathinfo(rawurldecode($document->fileName));
		$url = $file["filename"];
		
		$query = new VirageSearchQuery();
		$query->maxDate = null;
		$query->minDate = null;
		$query->query = null;
		$query->sort = "STARTTIME";
		$query->url = $url;
		$query->sortOrder = "asc";
		$query->stemming = true;
		$query->maxResults = 120;

		$documents = $this->VirageSearch2($token, $query);

		$full_text = '';
		foreach ($documents->documents as $doc){
			foreach ($doc->softSoundWords as $word){
				$full_text .= ($full_text == ''?'':' ') . $word;
			}
		}
		
		return $full_text;
	}
	
	/**
	 * Get the full text of a video document
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param VirageDocument $document The document [OPTIONAL]
	 * @access public
	 * @return string
	*/
	public function VirageGetFullText($token, $document_id, $document = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		return $this->_VirageGetFullText($token, $document_id, $document);
	}
	
	/**
	 * Gets the list of words
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param boolean $complete If set to true, get the words for the entire movie [OPTIONAL]
	 * @param VirageDocument $document The document [OPTIONAL]
	 * @access public
	 * @return VirageWord[]
	*/
	public function VirageGetWords($token, $document_id, $complete = null, $document = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		if ($document == null){
			$document = $this->VirageGetDocument($token, $document_id, false);
		}

		$file = pathinfo(rawurldecode($document->fileName));
		$url = $file["filename"];
		
		if ($complete === null) $complete = true;
		
		if ($complete){
			$query = new VirageSearchQuery();
			$query->maxDate = null;
			$query->minDate = null;
			$query->query = null;
			$query->sort = "STARTTIME";
			$query->url = $url;
			$query->sortOrder = "asc";
			$query->stemming = true;
			$query->maxResults = 120;
			
			$documents = $this->VirageSearch2($token, $query);
		}
		else {
			$documents = new VirageSearchResult();
			$documents->documents = array($document);
			$documents->resultsFound = 1;
		}

		$result = array();
		
		foreach ($documents->documents as $doc){
			foreach ($doc->softSoundWords as $key => $word){
				$w = new VirageWord();
				$w->word = $word;
				$w->time = array_key_exists($key, $doc->softSoundMsecTime) ? $doc->softSoundMsecTime[$key] : 0;
				
				$result[] = $w;
			}
		}
		
		return $result;
	}
	
	/**
	 * Gets a single image from a Virage document without authentication
	 * @param string $document_id The document identifier
	 * @param int $index The image index
	 * @param string $type The type of image to retrieve (small or big)
	 * @param boolean $getContent If set to false, do not retrieve the image content [OPTIONAL]
	 * @param boolean $cache If set to true, also cache the image [OPTIONAL]
	 * @param VirageDocument $document The Virage document [OPTIONAL]
	 * @access private
	 * @return VirageDocumentImage
	*/
	private function _GetVirageDocumentImage($document_id, $index, $type, $getContent = true, $cache, $document){
		if ($document == null){
			$document = $this->_VirageGetDocument($document_id, true);
		}
		
		if ($document == null) return array();
		if ($index > count($document->images->smallImageMSegTime)) return array();
		
		$content = null;
		
		$image = new VirageDocumentImage();
		$image->time = $document->images->smallImageMSegTime[$index];
		if ($getContent){
			$content = ($type == 'small'?$document->images->smallImageContent[$index]:$document->images->largeImageContent[$index]);
		}
		$image->content = $content;
		$image->cache_name = $type . '_' . $document->document_id . '_' . $index;
		
		if ($cache){
			$f = fopen($this->config['virage']['cache-folder'] . '/' . $image->cache_name . '.jpg', 'wb');
			if ($content == null){
				$content = ($type == 'small'?$document->images->smallImageContent[$index]:$document->images->largeImageContent[$index]);
			}
			$content = base64_decode($content);
			fwrite($f, $content, strlen($content));
			fclose($f);
		}
		
		return $image;
	}
	
	/**
	 * Gets a single image from a Virage document
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param int $index The image index
	 * @param string $type The type of image to retrieve (small or big)
	 * @param boolean $getContent If set to false, do not retrieve the image content [OPTIONAL]
	 * @param boolean $cache If set to true, also cache the image [OPTIONAL]
	 * @param VirageDocument $document The Virage document [OPTIONAL]
	 * @access public
	 * @return VirageDocumentImage
	*/
	public function GetVirageDocumentImage($token, $document_id, $index, $type, $getContent = true, $cache = false, $document = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		return $this->_GetVirageDocumentImage($document_id, $index, $type, $getContent, $cache, $document);
	}
	
	/**
	 * Gets all the headlines of a video document
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param VirageDocument $document The document [OPTIONAL]
	 * @param int $limit The limit of characters for a headline [OPTIONAL]
	 * @access public
	 * @return VirageHeadline[]
	*/
	public function VirageGetDocumentHeadlines($token, $document_id, $document = null, $limit = 10){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		if ($document == null){
			$document = $this->VirageGetDocument($token, $document_id, false);
		}

		$file = pathinfo(rawurldecode($document->fileName));
		$url = $file["filename"];
		
		$query = new VirageSearchQuery();
		$query->query = '*';
		$query->maxDate = null;
		$query->minDate = null;
		$query->query = null;
		$query->sort = "STARTTIME";
		$query->url = $url;
		$query->sortOrder = "asc";
		$query->stemming = true;
		$query->maxResults = 120;

		$documents = $this->VirageSearch2($token, $query);

		$results = array();
		foreach ($documents->documents as $doc){
			for ($i = 0; $i < count($doc->ocrWords); $i++) if (strlen($doc->ocrWords[$i]) > $limit){
				$headline = new VirageHeadline();
				$headline->word = $doc->ocrWords[$i];
				$headline->time = $doc->ocrMsecTime[$i];
				
				$results[] = $headline;
			}
		}
		
		return $results;
	}
	
	/**
	 * Gets all the images from a document
	 * @param string $token The session identifier
	 * @param string $document_id The document identifier
	 * @param string $type The type of image to retrieve (small or big)
	 * @param boolean $getContent If set to false, do not retrieve the image content [OPTIONAL]
	 * @param boolean $cache If set to true, also cache the image [OPTIONAL]
	 * @param VirageDocument $document The document [OPTIONAL]
	 * @access public
	 * @return VirageDocumentImage[]
	*/
	public function VirageGetDocumentAllImages($token, $document_id, $type, $getContent, $cache, $document = null){
		if( false === $this->CheckToken( $token )) {
			return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		
		if ($document == null){
			$document = $this->VirageGetDocument($token, $document_id, false);
		}

		$file = pathinfo(rawurldecode($document->fileName));
		$url = $file["filename"];
		
		$query = new VirageSearchQuery();
		$query->query = '*';
		$query->maxDate = null;
		$query->minDate = null;
		$query->query = null;
		$query->sort = "STARTTIME";
		$query->url = $url;
		$query->sortOrder = "asc";
		$query->stemming = true;
		$query->maxResults = 120;

		$documents = $this->VirageSearch2($token, $query, true);
		
		$results = array();
		foreach ($documents->documents as $doc){
			for ($i = 0; $i < count($doc->images->smallImageMSegTime); $i++){
				$results[] = $this->_GetVirageDocumentImage($document_id, $i, $type, $getContent, $cache, $doc);
			}
		}
		
		return $results;
	}

}
?>
