<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:exsl="http://exslt.org/common" extension-element-prefixes="exsl"
    xmlns:html="http://www.w3.org/1999/xhtml">
    <xsl:template match="/">
        <country-profile>
            <name>
                <xsl:value-of
                    select="normalize-space( //html:table[@class='infobox geography vcard']//th[1]/text() )"
                />
            </name>
            <flag>
                <xsl:value-of
                    select="normalize-space(         //table[@class='infobox geography vcard']//td[@class='maptable']//img[1]/@src )"
                />
            </flag>
            <coat_of_arms>
                <xsl:value-of
                    select="normalize-space( //table[@class='infobox geography vcard']//td[@class='maptable']//img[2]/@src )"
                />
            </coat_of_arms>
            <map>
                <xsl:value-of
                    select="normalize-space( //table[@class='infobox geography vcard']/tr/td/div/a/img/@src )"
                />
            </map>
            <capital>
                <xsl:value-of
                    select="normalize-space( //table[@class='infobox geography vcard']/tr/td/a[@title='Capital (political)']/../../td[2]/a )"/>
                <xsl:value-of
                    select="normalize-space( //table[@class='infobox geography vcard']/tr/td/b/a[@title='Capital (political)']/../../../td[2]/a )"
                />
            </capital>
            <details>
                <xsl:call-template name="details"/>
            </details>
            <!-- // WIKIPEDIA:	TOC & FIRST PARAGRAPH-->
            <toc>
                <!--xsl:copy-of select="//table[@id='toc']" /-->
                <xsl:for-each select="//table[@id='toc']/tr/td/ul">
                              <xsl:call-template name="toc_ul"/>
                </xsl:for-each>
            </toc>
            <!--first-paragraph>
                <xsl:for-each select="//table[@id='toc']/preceding::p[text()!='']">
                    <p>
                        <xsl:value-of select="."/>
                    </p>
                </xsl:for-each>
            </first-paragraph-->
            <!--// WIKIPEDIA:	TOC & FIRST PARAGRAPH -->
        </country-profile>
    </xsl:template>
    <xsl:template name="details">
        <xsl:variable name="root" select="/"/>
        <xsl:variable name="milestones">
            <xsl:for-each select=" //table[@class='infobox geography vcard']/tr ">
                <xsl:if test=" count( th ) = 1">
                    <xsl:element name="pos">
                        <xsl:attribute name="gid">
                            <xsl:value-of select=" generate-id() "/>
                        </xsl:attribute>
                        <xsl:value-of select=" position() "/>
                    </xsl:element>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        <xsl:for-each select=" exsl:node-set($milestones)/pos  ">
            <xsl:variable name="curpos">
                <xsl:value-of select=" position() "/>
            </xsl:variable>
            <xsl:choose>
                <xsl:when test=" position() = 1 ">
                    <!-- Nothing to do -->
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="first" select=" ../pos[ $curpos - 1] "/>
                    <xsl:variable name="last" select=" . "/>
                    <xsl:variable name="block">
                        <xsl:for-each
                            select="exsl:node-set( $root )//table[@class='infobox geography vcard']/tr">
                            <xsl:choose>
                                <xsl:when test=" position() &lt; $first ">
                                    <!-- Nothing to do -->
                                </xsl:when>
                                <xsl:when test=" position() &gt;= $last ">
                                    <!-- Nothing to do -->
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test=" count( th ) = 1 ">
                                            <xsl:element name="title">
                                                <xsl:attribute name="label">
                                                  <xsl:value-of select=" normalize-space( th ) "/>
                                                </xsl:attribute>
												<xsl:call-template name="get_note">
													<xsl:with-param name="node" select="td"/>
												</xsl:call-template>
                                            </xsl:element>
                                        </xsl:when>
                                        <xsl:when test=" count( td[ @colspan='3'] ) = 1 ">
                                            <xsl:element name="data">
												<xsl:call-template name="get_note">
													<xsl:with-param name="node" select="td"/>
												</xsl:call-template>
                                            </xsl:element>
                                        </xsl:when>
                                        <xsl:when test=" count( td ) = 3 ">
                                            <xsl:element name="data">
                                                <xsl:attribute name="label">
                                                  <xsl:value-of
                                                  select=" normalize-space( td[2] ) "/>
                                                </xsl:attribute>
												<xsl:call-template name="get_note">
													<xsl:with-param name="node" select="td[3]"/>
												</xsl:call-template>
                                            </xsl:element>
                                        </xsl:when>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:for-each>
                    </xsl:variable>
                    <xsl:if test=" position() &gt; 2 ">
                        <xsl:element name="detail">
                            <xsl:copy-of select=" exsl:node-set( $block ) "/>
                        </xsl:element>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>

	<xsl:template name="get_note">
		<xsl:param name="node"/>
		<xsl:for-each select="exsl:node-set($node)/text() | exsl:node-set($node)/a | exsl:node-set($node)/br">
			<xsl:choose>
				<xsl:when test=" . = 'br'">
					<xsl:text>&amp;nbsp;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		<xsl:choose>
			<xsl:when test="count(exsl:node-set($node)/sup[@class='reference']) != 0">
				&lt;sup&gt;
					&lt;a href="<xsl:value-of select="/div/text()"/><xsl:value-of select="exsl:node-set($node)/sup[@class='reference']/a/@href"/>"&gt;
						<xsl:value-of select="exsl:node-set($node)/sup[@class='reference']"/>
					&lt;/a&gt;
				&lt;/sup&gt;
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
    <xsl:template name="toc_ul">
        <ul>
            <!--xsl:apply-template name="toc_li" select="li" /-->
            <xsl:for-each select="./li | ./ul">
                <xsl:choose>
                    <xsl:when test=" . = 'ul'">
                        <!--xsl:when test=" name() = 'ul'"-->
                        <xsl:call-template name="toc_ul"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="toc_li"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </ul>
    </xsl:template>
    <xsl:template name="toc_li">
        <li>
            <xsl:for-each select="a">
              <xsl:call-template name="toc_a"/>
            </xsl:for-each>
            <xsl:for-each select="ul">
              <xsl:call-template name="toc_ul"/>
            </xsl:for-each>
        </li>
    </xsl:template>
    <xsl:template name="toc_a" match="a">
        <xsl:element name="a">
            <xsl:attribute name="href">
                <xsl:value-of select="@href"/>
            </xsl:attribute>
            <xsl:attribute name="target">
                <xsl:text>_blank</xsl:text>
            </xsl:attribute>
            <xsl:value-of select="./span[@class='tocnumber']/text()"/>
            <xsl:text>.</xsl:text>
            <xsl:value-of select="./span[@class='toctext']/text()"/>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>
