<?php
	/**
	 * Helpers Classes and Functions to access LexisNexis Web Service Kit
	 * @author Pascal (Meta) Havelange (havelangep@gmail.com)
	 * @copyright Copyright 2008, Pascal Havelange, All rights reserved
	 * */

	require_once( "Config.php" );

	define( "wsk_client_config_file", "wsk/config/config.xml" );
	define( "wsk_client_config_format", "xml" );

	require_once( "WSKAuthenticateRequest.class.php" );
	require_once( "WSKSourceIdList.class.php" );
	require_once( "WSKSourceInformation.class.php" );
	require_once( "WSKDateRestriction.class.php" );
	require_once( "WSKSearchOptions.class.php" );
	require_once( "WSKDocumentRange.class.php" );
	require_once( "WSKRetrievalOptions.class.php" );
	require_once( "WSKSearchRequest.class.php" );
	require_once( "WSKGetDocumentsByRangeRequest.class.php" );

	require_once( "WSKUserInformation.class.php" );
	require_once( "WSKAuthenticateResponse.class.php" );
	require_once( "WSKDocumentVersion.class.php" );
	require_once( "WSKDocumentVersionList.class.php" );
	require_once( "WSKSourceContextInfo.class.php" );
	require_once( "WSKShepardsSignal.class.php" );
	require_once( "WSKDocumentContainer.class.php" );
	require_once( "WSKDocumentContainerList.class.php" );
	require_once( "WSKGetDocumentsByRangeResponse.class.php" );
	require_once( "WSKRationale.class.php" );
	require_once( "WSKRationaleList.class.php" );
	require_once( "WSKDiagnostic.class.php" );
	require_once( "WSKDiagnosticList.class.php" );
	require_once( "WSKSearchResponse.class.php" );
	require_once( "WSKDocumentIdList.class.php" );
	require_once( "WSKGetDocumentsByDocumentIdRequest.class.php" );
	require_once( "WSKGetDocumentsByDocumentIdResponse.class.php" );
	require_once( "WSKNarrowSearchRequest.class.php" );
	require_once( "WSKNarrowSearchResponse.class.php" );
	require_once( "WSKGetSourceDetailsRequest.class.php" );
	require_once( "WSKSourceGuideList.class.php" );
	require_once( "WSKSecuredSource.class.php" );
	require_once( "WSKCombinabilityList.class.php" );
	require_once( "WSKSource.class.php" );
	require_once( "WSKGetSourceDetailsResponse.class.php" );
	require_once( "WSKBrowseSourcesRequest.class.php" );
	require_once( "WSKSourceList.class.php" );
	require_once( "WSKFolder.class.php" );
	require_once( "WSKFolderList.class.php" );
	require_once( "WSKBrowseSourcesResponse.class.php" );
	require_once( "WSKGetSortKeysRequest.class.php" );
	require_once( "WSKSortKey.class.php" );
	require_once( "WSKSortKeyList.class.php" );
	require_once( "WSKGetSortKeysResponse.class.php" );
	require_once( "WSKSortStrategyList.class.php" );
	require_once( "WSKSortStrategy.class.php" );
	require_once( "WSKSortResultsRequest.class.php" );
	require_once( "WSKSortResultsResponse.class.php" );

	require_once( "WSKAttachmentContainer.class.php" );
	require_once( "WSKAttachmentContainerList.class.php" );
	require_once( "WSKAttachmentIdList.class.php" );
	require_once( "WSKGetAttachmentsRequest.class.php" );
	require_once( "WSKGetAttachmentsResponse.class.php" );
	require_once( "WSKSearchSourceRequest.class.php" );

	/**
	 * Helper Class, specializing SoapClient for usage with LexisNexis Web Service Kit
	 * @param array $options An array of options to pass to the SoapClient constructor
	 * @example examples/authenticate.php	Establish a connection with the WSK
	 * @example examples/search.php			Run a Search query
	 * */
	class WSKClient extends SoapClient {

		public function __construct( $options = null ) {
			// Load Configuration File
			$config = new Config();
			$config_root = &$config->parseConfig( wsk_client_config_file, wsk_client_config_format );
			if( PEAR::isError( $config_root )) {
				throw new Exception( "Error parsing configuration file: " . $config_root->getMessage );
			}
			$config_array = $config_root->toArray();
			$this->config = $config_array["root"]["config"];

			$soap_options = array();
			$soap_options["trace"] = true;
			$soap_options["exceptions"] = true;
			$soap_options["classmap"] = $this->config["soap-wsk"]["classmap"];
			if( is_array( $soap_options )) {
				if( array_key_exists( "classmap", $soap_options )) {
					$more_classmap = $soap_options["classmap"];
					unset( $soap_options["classmap"] );
					foreach( $more_classmap as $k => $v ) {
						$soap_options["classmap"][$k] = $v;
					}
				}
				$soap_options = array_merge( $soap_options, $options );
			}
			if( array_key_exists( "proxy", $this->config ) && $this->config["proxy"]["enable"] ) {
				$soap_options["proxy_host"] = $this->config["proxy"]["host"];
				$soap_options["proxy_port"] = (int)$this->config["proxy"]["port"];	// ATTENTION!!! PROXY PORT DOIT  ETRE UN INT!!!!
				$soap_options["proxy_login"] = $this->config["proxy"]["user"];
				$soap_options["proxy_password"] = $this->config["proxy"]["password"];
			}
			parent::__construct( $this->config["soap-wsk"]["wsdl"], $soap_options );
			if( array_key_exists( "ssl", $this->config ) && array_key_exists( "certificate", $this->config["ssl"] )) {
				if( "" != $this->config["ssl"]["certificate"] ) {
					$this->_local_cert = $this->config["ssl"]["certificate"];
				}
			}
		}

		public static function getFaultDetails( $fault ) {
			$error = "";
			if( property_exists( $fault, "detail" ) && is_object( $fault->detail ) && property_exists( $fault->detail, "errorDetail") ) {
				switch( $fault->detail->errorDetail->errorCode ) {
					case "INVALID_USER_CREDENTIALS" : {
						$error .=  "Invalid Username/Password!";
					} break;
					case "INVALID_SECURITY_TOKEN" : {
						$error .=  "The security token is not valid!";
					} break;
					case "EXPIRED_SECURITY_TOKEN" : {
						$error .=  "The security token has expired!";
					} break;
					default: {
						$error .=  "{$fault->detail->errorDetail->errorCode}";
					}
				}
				return $error;
			} else {
				return false;
			}
		}
	}
?>