<?php
	/**
	 * Document version information.
	 * @see documentVersionList
	 * */
	class WSKDocumentVersion {
		
		/**
		 * An identifier associated with a single LexisNexis document.
		 * @var string
		 * */
		public $documentId;
		
		/**
		 * The title of the document version.
		 * @var string
		 * */
		public $documentTitle;
		
		/**
		 * Indicates that the "current-ness" of the document cannot be determined from the supplied version information.
		 * @var string
		 * @see dviPast
		 * @see dviCurrent
		 * @see dviFuture
		 * @see dviNonCurrent
		 * */
		public $documentVersionIndicator;
		
		/**
		 * @see $documentVersionIndicator
		 * */
		const dviPast = "Past";
		
		/**
		 * @see $documentVersionIndicator
		 * */
		const dviCurrent = "Current";
		
		/**
		 * @see $documentVersionIndicator
		 * */
		const dviFuture = "Future";
		
		/**
		 * @see $documentVersionIndicator
		 * */
		const dviNonCurrent = "NonCurrent";
		
		/**
		 * Effective starting date for this document to be the "current" version.
		 * @var string
		 * */
		public $effectiveFromDate;
		
		/**
		 * Effective ending date for this document to be the "current" version.
		 * @var string
		 * */
		public $effectiveToDate;
		
		/**
		 * Constructs a documentVersion object
		 * @param string $documentId	An identifier associated with a single LexisNexis document.
		 * @param string $documentTitle	The title of the document version.
		 * @param string $documentVersionIndicator	Indicates that the "current-ness" of the document cannot be determined from the supplied version information.
		 * @param string $effectiveFromDate	Effective starting date for this document to be the "current" version.
		 * @param string $effectiveToDate	Effective ending date for this document to be the "current" version.
		 * */
		public function __construct( $documentId, $documentTitle, $documentVersionIndicator, $effectiveFromDate, $effectiveToDate ) {
			$this->documentId = $documentId;
			$this->documentTitle = $documentTitle;
			$this->documentVersionIndicator = $documentVersionIndicator;
			$this->effectiveFromDate = $effectiveFromDate;
			$this->effectiveToDate = $effectiveToDate;
		}
	}
?>