<?php
	/**
	 * This class encloses the necessary elements to perform an NarrowSearch operation
	 * @example examples/narrowsearch.php Search for documents in search results
	 **/
	class WSKNarrowSearchRequest {
		
		/**
		 * This authentication token must be included in all non-authentication types of requests.
		 * @var string
		 * */
		public $binarySecurityToken;
		
		/**
		 * Contains a unique identifier that identifies the original search.
		 * @var string
		 * */
		public $searchId;
		
		/**
		 * Contains the user's search syntax.
		 * Example: dog or cat w/6 flea or tick
		 * @var string
		 * */
		public $query;
		
		/**
		 * Encloses the dateRestriction, searchMethod, sortOrder, and ignoreCommonWords elements which define a series of search options.
		 * @var WSKSearchOptions
		 * */
		public $searchOptions;
		
		/**
		 * Encloses the documentView, documentMarkup, and documentRange elements which define a series of retrieval options.
		 * @var WSKRetrievalOptions
		 * */
		public $retrievalOptions;
		
		/**
		 * @param string $binarySecurityToken This authentication token must be included in all non-authentication types of requests.
		 * @param string $searchId Contains a unique identifier that identifies the original search.
		 * @param string $query Contains the user's search syntax.
		 * @param WSKSearchOptions $searchOptions Encloses the dateRestriction, searchMethod, sortOrder, and ignoreCommonWords elements which define a series of search options.
		 * @param WSKRetrievalOptions $retrievalOptions Encloses the documentView, documentMarkup, and documentRange elements which define a series of retrieval options.
		 * */
		public function __construct( $binarySecurityToken, $searchId, $query, $searchOptions = null, $retrievalOptions = null ) {
			$this->binarySecurityToken = $binarySecurityToken;
			$this->query = $query;
			$this->searchId = $searchId;
			$this->searchOptions = $searchOptions;
			$this->retrievalOptions = $retrievalOptions;
		}
	}
?>