<?php
	/**
	 * This class encloses the necessary elements to perform a Search operation
	 * @example examples/search.php
	 * */
	class WSKSearchRequest {
		
		/**
		 * This authentication token must be included in all non-authentication types of requests.
		 * @var string
		 * */
		public $binarySecurityToken;
		
		/**
		 * Contains the user's search syntax.
		 * Example: dog or cat w/6 flea or tick
		 * @var string
		 * */
		public $query;
		
		/**
		 * Contains the WSKSourceIdList element which identifies the sources to be searched.
		 * @var WSKSourceInformation
		 * */
		public $sourceInformation;
		
		/**
		 * Encloses the WSKDateRestriction, searchMethod, sortOrder, and ignoreCommonWords elements which define a series of search options.
		 * @var WSKSearchOptions
		 * */
		public $searchOptions;
		
		/**
		 * Encloses the documentView, documentMarkup, and documentRange elements which define a series of retrieval options.
		 * @var WSKRetrievalOptions
		 * */
		public $retrievalOptions;
		
		/**
		 * @param string $binarySecurityToken
		 * @param string $query
		 * @param string[] $sources
		 * @param WSKSearchOptions $searchOptions
		 * @param WSKRetrievalOptions $retrievalOptions
		 * */
		public function __construct( $binarySecurityToken, $query, $sources, $searchOptions = null, $retrievalOptions = null ) {
			$this->binarySecurityToken = $binarySecurityToken;
			$this->query = $query;
			$this->sourceInformation = new WSKSourceInformation( $sources );
			$this->searchOptions = $searchOptions;
			$this->retrievalOptions = $retrievalOptions;
		}
	}
?>