<?php
	/**
	 * Will run an analysis on the articles per day datas
	 * @author Cosmin Popescu - cosminadrianpopescu@gmail.com
	 * @copyright Copyright 2008, Pascal (Meta) Havelange, All rights reserved
	 * */
        
        class DataAnalysis {
            
            /**
		 * The averages of articles per day
		 * @var float
		 * */
            public $avg = 0;

            /**
		 * The standard deviation of the articles per day
		 * @var float
		 * */
            public $dev;

            /**
		 * The articles per day
		 * @var ArticlesPerDay[]
		 * */
            private $articles_per_day;

            /**
		 * Number of articles for each day
		 * @var int[]
		 * */
            
            private $no;
            
            /**
		 * Percent by wich we allow the deviation from the avg + dev
		 * @var int
		 * */
            
            private $percent;
            
            /**
             * Calculates the average of an array
             * @param int[] $array The session identifier
             * @return float
             * @access private
             * */

            private function average($array){
                $sum = array_sum($array);
                $count = count($array);
                return $sum/$count;
            }
            
            /**
             * Calculates the standard deviation of an array
             * @param int[] $array The session identifier
             * @return float
             * @access private
             * */

            private function deviation ($array){
                if ($this->avg == 0){
                    $this->avg = $this->average($this->no);
                }
                foreach ($array as $value) {
                    $variance[] = pow($value - $this->avg, 2);
                }
                $deviation = sqrt($this->average($variance));
                return $deviation;
            }

	    public function __construct($articles_per_day, $percent = 0){
                $this->articles_per_day = $articles_per_day;
                $this->percent = $percent;
            }
            
            private function analyze($no){
                if (abs($no - $this->avg) <= $this->dev) return 0;
                $percent = ((abs($no - $this->avg) - $this->dev) / $this->dev) * 100;
                if ($percent <= $this->percent) return 0;
                
                return $no - $this->avg;
            }
            
            /**
             * Runs the analysis on the data and returns the results into the analysis_result field of each field data. 
             * @return ArticlesPerDay[]
             * */

          public function runAnalysis(){
                $this->no = array();
                foreach($this->articles_per_day as $n) array_push($this->no, $n->no);
                $this->avg = $this->average($this->no);
                $this->dev = $this->deviation($this->no);
                
                $rez = array();
                
                foreach($this->articles_per_day as $article_per_day){
                    $apd = new ArticlesPerDay();
                    $apd->no = $article_per_day->no;
                    $apd->date = $article_per_day->date;
                    $apd->analysis_result = $this->analyze($apd->no);
                    
                    array_push($rez, $apd);
                }
                
                return $rez;
            }

      }

?>