<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */


    /**
     * Holds an LDAP database entry
     * */
    class LDAPEntry {
        
        /**
         * User ID (ldap attribute: uid)
         * @var string
         * */
        public $user_id;
        
        /**
         * Title (Mr, Ms, Mrs) (ldap attribute: title)
         * @var string
         * */
        public $title;
        
        /**
         * Firstname (ldap attribute: givenname)
         * @var string
         * */
        public $firstname;
        
        /**
         * LAstname (ldap attribute: sn)
         * @var string
         * */
        public $lastname;
        
        /**
         * Display name (ldap attribute: cn)
         * @var string
         * */
        public $displayname;
        
        /**
         * Phone number (ldap attribute: telephonenumber)
         * @var string
         * */
        public $phone;
        
        /**
         * e-mail address (ldap attribute: mail)
         * @var string
         * */
        public $email;
        
        /**
         * ISO2 Country Code (ldap attribute: cn)
         * @var string
         * */
        public $country;
        
        /**
         * Building (ldap attribute: building)
         * @var string
         * */
        public $building;
        
        /**
         * Floor number (ldap attribute: floor)
         * @var string
         * */
        public $floor;
        
        /**
         * Office (ldap attribute: physicaldeliveryofficename)
         * @var string
         * */
        public $office;
        
        /**
         * Organisation (ldap attribute: sourceorganisation)
         * @var string
         * */
        public $organisation;
        
        /**
         * Full Department Name (ldap attribute: departmentnumber)
         * @var string
         * */
        public $department;
        
        /**
         * Directorate General (ldap attribute: dg)
         * @var string
         * */
        public $directorate;
        
        /**
         * Unit (ldap attribute: div)
         * @var string
         * */
        public $unit;
        
        /**
         * LDAP uid of the manager (ldap attribute: manager)
         * @var string
         * */
        public $manager;
        
        /**
         * LDAP CUD Groups the users belongs to (ldap attribute: cudgroup)
         * @var string[]
         * */
        public $groups;
        
        /**
         * LDAP object classes (ldap attribute: objectclass)
         * @var string[]
         * */
        public $classes;
        
        /**
         * LDAP 'dn' attribute (ldap attribute: dn)
         * @var string
         * */
        public $dn;
        
        /**
         * Construct an LDAP entry (empty or by assigning values soted in an array of strings, as returned by a RAW LDAP search)
         * @param string[] $ldap_entry_values_array
         * @return void
         * */
        public function __construct( $ldap_entry_values_array = null ) {
            $this->classes = array();
            $this->groups = array();
            if( null !== $ldap_entry_values_array && is_array( $ldap_entry_values_array )) {
                foreach( $ldap_entry_values_array as $key => $value ) {
                    switch( $key ) {
                        case "uid": {  $this->user_id = $value;   } break;

                        case "title": {  $this->title = $value;   } break;
                        case "cn": {  $this->displayname = $value;   } break;
                        case "givenname": {  $this->firstname = $value;   } break;
                        case "sn": {  $this->lastname = $value;   } break;    
                        case "mail": {  $this->email = $value;   } break;
                        case "telephonenumber": {  $this->phone = $value;   } break;

                        case "c": {  $this->country = $value;   } break;
                        case "building": {  $this->building = $value;   } break;
                        case "floor": {  $this->floor = $value;   } break;
                        case "physicaldeliveryofficename": {  $this->office = $value;   } break;

                        case "departmentnumber": {  $this->department = $value;   } break;
                        case "sourceorganisation": {  $this->organisation = $value;   } break;
                        case "dg": {  $this->directorate = $value;   } break;
                        case "div": {  $this->unit = $value;   } break;

                        case "manager": {  $this->manager = $value;   } break;

                        case "dn": {  $this->dn = $value;   } break;
                        case "objectclass": {
                            if( is_array( $value )) {
                                foreach( $value as $subval ) {
                                    $this->classes[] = $subval;
                                }
                            } else {
                                $this->classes = array($value);
                            }
                        } break;
                        case "cudgroup": {
                            if( is_array( $value )) {
                                foreach( $value as $subval ) {
                                    $this->groups[] = $subval;
                                }
                            } else {
                                $this->groups = array($value);
                            }
                        } break;
                    }
                }
            }
        }
    }
?>