<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

	
	//PEAR::XML_NITF
	require_once("XML/NITF.php");

    class LexisNexisDocument {
        
        /**
         * Document ID
         * @var string
         * */
        public $id;
        
        /**
         * Date of issue
         * @var int
         * */
        public $date;
        
        /**
         * Headline
         * @var string
         * */
        public $headline;
        
        /**
         * Lead paragraph
         * @var string
         * */
        public $lead;
        
        /**
         * Paragraphs of content
         * @var string[]
         * */
        public $content;
        
        /**
         * Name of the publisher
         * @var string
         * */
        public $publisher;
        
        /**
         * Author of the document
         * @var string
         * */
        public $author;
        
        /**
         * Copyright holder
         * @var string
         * */
        public $copyright;
        
        /**
         * Length of the document
         * @var int
         * @see $unit_of_measure
         * */
        public $length;
        
        /**
         * Unit used to measure the length of the document
         * @var string
         * @see $length
         * */
        public $unit_of_measure;
        
        /**
         * List of attached documents. Keys of the pair are the document Id, values are the mime type
         * @var Pair[]
         * */
        public $attachments;
        
        /**
         * RAW document data (NITF Format)
         * @var string
         * */
        public $raw_data;
        
        /**
         * Default constructor
         * @return void
         * @param string $id Document ID
         * @param string $raw_data Document DATA (NITF Format)
         * */
        public function __construct( $id = null, $raw_data = null ) {
            $this->id = $id;
            
            switch( $this->getXmlDocType( $raw_data )) {
            	case 'nitf': {	$this->parseNITF( $raw_data ); } break;
            	case 'html': {	$this->parseHTML( $raw_data ); } break;
            	default: {}
            }
        }
		
		/**
		 * Gets the lead paragraph of a document
		 * @param string $data The document data
		 * @access protected
		 * @return string
		 */
		protected function getNITFLead($data) {
			$xml = new DOMDocument();
			if (empty($data)) return null;
			if ($xml->loadXML($data)){
				$xpath = new DOMXPath( $xml );
				$query = "//body.content/block[@class='lead']/p";
				$rs = $xpath->query( $query );
				if( $rs->length ) {
					$node = $rs->item(0);
					$result = $xml->saveXML($node);
					$result = preg_replace('/^<p>(.*)<\/p>$/', '\1', $result);
					$result = preg_replace('/<em[^>]*>([^<]*)<\/em>/', '<span class="hit"><b>\1</b></span>', $result);
					return $result;
				}
			}

			return null;
		}

        /**
         * Parse a NITF document and assigns it to te current object
         * @param string $data
         * @return void
         * */
        public function parseNITF( $data ) {
            $this->raw_data = $data;
            if( empty( $this->raw_data ) ) {
                return;
            }
            if( !class_exists( "XML_NITF" )) {
                throw new Exception( "Class not found PEAR::XML::NITF, please upgrade your pear installation" );
            }
			
            $nitf_doc = &new XML_NITF();
			$nitf_doc->setInputString( $data );
            $rs = $nitf_doc->parse();
			if( PEAR::isError( $rs )) {
				throw new Exception( "Invalid NITF document: ".$rs->getMessage() );
			}

            $date = $nitf_doc->getDocData( "date.issue" );
            if( false !== strpos( $date, "T000000Z" )) {
                $date = str_replace( "T000000Z", "", $date );
            }
            $this->date = strtotime( $date );

            $this->headline = @iconv( 'UTF-8', 'UTF-8//IGNORE', $nitf_doc->getHeadline());
            $this->lead = @iconv( 'UTF-8', 'UTF-8//IGNORE', /*$nitf_doc->getLede()*/$this->getNITFLead($data));
            $this->publisher = @iconv( 'UTF-8', 'UTF-8//IGNORE', $nitf_doc->getPubData( "name" ));
            $this->author = @iconv( 'UTF-8', 'UTF-8//IGNORE', $nitf_doc->getByLine());
            $this->copyright = @iconv( 'UTF-8', 'UTF-8//IGNORE', $nitf_doc->getDocData( "copyright" ));
            $this->content = array();
            foreach( $nitf_doc->getContent() as $content ) {
            	$this->content[] = iconv( 'UTF-8', 'UTF-8//IGNORE', $content );
            }

            $this->length = (int)$nitf_doc->getPubData( "item-length" );
            $this->unit_of_measure = @iconv( 'UTF-8', 'UTF-8//IGNORE', $nitf_doc->getPubData( "unit-of-measure" ));
            
            $this->attachments = array();
            $medias = $nitf_doc->getMedia();
            if( is_array( $medias )) {
                foreach( $medias as $media ) {
                    $this->attachments[] = new Pair( $media["attachmentId"], $media["mime-type"] );
                }
            }
            
/*          $meta = $nitf_doc->getMetaData();
            $meta_eopt_datetime = strtotime( strtotime( $meta[ "_eoptdate" ]." ".$meta[ "_eopttime" ] ));
*/
/*            
ob_start();
var_dump( $this );
error_log( ob_get_contents() );
ob_end_clean();
*/
        }

        /**
         * Parse a LexisNexis HTML document and assigns it to te current object
         * @param string $data
         * @return void
         * */
        public function parseHTML( $data ) {
/*
$options = array(
	"clean" => true,
	"output-xhtml" => true,
	"show-body-only" => false,
	"newline" => "LF",
);
$tidy = tidy_parse_string( $data, $options, "utf8" );
$tidy->cleanRepair();
error_log( (string)$tidy );
*/
            $this->raw_data = $data;
            if( empty( $this->raw_data ) ) {
                return;
            }
            
        	$xml = new DOMDocument();
			if( !$xml->loadXML( $data )) {
				error_log( __FILE__ . '@' . __LINE__ . ': Invalid HTML document!' . "\n" . $data );
				return;
			}
			$xpath = new DOMXPath( $xml );
            
            $query = "//div[@class='PUB-DATE']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$date = $rs->item(0)->textContent;
            	$date = str_replace( 
            		array('janvier','février','mars','avril','mai','juin','juillet','août','aout','septembre','octobre','novembre','décembre'),
            		array('january','february','march','april','may','june','july','august','august','september','october','november','december'),
            		$date
            	);
            	$date = str_replace( 
            		array('lundi','mardi','mercredi','jeudi','vendredi','samedi','dimanche'),
            		array('monday','tuesday','wednesday','thursday','friday','saturday','sunday'),
            		$date
            	);
            	$this->date = strtotime( $date );
//error_log( '['.$rs->item(0)->textContent.']=>['.$date.']=>['.date( 'd/m/Y h:i:s', $this->date ).']' );
            }
            
            $query = "//div[@class='PUB']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$this->publisher = $rs->item(0)->textContent;
            }
            
            $query = "//div[@class='HEADLINE']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$this->headline = $rs->item(0)->textContent;
            }
            
            $query = "//div[@class='REAL-LEAD']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	//$this->lead = $rs->item(0)->textContent;
				$node = $rs->item(0);
				$this->lead = $xml->saveXML($node);
            }
            
            $query = "//div[@class='BODY']/div";
            $rs = $xpath->query( $query );
            $this->content = array();
            for( $i = 0; $i < $rs->length; $i ++ ) {
            	$this->content[] = $rs->item($i)->textContent;
            }
            
            $query = "//div[@class='LENGTH']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$arr = array();
            	$str = $rs->item(0)->textContent;
            	if( false !== ereg( '^[^0-9]*([0-9]+)[ ]*(.*)$', $str, $arr )) {
            		$this->length = (int)$arr[1];
            		$this->unit_of_measure = trim($arr[2]);
            	}
            }
            
            $query = "//div[@class='BYLINE']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$this->author = $rs->item(0)->textContent;
            }
            
            $query = "//div[@class='COPYRIGHT PUB-COPYRIGHT c2' or @class='COPYRIGHT' or @class='PUB-COPYRIGHT']";
            $rs = $xpath->query( $query );
            if( $rs->length ) {
            	$this->copyright = $rs->item(0)->textContent;
            }
            
            $query = "//span[@class='attachmentId']/@id";
            $rs = $xpath->query( $query );
            $this->attachments = array();
            for( $i = 0; $i < $rs->length; $i ++ ) {
            	$this->attachments[] = new Pair( $rs->item($i)->nodeValue, 'application/octet-stream' );
            }
/*            
ob_start();
var_dump( $this );
error_log( ob_get_contents() );
ob_end_clean();
*/
        }
        
        /**
         * Extracts the DOCTYPE name of an XML document
         * @param string $data XML data
         * @return string
         */
        public function getXmlDocType( $data ) {
        	if( empty( $data )) {
        		return null;
        	}
        	$xml = new DOMDocument();
			if( $xml->loadXML( $data ) ) {
				return $xml->doctype->name;
			}
			return null;
		}
    }
?>