<?php

	/**
	 * Send e-mail messages via the Commission's SMTP server
	 * @author Pascal (Meta) Havelange (havelangep@gmail.com)
 	 * @copyright &copy; 2008 All rights reserved
 	 * @package MetaNull
	 */

	require_once( "msmtp.inc.php" ); 
	
	/**
	 * SMTP e-mail messaging, set on the European Commission's SMTP server
	 * @author Pascal (Meta) Havelange (havelangep@gmail.com)
 	 * @copyright &copy; 2008 All rights reserved
 	 * @package MetaNull
	 */
	class EC_SMTP extends mSmtp {
		
		/**
		 * Server Host
		 * @var string
		 */
		const EC_SMTP_SERVER = "internal-smtp.cec.eu.int";
		
		/**
		 * Server Host
		 * @var string
		 */
		const EC_SMTP_SERVER_PORT = 25;
		
		/**
		 * E-mail address to be used as the originating address
		 * @var string
		 * @access private
		 */
		private $mailbox = false;
		
		/**
		 * Create the Object
		 * @var string $mailbox E-mail address to be used as the originating address
		 */
		public function __construct( $mailbox ) {
			parent::__construct( $mailbox, self::EC_SMTP_SERVER, self::EC_SMTP_SERVER_PORT );
		}
		
		/**
		 * Quickly send a simple e-mail message 
		 * @static
		 * @param string $from The originating e-mail address
		 * @param string|array The destinataire addresses
		 * @param string Subject of the message
		 * @param bool $copy_sender Send a copy of the message to the sender
		 */
		static function quickSend( $from, $to, $subject, $message, $copy_sender = false ) {
			$smtp = new EC_SMTP( $from );
			$smtp->setRecipients( $to );
			$smtp->setSubject( $subject );
			$smtp->setMessage( $message );
			$smtp->send();

			if( $copy_sender ) {
				$smtp->setRecipients( $from );
				$smtp->send();
			}
		}
	}

?>