<?php
	/**
	 * Encloses the documentId and document elements which encapsulates the search/retrieve result, including a document excerpt and a unique document identifier.
	 * @see WSKDocumentContainerList
	 * @see getDocumentsByRangeResponse
	 * */
	class WSKDocumentContainer {
		
		/**
		 * Contains a unique identifier that independently represents a document for up to 48 hours.
		 * @var string
		 **/
		public $documentId;
		
		/**
		 * Contains the document (Base 64).
		 * @var string
		 * */
		public $document;
		
		/**
		 * Encloses zero or more documentVersion elements, each of which identifies a document version.
		 * @var WSKDocumentVersionList
		 * */
		public $documentVersionList;
		
		/**
		 * @var WSKSourceContextInfo
		 * */
		public $sourceContextInfo;
		
		/**
		 * Encloses the Shepard's Signal information if requested.
		 * @var WSKShepardsSignal
		 * */
		public $shepardsSignal;
		
		/**
		 * Constructs a documentContainer object
		 * @param string $documentId
		 * @param string $document
		 * @param WSKDocumentVersionList $documentVersionList
		 * @param WSKSourceContextInfo $sourceContextInfo
		 * @param WSKShepardsSignal $shepardsSignal	Encloses the Shepard's Signal information if requested.
		 * */
		public function __construct( $documentId = null, $document = null, $documentVersionList = null, $sourceContextInfo = null, $shepardsSignal = null ) {
			$this->documentId = $documentId;
			$this->document = $document;
			$this->documentVersionList = $documentVersionList;
			$this->sourceContextInfo = $sourceContextInfo;
			$this->shepardsSignal = $shepardsSignal;
		}
	}
?>