<?php
	/**
	 * Encloses the WSKDateRestriction, searchMethod, sortOrder, and ignoreCommonWords elements which define a series of search options.
	 * */
	class WSKSearchOptions {
		/**
		 * @var WSKDateRestriction
		 * */
		public $dateRestriction;
		
		/**
		 * @var string
		 * Identifies the type of search logic to be applied to the query string.
	     * @see smBoolean
		 * @see smMatchOnAllWords
	     * @see smMatchOnAnyWords
		 * @see smMatchOnPhrase
	     * @see smQuickSearch
		 * @see smBooleanWithContinue
	     * @see smBooleanWithNaturalLanguageContinue
		 * @see smFreestyle
	     * @see smRaw
		 * */
		public $searchMethod;
		
		/**
		 * The software will look for LexisNexis search term connectors (AND, OR, AND NOT, etc.) to identify how the terms should appear in the target documents.
	     * @see $searchMethod
	     * */
		const smBoolean = "Boolean";
		
		/**
		 * Documents must contain all the search terms before they will be retrieved.
	     * @see $searchMethod
	     * */
		const smMatchOnAllWords = "MatchOnAllWords";
		
		/**
		 * Documents containing any of the search terms will be retrieved.
	     * @see $searchMethod
	     * */
		const smMatchOnAnyWords = "MatchOnAnyWords";
		
		/**
		 * All terms will be linked together and treated as a phrase.
	     * @see $searchMethod
	     * */
		const smMatchOnPhrase = "MatchOnPhrase";
		
		/**
		 * Searches using the QuickSearch method.
	     * @see $searchMethod
	     * */
		const smQuickSearch = "QuickSearch";
		
		/**
		 * Allows user (if functionality enabled) to continue search after maximum number of allowable documents is found.
	     * @see $searchMethod
	     * */
		const smBooleanWithContinue = "BooleanWithContinue";
		
		/**
		 * Allows user (if functionality enabled) to continue search after maximum number of allowable documents is found.  The continued search is run as a natural language search.
	     * @see $searchMethod
	     * */
		const smBooleanWithNaturalLanguageContinue = "BooleanWithNaturalLanguageContinue";
		
		/**
		 * Searches using the Freestyle method.
	     * @see $searchMethod
	     * */
		const smFreestyle = "Freestyle";
		
		/**
		 * This is intended for internal LexisNexis use only.  Search logic is passed directly the LexisNexis infrastructure.
	     * @see $searchMethod
	     * */
		const smRaw = "Raw";
		
		/**
		 * Identifies how the results set should be sorted before delivery.
	     * @see soImplied
		 * @see soRelevance
	     * @see soDate
		 * @var string
		 * */
		public $sortOrder;
		
		/**
		 * Use the sort option that is recommended for this type of source.
		 * @see $sortOrder
		 * */
		const soImplied = "Implied";
		
		/**
		 * The documents that best satisfy the user's search criteria are delivered first.
		 * @see $sortOrder
		 * */
		const soRelevance = "Relevance";
		
		/**
		 * The most recent documents are delivered first.
		 * @see $sortOrder
		 * */
		const soDate = "Date";
		
		/**
		 * true indicates that "common" words in a search will be ignored.
		 * @var boolean
		 * */
		public $ignoreCommonWords;
		
		/**
		 * Constructs a WSKSearchOptions object
		 * @param WSKDateRestriction $dateRestriction
		 * @param string $searchMethod
		 * @param string $sortOrder
		 * @param boolean $ignoreCommonWords
		 * */
		public function __construct( $dateRestriction = null, $searchMethod = null, $sortOrder = null, $ignoreCommonWords = null ) {
			$this->dateRestriction = $dateRestriction;
			$this->searchMethod = $searchMethod;
			$this->sortOrder = $sortOrder;
			$this->ignoreCommonWords = $ignoreCommonWords;
		}
	}
?>