<?php
	/**
	 * This class encloses the necessary elements to perform a SortResults operation
	 * */
	class WSKSortResultsRequest {
		
		/**
		 * This authentication token must be included in all non-authentication types of requests.
		 * @var string
		 * */
		public $binarySecurityToken;
		
		/**
		 * Contains a unique identifier that identifies the original search.
		 * @var string
		 **/
		public $searchId;
		
		/**
		 * Strategy used to sort the results.
		 * @var string
		 * @see SO_RELEVANCE
		 * @see SO_DATE
		 **/
		public $sortOrder;
		
		/**
		 * @see $sortOrder
		 * */
		const SO_RELEVANCE = "Relevance";
		
		/**
		 * @see $sortOrder
		 * */
		const SO_DATE = "Date";
		
		/**
		 * Encloses one or more sortStrategy  elements.
		 * @var WSKSortStrategyList
		 * */
		public $sortStrategyList;
		
		/**
		 * Encloses the documentView, documentMarkup, and documentRange elements which define a series of retrieval options.
		 * @var WSKRetrievalOptions
		 * */
		public $retrievalOptions;
		
		/**
		 * @param string $binarySecurityToken
		 * @param string $searchId
		 * @param string $sortOrder
		 * @param WSKSortStrategyList $sortStrategyList
		 * @param WSKRetrievalOptions $retrievalOptions
		 * */
		public function __construct( $binarySecurityToken, $searchId, $sortOrder = self::SO_DATE, $sortStrategyList = null, $retrievalOptions = null ) {
			$this->binarySecurityToken = $binarySecurityToken;
			$this->searchId = $searchId;
			$this->sortOrder = $sortOrder;
			$this->sortStrategyList = $sortStrategyList;
			$this->retrievalOptions = $retrievalOptions;
		}
	}
?>